-- Information about category:
-- Only one drop will be given per category, except in the cases when category is -1.
-- Category -1 is used for SPOIL/SWEEP drops only!  Do NOT change this.
-- In general, category 0 is for adena and 1 seal stone color (each seal stone color should be in a different category).
-- In general, category 1 is for full drops and parts of equipable items.  However, you can change this.
-- In general, category 2 is for all other items.  However, you can change this.
-- In general, more categories are only used for RBs who have 1 item per category (i.e. do not really drop categorized),
-- You can create more categories as you see fit.  Just make sure the "category" number is non-negative!!
-- Also, it is NOT a problem if category numbers are skipped (so you can have -1, 1, 5, 10 as your categories).
--
-- If you wish to allow more than one item to be given from the same category, you can
-- split them up over several categories.
-- In addition, RBs and Grandbosses (mainly) may have the exact same item repeated in multiple categories.
-- This allows mobs to give 1 copy of the drop to each of several people (if they are lucky enough to get the drops).
-- Calculation for each drop, when in categories, is equivallent in chance as when outside of categories.
-- First, the sum of chances for each category is calculated as category chance.  If the category is selected
-- for drops (i.e. its chance is successful), then exactly 1 item from that category will be selected, with 
-- such a chance that the overall probability is maintained unchanged. 
--
-- Category Explanation (non-RaidBoss & non-GrandBoss)
--   -1 is sweep
--    0 is adena and one of the seal stones (your choice)
--    1 is any item that is in weapon.sql, any item in armor.sql, and some of the items from etcitem. Before dropping the column, I had those marked in etcitem.sql. However, you can recognize them easily. If they are parts unique for crafting equipable items, it's category 1.
--    2 is almost all of the other items except:
--    3 and 4 are used for the other two seal stones (1 category each).
--
-- Category Explanation (RaidBoss & their minions)
--    0 is full armor and armor mats
--    1 is full weapon and weapon mats
--    2 is anything else (scrolls,arrows,etc)
--
-- Category Explanation (GrandBoss)
--    0+ is defined catagories
--    Any other mobs within this range (minions, etc) use the default drop categories (most often 2)

DROP TABLE IF EXISTS `droplist`;
CREATE TABLE `droplist` (
  `mobId` smallint(5) unsigned NOT NULL,
  `itemId` smallint(5) unsigned NOT NULL,
  `min` int(8) unsigned NOT NULL DEFAULT '0',
  `max` int(8) unsigned NOT NULL DEFAULT '0',
  `category` smallint(3) NOT NULL DEFAULT '0',
  `chance` decimal(30,15) unsigned NOT NULL,
  PRIMARY KEY (`mobId`,`itemId`,`category`),
  KEY `key_mobId` (`mobId`)
) ENGINE=MyISAM DEFAULT CHARSET=UTF8;

INSERT INTO `droplist` VALUES
-- Huge Pig
(13031, 9142, 1, 2, 0, 1000000), -- Apiga
-- Super Huge Pig
(13034, 9142, 4, 6, 0, 1000000), -- Apiga
(13034, 9144, 1, 1, 1, 500000), -- Pirate's Booty
-- Golden Pig
(13035, 9142, 1, 3, 0, 1000000), -- Apiga
(13035, 9144, 1, 1, 1, 1000000), -- Pirate's Booty
-- Treasure Chest
(13036, 9170, 1, 4, 0, 1000000), -- Magic Reagents
(13036, 9168, 1, 2, 1, 1000000), -- Philosopher's Stone Ore
(13036, 9169, 1, 1, 2, 100000), -- Philosopher's Stone Conversion Formula
(13036, 9162, 1, 1, 3, 16500), -- Red Philosopher's Stone Transmutation Circle
(13036, 9163, 1, 1, 3, 16500), -- Blue Philosopher's Stone Transmutation Circle
(13036, 9164, 1, 1, 3, 16500), -- Orange Philosopher's Stone Transmutation Circle
(13036, 9165, 1, 1, 3, 16500), -- Black Philosopher's Stone Transmutation Circle
(13036, 9166, 1, 1, 3, 16500), -- White Philosopher's Stone Transmutation Circle
(13036, 9167, 1, 1, 3, 17500), -- Green Philosopher's Stone Transmutation Circle
-- Event Treasure Chest
(13098, 10272, 3, 7, 0, 1000000), -- Treasure Sack Piece
-- Giant Rat
(13120, 10639, 1, 2, 0, 1000000), -- Mouse Coin
-- Super Giant Rat
(13123, 10639, 4, 6, 0, 1000000), -- Mouse Coin
(13123, 9140, 1, 1, 1, 50000), -- Salvation Bow
-- Giant Rat
(13124, 10639, 1, 3, 0, 1000000), -- Mouse Coin
(13124, 9140, 1, 1, 1, 100000), -- Salvation Bow
-- Blood Queen
(18001, 1806, 1, 1, -1, 10868), -- Recipe: Soulshot (B-Grade)
(18001, 57, 765, 1528, 0, 700000), -- Adena
(18001, 2397, 1, 1, 1, 11.433116), -- Tunic of Zubei
(18001, 4069, 1, 1, 1, 2101.99852), -- Tunic of Zubei Fabric
(18001, 2402, 1, 1, 1, 18.323548), -- Stockings of Zubei
(18001, 4070, 1, 1, 1, 3191.561972), -- Stockings of Zubei Fabric
(18001, 2406, 1, 1, 1, 7.821196), -- Avadon Robe
(18001, 4071, 1, 1, 1, 1614.861648), -- Avadon Robe Fabric
(18001, 1864, 1, 1, 2, 178348.515968), -- Stem
(18001, 1866, 1, 1, 2, 59449.60096), -- Suede
(18001, 1878, 1, 1, 2, 35669.760576), -- Braided Hemp
(18001, 1885, 1, 1, 2, 7431.307712), -- High-Grade Suede
(18001, 1889, 1, 1, 2, 5944.81664), -- Compound Braid
(18001, 4197, 1, 1, 2, 67.998144), -- Recipe: Demon's Dagger (100%)
(18001, 1419, 1, 1, 3, 200000), -- Blood Mark
-- Bearded Keltir
(18003, 1871, 1, 1, -1, 9797), -- Charcoal
-- Offering of the Branded, Warrior
(18012, 57, 148, 293, 0, 700000), -- Adena
-- Offering of the Branded, Follower
(18013, 57, 148, 293, 0, 700000), -- Adena
-- Offering of the Branded, Berserker
(18014, 57, 228, 455, 0, 700000), -- Adena
-- Offering of the Branded, Zealot
(18015, 57, 194, 387, 0, 700000), -- Adena
-- Offering of the Branded, Disciple
(18017, 57, 194, 387, 0, 700000), -- Adena
-- Offering of the Branded, Saint
(18018, 57, 253, 504, 0, 700000), -- Adena
-- Apostate's Offering, Warrior
(18022, 57, 265, 529, 0, 700000), -- Adena
-- Apostate's Offering, Follower
(18023, 57, 265, 529, 0, 700000), -- Adena
-- Apostate's Offering, Berserker
(18024, 57, 381, 761, 0, 700000), -- Adena
-- Apostate's Offering, Zealot
(18025, 57, 335, 669, 0, 700000), -- Adena
-- Apostate's Offering, Disciple
(18027, 57, 335, 669, 0, 700000), -- Adena
-- Apostate's Offering, Saint
(18028, 57, 414, 829, 0, 700000), -- Adena
-- Witch's Offering, Warrior
(18032, 57, 431, 863, 0, 700000), -- Adena
-- Witch's Offering, Follower
(18033, 57, 431, 863, 0, 700000), -- Adena
-- Witch's Offering, Berserker
(18034, 57, 585, 1171, 0, 700000), -- Adena
-- Witch's Offering, Zealot
(18035, 57, 525, 1049, 0, 700000), -- Adena
-- Witch's Offering, Disciple
(18037, 57, 525, 1049, 0, 700000), -- Adena
-- Witch's Offering, Saint
(18038, 57, 629, 1257, 0, 700000), -- Adena
-- Dark Omen Offering Warrior
(18042, 57, 651, 1302, 0, 700000), -- Adena
-- Dark Omen Offering Follower
(18043, 57, 651, 1302, 0, 700000), -- Adena
-- Dark Omen Offering Berserker
(18044, 57, 848, 1697, 0, 700000), -- Adena
-- Dark Omen Offering Zealot
(18045, 57, 770, 1541, 0, 700000), -- Adena
-- Dark Omen Offering Disciple
(18047, 57, 770, 1541, 0, 700000), -- Adena
-- Dark Omen Offering Saint
(18048, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Warrior
(18052, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Follower
(18053, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Berserker
(18054, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Zealot
(18055, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Disciple
(18057, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Saint
(18058, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of the Branded, Warrior
(18062, 57, 148, 293, 0, 700000), -- Adena
-- Offering of the Branded, Follower
(18063, 57, 148, 293, 0, 700000), -- Adena
-- Offering of the Branded, Berserker
(18064, 57, 228, 455, 0, 700000), -- Adena
-- Offering of the Branded, Zealot
(18065, 57, 194, 387, 0, 700000), -- Adena
-- Offering of the Branded, Disciple
(18067, 57, 194, 387, 0, 700000), -- Adena
-- Offering of the Branded, Saint
(18068, 57, 253, 504, 0, 700000), -- Adena
-- Apostate's Offering, Warrior
(18072, 57, 265, 529, 0, 700000), -- Adena
-- Apostate's Offering, Follower
(18073, 57, 265, 529, 0, 700000), -- Adena
-- Apostate's Offering, Berserker
(18074, 57, 381, 761, 0, 700000), -- Adena
-- Apostate's Offering, Zealot
(18075, 57, 335, 669, 0, 700000), -- Adena
-- Apostate's Offering, Disciple
(18077, 57, 335, 669, 0, 700000), -- Adena
-- Apostate's Offering, Saint
(18078, 57, 414, 829, 0, 700000), -- Adena
-- Witch's Offering, Warrior
(18082, 57, 431, 863, 0, 700000), -- Adena
-- Witch's Offering, Follower
(18083, 57, 431, 863, 0, 700000), -- Adena
-- Witch's Offering, Berserker
(18084, 57, 585, 1171, 0, 700000), -- Adena
-- Witch's Offering, Zealot
(18085, 57, 525, 1049, 0, 700000), -- Adena
-- Witch's Offering, Disciple
(18087, 57, 525, 1049, 0, 700000), -- Adena
-- Witch's Offering, Saint
(18088, 57, 629, 1257, 0, 700000), -- Adena
-- Dark Omen Offering Warrior
(18092, 57, 651, 1302, 0, 700000), -- Adena
-- Dark Omen Offering Follower
(18093, 57, 651, 1302, 0, 700000), -- Adena
-- Dark Omen Offering Berserker
(18094, 57, 848, 1697, 0, 700000), -- Adena
-- Dark Omen Offering Zealot
(18095, 57, 770, 1541, 0, 700000), -- Adena
-- Dark Omen Offering Disciple
(18097, 57, 770, 1541, 0, 700000), -- Adena
-- Dark Omen Offering Saint
(18098, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Warrior
(18102, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Follower
(18103, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Berserker
(18104, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Zealot
(18105, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Disciple
(18107, 57, 902, 1804, 0, 700000), -- Adena
-- Offering of Forbidden Path, Saint
(18108, 57, 902, 1804, 0, 700000), -- Adena
-- Treasures of the Festival
(18109, 8923, 1, 1, 0, 95.97756), -- Scar
(18109, 8913, 1, 1, 0, 95.97756), -- Butterfly Hairpin
(18109, 955, 1, 1, 0, 956.34783), -- Scroll: Enchant Weapon (D-Grade)
(18109, 956, 1, 1, 0, 7972.307466), -- Scroll: Enchant Armor (D-Grade)
(18109, 1060, 1, 1, 0, 531483.965148), -- Lesser Healing Potion
(18109, 1061, 1, 1, 0, 144949.424436), -- Greater Healing Potion
-- Treasures of the Festival
(18110, 8923, 1, 1, 0, 146.753787), -- Scar
(18110, 8913, 1, 1, 0, 146.753787), -- Butterfly Hairpin
(18110, 951, 1, 1, 0, 665.075673), -- Scroll: Enchant Weapon (C-Grade)
(18110, 952, 1, 1, 0, 4879.303216), -- Scroll: Enchant Armor (C-Grade)
(18110, 1832, 1, 1, 0, 406595.417778), -- Greater Antidote
(18110, 1061, 1, 1, 0, 221779.318788), -- Greater Healing Potion
(18110, 1834, 1, 1, 0, 406594.376971), -- Emergency Dressing
-- Treasures of the Festival
(18111, 8923, 1, 1, 0, 231.639408), -- Scar
(18111, 8913, 1, 1, 0, 231.639408), -- Butterfly Hairpin
(18111, 951, 1, 1, 0, 1053.266368), -- Scroll: Enchant Weapon (C-Grade)
(18111, 952, 1, 1, 0, 7724.990416), -- Scroll: Enchant Armor (C-Grade)
(18111, 734, 1, 1, 0, 96561.390288), -- Haste Potion
(18111, 1539, 1, 1, 0, 128748.237552), -- Greater Healing Potion
(18111, 735, 1, 1, 0, 48280.83656), -- Alacrity Potion
-- Treasures of the Festival
(18112, 8923, 1, 1, 0, 336.91392), -- Scar
(18112, 8913, 1, 1, 0, 336.91392), -- Butterfly Hairpin
(18112, 947, 1, 1, 0, 336.91392), -- Scroll: Enchant Weapon (B-Grade)
(18112, 948, 1, 1, 0, 2106.915264), -- Scroll: Enchant Armor (B-Grade)
(18112, 734, 1, 1, 0, 140459.814336), -- Haste Potion
(18112, 1539, 1, 1, 0, 187280.01984), -- Greater Healing Potion
(18112, 735, 1, 1, 0, 70230.5088), -- Alacrity Potion
-- Treasures of the Festival
(18113, 8923, 1, 1, 0, 450.971144), -- Scar
(18113, 8913, 1, 1, 0, 450.971144), -- Butterfly Hairpin
(18113, 729, 1, 1, 0, 125.032284), -- Scroll: Enchant Weapon (A-Grade)
(18113, 730, 1, 1, 0, 939.345108), -- Scroll: Enchant Armor (A-Grade)
(18113, 734, 1, 1, 0, 187891.463292), -- Haste Potion
(18113, 1539, 1, 1, 0, 250521.951056), -- Greater Healing Potion
(18113, 735, 1, 1, 0, 93946.265972), -- Alacrity Potion
-- Treasures of the Festival
(18114, 8923, 1, 1, 0, 95.97756), -- Scar
(18114, 8913, 1, 1, 0, 95.97756), -- Butterfly Hairpin
(18114, 955, 1, 1, 0, 956.34783), -- Scroll: Enchant Weapon (D-Grade)
(18114, 956, 1, 1, 0, 7972.307466), -- Scroll: Enchant Armor (D-Grade)
(18114, 1060, 1, 1, 0, 531483.965148), -- Lesser Healing Potion
(18114, 1061, 1, 1, 0, 144949.424436), -- Greater Healing Potion
-- Treasures of the Festival
(18115, 8923, 1, 1, 0, 146.753787), -- Scar
(18115, 8913, 1, 1, 0, 146.753787), -- Butterfly Hairpin
(18115, 951, 1, 1, 0, 665.075673), -- Scroll: Enchant Weapon (C-Grade)
(18115, 952, 1, 1, 0, 4879.303216), -- Scroll: Enchant Armor (C-Grade)
(18115, 1832, 1, 1, 0, 406595.417778), -- Greater Antidote
(18115, 1061, 1, 1, 0, 221779.318788), -- Greater Healing Potion
(18115, 1834, 1, 1, 0, 406594.376971), -- Emergency Dressing
-- Treasures of the Festival
(18116, 8923, 1, 1, 0, 231.639408), -- Scar
(18116, 8913, 1, 1, 0, 231.639408), -- Butterfly Hairpin
(18116, 951, 1, 1, 0, 1053.266368), -- Scroll: Enchant Weapon (C-Grade)
(18116, 952, 1, 1, 0, 7724.990416), -- Scroll: Enchant Armor (C-Grade)
(18116, 734, 1, 1, 0, 96561.390288), -- Haste Potion
(18116, 1539, 1, 1, 0, 128748.237552), -- Greater Healing Potion
(18116, 735, 1, 1, 0, 48280.83656), -- Alacrity Potion
-- Treasures of the Festival
(18117, 8923, 1, 1, 0, 336.91392), -- Scar
(18117, 8913, 1, 1, 0, 336.91392), -- Butterfly Hairpin
(18117, 947, 1, 1, 0, 336.91392), -- Scroll: Enchant Weapon (B-Grade)
(18117, 948, 1, 1, 0, 2106.915264), -- Scroll: Enchant Armor (B-Grade)
(18117, 734, 1, 1, 0, 140459.814336), -- Haste Potion
(18117, 1539, 1, 1, 0, 187280.01984), -- Greater Healing Potion
(18117, 735, 1, 1, 0, 70230.5088), -- Alacrity Potion
-- Treasures of the Festival
(18118, 8923, 1, 1, 0, 450.971144), -- Scar
(18118, 8913, 1, 1, 0, 450.971144), -- Butterfly Hairpin
(18118, 729, 1, 1, 0, 125.032284), -- Scroll: Enchant Weapon (A-Grade)
(18118, 730, 1, 1, 0, 939.345108), -- Scroll: Enchant Armor (A-Grade)
(18118, 734, 1, 1, 0, 187891.463292), -- Haste Potion
(18118, 1539, 1, 1, 0, 250521.951056), -- Greater Healing Potion
(18118, 735, 1, 1, 0, 93946.265972), -- Alacrity Potion
-- Halisha's Treasure Chest
(18256, 57, 1370, 2743, 0, 700000), -- Adena
(18256, 81, 1, 1, 1, 1.185316), -- Dragon Slayer
(18256, 5529, 1, 1, 1, 439.07842), -- Dragon Slayer Edge
(18256, 151, 1, 1, 1, 1.185316), -- Sword of Miracles
(18256, 5546, 1, 1, 1, 482.285848), -- Sword of Miracles Edge
(18256, 2500, 1, 1, 1, 1.185316), -- Dark Legion's Edge
(18256, 5545, 1, 1, 1, 439.079784), -- Dark Legion's Edge Blade
(18256, 1895, 1, 1, 2, 54857.316515), -- Metallic Fiber
(18256, 4040, 1, 1, 2, 3840.038795), -- Mold Lubricant
(18256, 4042, 1, 1, 2, 3200.020945), -- Enria
(18256, 4043, 1, 1, 2, 6400.04189), -- Asofe
(18256, 959, 1, 1, 2, 7.581855), -- Scroll: Enchant Weapon (S-Grade)
-- Treasure Chest
(18265, 57, 480, 858, 0, 700000), -- Adena
(18265, 955, 1, 1, 1, 3739.397843), -- Scroll: Enchant Weapon (D-Grade)
(18265, 956, 1, 1, 1, 31161.602157), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18266, 57, 483, 891, 0, 700000), -- Adena
(18266, 955, 1, 1, 1, 3854.576568), -- Scroll: Enchant Weapon (D-Grade)
(18266, 956, 1, 1, 1, 32121.423432), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18267, 57, 484, 932, 0, 700000), -- Adena
(18267, 955, 1, 1, 1, 3904.826635), -- Scroll: Enchant Weapon (D-Grade)
(18267, 956, 1, 1, 1, 32540.173365), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18268, 57, 708, 1417, 0, 700000), -- Adena
(18268, 955, 1, 1, 1, 5803.93631), -- Scroll: Enchant Weapon (D-Grade)
(18268, 956, 1, 1, 1, 48366.06369), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18269, 57, 732, 1465, 0, 700000), -- Adena
(18269, 955, 1, 1, 1, 5939.043633), -- Scroll: Enchant Weapon (D-Grade)
(18269, 956, 1, 1, 1, 49491.956367), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18270, 57, 758, 1520, 0, 700000), -- Adena
(18270, 955, 1, 1, 1, 6162.758217), -- Scroll: Enchant Weapon (D-Grade)
(18270, 956, 1, 1, 1, 51356.241783), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18271, 57, 789, 1572, 0, 700000), -- Adena
(18271, 955, 1, 1, 1, 6337.829879), -- Scroll: Enchant Weapon (D-Grade)
(18271, 956, 1, 1, 1, 52815.170121), -- Scroll: Enchant Armor (D-Grade)
-- Treasure Chest
(18272, 57, 1257, 2519, 0, 700000), -- Adena
(18272, 951, 1, 1, 1, 4563), -- Scroll: Enchant Weapon (C-Grade)
(18272, 952, 1, 1, 1, 33462), -- Scroll: Enchant Armor (C-Grade)
-- Treasure Chest
(18273, 57, 1293, 2582, 0, 700000), -- Adena
(18273, 951, 1, 1, 1, 4603.08), -- Scroll: Enchant Weapon (C-Grade)
(18273, 952, 1, 1, 1, 33755.92), -- Scroll: Enchant Armor (C-Grade)
-- Treasure Chest
(18274, 57, 1330, 2656, 0, 700000), -- Adena
(18274, 951, 1, 1, 1, 4651.44), -- Scroll: Enchant Weapon (C-Grade)
(18274, 952, 1, 1, 1, 34110.56), -- Scroll: Enchant Armor (C-Grade)
-- Treasure Chest
(18275, 57, 1952, 3909, 0, 700000), -- Adena
(18275, 951, 1, 1, 1, 6717.72), -- Scroll: Enchant Weapon (C-Grade)
(18275, 952, 1, 1, 1, 49263.28), -- Scroll: Enchant Armor (C-Grade)
-- Treasure Chest
(18276, 57, 1997, 3995, 0, 700000), -- Adena
(18276, 947, 1, 1, 1, 1467.999633), -- Scroll: Enchant Weapon (B-Grade)
(18276, 948, 1, 1, 1, 9175.000367), -- Scroll: Enchant Armor (B-Grade)
-- Treasure Chest
(18277, 57, 2049, 4095, 0, 700000), -- Adena
(18277, 947, 1, 1, 1, 1432.965159), -- Scroll: Enchant Weapon (B-Grade)
(18277, 948, 1, 1, 1, 8956.034841), -- Scroll: Enchant Armor (B-Grade)
-- Treasure Chest
(18278, 57, 2683, 5361, 0, 700000), -- Adena
(18278, 947, 1, 1, 1, 1876.965048), -- Scroll: Enchant Weapon (B-Grade)
(18278, 948, 1, 1, 1, 11731.034952), -- Scroll: Enchant Armor (B-Grade)
-- Treasure Chest
(18279, 57, 2736, 5473, 0, 700000), -- Adena
(18279, 947, 1, 1, 1, 1915.034004), -- Scroll: Enchant Weapon (B-Grade)
(18279, 948, 1, 1, 1, 11968.965996), -- Scroll: Enchant Armor (B-Grade)
-- Treasure Chest
(18280, 57, 2790, 5576, 0, 700000), -- Adena
(18280, 729, 1, 1, 1, 542.235023), -- Scroll: Enchant Weapon (A-Grade)
(18280, 730, 1, 1, 1, 4066.764977), -- Scroll: Enchant Armor (A-Grade)
-- Treasure Chest
(18281, 57, 2849, 5701, 0, 700000), -- Adena
(18281, 729, 1, 1, 1, 554.235017), -- Scroll: Enchant Weapon (A-Grade)
(18281, 730, 1, 1, 1, 4156.764983), -- Scroll: Enchant Armor (A-Grade)
-- Treasure Chest
(18282, 57, 4009, 8028, 0, 700000), -- Adena
(18282, 729, 1, 1, 1, 780.470198), -- Scroll: Enchant Weapon (A-Grade)
(18282, 730, 1, 1, 1, 5853.529802), -- Scroll: Enchant Armor (A-Grade)
-- Treasure Chest
(18283, 57, 4078, 8168, 0, 700000), -- Adena
(18283, 959, 1, 1, 1, 285.908805), -- Scroll: Enchant Weapon (S-Grade)
(18283, 960, 1, 1, 1, 2859.091195), -- Scroll: Enchant Armor (S-Grade)
-- Treasure Chest
(18284, 57, 4146, 8295, 0, 700000), -- Adena
(18284, 959, 1, 1, 1, 290.363346), -- Scroll: Enchant Weapon (S-Grade)
(18284, 960, 1, 1, 1, 2903.636654), -- Scroll: Enchant Armor (S-Grade)
-- Treasure Chest
(18285, 57, 5312, 10638, 0, 700000), -- Adena
(18285, 959, 1, 1, 1, 372.363264), -- Scroll: Enchant Weapon (S-Grade)
(18285, 960, 1, 1, 1, 3723.636736), -- Scroll: Enchant Armor (S-Grade)
-- Treasure Chest
(18286, 57, 5393, 10798, 0, 700000), -- Adena
(18286, 959, 1, 1, 1, 377.908713), -- Scroll: Enchant Weapon (S-Grade)
(18286, 960, 1, 1, 1, 3779.091287), -- Scroll: Enchant Armor (S-Grade)
-- Otherworldly Invader Food
(18287, 57, 186, 372, 0, 700000), -- Adena
(18287, 955, 1, 1, 1, 1507.180581), -- Scroll: Enchant Weapon (D-Grade)
(18287, 956, 1, 1, 1, 12559.819419), -- Scroll: Enchant Armor (D-Grade)
-- Otherworldly Invader Food
(18288, 57, 207, 413, 0, 700000), -- Adena
(18288, 955, 1, 1, 1, 1679.573668), -- Scroll: Enchant Weapon (D-Grade)
(18288, 956, 1, 1, 1, 13996.426332), -- Scroll: Enchant Armor (D-Grade)
-- Dimension Invader Food
(18289, 57, 308, 617, 0, 700000), -- Adena
(18289, 951, 1, 1, 1, 1118.76), -- Scroll: Enchant Weapon (C-Grade)
(18289, 952, 1, 1, 1, 8204.24), -- Scroll: Enchant Armor (C-Grade)
-- Dimension Invader Food
(18290, 57, 338, 676, 0, 700000), -- Adena
(18290, 951, 1, 1, 1, 1204.44), -- Scroll: Enchant Weapon (C-Grade)
(18290, 952, 1, 1, 1, 8832.56), -- Scroll: Enchant Armor (C-Grade)
-- Purgatory Invader Food
(18291, 57, 472, 944, 0, 700000), -- Adena
(18291, 947, 1, 1, 1, 346.758534), -- Scroll: Enchant Weapon (B-Grade)
(18291, 948, 1, 1, 1, 2167.241466), -- Scroll: Enchant Armor (B-Grade)
-- Purgatory Invader Food
(18292, 57, 519, 1010, 0, 700000), -- Adena
(18292, 947, 1, 1, 1, 374.620596), -- Scroll: Enchant Weapon (B-Grade)
(18292, 948, 1, 1, 1, 2341.379404), -- Scroll: Enchant Armor (B-Grade)
-- Forbidden Path Invader Food
(18293, 57, 681, 1361, 0, 700000), -- Adena
(18293, 729, 1, 1, 1, 132.352875), -- Scroll: Enchant Weapon (A-Grade)
(18293, 730, 1, 1, 1, 992.647125), -- Scroll: Enchant Armor (A-Grade)
-- Forbidden Path Invader Food
(18294, 57, 728, 1457, 0, 700000), -- Adena
(18294, 729, 1, 1, 1, 141.646988), -- Scroll: Enchant Weapon (A-Grade)
(18294, 730, 1, 1, 1, 1062.353012), -- Scroll: Enchant Armor (A-Grade)
-- Dark Omen Invader Food
(18295, 57, 938, 1879, 0, 700000), -- Adena
(18295, 729, 1, 1, 1, 182.588144), -- Scroll: Enchant Weapon (A-Grade)
(18295, 730, 1, 1, 1, 1369.411856), -- Scroll: Enchant Armor (A-Grade)
-- Dark Omen Invader Food
(18296, 57, 995, 1993, 0, 700000), -- Adena
(18296, 959, 1, 1, 1, 69.727203), -- Scroll: Enchant Weapon (S-Grade)
(18296, 960, 1, 1, 1, 697.272797), -- Scroll: Enchant Armor (S-Grade)
-- Messenger Invader Food
(18297, 57, 1239, 2481, 0, 700000), -- Adena
(18297, 959, 1, 1, 1, 86.818095), -- Scroll: Enchant Weapon (S-Grade)
(18297, 960, 1, 1, 1, 868.181905), -- Scroll: Enchant Armor (S-Grade)
-- Messenger Invader Food
(18298, 57, 1301, 2604, 0, 700000), -- Adena
(18298, 959, 1, 1, 1, 91.181727), -- Scroll: Enchant Weapon (S-Grade)
(18298, 960, 1, 1, 1, 911.818273), -- Scroll: Enchant Armor (S-Grade)
-- Caught Frog
(18319, 6529, 1, 1, 0, 1159), -- Baby Duck Rod
(18319, 6535, 12, 36, 1, 120767.548307), -- Fishing Shot (No-Grade)
(18319, 6520, 1, 1, 1, 86952.648307), -- Green Colored Lure
(18319, 6523, 1, 1, 1, 57968.544921), -- Purple Colored Lure
(18319, 6526, 1, 1, 1, 72460.258465), -- Yellow Colored Lure
-- Caught Undine
(18320, 6530, 1, 1, 0, 527), -- Albatross Rod
(18320, 6536, 12, 36, 1, 109760), -- Fishing Shot (D-Grade)
(18320, 6520, 1, 1, 1, 131712), -- Green Colored Lure
(18320, 6523, 1, 1, 1, 87808), -- Purple Colored Lure
(18320, 6526, 1, 1, 1, 109760), -- Yellow Colored Lure
-- Caught Rakul
(18321, 6531, 1, 1, 0, 200), -- Pelican Rod
(18321, 6537, 12, 36, 1, 118752.3), -- Fishing Shot (C-Grade)
(18321, 6520, 2, 6, 1, 33250.644), -- Green Colored Lure
(18321, 6523, 1, 1, 1, 110835.48), -- Purple Colored Lure
(18321, 6526, 1, 1, 1, 133002.576), -- Yellow Colored Lure
-- Caught Sea Giant
(18322, 6532, 1, 1, 0, 108), -- KingFisher Rod
(18322, 6538, 15, 45, 1, 43231.999833), -- Fishing Shot (B-Grade)
(18322, 6520, 2, 6, 1, 67550.347116), -- Green Colored Lure
(18322, 6523, 1, 1, 1, 180133.823052), -- Purple Colored Lure
(18322, 6526, 3, 9, 1, 36026.829999), -- Yellow Colored Lure
-- Caught Sea Horse Soldier
(18323, 6533, 1, 1, 0, 41), -- Cygnus Pole
(18323, 6539, 3, 9, 1, 169120.014807), -- Fishing Shot (A-Grade)
(18323, 6520, 2, 6, 1, 67648.102885), -- Green Colored Lure
(18323, 6523, 1, 1, 1, 202944.308655), -- Purple Colored Lure
(18323, 6526, 2, 6, 1, 45098.573653), -- Yellow Colored Lure
-- Caught Homunculus
(18324, 6533, 1, 1, 0, 61), -- Cygnus Pole
(18324, 6539, 3, 9, 1, 204003.714807), -- Fishing Shot (A-Grade)
(18324, 6520, 2, 6, 1, 81601.602885), -- Green Colored Lure
(18324, 6523, 1, 1, 1, 244804.808655), -- Purple Colored Lure
(18324, 6526, 2, 6, 1, 54400.873653), -- Yellow Colored Lure
-- Caught Flava
(18325, 6534, 1, 1, 0, 17), -- Triton Pole
(18325, 6540, 3, 9, 1, 141546.6), -- Fishing Shot (S-Grade)
(18325, 6520, 2, 6, 1, 70773.3), -- Green Colored Lure
(18325, 6523, 1, 1, 1, 212319.9), -- Purple Colored Lure
(18325, 6526, 2, 6, 1, 47182.2), -- Yellow Colored Lure
-- Caught Gigantic Eye
(18326, 6534, 1, 1, 0, 30), -- Triton Pole
(18326, 6540, 3, 9, 1, 171546.6), -- Fishing Shot (S-Grade)
(18326, 6520, 2, 6, 1, 85773.3), -- Green Colored Lure
(18326, 6523, 1, 1, 1, 257319.9), -- Purple Colored Lure
(18326, 6526, 2, 6, 1, 57182.2), -- Yellow Colored Lure
-- Gremlin
(18342, 57, 7, 13, 0, 1000000), -- Adena
-- Sprigant
(18345, 960, 1, 1, -1, 931), -- Scroll: Enchant Armor (S-Grade)
(18345, 1894, 1, 1, -1, 81680), -- Crafted Leather
(18345, 4039, 1, 1, -1, 77596), -- Mold Glue
(18345, 8787, 1, 1, 0, 397600), -- Sprigant's Fruit
-- Sprigant
(18346, 6701, 1, 1, -1, 6885), -- Sealed Imperial Crusader Breastplate Part
(18346, 6901, 1, 1, -1, 2328), -- Recipe: Shining Arrow (100%)
(18346, 6702, 1, 1, -1, 8863), -- Sealed Imperial Crusader Gaiters Pattern
(18346, 8787, 1, 1, 0, 397600), -- Sprigant's Fruit
-- Kamael Guard
(18352, 9703, 1, 1, 2, 1000000), -- Gate Key: Kamael
-- Guardian of Records
(18353, 9704, 1, 1, 2, 1000000), -- Gate Key: Archives
-- Guardian of Observation
(18354, 9705, 1, 1, 2, 1000000), -- Gate Key: Observation
-- Spicula's Guard
(18355, 9706, 1, 1, 2, 1000000), -- Gate Key: Spicula
-- Harkilgamed's Gatekeeper
(18356, 9707, 1, 1, 2, 1000000), -- Gate Key: Harkilgamed
-- Rodenpicula's Gatekeeper
(18357, 9708, 1, 1, 2, 1000000), -- Gate Key: Rodenpicula
-- Guardian of Secrets
(18358, 9713, 1, 1, 2, 1000000), -- Nornil's Power
-- Arviterre's Guardian
(18359, 9709, 1, 1, 2, 1000000), -- Gate Key: Arviterre
-- Katenar's Gatekeeper
(18360, 9710, 1, 1, 2, 1000000), -- Gate Key: Katenar
-- Guardian of Prediction
(18361, 9711, 1, 1, 2, 1000000), -- Gate Key: Prediction
-- Remnant Diabolist
(18463, 1895, 1, 27, -1, 934652), -- Metallic Fiber
(18463, 4042, 1, 1, -1, 763299), -- Enria
(18463, 6710, 1, 1, -1, 495300), -- Sealed Draconic Leather Helmet Pattern
(18463, 57, 23038, 47020, 0, 700000), -- Adena
(18463, 236, 1, 1, 1, 62.628408), -- Soul Separator
(18463, 5537, 1, 1, 1, 23193.371592), -- Soul Separator Head
(18463, 1873, 3, 9, 2, 140916.6692), -- Silver Nugget
(18463, 1868, 32, 96, 2, 66054.82012), -- Thread
(18463, 1876, 4, 12, 2, 46972.082872), -- Mithril Ore
(18463, 1895, 3, 9, 2, 86275.657672), -- Metallic Fiber
(18463, 4042, 1, 1, 2, 35228.957008), -- Enria
(18463, 1808, 1, 1, 2, 939.584656), -- Recipe: Soulshot (S-Grade)
(18463, 9675, 5, 15, 2, 28183.33384), -- Prayer Fragment
(18463, 1344, 1650, 4950, 2, 16012.894632), -- Mithril Arrow
-- Remnant Diviner
(18464, 6901, 1, 1, -1, 44546), -- Recipe: Shining Arrow (100%)
(18464, 6711, 1, 1, -1, 147144), -- Sealed Major Arcana Robe Part
(18464, 57, 22408, 45735, 0, 700000), -- Adena
(18464, 305, 1, 1, 1, 60.916728), -- Tallum Glaive
(18464, 5541, 1, 1, 1, 22551.083272), -- Tallum Glaive Edge
(18464, 1871, 9, 27, 2, 114219.291882), -- Charcoal
(18464, 1866, 14, 42, 2, 48951.283356), -- Suede
(18464, 1877, 1, 1, 2, 82237.993554), -- Adamantite Nugget
(18464, 4041, 1, 1, 2, 17877.680184), -- Mold Hardener
(18464, 4040, 1, 1, 2, 41118.812136), -- Mold Lubricant
(18464, 6901, 1, 1, 2, 2055.792894), -- Recipe: Shining Arrow (100%)
(18464, 9675, 4, 12, 2, 34265.67678), -- Prayer Fragment
(18464, 1344, 900, 2700, 2, 28555.469214), -- Mithril Arrow
-- Derek
(18465, 6714, 1, 5, -1, 695358), -- Sealed Major Arcana Circlet Pattern
(18465, 6901, 1, 1, -1, 231473), -- Recipe: Shining Arrow (100%)
(18465, 7579, 1, 1, -1, 281174), -- Draconic Bow Shaft
(18465, 57, 116439, 237651, 0, 700000), -- Adena
(18465, 5313, 1, 1, 1, 1214.018262), -- Sealed Gauntlets of Nightmare
(18465, 5514, 1, 1, 1, 180416.481738), -- Sealed Gauntlets of Nightmare Design
(18465, 5314, 1, 1, 1, 1214.018262), -- Sealed Boots of Nightmare
(18465, 5502, 1, 1, 1, 180416.481738), -- Sealed Boots of Nightmare Lining
(18465, 5318, 1, 1, 1, 1214.018262), -- Sealed Majestic Gauntlets
(18465, 5515, 1, 1, 1, 180416.481738), -- Sealed Majestic Gauntlets Design
(18465, 5319, 1, 1, 1, 1214.018262), -- Sealed Majestic Boots
(18465, 5503, 1, 1, 1, 180416.481738), -- Sealed Majestic Boots Lining
(18465, 1875, 3, 9, 2, 158272.236542), -- Stone of Purity
(18465, 1879, 32, 96, 2, 37095.31798), -- Cokes
(18465, 1885, 22, 66, 2, 26378.626078), -- High-Grade Suede
(18465, 5550, 1, 1, 2, 189926.87588), -- Durable Metal Plate
(18465, 5549, 10, 30, 2, 67831.095682), -- Metallic Thread
(18465, 959, 1, 1, 2, 569.847838), -- Scroll: Enchant Weapon (S-Grade)
-- Coral Treasure Chest
(18477, 6684, 1, 1, 0, 12078.56754), -- Sealed Major Arcana Robe
(18477, 6711, 12, 36, 0, 216942.43246), -- Sealed Major Arcana Robe Part
(18477, 9460, 1, 1, 1, 7050.850092), -- Dynasty Ring - Stun Resistance
(18477, 9463, 1, 1, 1, 7050.850092), -- Dynasty Ring - Poison Resistance
(18477, 9466, 1, 1, 1, 7050.850092), -- Dynasty Ring - Bleed Resistance
(18477, 9469, 1, 1, 1, 7050.850092), -- Dynasty Ring - Sleep Resistance
(18477, 9472, 1, 1, 1, 7050.850092), -- Dynasty Ring - Paralysis Resistance
(18477, 9475, 1, 1, 1, 7050.850092), -- Dynasty Ring - Hold Resistance
(18477, 9478, 1, 1, 1, 7050.899448), -- Dynasty Ring - Fear Resistance
-- Beleth's Slave
(18490, 57, 5380, 10776, 0, 700000), -- Adena
(18490, 164, 1, 1, 1, 4.187562), -- Elysian
(18490, 5533, 1, 1, 1, 1549.528413), -- Elysian Head
(18490, 213, 1, 1, 1, 4.187562), -- Branch of the Mother Tree
(18490, 5544, 1, 1, 1, 1548.000015), -- Branch of the Mother Tree Head
(18490, 7895, 1, 1, 1, 4.187562), -- Flaming Dragon Skull
(18490, 8342, 1, 1, 1, 1549.528413), -- Flaming Dragon Skull Piece
(18490, 7902, 1, 1, 1, 4.187562), -- Doom Crusher
(18490, 8349, 1, 1, 1, 1549.192911), -- Doom Crusher Head
(18490, 1873, 2, 6, 2, 64613.214492), -- Silver Nugget
(18490, 1868, 15, 45, 2, 43075.476328), -- Thread
(18490, 1876, 1, 1, 2, 129226.428984), -- Mithril Ore
(18490, 1895, 1, 1, 2, 184609.49369), -- Metallic Fiber
(18490, 4042, 1, 1, 2, 10768.869082), -- Enria
(18490, 960, 1, 1, 2, 258.619206), -- Scroll: Enchant Armor (S-Grade)
(18490, 6901, 1, 1, 2, 645.898218), -- Recipe: Shining Arrow (100%)
-- Ancient Experiment
(18545, 1871, 1, 21, -1, 877846), -- Charcoal
(18545, 4553, 1, 1, -1, 38625), -- Greater Dye of STR (Str+1 Con-1)
(18545, 1908, 1, 1, -1, 914423), -- Moonstone Earring Wire
(18545, 354, 1, 1, 0, 587.201116), -- Chain Mail Shirt
(18545, 1959, 1, 1, 0, 30730.634002), -- Chain Mail Shirt Material
(18545, 381, 1, 1, 0, 939.370152), -- Chain Gaiters
(18545, 1960, 1, 1, 0, 62513.79473), -- Chain Gaiters Part
(18545, 1871, 4, 12, 1, 95077.506048), -- Charcoal
(18545, 1866, 1, 3, 1, 169026.1776), -- Suede
(18545, 1877, 1, 1, 1, 30424.711968), -- Adamantite Nugget
(18545, 4041, 1, 1, 1, 6614.100416), -- Mold Hardener
(18545, 4040, 1, 1, 1, 15212.355984), -- Mold Lubricant
(18545, 2164, 1, 1, 1, 58509.147984), -- Recipe: Ring of Protection
-- Ancient Experiment
(18546, 2163, 1, 7, -1, 745273), -- Recipe: Earring of Protection
(18546, 1909, 1, 17, -1, 876726), -- Aquastone Ring Wire
(18546, 2164, 1, 9, -1, 898914), -- Recipe: Ring of Protection
(18546, 226, 1, 1, 0, 783.216815), -- Cursed Dagger
(18546, 2070, 1, 1, 0, 54819.283185), -- Cursed Dagger Blade
(18546, 232, 1, 1, 0, 783.216815), -- Dark Elven Dagger
(18546, 2072, 1, 1, 0, 54819.283185), -- Dark Elven Dagger Edge
(18546, 1870, 24, 72, 1, 95884.05276), -- Coal
(18546, 1865, 52, 156, 1, 43832.62608), -- Varnish
(18546, 1874, 4, 12, 1, 38353.54782), -- Oriharukon Ore
(18546, 4043, 5, 15, 1, 15341.63898), -- Asofe
(18546, 4039, 1, 1, 1, 153414.5577), -- Mold Glue
(18546, 2165, 4, 12, 1, 19593.57666), -- Recipe: Necklace of Protection
-- Ancient Experiment
(18547, 1910, 1, 17, -1, 945042), -- Aquastone Necklace Chain
(18547, 1866, 1, 159, -1, 941262), -- Suede
(18547, 1871, 1, 237, -1, 949172), -- Charcoal
(18547, 71, 1, 1, 0, 1009.370349), -- Flamberge
(18547, 2059, 1, 1, 0, 66090.296364), -- Flamberge Blade
(18547, 72, 1, 1, 0, 1009.370349), -- Stormbringer
(18547, 2060, 1, 1, 0, 70647.928584), -- Stormbringer Blade
(18547, 7887, 1, 1, 0, 1009.370349), -- Mysterious Sword
(18547, 8334, 1, 1, 0, 70650.664005), -- Mysterious Sword Blade
(18547, 1866, 60, 180, 1, 49428.388719), -- Suede
(18547, 1871, 240, 720, 1, 18535.484916), -- Charcoal
(18547, 5220, 4, 12, 1, 39542.539398), -- Metal Hardener
(18547, 1885, 3, 9, 1, 105917.608161), -- High-Grade Suede
(18547, 4041, 1, 1, 1, 77365.875252), -- Mold Hardener
(18547, 2213, 1, 1, 1, 138153.103554), -- Recipe: Dwarven Chain Mail Shirt
-- Ancient Experiment
(18548, 4554, 1, 1, -1, 115844), -- Greater Dye of STR (Str+1 Dex-1)
(18548, 1954, 1, 3, -1, 769829), -- Karmian Stocking Design
(18548, 2165, 1, 3, -1, 554808), -- Recipe: Necklace of Protection
(18548, 96, 1, 1, 0, 258.805603), -- Scythe
(18548, 2062, 1, 1, 0, 17891.50958), -- Scythe Edge
(18548, 298, 1, 1, 0, 258.805603), -- Orcish Glaive
(18548, 2075, 1, 1, 0, 17891.50958), -- Orcish Glaive Blade
(18548, 302, 1, 1, 0, 258.805603), -- Body Slasher
(18548, 2076, 1, 1, 0, 17891.564031), -- Body Slasher Blade
(18548, 1864, 21, 63, 1, 108630.218445), -- Stem
(18548, 1869, 16, 48, 1, 71288.62734), -- Iron Ore
(18548, 1878, 3, 9, 1, 152082.107485), -- Braided Hemp
(18548, 1884, 22, 66, 1, 31196.58402), -- Cord
(18548, 4039, 1, 1, 1, 76041.301665), -- Mold Glue
(18548, 2214, 1, 1, 1, 56606.161045), -- Recipe: Dwarven Chain Gaiters
-- Ancient Experiment
(18549, 1958, 1, 1, -1, 546211), -- Reinforced Mithril Boots Design
(18549, 2213, 1, 1, -1, 94357), -- Recipe: Dwarven Chain Mail Shirt
(18549, 1959, 1, 1, -1, 163679), -- Chain Mail Shirt Material
(18549, 62, 1, 1, 0, 328.630137), -- Reinforced Mithril Boots
(18549, 1958, 1, 1, 0, 14341.688526), -- Reinforced Mithril Boots Design
(18549, 2429, 1, 1, 0, 328.630137), -- Chain Boots
(18549, 2937, 1, 1, 0, 14341.688526), -- Chain Boots Part
(18549, 2430, 1, 1, 0, 328.630137), -- Karmian Boots
(18549, 2938, 1, 1, 0, 14341.688526), -- Karmian Boots Fabric
(18549, 2431, 1, 1, 0, 328.630137), -- Plated Leather Boots
(18549, 2939, 1, 1, 0, 14341.688526), -- Plate Leather Boots Lining
(18549, 2432, 1, 1, 0, 328.630137), -- Dwarven Chain Boots
(18549, 2940, 1, 1, 0, 14341.688526), -- Dwarven Chain Boots Part
(18549, 2433, 1, 1, 0, 328.630137), -- Boots of Seal
(18549, 2941, 1, 1, 0, 14341.688526), -- Boots of Seal Pattern
(18549, 2452, 1, 1, 0, 328.630137), -- Reinforced Mithril Gloves
(18549, 2942, 1, 1, 0, 14341.688526), -- Reinforced Mithril Gloves Design
(18549, 2453, 1, 1, 0, 328.630137), -- Chain Gloves
(18549, 2943, 1, 1, 0, 14341.688526), -- Chain Gloves Design
(18549, 2454, 1, 1, 0, 328.630137), -- Karmian Gloves
(18549, 2944, 1, 1, 0, 14341.820559), -- Karmian Gloves Fabric
(18549, 1870, 1, 3, 1, 239324.368574), -- Coal
(18549, 1865, 1, 3, 1, 159549.735313), -- Varnish
(18549, 1874, 1, 1, 1, 31910.134579), -- Oriharukon Ore
(18549, 4043, 1, 1, 1, 15954.832894), -- Asofe
(18549, 4039, 1, 1, 1, 15954.832894), -- Mold Glue
(18549, 2215, 1, 1, 1, 6097.095746), -- Recipe: Robe of Seal
-- Cruma Phantom
(18550, 5220, 1, 9, -1, 943019), -- Metal Hardener
(18550, 1885, 1, 21, -1, 893011), -- High-Grade Suede
(18550, 4601, 1, 1, -1, 261950), -- Greater Dye of STR (Str+3 Con-3)
(18550, 75, 1, 1, 0, 210.750709), -- Caliburs
(18550, 2089, 1, 1, 0, 18977.841077), -- Caliburs Edge
(18550, 76, 1, 1, 0, 210.750709), -- Sword of Delusion
(18550, 2090, 1, 1, 0, 18977.841077), -- Delusional Blade
(18550, 77, 1, 1, 0, 210.750709), -- Tsurugi
(18550, 2091, 1, 1, 0, 18977.841077), -- Tsurugi Blade
(18550, 84, 1, 1, 0, 210.750709), -- Homunkulus's Sword
(18550, 2092, 1, 1, 0, 18977.841077), -- Homunkulus's Sword Blade
(18550, 134, 1, 1, 0, 210.750709), -- Sword of Nightmare
(18550, 2095, 1, 1, 0, 18977.841077), -- Sword of Nightmare Blade
(18550, 145, 1, 1, 0, 210.750709), -- Sword of Whispering Death
(18550, 2096, 1, 1, 0, 18977.841077), -- Sword of Whispering Death Blade
(18550, 7882, 1, 1, 0, 210.750709), -- Pa'agrian Sword
(18550, 8329, 1, 1, 0, 18128.698575), -- Pa'agrian Sword Blade
(18550, 1866, 60, 180, 1, 45135.921911), -- Suede
(18550, 1871, 240, 720, 1, 16925.91955), -- Charcoal
(18550, 5220, 4, 12, 1, 36108.491929), -- Metal Hardener
(18550, 1885, 3, 9, 1, 96719.657238), -- High-Grade Suede
(18550, 4041, 1, 1, 1, 70647.191803), -- Mold Hardener
(18550, 2169, 1, 1, 1, 143795.817569), -- Recipe: Necklace of Seal
-- Cruma Phantom
(18551, 1539, 1, 55, -1, 926751), -- Greater Healing Potion
(18551, 1914, 1, 13, -1, 937164), -- Earring of Seal Gemstone
(18551, 2169, 1, 5, -1, 688912), -- Recipe: Necklace of Seal
(18551, 162, 1, 1, 0, 162.37837), -- War Axe
(18551, 2097, 1, 1, 0, 14366.862426), -- War Axe Blade
(18551, 174, 1, 1, 0, 162.37837), -- Nirvana Axe
(18551, 2098, 1, 1, 0, 14366.862426), -- Nirvana Axe Blade
(18551, 196, 1, 1, 0, 162.37837), -- Stick of Eternity
(18551, 2099, 1, 1, 0, 15119.97599), -- Stick of Eternity Shaft
(18551, 197, 1, 1, 0, 162.37837), -- Paradia Staff
(18551, 2100, 1, 1, 0, 15119.97599), -- Paradia Staff Head
(18551, 199, 1, 1, 0, 162.37837), -- Pa'agrian Hammer
(18551, 2102, 1, 1, 0, 14577.685913), -- Pa'agrian Hammer Head
(18551, 200, 1, 1, 0, 162.37837), -- Sage's Staff
(18551, 2103, 1, 1, 0, 15119.97599), -- Sage's Staff Head
(18551, 201, 1, 1, 0, 162.37837), -- Club of Nature
(18551, 2104, 1, 1, 0, 15119.97599), -- Club of Nature Head
(18551, 202, 1, 1, 0, 162.37837), -- Mace of Underworld
(18551, 2105, 1, 1, 0, 14366.862426), -- Mace of Underworld Head
(18551, 7898, 1, 1, 0, 162.37837), -- Karik Horn
(18551, 8345, 1, 1, 0, 14577.417519), -- Karik Horn Piece
(18551, 1871, 240, 720, 1, 16767.050288), -- Charcoal
(18551, 1866, 52, 156, 1, 51099.959128), -- Suede
(18551, 1877, 4, 12, 1, 40241.13678), -- Adamantite Nugget
(18551, 4041, 1, 1, 1, 69984.679656), -- Mold Hardener
(18551, 4040, 1, 1, 1, 160964.54712), -- Mold Lubricant
(18551, 2170, 4, 12, 1, 21090.627028), -- Recipe: Nassen's Earring
-- Cruma Phantom
(18552, 1915, 1, 11, -1, 827471), -- Ring of Ages Gemstone
(18552, 2170, 1, 3, -1, 664514), -- Recipe: Nassen's Earring
(18552, 1916, 1, 5, -1, 799302), -- Necklace of Mermaid Teardrop
(18552, 283, 1, 1, 0, 705.24312), -- Akat Long Bow
(18552, 2109, 1, 1, 0, 65328.75688), -- Akat Longbow Shaft
(18552, 1867, 28, 84, 1, 92473.036317), -- Animal Skin
(18552, 1872, 60, 180, 1, 43153.98417), -- Animal Bone
(18552, 1882, 3, 9, 1, 143847.111123), -- Leather
(18552, 1894, 1, 1, 1, 136276.393725), -- Crafted Leather
(18552, 4042, 1, 1, 1, 64731.473478), -- Enria
(18552, 2231, 1, 1, 1, 16741.001187), -- Recipe: Full Plate Armor
-- Cruma Phantom
(18553, 1865, 1, 123, -1, 934946), -- Varnish
(18553, 1870, 1, 123, -1, 934946), -- Coal
(18553, 4602, 1, 1, -1, 128815), -- Greater Dye of STR (Str+3 Dex-3)
(18553, 854, 1, 1, 0, 3526.248132), -- Earring of Seal
(18553, 1914, 1, 1, 0, 224427.92216), -- Earring of Seal Gemstone
(18553, 885, 1, 1, 0, 5287.477588), -- Ring of Ages
(18553, 1915, 1, 1, 0, 351966.246764), -- Ring of Ages Gemstone
(18553, 917, 1, 1, 0, 2644.87556), -- Necklace of Mermaid
(18553, 1916, 1, 1, 0, 169991.229796), -- Necklace of Mermaid Teardrop
(18553, 1865, 28, 84, 1, 71343.602305), -- Varnish
(18553, 1870, 60, 180, 1, 33293.56505), -- Coal
(18553, 1879, 3, 9, 1, 110979.130295), -- Cokes
(18553, 1875, 4, 12, 1, 29594.550771), -- Stone of Purity
(18553, 4040, 1, 1, 1, 79904.904197), -- Mold Lubricant
(18553, 2232, 1, 1, 1, 22961.247382), -- Recipe: Drake Leather Armor
-- Tomlan Kamos
(18554, 25, 1, 1, 0, 209298.796681), -- Piece Bone Breastplate
(18554, 1926, 8, 22, 0, 172512.732353), -- Piece Bone Breastplate Fragment
(18554, 26, 1, 1, 0, 135474.075386), -- Bronze Breastplate
(18554, 32, 4, 10, 0, 47839.839814), -- Piece Bone Gaiters
(18554, 1928, 24, 72, 0, 77743.592238), -- Piece Bone Gaiters Fragment
(18554, 34, 4, 12, 0, 27137.963528), -- Bronze Gaiters
(18554, 25, 5, 13, 1, 34883.157192), -- Piece Bone Breastplate
(18554, 1926, 8, 22, 1, 258769.259268), -- Piece Bone Breastplate Fragment
(18554, 26, 1, 1, 1, 203211.159996), -- Bronze Breastplate
(18554, 32, 4, 10, 1, 71759.7621), -- Piece Bone Gaiters
(18554, 1928, 24, 72, 1, 116615.96544), -- Piece Bone Gaiters Fragment
(18554, 34, 4, 12, 1, 40706.696004), -- Bronze Gaiters
(18554, 955, 1, 1, 2, 298878.528135), -- Scroll: Enchant Weapon (D-Grade)
(18554, 956, 3, 9, 2, 415108.471865), -- Scroll: Enchant Armor (D-Grade)
-- Ol Ariosh
(18555, 432, 1, 1, 0, 354880.951371), -- Cursed Tunic
(18555, 465, 1, 3, 0, 284140.048629), -- Cursed Stockings
(18555, 432, 2, 4, 1, 177440.48714), -- Cursed Tunic
(18555, 465, 1, 3, 1, 426211.51286), -- Cursed Stockings
(18555, 955, 1, 1, 2, 332602.184145), -- Scroll: Enchant Weapon (D-Grade)
(18555, 956, 3, 9, 2, 461946.815855), -- Scroll: Enchant Armor (D-Grade)
-- Ranc Deumus
(18557, 432, 1, 1, 0, 354880.951371), -- Cursed Tunic
(18557, 465, 1, 3, 0, 284140.048629), -- Cursed Stockings
(18557, 432, 2, 4, 1, 177440.48714), -- Cursed Tunic
(18557, 465, 1, 3, 1, 426211.51286), -- Cursed Stockings
(18557, 955, 1, 1, 2, 332602.184145), -- Scroll: Enchant Weapon (D-Grade)
(18557, 956, 3, 9, 2, 461946.815855), -- Scroll: Enchant Armor (D-Grade)
-- Crimson Hatu Otis
(18558, 63, 3, 9, 0, 26632.283392), -- Gauntlets
(18558, 553, 4, 10, 0, 22828.191121), -- Iron Boots
(18558, 1940, 60, 180, 0, 38855.72159), -- Iron Boots Design
(18558, 2422, 1, 1, 0, 159795.882849), -- Reinforced Leather Boots
(18558, 2423, 1, 1, 0, 159795.882849), -- Boots of Knowledge
(18558, 2446, 1, 1, 0, 159795.882849), -- Reinforced Leather Gloves
(18558, 2447, 1, 1, 0, 159795.15535), -- Gloves of Knowledge
(18558, 63, 3, 9, 1, 39948.457824), -- Gauntlets
(18558, 553, 4, 10, 1, 34241.2488), -- Iron Boots
(18558, 1940, 60, 180, 1, 58283.318016), -- Iron Boots Design
(18558, 2422, 4, 12, 1, 29961.176256), -- Reinforced Leather Boots
(18558, 2423, 5, 13, 1, 26632.305216), -- Boots of Knowledge
(18558, 2446, 1, 1, 1, 239690.746944), -- Reinforced Leather Gloves
(18558, 2447, 1, 1, 1, 239690.746944), -- Gloves of Knowledge
(18558, 955, 1, 1, 2, 425206.739264), -- Scroll: Enchant Weapon (D-Grade)
(18558, 956, 12, 36, 2, 147641.260736), -- Scroll: Enchant Armor (D-Grade)
-- Seer Flouros
(18559, 47, 1, 1, 0, 413972.422365), -- Helmet
(18559, 628, 1, 3, 0, 295838.577635), -- Hoplon
(18559, 47, 2, 4, 1, 206986.048544), -- Helmet
(18559, 628, 1, 3, 1, 443757.951456), -- Hoplon
(18559, 955, 1, 1, 2, 471697.953176), -- Scroll: Enchant Weapon (D-Grade)
(18559, 956, 12, 36, 2, 163784.046824), -- Scroll: Enchant Armor (D-Grade)
-- Granitick Duerga
(18561, 83, 1, 1, 0, 14680.9374), -- Sword of Magic
(18561, 124, 1, 1, 0, 10875.74376), -- Two-Handed Sword
(18561, 2026, 1, 1, 0, 486625.345305), -- Two-Handed Sword Edge
(18561, 127, 1, 1, 0, 10875.74376), -- Crimson Sword
(18561, 130, 1, 1, 0, 10875.74376), -- Elven Sword
(18561, 144, 1, 1, 0, 14681.486015), -- Sword of Occult
(18561, 83, 1, 1, 1, 22021.393563), -- Sword of Magic
(18561, 124, 1, 1, 1, 16313.517227), -- Two-Handed Sword
(18561, 2026, 1, 3, 1, 364965.661193), -- Two-Handed Sword Edge
(18561, 127, 1, 1, 1, 16313.517227), -- Crimson Sword
(18561, 130, 1, 1, 1, 16313.517227), -- Elven Sword
(18561, 144, 1, 1, 1, 22021.393563), -- Sword of Occult
(18561, 955, 1, 1, 2, 471697.953176), -- Scroll: Enchant Weapon (D-Grade)
(18561, 956, 12, 36, 2, 163784.046824), -- Scroll: Enchant Armor (D-Grade)
-- Blade Otis
(18562, 353, 1, 1, 0, 49540.14856), -- Half Plate Armor
(18562, 1950, 8, 22, 0, 161220.990448), -- Half Plate Temper
(18562, 380, 1, 1, 0, 79264.237696), -- Plate Gaiters
(18562, 1951, 4, 12, 0, 470142.623296), -- Plate Gaiters Part
(18562, 353, 1, 1, 1, 74310.286), -- Half Plate Armor
(18562, 1950, 8, 22, 1, 241832.23845), -- Half Plate Temper
(18562, 380, 1, 1, 1, 118896.4576), -- Plate Gaiters
(18562, 1951, 24, 72, 1, 117536.01795), -- Plate Gaiters Part
(18562, 951, 1, 1, 2, 263413.35), -- Scroll: Enchant Weapon (C-Grade)
(18562, 952, 3, 9, 2, 321949.65), -- Scroll: Enchant Armor (C-Grade)
-- Weird Bunei
(18564, 281, 1, 1, 0, 19239.801579), -- Crystallized Ice Bow
(18564, 2074, 1, 3, 0, 600579.198421), -- Crystallized Ice Bow Shaft
(18564, 281, 1, 1, 1, 28859.675064), -- Crystallized Ice Bow
(18564, 2074, 3, 9, 1, 300284.324936), -- Crystallized Ice Bow Shaft
(18564, 951, 1, 1, 2, 299778.75), -- Scroll: Enchant Weapon (C-Grade)
(18564, 952, 3, 9, 2, 366396.25), -- Scroll: Enchant Armor (C-Grade)
-- Brave Martim
(18565, 631, 1, 1, 0, 110842.592416), -- Eldarake
(18565, 1964, 40, 120, 0, 57101.028168), -- Eldarake Temper
(18565, 2413, 1, 1, 0, 77597.5498), -- Chain Hood
(18565, 2936, 14, 42, 0, 148178.142568), -- Chain Hood Pattern
(18565, 2495, 1, 1, 0, 110842.592416), -- Chain Shield
(18565, 2945, 9, 27, 0, 253782.094632), -- Chain Shield Fragment
(18565, 631, 1, 1, 1, 166263.857452), -- Eldarake
(18565, 1964, 40, 120, 1, 85650.811702), -- Eldarake Temper
(18565, 2413, 1, 1, 1, 116396.047976), -- Chain Hood
(18565, 2936, 14, 42, 1, 222265.850216), -- Chain Hood Pattern
(18565, 2495, 1, 1, 1, 166263.857452), -- Chain Shield
(18565, 2945, 81, 243, 1, 42297.575202), -- Chain Shield Fragment
(18565, 951, 1, 1, 2, 299778.75), -- Scroll: Enchant Weapon (C-Grade)
(18565, 952, 3, 9, 2, 366396.25), -- Scroll: Enchant Armor (C-Grade)
-- Kaim Abigore
(18566, 266, 1, 1, 0, 8318.72104), -- Great Pata
(18566, 2120, 1, 3, 0, 470870.27896), -- Great Pata Blade
(18566, 266, 1, 1, 1, 12478.07288), -- Great Pata
(18566, 2120, 1, 3, 1, 706304.92712), -- Great Pata Blade
(18566, 947, 1, 1, 2, 76242.187836), -- Scroll: Enchant Weapon (B-Grade)
(18566, 948, 1, 1, 2, 476513.812164), -- Scroll: Enchant Armor (B-Grade)
-- Knight Montagnar
(18568, 357, 1, 1, 0, 8370.795283), -- Zubei's Breastplate
(18568, 4056, 16, 48, 0, 37781.283302), -- Zubei's Breastplate Part
(18568, 383, 1, 1, 0, 13389.979323), -- Zubei's Gaiters
(18568, 4057, 6, 18, 0, 155704.286973), -- Zubei's Gaiter Material
(18568, 2376, 1, 1, 0, 8370.795283), -- Avadon Breastplate
(18568, 4064, 3, 7, 0, 241799.758908), -- Avadon Breastplate Part
(18568, 2379, 1, 1, 0, 13389.979323), -- Avadon Gaiters
(18568, 4065, 11, 31, 0, 88974.121605), -- Avadon Gaiters Material
(18568, 357, 1, 1, 1, 12556.180609), -- Zubei's Breastplate
(18568, 4056, 16, 48, 1, 56672.977225), -- Zubei's Breastplate Part
(18568, 383, 1, 1, 1, 20085.760567), -- Zubei's Gaiters
(18568, 4057, 6, 18, 1, 233561.472957), -- Zubei's Gaiter Material
(18568, 2376, 1, 1, 1, 12556.180609), -- Avadon Breastplate
(18568, 4064, 23, 67, 1, 40300.666186), -- Avadon Breastplate Part
(18568, 2379, 1, 1, 1, 20085.760567), -- Avadon Gaiters
(18568, 4065, 11, 31, 1, 133464.00128), -- Avadon Gaiters Material
(18568, 947, 1, 1, 2, 103909.353333), -- Scroll: Enchant Weapon (B-Grade)
(18568, 948, 1, 1, 2, 649433.646667), -- Scroll: Enchant Armor (B-Grade)
-- Summer Yaganitan
(18570, 78, 1, 1, 0, 2666.424), -- Great Sword
(18570, 4104, 1, 3, 0, 254821.2536), -- Great Sword Blade
(18570, 142, 1, 1, 0, 2666.424), -- Keshanberk
(18570, 4107, 2, 4, 0, 167248.667875), -- Keshanberk Blade
(18570, 148, 1, 1, 0, 2666.424), -- Sword of Valhalla
(18570, 4108, 2, 6, 0, 125435.806525), -- Sword of Valhalla Blade
(18570, 78, 1, 1, 1, 3999.633894), -- Great Sword
(18570, 4104, 5, 15, 1, 76452.511293), -- Great Sword Blade
(18570, 142, 1, 1, 1, 3999.633894), -- Keshanberk
(18570, 4107, 2, 4, 1, 250894.470438), -- Keshanberk Blade
(18570, 148, 1, 1, 1, 3999.633894), -- Sword of Valhalla
(18570, 4108, 2, 6, 1, 188171.116587), -- Sword of Valhalla Blade
(18570, 947, 1, 1, 2, 103909.353333), -- Scroll: Enchant Weapon (B-Grade)
(18570, 948, 1, 1, 2, 649433.646667), -- Scroll: Enchant Armor (B-Grade)
-- Venomous Storace
(18571, 2398, 1, 1, 0, 9540.4291), -- Blue Wolf Tunic
(18571, 4084, 16, 48, 0, 48108.8423), -- Blue Wolf Tunic Fabric
(18571, 2399, 1, 1, 0, 9540.4291), -- Tunic of Doom
(18571, 4085, 3, 7, 0, 307896.59072), -- Tunic of Doom Pattern
(18571, 2403, 1, 1, 0, 15268.753528), -- Blue Wolf Stockings
(18571, 4086, 6, 18, 0, 173220.978884), -- Blue Wolf Stockings Pattern
(18571, 2404, 1, 1, 0, 15268.753528), -- Stockings of Doom
(18571, 4087, 11, 31, 0, 98983.22284), -- Stockings of Doom Pattern
(18571, 2398, 1, 1, 1, 14310.641774), -- Blue Wolf Tunic
(18571, 4084, 16, 48, 1, 72164.893931), -- Blue Wolf Tunic Fabric
(18571, 2399, 1, 1, 1, 14310.641774), -- Tunic of Doom
(18571, 4085, 23, 67, 1, 51317.28485), -- Tunic of Doom Pattern
(18571, 2403, 1, 1, 1, 22903.937849), -- Blue Wolf Stockings
(18571, 4086, 6, 18, 1, 259838.236606), -- Blue Wolf Stockings Pattern
(18571, 2404, 1, 1, 1, 22903.937849), -- Stockings of Doom
(18571, 4087, 11, 31, 1, 148479.425367), -- Stockings of Doom Pattern
(18571, 729, 1, 1, 2, 38276.569097), -- Scroll: Enchant Weapon (A-Grade)
(18571, 730, 1, 1, 2, 287074.430903), -- Scroll: Enchant Armor (A-Grade)
-- Kel Bilette
(18573, 601, 1, 1, 0, 28834.965858), -- Sealed Doom Boots
(18573, 4099, 60, 180, 0, 33376.171267), -- Sealed Doom Boots Part
(18573, 2439, 1, 1, 0, 28834.965858), -- Sealed Blue Wolf Boots
(18573, 4090, 11, 31, 0, 190722.323133), -- Sealed Blue Wolf Boots Design
(18573, 2475, 1, 1, 0, 28834.965858), -- Sealed Doom Gloves
(18573, 4091, 16, 48, 0, 125161.334255), -- Sealed Doom Gloves Part
(18573, 2487, 1, 1, 0, 28834.965858), -- Sealed Blue Wolf Gloves
(18573, 4096, 23, 67, 0, 89003.307913), -- Sealed Blue Wolf Gloves Fabric
(18573, 601, 1, 1, 1, 43252.495395), -- Sealed Doom Boots
(18573, 4099, 60, 180, 1, 50065.14697), -- Sealed Doom Boots Part
(18573, 2439, 1, 1, 1, 43252.495395), -- Sealed Blue Wolf Boots
(18573, 4090, 116, 346, 1, 26007.846335), -- Sealed Blue Wolf Boots Design
(18573, 2475, 1, 1, 1, 43252.495395), -- Sealed Doom Gloves
(18573, 4091, 16, 48, 1, 187744.01597), -- Sealed Doom Gloves Part
(18573, 2487, 1, 1, 1, 43252.495395), -- Sealed Blue Wolf Gloves
(18573, 4096, 23, 67, 1, 133508.009145), -- Sealed Blue Wolf Gloves Fabric
(18573, 729, 1, 1, 2, 38549.863078), -- Scroll: Enchant Weapon (A-Grade)
(18573, 730, 1, 1, 2, 289124.136922), -- Scroll: Enchant Armor (A-Grade)
-- Warlord Tamuze
(18575, 171, 1, 1, 0, 1414.518996), -- Deadman's Glory
(18575, 4116, 1, 3, 0, 155937.89518), -- Deadman's Glory Stone
(18575, 175, 1, 1, 0, 1414.518996), -- Art of Battle Axe
(18575, 4117, 2, 4, 0, 103958.362556), -- Art of Battle Axe Blade
(18575, 210, 1, 1, 0, 1414.518996), -- Staff of Evil Spirits
(18575, 4118, 1, 1, 0, 295484.094076), -- Evil Spirit Head
(18575, 7893, 1, 1, 0, 1414.518996), -- Kaim Vanul's Bones
(18575, 8340, 2, 6, 0, 77968.596244), -- Bones Head of Kaim Vanul
(18575, 7901, 1, 1, 0, 1414.518996), -- Star Buster
(18575, 8348, 3, 7, 0, 62270.456964), -- Star Buster Head
(18575, 171, 1, 1, 1, 2121.776835), -- Deadman's Glory
(18575, 4116, 1, 3, 1, 233900.73462), -- Deadman's Glory Stone
(18575, 175, 1, 1, 1, 2121.776835), -- Art of Battle Axe
(18575, 4117, 2, 4, 1, 155933.82308), -- Art of Battle Axe Blade
(18575, 210, 1, 1, 1, 2121.776835), -- Staff of Evil Spirits
(18575, 4118, 3, 9, 1, 73869.191515), -- Evil Spirit Head
(18575, 7893, 1, 1, 1, 2121.776835), -- Kaim Vanul's Bones
(18575, 8340, 2, 6, 1, 116950.36731), -- Bones Head of Kaim Vanul
(18575, 7901, 1, 1, 1, 2121.776835), -- Star Buster
(18575, 8348, 3, 7, 1, 93401.9993), -- Star Buster Head
(18575, 729, 1, 1, 2, 38549.863078), -- Scroll: Enchant Weapon (A-Grade)
(18575, 730, 1, 1, 2, 289124.136922), -- Scroll: Enchant Armor (A-Grade)
-- White Allosce
(18577, 6323, 1, 1, 0, 17972.441864), -- Sealed Phoenix Necklace
(18577, 6343, 14, 42, 0, 91949.975538), -- Sealed Phoenix Necklace Beads
(18577, 6324, 1, 1, 0, 23963.118339), -- Sealed Phoenix Earring
(18577, 6341, 9, 27, 0, 185027.559302), -- Sealed Phoenix Earring Gemstone
(18577, 6325, 1, 1, 0, 35944.471289), -- Sealed Phoenix Ring
(18577, 6345, 40, 120, 0, 57581.433668), -- Sealed Phoenix Ring Gemstone
(18577, 6323, 1, 1, 1, 26958.684584), -- Sealed Phoenix Necklace
(18577, 6343, 14, 42, 1, 137925.074778), -- Sealed Phoenix Necklace Beads
(18577, 6324, 1, 1, 1, 35944.706559), -- Sealed Phoenix Earring
(18577, 6341, 9, 27, 1, 277541.563262), -- Sealed Phoenix Earring Gemstone
(18577, 6325, 1, 1, 1, 53916.750509), -- Sealed Phoenix Ring
(18577, 6345, 40, 120, 1, 86372.220308), -- Sealed Phoenix Ring Gemstone
(18577, 729, 1, 1, 2, 39023.5099), -- Scroll: Enchant Weapon (A-Grade)
(18577, 730, 1, 1, 2, 292676.4901), -- Scroll: Enchant Armor (A-Grade)
-- Energy Seed - Water
(18678, 14016, 1, 2, 0, 1000000), -- Water Energy Compression Stone
-- Energy Seed - Fire
(18679, 14015, 1, 2, 0, 1000000), -- Fire Energy Compression Stone
-- Energy Seed - Wind
(18680, 14017, 1, 2, 0, 1000000), -- Wind Energy Compression Stone
-- Energy Seed - Earth
(18681, 14018, 1, 2, 0, 1000000), -- Earth Energy Compression Stone
-- Energy Seed - Holy
(18682, 14020, 1, 2, 0, 1000000), -- Holy Energy Compression Stone
-- Energy Seed - Dark
(18683, 14019, 1, 2, 0, 1000000), -- Dark Energy Compression Stone
-- Red Star Stone
(18684, 14009, 1, 2, 0, 1000000), -- Extracted Red Star Stone
-- Red Star Stone
(18685, 14009, 1, 2, 0, 1000000), -- Extracted Red Star Stone
-- Red Star Stone
(18686, 14009, 1, 2, 0, 1000000), -- Extracted Red Star Stone
-- Blue Star Stone
(18687, 14010, 1, 2, 0, 1000000), -- Extracted Blue Star Stone
-- Blue Star Stone
(18688, 14010, 1, 2, 0, 1000000), -- Extracted Blue Star Stone
-- Blue Star Stone
(18689, 14010, 1, 2, 0, 1000000), -- Extracted Blue Star Stone
-- Green Star Stone
(18690, 14011, 1, 2, 0, 1000000), -- Extracted Green Star Stone
-- Green Star Stone
(18691, 14011, 1, 2, 0, 1000000), -- Extracted Green Star Stone
-- Green Star Stone
(18692, 14011, 1, 2, 0, 1000000), -- Extracted Green Star Stone
-- Newborn Lavasaurus
(18799, 960, 1, 1, -1, 5298), -- Scroll: Enchant Armor (S-Grade)
(18799, 1894, 1, 1, -1, 464713), -- Crafted Leather
(18799, 9540, 1, 1, -1, 23694), -- Sealed Dynasty Tunic Piece
(18799, 57, 2420, 4913, 0, 700000), -- Adena
(18799, 6371, 1, 1, 1, 11.436396), -- Demon Splinter
(18799, 6695, 1, 1, 1, 5184.563604), -- Demon Splinter Blade
(18799, 9628, 1, 1, 2, 12784.656007), -- Leonard
(18799, 9630, 1, 1, 2, 8579.171442), -- Orichalcum
(18799, 9629, 1, 1, 2, 7087.172551), -- Adamantine
-- Fledgling Lavasaurus
(18800, 960, 1, 1, -1, 5298), -- Scroll: Enchant Armor (S-Grade)
(18800, 1894, 1, 1, -1, 464713), -- Crafted Leather
(18800, 9540, 1, 1, -1, 23694), -- Sealed Dynasty Tunic Piece
(18800, 57, 2420, 4913, 0, 700000), -- Adena
(18800, 6680, 1, 1, 1, 31.394825), -- Sealed Draconic Leather Armor
(18800, 6707, 1, 1, 1, 12113.605175), -- Sealed Draconic Leather Armor Part
(18800, 9628, 1, 1, 2, 12784.656007), -- Leonard
(18800, 9630, 1, 1, 2, 8579.171442), -- Orichalcum
(18800, 9629, 1, 1, 2, 7087.172551), -- Adamantine
-- Adult Lavasaurus
(18801, 960, 1, 1, -1, 5298), -- Scroll: Enchant Armor (S-Grade)
(18801, 1894, 1, 1, -1, 464713), -- Crafted Leather
(18801, 9540, 1, 1, -1, 23694), -- Sealed Dynasty Tunic Piece
(18801, 57, 2420, 4913, 0, 700000), -- Adena
(18801, 6370, 1, 1, 1, 11.436432), -- Saint Spear
(18801, 6694, 1, 1, 1, 5380.563568), -- Saint Spear Blade
(18801, 9628, 1, 1, 2, 12784.656007), -- Leonard
(18801, 9630, 1, 1, 2, 8579.171442), -- Orichalcum
(18801, 9629, 1, 1, 2, 7087.172551), -- Adamantine
-- Elderly Lavasaurus
(18802, 960, 1, 1, -1, 5448), -- Scroll: Enchant Armor (S-Grade)
(18802, 1894, 1, 1, -1, 477927), -- Crafted Leather
(18802, 9540, 1, 1, -1, 24368), -- Sealed Dynasty Tunic Piece
(18802, 57, 2540, 5000, 0, 700000), -- Adena
(18802, 6674, 1, 1, 1, 19.674879), -- Sealed Imperial Crusader Breastplate
(18802, 6675, 1, 1, 1, 31.470591), -- Sealed Imperial Crusader Gaiters
(18802, 6701, 1, 1, 1, 6692.638173), -- Sealed Imperial Crusader Breastplate Part
(18802, 6702, 1, 1, 1, 8615.216357), -- Sealed Imperial Crusader Gaiters Pattern
(18802, 9628, 1, 1, 2, 13148.18582), -- Leonard
(18802, 9630, 1, 1, 2, 8823.11892), -- Orichalcum
(18802, 9629, 1, 1, 2, 7288.69526), -- Adamantine
-- Ancient Lavasaurus
(18803, 960, 1, 1, -1, 5448), -- Scroll: Enchant Armor (S-Grade)
(18803, 1894, 1, 1, -1, 477927), -- Crafted Leather
(18803, 9540, 1, 1, -1, 24368), -- Sealed Dynasty Tunic Piece
(18803, 57, 2540, 5000, 0, 700000), -- Adena
(18803, 6674, 1, 1, 1, 19.674879), -- Sealed Imperial Crusader Breastplate
(18803, 6675, 1, 1, 1, 31.470591), -- Sealed Imperial Crusader Gaiters
(18803, 6701, 1, 1, 1, 6692.638173), -- Sealed Imperial Crusader Breastplate Part
(18803, 6702, 1, 1, 1, 8615.216357), -- Sealed Imperial Crusader Gaiters Pattern
(18803, 9628, 1, 1, 2, 13148.18582), -- Leonard
(18803, 9630, 1, 1, 2, 8823.11892), -- Orichalcum
(18803, 9629, 1, 1, 2, 7288.69526), -- Adamantine
-- Frightened Ragna Orc
(18807, 9544, 1, 1, -1, 4497), -- Sealed Dynasty Shoes Piece
(18807, 9630, 1, 1, -1, 4947), -- Orichalcum
(18807, 9619, 1, 1, -1, 526), -- Dynasty Bow Piece
(18807, 5311, 1, 1, 0, 2.630522), -- Sealed Armor of Nightmare
(18807, 5522, 1, 1, 0, 394.369478), -- Sealed Armor of Nightmare Pattern
(18807, 5316, 1, 1, 0, 2.630522), -- Sealed Majestic Plate Armor
(18807, 5523, 1, 1, 0, 394.369478), -- Sealed Majestic Plate Armor Pattern
(18807, 1879, 1, 1, 1, 12861.832924), -- Cokes
(18807, 1885, 1, 1, 1, 6430.916462), -- High-Grade Suede
(18807, 9628, 1, 1, 1, 605.272698), -- Leonard
(18807, 9630, 1, 1, 1, 406.161404), -- Orichalcum
(18807, 9629, 1, 1, 1, 335.518346), -- Adamantine
(18807, 5282, 1, 1, 1, 34.298166), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Dark Shaman Varangka
(18808, 9628, 2, 6, 0, 59214.703296), -- Leonard
(18808, 9630, 3, 9, 0, 26490.574944), -- Orichalcum
(18808, 9629, 3, 9, 0, 18757.417344), -- Adamantine
(18808, 9573, 2, 6, 0, 41943.51168), -- Life Stone - Level 80
(18808, 9574, 1, 1, 0, 52429.3896), -- Mid-Grade Life Stone - Level 80
(18808, 9575, 1, 1, 0, 5243.141664), -- High-Grade Life Stone - Level 80
(18808, 9550, 1, 3, 0, 120797.39472), -- Dark Stone
(18808, 9551, 1, 3, 0, 80531.866752), -- Holy Stone
-- Chieftain's Treasure Chest
(18816, 9546, 1, 1, 0, 25050), -- Fire Stone
(18816, 9547, 1, 1, 0, 25050), -- Water Stone
(18816, 9548, 1, 1, 0, 25050), -- Earth Stone
(18816, 9549, 1, 1, 0, 25050), -- Wind Stone
(18816, 9550, 1, 1, 0, 24900), -- Dark Stone
(18816, 9551, 1, 1, 0, 24900), -- Holy Stone
-- Priest Ugoros
(18863, 57, 285165, 582813, 0, 700000), -- Adena
(18863, 10223, 1, 1, 1, 373.066462), -- Icarus Spitter
(18863, 10405, 1, 1, 1, 123692.933538), -- Icarus Spitter Piece
(18863, 1879, 135, 405, 2, 35731.17086), -- Cokes
(18863, 1885, 144, 432, 2, 16749.12722), -- High-Grade Suede
(18863, 9628, 3, 9, 2, 64856.87628), -- Leonard
(18863, 9630, 5, 15, 2, 30465.66334), -- Orichalcum
(18863, 9629, 5, 15, 2, 22879.15728), -- Adamantine
(18863, 10483, 4, 12, 2, 50247.03488), -- Life Stone - Level 82
(18863, 10484, 1, 1, 2, 100494.06976), -- Mid-Grade Life Stone - Level 82
(18863, 10485, 1, 1, 2, 10049.33762), -- High-Grade Life Stone - Level 82
(18863, 9554, 1, 1, 2, 11576.90352), -- Earth Crystal
(18863, 10381, 1, 1, 2, 3730.65924), -- Recipe - Icarus Spitter (60%)
-- Baby Alpine Kookaburra
(18873, 15772, 1, 1, -1, 13393), -- Sealed Moirai Ring Gem
(18873, 15773, 1, 1, -1, 7527), -- Sealed Moirai Earring Gem
(18873, 15774, 1, 1, -1, 6495), -- Sealed Moirai Necklace Gem
(18873, 15812, 1, 1, -1, 1772), -- Recipe - Sealed Moirai Ring (70%) 
(18873, 15813, 1, 1, -1, 1181), -- Recipe - Sealed Moirai Earring (70%) 
(18873, 15814, 1, 1, -1, 886), -- Recipe - Sealed Moirai Necklace (70%) 
(18873, 57, 475, 959, 0, 700000), -- Adena
(18873, 15766, 1, 1, 1, 5.818546), -- Sealed Moirai Ring
(18873, 15767, 1, 1, 1, 3.877526), -- Sealed Moirai Earring
(18873, 15768, 1, 1, 1, 2.907016), -- Sealed Moirai Necklace
(18873, 15772, 1, 1, 1, 2199.058296), -- Sealed Moirai Ring Gem
(18873, 15773, 1, 1, 1, 1235.906116), -- Sealed Moirai Earring Gem
(18873, 15774, 1, 1, 1, 1066.4325), -- Sealed Moirai Necklace Gem
(18873, 9573, 1, 1, 2, 2214.118422), -- Life Stone - Level 80
(18873, 9574, 1, 1, 2, 553.528194), -- Mid-Grade Life Stone - Level 80
(18873, 9575, 1, 1, 2, 55.353384), -- High-Grade Life Stone - Level 80
-- Young Kookaburra
(18874, 15654, 1, 1, -1, 13628), -- Sealed Moirai Gauntlet Piece
(18874, 15655, 1, 1, -1, 13628), -- Sealed Moirai Leather Gloves Piece
(18874, 15656, 1, 1, -1, 13628), -- Sealed Moirai Gloves Piece
(18874, 15657, 1, 1, -1, 13628), -- Sealed Moirai Boots Piece
(18874, 15658, 1, 1, -1, 13628), -- Sealed Moirai Leather Boots Piece
(18874, 15659, 1, 1, -1, 13628), -- Sealed Moirai Shoes Piece
(18874, 15784, 1, 1, -1, 1813), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18874, 15785, 1, 1, -1, 1813), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18874, 15786, 1, 1, -1, 1813), -- Recipe - Sealed Moirai Gloves (60%) 
(18874, 15787, 1, 1, -1, 1813), -- Recipe - Sealed Moirai Boots (60%) 
(18874, 15788, 1, 1, -1, 1813), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18874, 15789, 1, 1, -1, 1813), -- Recipe - Sealed Moirai Shoes (60%) 
(18874, 57, 1494, 3016, 0, 700000), -- Adena
(18874, 15703, 1, 1, 1, 11.90856), -- Sealed Moirai Gauntlet 
(18874, 15704, 1, 1, 1, 11.90856), -- Sealed Moirai Leather Gloves 
(18874, 15705, 1, 1, 1, 11.90856), -- Sealed Moirai Gloves 
(18874, 15654, 1, 1, 1, 4473.433744), -- Sealed Moirai Gauntlet Piece
(18874, 15655, 1, 1, 1, 4473.433744), -- Sealed Moirai Leather Gloves Piece
(18874, 15656, 1, 1, 1, 4473.406832), -- Sealed Moirai Gloves Piece
(18874, 1895, 1, 1, 2, 107409.360588), -- Metallic Fiber
(18874, 4040, 1, 1, 2, 7518.687308), -- Mold Lubricant
(18874, 9628, 1, 1, 2, 2948.545938), -- Leonard
(18874, 9630, 1, 1, 2, 1978.647362), -- Orichalcum
(18874, 9573, 1, 1, 2, 2610.610778), -- Life Stone - Level 80
(18874, 9574, 1, 1, 2, 652.683528), -- Mid-Grade Life Stone - Level 80
(18874, 9575, 1, 1, 2, 65.243686), -- High-Grade Life Stone - Level 80
(18874, 960, 1, 1, 2, 150.220812), -- Scroll: Enchant Armor (S-Grade)
-- Adult Kookaburra
(18876, 15649, 1, 1, -1, 55084), -- Sealed Moirai Leather Breastplate Piece
(18876, 1894, 1, 1, -1, 602057), -- Crafted Leather
(18876, 15782, 1, 1, -1, 10871), -- Recipe - Sealed Moirai Leather Legging (60%) 
(18876, 57, 4199, 8477, 0, 700000), -- Adena
(18876, 15698, 1, 1, 1, 33.4696), -- Sealed Moirai Leather Breastplate 
(18876, 15649, 1, 1, 1, 13566.5304), -- Sealed Moirai Leather Breastplate Piece
(18876, 1879, 1, 1, 2, 100624.99375), -- Cokes
(18876, 1885, 1, 1, 2, 50312.395), -- High-Grade Suede
(18876, 9628, 1, 1, 2, 4735.35375), -- Leonard
(18876, 9630, 1, 1, 2, 3177.685), -- Orichalcum
(18876, 9629, 1, 1, 2, 2624.91125), -- Adamantine
(18876, 5550, 1, 1, 2, 8049.95875), -- Durable Metal Plate
(18876, 1890, 1, 1, 2, 9217.44625), -- Mithril Alloy
(18876, 1888, 1, 1, 2, 18295.5275), -- Synthetic Cokes
(18876, 17030, 1, 1, 2, 1006.32125), -- Forgotten Scroll - Create Item Lv 10
(18876, 9555, 1, 1, 2, 120.82375), -- Wind Crystal
(18876, 10483, 1, 1, 2, 4192.7675), -- Life Stone - Level 82
(18876, 10484, 1, 1, 2, 1048.09), -- Mid-Grade Life Stone - Level 82
(18876, 10485, 1, 1, 2, 104.7275), -- High-Grade Life Stone - Level 82
(18876, 15779, 1, 1, 2, 238.99875), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
-- Full Grown Kookaburra
(18878, 10397, 1, 1, -1, 2321), -- Icarus Sawsword Piece
(18878, 10399, 1, 1, -1, 2321), -- Icarus Spirit Piece
(18878, 10400, 1, 1, -1, 2313), -- Icarus Heavy Arms Piece
(18878, 9628, 1, 1, -1, 42455), -- Leonard
(18878, 10373, 1, 1, -1, 349), -- Recipe - Icarus Sawsword (60%)
(18878, 10375, 1, 1, -1, 349), -- Recipe - Icarus Spirit (60%)
(18878, 10376, 1, 1, -1, 349), -- Recipe - Icarus Heavy Arms (60%)
(18878, 15801, 1, 1, -1, 4640), -- Recipe - Sealed Vesper Gauntlet (60%) 
(18878, 15802, 1, 1, -1, 4640), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(18878, 15803, 1, 1, -1, 4640), -- Recipe - Sealed Vesper Gloves (60%) 
(18878, 57, 4416, 8914, 0, 700000), -- Adena
(18878, 10215, 1, 1, 1, 1.145718), -- Icarus Sawsword
(18878, 10217, 1, 1, 1, 1.145718), -- Icarus Spirit
(18878, 10397, 1, 1, 1, 380.590546), -- Icarus Sawsword Piece
(18878, 10399, 1, 1, 1, 380.590546), -- Icarus Spirit Piece
(18878, 14109, 1, 1, 1, 15.212589), -- Sealed Vesper Gauntlet
(18878, 14113, 1, 1, 1, 15.212589), -- Sealed Vesper Leather Gloves
(18878, 14116, 1, 1, 1, 15.212589), -- Sealed Vesper Gloves
(18878, 15667, 1, 1, 1, 6802.615757), -- Sealed Vesper Gauntlet Piece
(18878, 15671, 1, 1, 1, 6802.615757), -- Sealed Vesper Leather Gloves Piece
(18878, 15674, 1, 1, 1, 6802.658191), -- Sealed Vesper Gloves Piece
(18878, 1879, 1, 1, 2, 105812.854197), -- Cokes
(18878, 1885, 1, 1, 2, 52906.320585), -- High-Grade Suede
(18878, 9628, 1, 1, 2, 4979.506125), -- Leonard
(18878, 9630, 1, 1, 2, 3341.541522), -- Orichalcum
(18878, 9629, 1, 1, 2, 2760.403866), -- Adamantine
(18878, 5550, 1, 1, 2, 8465.053899), -- Durable Metal Plate
(18878, 1890, 1, 1, 2, 9692.7285), -- Mithril Alloy
(18878, 1888, 1, 1, 2, 19238.681397), -- Synthetic Cokes
(18878, 10483, 1, 1, 2, 4408.806792), -- Life Stone - Level 82
(18878, 10484, 1, 1, 2, 1102.201698), -- Mid-Grade Life Stone - Level 82
(18878, 10485, 1, 1, 2, 110.134959), -- High-Grade Life Stone - Level 82
(18878, 10373, 1, 1, 2, 40.901184), -- Recipe - Icarus Sawsword (60%)
(18878, 10375, 1, 1, 2, 40.901184), -- Recipe - Icarus Spirit (60%)
(18878, 9553, 1, 1, 2, 126.964092), -- Water Crystal
-- Baby Alpine Cougar
(18880, 15772, 1, 1, -1, 13393), -- Sealed Moirai Ring Gem
(18880, 15773, 1, 1, -1, 7527), -- Sealed Moirai Earring Gem
(18880, 15774, 1, 1, -1, 6495), -- Sealed Moirai Necklace Gem
(18880, 15812, 1, 1, -1, 1772), -- Recipe - Sealed Moirai Ring (70%) 
(18880, 15813, 1, 1, -1, 1181), -- Recipe - Sealed Moirai Earring (70%) 
(18880, 15814, 1, 1, -1, 886), -- Recipe - Sealed Moirai Necklace (70%) 
(18880, 57, 475, 959, 0, 700000), -- Adena
(18880, 15766, 1, 1, 1, 5.818546), -- Sealed Moirai Ring
(18880, 15767, 1, 1, 1, 3.877526), -- Sealed Moirai Earring
(18880, 15768, 1, 1, 1, 2.907016), -- Sealed Moirai Necklace
(18880, 15772, 1, 1, 1, 2199.058296), -- Sealed Moirai Ring Gem
(18880, 15773, 1, 1, 1, 1235.906116), -- Sealed Moirai Earring Gem
(18880, 15774, 1, 1, 1, 1066.4325), -- Sealed Moirai Necklace Gem
(18880, 9573, 1, 1, 2, 2214.118422), -- Life Stone - Level 80
(18880, 9574, 1, 1, 2, 553.528194), -- Mid-Grade Life Stone - Level 80
(18880, 9575, 1, 1, 2, 55.353384), -- High-Grade Life Stone - Level 80
-- Young Cougar
(18881, 15654, 1, 1, -1, 12579), -- Sealed Moirai Gauntlet Piece
(18881, 15655, 1, 1, -1, 12579), -- Sealed Moirai Leather Gloves Piece
(18881, 15656, 1, 1, -1, 12579), -- Sealed Moirai Gloves Piece
(18881, 15657, 1, 1, -1, 12579), -- Sealed Moirai Boots Piece
(18881, 15658, 1, 1, -1, 12579), -- Sealed Moirai Leather Boots Piece
(18881, 15659, 1, 1, -1, 12579), -- Sealed Moirai Shoes Piece
(18881, 960, 1, 1, -1, 564), -- Scroll: Enchant Armor (S-Grade)
(18881, 15784, 1, 1, -1, 1674), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18881, 15785, 1, 1, -1, 1674), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18881, 15786, 1, 1, -1, 1674), -- Recipe - Sealed Moirai Gloves (60%) 
(18881, 15787, 1, 1, -1, 1674), -- Recipe - Sealed Moirai Boots (60%) 
(18881, 15788, 1, 1, -1, 1674), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18881, 15789, 1, 1, -1, 1674), -- Recipe - Sealed Moirai Shoes (60%) 
(18881, 57, 1494, 3016, 0, 700000), -- Adena
(18881, 15706, 1, 1, 1, 11.90856), -- Sealed Moirai Boots 
(18881, 15707, 1, 1, 1, 11.90856), -- Sealed Moirai Leather Boots 
(18881, 15708, 1, 1, 1, 11.90856), -- Sealed Moirai Shoes 
(18881, 15657, 1, 1, 1, 4473.433744), -- Sealed Moirai Boots Piece
(18881, 15658, 1, 1, 1, 4473.433744), -- Sealed Moirai Leather Boots Piece
(18881, 15659, 1, 1, 1, 4473.406832), -- Sealed Moirai Shoes Piece
(18881, 1895, 1, 1, 2, 107409.360588), -- Metallic Fiber
(18881, 4040, 1, 1, 2, 7518.687308), -- Mold Lubricant
(18881, 9628, 1, 1, 2, 2948.545938), -- Leonard
(18881, 9630, 1, 1, 2, 1978.647362), -- Orichalcum
(18881, 9573, 1, 1, 2, 2610.610778), -- Life Stone - Level 80
(18881, 9574, 1, 1, 2, 652.683528), -- Mid-Grade Life Stone - Level 80
(18881, 9575, 1, 1, 2, 65.243686), -- High-Grade Life Stone - Level 80
(18881, 960, 1, 1, 2, 150.220812), -- Scroll: Enchant Armor (S-Grade)
-- Adult Cougar
(18883, 15648, 1, 1, -1, 20354), -- Sealed Moirai Breastplate Piece
(18883, 15651, 1, 1, -1, 34113), -- Sealed Moirai Gaiter Piece
(18883, 959, 1, 1, -1, 343), -- Scroll: Enchant Weapon (S-Grade)
(18883, 9630, 1, 1, -1, 45154), -- Orichalcum
(18883, 15778, 1, 1, -1, 2548), -- Recipe - Sealed Moirai Breastplate (60%) 
(18883, 15781, 1, 1, -1, 4076), -- Recipe - Sealed Moirai Gaiter (60%) 
(18883, 57, 4199, 8477, 0, 700000), -- Adena
(18883, 15697, 1, 1, 1, 25.102341), -- Sealed Moirai Breastplate 
(18883, 15648, 1, 1, 1, 10027.897659), -- Sealed Moirai Breastplate Piece
(18883, 1879, 1, 1, 2, 100625.187219), -- Cokes
(18883, 1885, 1, 1, 2, 50312.695455), -- High-Grade Suede
(18883, 9628, 1, 1, 2, 4735.408368), -- Leonard
(18883, 9630, 1, 1, 2, 3177.5796), -- Orichalcum
(18883, 9629, 1, 1, 2, 2624.965917), -- Adamantine
(18883, 5550, 1, 1, 2, 8050.072011), -- Durable Metal Plate
(18883, 1890, 1, 1, 2, 9217.628823), -- Mithril Alloy
(18883, 1888, 1, 1, 2, 18295.52562), -- Synthetic Cokes
(18883, 17030, 1, 1, 2, 1006.23354), -- Forgotten Scroll - Create Item Lv 10
(18883, 9555, 1, 1, 2, 120.788763), -- Wind Crystal
(18883, 10483, 1, 1, 2, 4192.775544), -- Life Stone - Level 82
(18883, 10484, 1, 1, 2, 1048.193886), -- Mid-Grade Life Stone - Level 82
(18883, 10485, 1, 1, 2, 104.900865), -- High-Grade Life Stone - Level 82
(18883, 15778, 1, 1, 2, 179.044389), -- Recipe - Sealed Moirai Breastplate (60%) 
-- Full Grown Cougar
(18885, 10404, 1, 1, -1, 2892), -- Icarus Hall Piece
(18885, 10402, 1, 1, -1, 2892), -- Icarus Hammer Piece
(18885, 9628, 1, 1, -1, 53068), -- Leonard
(18885, 10380, 1, 1, -1, 436), -- Recipe - Icarus Hall (60%)
(18885, 10378, 1, 1, -1, 436), -- Recipe - Icarus Hammer (60%)
(18885, 15804, 1, 1, -1, 5799), -- Recipe - Sealed Vesper Boots (60%) 
(18885, 15805, 1, 1, -1, 5799), -- Recipe - Sealed Vesper Leather Boots (60%) 
(18885, 15806, 1, 1, -1, 5799), -- Recipe - Sealed Vesper Shoes (60%) 
(18885, 57, 4416, 8914, 0, 700000), -- Adena
(18885, 10222, 1, 1, 1, 1.432145), -- Icarus Hall
(18885, 10404, 1, 1, 1, 474.144151), -- Icarus Hall Piece
(18885, 14110, 1, 1, 1, 19.00847), -- Sealed Vesper Boots
(18885, 14114, 1, 1, 1, 19.00847), -- Sealed Vesper Leather Boots
(18885, 14117, 1, 1, 1, 19.00847), -- Sealed Vesper Shoes
(18885, 15668, 1, 1, 1, 8502.124085), -- Sealed Vesper Boots Piece
(18885, 15672, 1, 1, 1, 8502.124085), -- Sealed Vesper Leather Boots Piece
(18885, 15675, 1, 1, 1, 8502.150124), -- Sealed Vesper Shoes Piece
(18885, 1879, 1, 1, 2, 113952.39222), -- Cokes
(18885, 1885, 1, 1, 2, 56976.19611), -- High-Grade Suede
(18885, 9628, 1, 1, 2, 5362.44123), -- Leonard
(18885, 9630, 1, 1, 2, 3598.58593), -- Orichalcum
(18885, 9629, 1, 1, 2, 2972.6352), -- Adamantine
(18885, 5550, 1, 1, 2, 9116.08128), -- Durable Metal Plate
(18885, 1890, 1, 1, 2, 10438.39933), -- Mithril Alloy
(18885, 1888, 1, 1, 2, 20718.53336), -- Synthetic Cokes
(18885, 10483, 1, 1, 2, 4747.959), -- Life Stone - Level 82
(18885, 10484, 1, 1, 2, 1186.98975), -- Mid-Grade Life Stone - Level 82
(18885, 10485, 1, 1, 2, 118.81366), -- High-Grade Life Stone - Level 82
(18885, 10380, 1, 1, 2, 44.03904), -- Recipe - Icarus Hall (60%)
(18885, 9553, 1, 1, 2, 136.93389), -- Water Crystal
-- Baby Alpine Buffalo
(18887, 15772, 1, 1, -1, 14529), -- Sealed Moirai Ring Gem
(18887, 15773, 1, 1, -1, 8165), -- Sealed Moirai Earring Gem
(18887, 15774, 1, 1, -1, 7046), -- Sealed Moirai Necklace Gem
(18887, 15812, 1, 1, -1, 1922), -- Recipe - Sealed Moirai Ring (70%) 
(18887, 15813, 1, 1, -1, 1281), -- Recipe - Sealed Moirai Earring (70%) 
(18887, 15814, 1, 1, -1, 961), -- Recipe - Sealed Moirai Necklace (70%) 
(18887, 57, 511, 1045, 0, 700000), -- Adena
(18887, 15766, 1, 1, 1, 6.312233), -- Sealed Moirai Ring
(18887, 15767, 1, 1, 1, 4.206523), -- Sealed Moirai Earring
(18887, 15768, 1, 1, 1, 3.153668), -- Sealed Moirai Necklace
(18887, 15772, 1, 1, 1, 2385.642108), -- Sealed Moirai Ring Gem
(18887, 15773, 1, 1, 1, 1340.769218), -- Sealed Moirai Earring Gem
(18887, 15774, 1, 1, 1, 1156.91625), -- Sealed Moirai Necklace Gem
(18887, 9573, 1, 1, 2, 1200.99072), -- Life Stone - Level 80
(18887, 9574, 1, 1, 2, 300.24768), -- Mid-Grade Life Stone - Level 80
(18887, 9575, 1, 1, 2, 30.024325), -- High-Grade Life Stone - Level 80
(18887, 15812, 1, 1, 2, 315.58877), -- Recipe - Sealed Moirai Ring (70%) 
(18887, 15813, 1, 1, 2, 210.36741), -- Recipe - Sealed Moirai Earring (70%) 
(18887, 15814, 1, 1, 2, 157.781095), -- Recipe - Sealed Moirai Necklace (70%) 
-- Young Buffalo
(18888, 15654, 1, 1, -1, 13453), -- Sealed Moirai Gauntlet Piece
(18888, 15655, 1, 1, -1, 13453), -- Sealed Moirai Leather Gloves Piece
(18888, 15656, 1, 1, -1, 13453), -- Sealed Moirai Gloves Piece
(18888, 15657, 1, 1, -1, 13453), -- Sealed Moirai Boots Piece
(18888, 15658, 1, 1, -1, 13453), -- Sealed Moirai Leather Boots Piece
(18888, 15659, 1, 1, -1, 13453), -- Sealed Moirai Shoes Piece
(18888, 960, 1, 1, -1, 603), -- Scroll: Enchant Armor (S-Grade)
(18888, 15784, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18888, 15785, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18888, 15786, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Gloves (60%) 
(18888, 15787, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Boots (60%) 
(18888, 15788, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18888, 15789, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Shoes (60%) 
(18888, 57, 1585, 3238, 0, 700000), -- Adena
(18888, 15703, 1, 1, 1, 12.736035), -- Sealed Moirai Gauntlet 
(18888, 15704, 1, 1, 1, 12.736035), -- Sealed Moirai Leather Gloves 
(18888, 15705, 1, 1, 1, 12.736035), -- Sealed Moirai Gloves 
(18888, 15654, 1, 1, 1, 4784.273559), -- Sealed Moirai Gauntlet Piece
(18888, 15655, 1, 1, 1, 4784.273559), -- Sealed Moirai Leather Gloves Piece
(18888, 15656, 1, 1, 1, 4784.244777), -- Sealed Moirai Gloves Piece
(18888, 1895, 1, 1, 2, 70689.89797), -- Metallic Fiber
(18888, 4040, 1, 1, 2, 4948.314395), -- Mold Lubricant
(18888, 9628, 1, 1, 2, 1940.49271), -- Leonard
(18888, 9630, 1, 1, 2, 1302.1662), -- Orichalcum
(18888, 9573, 1, 1, 2, 1718.16357), -- Life Stone - Level 80
(18888, 9574, 1, 1, 2, 429.499475), -- Mid-Grade Life Stone - Level 80
(18888, 9575, 1, 1, 2, 42.991365), -- High-Grade Life Stone - Level 80
(18888, 15784, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18888, 15785, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18888, 15786, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Gloves (60%) 
(18888, 15787, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Boots (60%) 
(18888, 15788, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18888, 15789, 1, 1, 2, 293.981415), -- Recipe - Sealed Moirai Shoes (60%) 
-- Adult Buffalo
(18890, 15653, 1, 1, -1, 95975), -- Sealed Moirai Stockings Piece
(18890, 959, 1, 1, -1, 737), -- Scroll: Enchant Weapon (S-Grade)
(18890, 15783, 1, 1, -1, 11675), -- Recipe - Sealed Moirai Stockings (60%) 
(18890, 57, 4472, 9140, 0, 700000), -- Adena
(18890, 15699, 1, 1, 1, 35.942905), -- Sealed Moirai Tunic 
(18890, 15650, 1, 1, 1, 14569.057095), -- Sealed Moirai Tunic Piece
(18890, 1879, 1, 1, 2, 108064.57611), -- Cokes
(18890, 1885, 1, 1, 2, 54032.178648), -- High-Grade Suede
(18890, 9628, 1, 1, 2, 5085.456174), -- Leonard
(18890, 9630, 1, 1, 2, 3412.623144), -- Orichalcum
(18890, 9629, 1, 1, 2, 2818.980762), -- Adamantine
(18890, 5550, 1, 1, 2, 8645.122326), -- Durable Metal Plate
(18890, 1890, 1, 1, 2, 9898.926546), -- Mithril Alloy
(18890, 1888, 1, 1, 2, 19648.184316), -- Synthetic Cokes
(18890, 17030, 1, 1, 2, 1080.722346), -- Forgotten Scroll - Create Item Lv 10
(18890, 9556, 1, 1, 2, 129.756702), -- Dark Crystal
(18890, 10483, 1, 1, 2, 4502.754492), -- Life Stone - Level 82
(18890, 10484, 1, 1, 2, 1125.579216), -- Mid-Grade Life Stone - Level 82
(18890, 10485, 1, 1, 2, 112.470396), -- High-Grade Life Stone - Level 82
(18890, 15780, 1, 1, 2, 256.668822), -- Recipe - Sealed Moirai Tunic (60%) 
-- Full Grown Buffalo
(18892, 10403, 1, 1, -1, 6197), -- Icarus Hand Piece
(18892, 1894, 1, 1, -1, 508785), -- Crafted Leather
(18892, 10379, 1, 1, -1, 935), -- Recipe - Icarus Hand (60%)
(18892, 15819, 1, 1, -1, 1011), -- Recipe - Vesper Fighter (60%)
(18892, 57, 4692, 9589, 0, 700000), -- Adena
(18892, 10221, 1, 1, 1, 2.455272), -- Icarus Hand
(18892, 10403, 1, 1, 1, 814.193856), -- Icarus Hand Piece
(18892, 13457, 1, 1, 1, 2.657448), -- Vesper Cutter
(18892, 13461, 1, 1, 1, 2.657448), -- Vesper Fighter
(18892, 15638, 1, 1, 1, 1122.035976), -- Vesper Fighter Piece
(18892, 1879, 1, 1, 2, 132278.345098), -- Cokes
(18892, 1885, 1, 1, 2, 66139.172549), -- High-Grade Suede
(18892, 9628, 1, 1, 2, 6224.853907), -- Leonard
(18892, 9630, 1, 1, 2, 4177.222102), -- Orichalcum
(18892, 9629, 1, 1, 2, 3450.771832), -- Adamantine
(18892, 5550, 1, 1, 2, 10582.225032), -- Durable Metal Plate
(18892, 1890, 1, 1, 2, 12117.084064), -- Mithril Alloy
(18892, 1888, 1, 1, 2, 24050.559818), -- Synthetic Cokes
(18892, 10483, 1, 1, 2, 5511.708587), -- Life Stone - Level 82
(18892, 10484, 1, 1, 2, 1377.860622), -- Mid-Grade Life Stone - Level 82
(18892, 10485, 1, 1, 2, 137.839282), -- High-Grade Life Stone - Level 82
(18892, 10379, 1, 1, 2, 51.357107), -- Recipe - Icarus Hand (60%)
-- Baby Alpine Grendel
(18894, 15772, 1, 1, -1, 14529), -- Sealed Moirai Ring Gem
(18894, 15773, 1, 1, -1, 8165), -- Sealed Moirai Earring Gem
(18894, 15774, 1, 1, -1, 7046), -- Sealed Moirai Necklace Gem
(18894, 15812, 1, 1, -1, 1922), -- Recipe - Sealed Moirai Ring (70%) 
(18894, 15813, 1, 1, -1, 1281), -- Recipe - Sealed Moirai Earring (70%) 
(18894, 15814, 1, 1, -1, 961), -- Recipe - Sealed Moirai Necklace (70%) 
(18894, 57, 511, 1045, 0, 700000), -- Adena
(18894, 15766, 1, 1, 1, 6.312233), -- Sealed Moirai Ring
(18894, 15767, 1, 1, 1, 4.206523), -- Sealed Moirai Earring
(18894, 15768, 1, 1, 1, 3.153668), -- Sealed Moirai Necklace
(18894, 15772, 1, 1, 1, 2385.642108), -- Sealed Moirai Ring Gem
(18894, 15773, 1, 1, 1, 1340.769218), -- Sealed Moirai Earring Gem
(18894, 15774, 1, 1, 1, 1156.91625), -- Sealed Moirai Necklace Gem
(18894, 9573, 1, 1, 2, 1200.99072), -- Life Stone - Level 80
(18894, 9574, 1, 1, 2, 300.24768), -- Mid-Grade Life Stone - Level 80
(18894, 9575, 1, 1, 2, 30.024325), -- High-Grade Life Stone - Level 80
(18894, 15812, 1, 1, 2, 315.58877), -- Recipe - Sealed Moirai Ring (70%) 
(18894, 15813, 1, 1, 2, 210.36741), -- Recipe - Sealed Moirai Earring (70%) 
(18894, 15814, 1, 1, 2, 157.781095), -- Recipe - Sealed Moirai Necklace (70%) 
-- Young Grendel
(18895, 15654, 1, 1, -1, 13453), -- Sealed Moirai Gauntlet Piece
(18895, 15655, 1, 1, -1, 13453), -- Sealed Moirai Leather Gloves Piece
(18895, 15656, 1, 1, -1, 13453), -- Sealed Moirai Gloves Piece
(18895, 15657, 1, 1, -1, 13453), -- Sealed Moirai Boots Piece
(18895, 15658, 1, 1, -1, 13453), -- Sealed Moirai Leather Boots Piece
(18895, 15659, 1, 1, -1, 13453), -- Sealed Moirai Shoes Piece
(18895, 960, 1, 1, -1, 603), -- Scroll: Enchant Armor (S-Grade)
(18895, 15784, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18895, 15785, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18895, 15786, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Gloves (60%) 
(18895, 15787, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Boots (60%) 
(18895, 15788, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18895, 15789, 1, 1, -1, 1790), -- Recipe - Sealed Moirai Shoes (60%) 
(18895, 57, 1585, 3238, 0, 700000), -- Adena
(18895, 15706, 1, 1, 1, 12.736035), -- Sealed Moirai Boots 
(18895, 15707, 1, 1, 1, 12.736035), -- Sealed Moirai Leather Boots 
(18895, 15708, 1, 1, 1, 12.736035), -- Sealed Moirai Shoes 
(18895, 15657, 1, 1, 1, 4784.273559), -- Sealed Moirai Boots Piece
(18895, 15658, 1, 1, 1, 4784.273559), -- Sealed Moirai Leather Boots Piece
(18895, 15659, 1, 1, 1, 4784.244777), -- Sealed Moirai Shoes Piece
(18895, 1895, 1, 1, 2, 70689.89797), -- Metallic Fiber
(18895, 4040, 1, 1, 2, 4948.314395), -- Mold Lubricant
(18895, 9628, 1, 1, 2, 1940.49271), -- Leonard
(18895, 9630, 1, 1, 2, 1302.1662), -- Orichalcum
(18895, 9573, 1, 1, 2, 1718.16357), -- Life Stone - Level 80
(18895, 9574, 1, 1, 2, 429.499475), -- Mid-Grade Life Stone - Level 80
(18895, 9575, 1, 1, 2, 42.991365), -- High-Grade Life Stone - Level 80
(18895, 15784, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18895, 15785, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18895, 15786, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Gloves (60%) 
(18895, 15787, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Boots (60%) 
(18895, 15788, 1, 1, 2, 293.89858), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18895, 15789, 1, 1, 2, 293.981415), -- Recipe - Sealed Moirai Shoes (60%) 
-- Adult Grendel
(18897, 10398, 1, 1, -1, 7900), -- Icarus Disperser Piece
(18897, 959, 1, 1, -1, 737), -- Scroll: Enchant Weapon (S-Grade)
(18897, 10374, 1, 1, -1, 1188), -- Recipe - Icarus Disperser (60%)
(18897, 57, 4472, 9140, 0, 700000), -- Adena
(18897, 10216, 1, 1, 1, 5.849098), -- Icarus Disperser
(18897, 10398, 1, 1, 1, 1945.150902), -- Icarus Disperser Piece
(18897, 1879, 1, 1, 2, 108064.41565), -- Cokes
(18897, 1885, 1, 1, 2, 54032.207825), -- High-Grade Suede
(18897, 9628, 1, 1, 2, 5085.487136), -- Leonard
(18897, 9630, 1, 1, 2, 3412.548989), -- Orichalcum
(18897, 9629, 1, 1, 2, 2819.052704), -- Adamantine
(18897, 5550, 1, 1, 2, 8645.153252), -- Durable Metal Plate
(18897, 1890, 1, 1, 2, 9899.037116), -- Mithril Alloy
(18897, 1888, 1, 1, 2, 19648.115318), -- Synthetic Cokes
(18897, 17030, 1, 1, 2, 1080.753456), -- Forgotten Scroll - Create Item Lv 10
(18897, 9556, 1, 1, 2, 129.629207), -- Dark Crystal
(18897, 10483, 1, 1, 2, 4502.702202), -- Life Stone - Level 82
(18897, 10484, 1, 1, 2, 1125.566251), -- Mid-Grade Life Stone - Level 82
(18897, 10485, 1, 1, 2, 112.578485), -- High-Grade Life Stone - Level 82
(18897, 10374, 1, 1, 2, 41.752409), -- Recipe - Icarus Disperser (60%)
-- Full Grown Grendel
(18899, 10405, 1, 1, -1, 4957), -- Icarus Spitter Piece
(18899, 1894, 1, 1, -1, 407028), -- Crafted Leather
(18899, 9628, 1, 1, -1, 90983), -- Leonard
(18899, 10381, 1, 1, -1, 748), -- Recipe - Icarus Spitter (60%)
(18899, 15825, 1, 1, -1, 809), -- Recipe - Vesper Thrower (60%)
(18899, 57, 4692, 9589, 0, 700000), -- Adena
(18899, 10223, 1, 1, 1, 3.069664), -- Icarus Spitter
(18899, 10405, 1, 1, 1, 1017.466528), -- Icarus Spitter Piece
(18899, 13467, 1, 1, 1, 3.321396), -- Vesper Thrower
(18899, 15644, 1, 1, 1, 1420.142412), -- Vesper Thrower Piece
(18899, 1879, 1, 1, 2, 132278.345098), -- Cokes
(18899, 1885, 1, 1, 2, 66139.172549), -- High-Grade Suede
(18899, 9628, 1, 1, 2, 6224.853907), -- Leonard
(18899, 9630, 1, 1, 2, 4177.222102), -- Orichalcum
(18899, 9629, 1, 1, 2, 3450.771832), -- Adamantine
(18899, 5550, 1, 1, 2, 10582.225032), -- Durable Metal Plate
(18899, 1890, 1, 1, 2, 12117.084064), -- Mithril Alloy
(18899, 1888, 1, 1, 2, 24050.559818), -- Synthetic Cokes
(18899, 10483, 1, 1, 2, 5511.708587), -- Life Stone - Level 82
(18899, 10484, 1, 1, 2, 1377.860622), -- Mid-Grade Life Stone - Level 82
(18899, 10485, 1, 1, 2, 137.839282), -- High-Grade Life Stone - Level 82
(18899, 10381, 1, 1, 2, 51.357107), -- Recipe - Icarus Spitter (60%)
-- Farm Bandit
(18906, 15654, 1, 1, -1, 5826), -- Sealed Moirai Gauntlet Piece
(18906, 15655, 1, 1, -1, 5826), -- Sealed Moirai Leather Gloves Piece
(18906, 15656, 1, 1, -1, 5826), -- Sealed Moirai Gloves Piece
(18906, 15657, 1, 1, -1, 5826), -- Sealed Moirai Boots Piece
(18906, 15658, 1, 1, -1, 5826), -- Sealed Moirai Leather Boots Piece
(18906, 15659, 1, 1, -1, 5826), -- Sealed Moirai Shoes Piece
(18906, 9630, 1, 1, -1, 3434), -- Orichalcum
(18906, 15784, 1, 1, -1, 775), -- Recipe - Sealed Moirai Gauntlet (60%) 
(18906, 15785, 1, 1, -1, 775), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(18906, 15786, 1, 1, -1, 775), -- Recipe - Sealed Moirai Gloves (60%) 
(18906, 15787, 1, 1, -1, 775), -- Recipe - Sealed Moirai Boots (60%) 
(18906, 15788, 1, 1, -1, 775), -- Recipe - Sealed Moirai Leather Boots (60%) 
(18906, 15789, 1, 1, -1, 775), -- Recipe - Sealed Moirai Shoes (60%) 
(18906, 57, 686, 1402, 0, 700000), -- Adena
(18906, 15703, 1, 1, 1, 2.757638), -- Sealed Moirai Gauntlet 
(18906, 15704, 1, 1, 1, 2.757638), -- Sealed Moirai Leather Gloves 
(18906, 15705, 1, 1, 1, 2.757638), -- Sealed Moirai Gloves 
(18906, 15706, 1, 1, 1, 2.757638), -- Sealed Moirai Boots 
(18906, 15707, 1, 1, 1, 2.757638), -- Sealed Moirai Leather Boots 
(18906, 15708, 1, 1, 1, 2.757638), -- Sealed Moirai Shoes 
(18906, 15654, 1, 1, 1, 1037.071536), -- Sealed Moirai Gauntlet Piece
(18906, 15655, 1, 1, 1, 1037.071536), -- Sealed Moirai Leather Gloves Piece
(18906, 15656, 1, 1, 1, 1037.071536), -- Sealed Moirai Gloves Piece
(18906, 15657, 1, 1, 1, 1037.071536), -- Sealed Moirai Boots Piece
(18906, 15658, 1, 1, 1, 1037.071536), -- Sealed Moirai Leather Boots Piece
(18906, 15659, 1, 1, 1, 1037.096492), -- Sealed Moirai Shoes Piece
(18906, 1879, 1, 1, 2, 29016.503055), -- Cokes
(18906, 1885, 1, 1, 2, 14508.227475), -- High-Grade Suede
(18906, 9628, 1, 1, 2, 1365.460425), -- Leonard
(18906, 9630, 1, 1, 2, 916.30404), -- Orichalcum
(18906, 9629, 1, 1, 2, 756.932175), -- Adamantine
(18906, 10483, 1, 1, 2, 1209.022965), -- Life Stone - Level 82
(18906, 10484, 1, 1, 2, 302.243715), -- Mid-Grade Life Stone - Level 82
(18906, 10485, 1, 1, 2, 30.30615), -- High-Grade Life Stone - Level 82
-- Beast Devourer
(18907, 15645, 1, 1, -1, 5317), -- Sealed Moirai Helmet Piece
(18907, 15646, 1, 1, -1, 5317), -- Sealed Moirai Leather Helmet Piece
(18907, 15647, 1, 1, -1, 5317), -- Sealed Moirai Circlet Piece
(18907, 15693, 1, 1, -1, 9532), -- Sealed Moirai Shield Piece
(18907, 15692, 1, 1, -1, 9532), -- Sealed Moirai Sigil Piece
(18907, 15775, 1, 1, -1, 710), -- Recipe - Sealed Moirai Helmet (60%) 
(18907, 15776, 1, 1, -1, 710), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(18907, 15777, 1, 1, -1, 710), -- Recipe - Sealed Moirai Circlet (60%) 
(18907, 15791, 1, 1, -1, 1014), -- Recipe - Sealed Moirai Shield (60%) 
(18907, 15790, 1, 1, -1, 1014), -- Recipe - Sealed Moirai Sigil (60%) 
(18907, 57, 725, 1481, 0, 700000), -- Adena
(18907, 15694, 1, 1, 1, 2.330272), -- Sealed Moirai Helmet 
(18907, 15695, 1, 1, 1, 2.330272), -- Sealed Moirai Leather Helmet 
(18907, 15696, 1, 1, 1, 2.330272), -- Sealed Moirai Circlet 
(18907, 15710, 1, 1, 1, 3.333904), -- Sealed Moirai Shield 
(18907, 15709, 1, 1, 1, 3.333904), -- Sealed Moirai Sigil 
(18907, 15645, 1, 1, 1, 873.840464), -- Sealed Moirai Helmet Piece
(18907, 15646, 1, 1, 1, 873.840464), -- Sealed Moirai Leather Helmet Piece
(18907, 15647, 1, 1, 1, 873.840464), -- Sealed Moirai Circlet Piece
(18907, 15693, 1, 1, 1, 1566.409992), -- Sealed Moirai Shield Piece
(18907, 15692, 1, 1, 1, 1566.409992), -- Sealed Moirai Sigil Piece
(18907, 1879, 1, 1, 2, 30649.944283), -- Cokes
(18907, 1885, 1, 1, 2, 15324.946735), -- High-Grade Suede
(18907, 9628, 1, 1, 2, 1442.327005), -- Leonard
(18907, 9630, 1, 1, 2, 967.886024), -- Orichalcum
(18907, 9629, 1, 1, 2, 799.542555), -- Adamantine
(18907, 10483, 1, 1, 2, 1277.083129), -- Life Stone - Level 82
(18907, 10484, 1, 1, 2, 319.258079), -- Mid-Grade Life Stone - Level 82
(18907, 10485, 1, 1, 2, 32.01219), -- High-Grade Life Stone - Level 82
-- Sel Mahum Chef
(18908, 15492, 1, 2, 0, 250000), -- Sel Mahum Salmon Porridge
-- Solina Knights
(18909, 15667, 1, 1, -1, 8451), -- Sealed Vesper Gauntlet Piece
(18909, 15671, 1, 1, -1, 8451), -- Sealed Vesper Leather Gloves Piece
(18909, 15674, 1, 1, -1, 8451), -- Sealed Vesper Gloves Piece
(18909, 15668, 1, 1, -1, 8451), -- Sealed Vesper Boots Piece
(18909, 15672, 1, 1, -1, 8451), -- Sealed Vesper Leather Boots Piece
(18909, 15675, 1, 1, -1, 8451), -- Sealed Vesper Shoes Piece
(18909, 9630, 1, 1, -1, 5805), -- Orichalcum
(18909, 15801, 1, 1, -1, 945), -- Recipe - Sealed Vesper Gauntlet (60%) 
(18909, 15802, 1, 1, -1, 945), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(18909, 15803, 1, 1, -1, 945), -- Recipe - Sealed Vesper Gloves (60%) 
(18909, 15804, 1, 1, -1, 945), -- Recipe - Sealed Vesper Boots (60%) 
(18909, 15805, 1, 1, -1, 945), -- Recipe - Sealed Vesper Leather Boots (60%) 
(18909, 15806, 1, 1, -1, 945), -- Recipe - Sealed Vesper Shoes (60%) 
(18909, 57, 1170, 2361, 0, 700000), -- Adena
(18909, 14109, 1, 1, 1, 3.363252), -- Sealed Vesper Gauntlet
(18909, 14113, 1, 1, 1, 3.363252), -- Sealed Vesper Leather Gloves
(18909, 14116, 1, 1, 1, 3.363252), -- Sealed Vesper Gloves
(18909, 14110, 1, 1, 1, 3.363252), -- Sealed Vesper Boots
(18909, 14114, 1, 1, 1, 3.363252), -- Sealed Vesper Leather Boots
(18909, 14117, 1, 1, 1, 3.363252), -- Sealed Vesper Shoes
(18909, 15667, 1, 1, 1, 1503.473095), -- Sealed Vesper Gauntlet Piece
(18909, 15671, 1, 1, 1, 1503.473095), -- Sealed Vesper Leather Gloves Piece
(18909, 15674, 1, 1, 1, 1503.473095), -- Sealed Vesper Gloves Piece
(18909, 15668, 1, 1, 1, 1503.473095), -- Sealed Vesper Boots Piece
(18909, 15672, 1, 1, 1, 1503.473095), -- Sealed Vesper Leather Boots Piece
(18909, 15675, 1, 1, 1, 1503.455013), -- Sealed Vesper Shoes Piece
(18909, 1879, 1, 1, 2, 28026.766601), -- Cokes
(18909, 1885, 1, 1, 2, 14013.406965), -- High-Grade Suede
(18909, 9628, 1, 1, 2, 1318.917243), -- Leonard
(18909, 9630, 1, 1, 2, 885.0523), -- Orichalcum
(18909, 9629, 1, 1, 2, 731.138392), -- Adamantine
(18909, 9573, 1, 1, 2, 1167.795746), -- Life Stone - Level 80
(18909, 9574, 1, 1, 2, 291.925272), -- Mid-Grade Life Stone - Level 80
(18909, 9575, 1, 1, 2, 29.201993), -- High-Grade Life Stone - Level 80
(18909, 15801, 1, 1, 2, 144.116805), -- Recipe - Sealed Vesper Gauntlet (60%) 
(18909, 15802, 1, 1, 2, 144.116805), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(18909, 15803, 1, 1, 2, 144.116805), -- Recipe - Sealed Vesper Gloves (60%) 
(18909, 15804, 1, 1, 2, 144.116805), -- Recipe - Sealed Vesper Boots (60%) 
(18909, 15805, 1, 1, 2, 144.116805), -- Recipe - Sealed Vesper Leather Boots (60%) 
(18909, 15806, 1, 1, 2, 144.211463), -- Recipe - Sealed Vesper Shoes (60%) 
-- Solina Knight Captain
(18910, 15667, 1, 1, -1, 13541), -- Sealed Vesper Gauntlet Piece
(18910, 15671, 1, 1, -1, 13541), -- Sealed Vesper Leather Gloves Piece
(18910, 15674, 1, 1, -1, 13541), -- Sealed Vesper Gloves Piece
(18910, 15668, 1, 1, -1, 13541), -- Sealed Vesper Boots Piece
(18910, 15672, 1, 1, -1, 13541), -- Sealed Vesper Leather Boots Piece
(18910, 15675, 1, 1, -1, 13541), -- Sealed Vesper Shoes Piece
(18910, 15801, 1, 1, -1, 1515), -- Recipe - Sealed Vesper Gauntlet (60%) 
(18910, 15802, 1, 1, -1, 1515), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(18910, 15803, 1, 1, -1, 1515), -- Recipe - Sealed Vesper Gloves (60%) 
(18910, 15804, 1, 1, -1, 1515), -- Recipe - Sealed Vesper Boots (60%) 
(18910, 15805, 1, 1, -1, 1515), -- Recipe - Sealed Vesper Leather Boots (60%) 
(18910, 15806, 1, 1, -1, 1515), -- Recipe - Sealed Vesper Shoes (60%) 
(18910, 57, 1730, 3492, 0, 700000), -- Adena
(18910, 14109, 1, 1, 1, 4.974012), -- Sealed Vesper Gauntlet
(18910, 14113, 1, 1, 1, 4.974012), -- Sealed Vesper Leather Gloves
(18910, 14116, 1, 1, 1, 4.974012), -- Sealed Vesper Gloves
(18910, 14110, 1, 1, 1, 4.974012), -- Sealed Vesper Boots
(18910, 14114, 1, 1, 1, 4.974012), -- Sealed Vesper Leather Boots
(18910, 14117, 1, 1, 1, 4.974012), -- Sealed Vesper Shoes
(18910, 15667, 1, 1, 1, 2223.530445), -- Sealed Vesper Gauntlet Piece
(18910, 15671, 1, 1, 1, 2223.530445), -- Sealed Vesper Leather Gloves Piece
(18910, 15674, 1, 1, 1, 2223.530445), -- Sealed Vesper Gloves Piece
(18910, 15668, 1, 1, 1, 2223.530445), -- Sealed Vesper Boots Piece
(18910, 15672, 1, 1, 1, 2223.530445), -- Sealed Vesper Leather Boots Piece
(18910, 15675, 1, 1, 1, 2223.503703), -- Sealed Vesper Shoes Piece
(18910, 1895, 1, 1, 2, 142118.63211), -- Metallic Fiber
(18910, 4040, 1, 1, 2, 9948.240778), -- Mold Lubricant
(18910, 4042, 1, 1, 2, 8290.230872), -- Enria
(18910, 4043, 1, 1, 2, 16580.461744), -- Asofe
(18910, 10483, 1, 1, 2, 3454.202416), -- Life Stone - Level 82
(18910, 10484, 1, 1, 2, 863.550604), -- Mid-Grade Life Stone - Level 82
(18910, 10485, 1, 1, 2, 86.681476), -- High-Grade Life Stone - Level 82
-- Abbey Treasure Chest
(18911, 730, 1, 1, 0, 600000), -- Scroll: Enchant Armor (A-Grade)
(18911, 960, 1, 1, 0, 400000), -- Scroll: Enchant Armor (S-Grade)
-- Pavel Safety Device
(18917, 57, 361, 738, 0, 700000), -- Adena
(18917, 9546, 1, 1, 1, 1767.836869), -- Fire Stone
(18917, 9547, 1, 1, 1, 1767.836869), -- Water Stone
(18917, 9548, 1, 1, 1, 1767.836869), -- Earth Stone
(18917, 9549, 1, 1, 1, 1767.836869), -- Wind Stone
(18917, 9550, 1, 1, 1, 1767.836869), -- Dark Stone
(18917, 9551, 1, 1, 1, 1767.815655), -- Holy Stone
-- Abbey Treasure Chest
(18934, 960, 1, 1, 0, 1000000), -- Scroll: Enchant Armor (S-Grade)
-- Goblin
(20003, 1871, 1, 1, -1, 56617), -- Charcoal
(20003, 116, 1, 1, -1, 452932), -- Magic Ring
(20003, 1786, 1, 1, -1, 45293), -- Recipe: Broad Sword
(20003, 57, 30, 42, 0, 700000), -- Adena
(20003, 112, 1, 1, 1, 102689.2683), -- Apprentice's Earring
(20003, 118, 1, 1, 1, 76513.51329), -- Necklace of Magic
(20003, 116, 1, 1, 1, 156087.21841), -- Magic Ring
(20003, 1864, 1, 1, 2, 19511.058856), -- Stem
(20003, 1865, 1, 1, 2, 9755.529428), -- Varnish
(20003, 1866, 1, 1, 2, 6503.663956), -- Suede
(20003, 1873, 1, 1, 2, 3902.184976), -- Silver Nugget
(20003, 1868, 1, 1, 2, 19511.058856), -- Thread
(20003, 1788, 1, 1, 2, 7804.503928), -- Recipe: Bow
-- Imp
(20004, 1866, 1, 1, -1, 51827), -- Suede
(20004, 2006, 1, 1, -1, 5553), -- Willow Staff Head
(20004, 2005, 1, 1, -1, 5553), -- Broadsword Blade
(20004, 57, 41, 58, 0, 700000), -- Adena
(20004, 1122, 1, 1, 1, 6514.326819), -- Cotton Shoes
(20004, 1129, 1, 1, 1, 6514.326819), -- Crude Leather Shoes
(20004, 1119, 1, 1, 1, 6514.346362), -- Short Leather Gloves
(20004, 1871, 1, 1, 2, 15309), -- Charcoal
(20004, 1866, 1, 1, 2, 10205.989794), -- Suede
(20004, 1666, 1, 1, 2, 5103.010206), -- Recipe: Wooden Arrow
-- Imp Elder
(20005, 1060, 1, 1, -1, 216259), -- Lesser Healing Potion
(20005, 1866, 1, 1, -1, 64878), -- Suede
(20005, 1666, 1, 1, -1, 32439), -- Recipe: Wooden Arrow
(20005, 57, 51, 72, 0, 700000), -- Adena
(20005, 19, 1, 1, 1, 11732.93531), -- Small Shield
(20005, 42, 1, 1, 1, 8213.06469), -- Leather Cap
(20005, 1870, 1, 1, 2, 14372.907594), -- Coal
(20005, 1865, 1, 1, 2, 14372.907594), -- Varnish
(20005, 1789, 1, 1, 2, 2656.750109), -- Recipe: Cedar Staff
(20005, 17, 10, 30, 2, 71864.434703), -- Wooden Arrow
-- Orc Archer
(20006, 1060, 1, 1, -1, 285245), -- Lesser Healing Potion
(20006, 113, 1, 1, -1, 41407), -- Mystic's Earring
(20006, 2006, 1, 1, -1, 9169), -- Willow Staff Head
(20006, 57, 69, 94, 0, 700000), -- Adena
(20006, 14, 1, 1, 1, 789.869388), -- Bow
(20006, 2007, 1, 1, 1, 2708.130612), -- Bow Shaft
(20006, 1866, 1, 1, 2, 16851.42), -- Suede
(20006, 1871, 1, 1, 2, 25277.13), -- Charcoal
(20006, 2136, 1, 1, 2, 7434.45), -- Recipe: Cokes
-- Green Fungus
(20007, 1866, 1, 1, -1, 99228), -- Suede
(20007, 1122, 1, 1, -1, 63337), -- Cotton Shoes
(20007, 1875, 1, 1, -1, 9923), -- Stone of Purity
(20007, 57, 80, 108, 0, 700000), -- Adena
(20007, 22, 1, 1, 1, 4702.317224), -- Leather Shirt
(20007, 29, 1, 1, 1, 7515.682776), -- Leather Pants
(20007, 1864, 1, 1, 2, 58620.9312), -- Stem
(20007, 1869, 1, 1, 2, 29310.528), -- Iron Ore
(20007, 1796, 1, 1, 2, 36868.5408), -- Recipe: Leather Tunic
-- Felim Lizardman
(20008, 1793, 1, 1, -1, 16388), -- Recipe: Sword of Reflection
(20008, 1871, 1, 1, -1, 222882), -- Charcoal
(20008, 1870, 1, 1, -1, 222882), -- Coal
(20008, 57, 114, 168, 0, 700000), -- Adena
(20008, 2371, 1, 1, 1, 675.404192), -- Fist of Butcher
(20008, 255, 1, 1, 1, 316.595808), -- Fox Claw Gloves
(20008, 1870, 1, 1, 2, 43890.42816), -- Coal
(20008, 1865, 1, 1, 2, 43890.42816), -- Varnish
(20008, 1792, 1, 1, 2, 3227.14368), -- Recipe: Short Spear
-- Vuku Orc
(20009, 1870, 1, 1, -1, 222882), -- Coal
(20009, 43, 1, 1, -1, 14567), -- Wooden Helmet
(20009, 1831, 1, 1, -1, 594351), -- Antidote
(20009, 57, 114, 168, 0, 700000), -- Adena
(20009, 2371, 1, 1, 1, 675.404192), -- Fist of Butcher
(20009, 255, 1, 1, 1, 316.595808), -- Fox Claw Gloves
(20009, 1866, 1, 1, 2, 29260.278432), -- Suede
(20009, 1871, 1, 1, 2, 43890.417648), -- Charcoal
(20009, 736, 1, 1, 2, 21945.30392), -- Scroll of Escape
-- Felim Lizardman Scout
(20010, 1833, 1, 1, -1, 617635), -- Bandage
(20010, 1896, 1, 1, -1, 98141), -- Necklace of Anguish Chain
(20010, 1792, 1, 1, -1, 17030), -- Recipe: Short Spear
(20010, 57, 116, 177, 0, 700000), -- Adena
(20010, 271, 1, 1, 1, 658), -- Hunting Bow
(20010, 1871, 1, 1, 2, 45609.893496), -- Charcoal
(20010, 1866, 1, 1, 2, 30406.595664), -- Suede
(20010, 1798, 1, 1, 2, 44715.51084), -- Recipe: Leather Helmet
-- Vuku Orc Archer
(20011, 1792, 1, 1, -1, 17541), -- Recipe: Short Spear
(20011, 1921, 1, 1, -1, 153911), -- Leather Shoes Texture
(20011, 1867, 1, 1, -1, 318082), -- Animal Skin
(20011, 57, 120, 182, 0, 700000), -- Adena
(20011, 271, 1, 1, 1, 678), -- Hunting Bow
(20011, 1867, 1, 1, 2, 62637.833517), -- Animal Skin
(20011, 1872, 1, 1, 2, 62637.833517), -- Animal Bone
(20011, 1799, 1, 1, 2, 69597.332966), -- Recipe: Leather Gloves
-- Gora Werewolf
(20012, 1865, 1, 1, -1, 242317), -- Varnish
(20012, 734, 1, 1, -1, 40386), -- Haste Potion
(20012, 1897, 1, 1, -1, 57694), -- Necklace of Wisdom Chain
(20012, 57, 120, 187, 0, 700000), -- Adena
(20012, 1101, 1, 1, 1, 917.695683), -- Tunic of Devotion
(20012, 1104, 1, 1, 1, 1465.304317), -- Stockings of Devotion
(20012, 1865, 1, 1, 2, 35788.225837), -- Varnish
(20012, 1870, 1, 1, 2, 35788.225837), -- Coal
(20012, 1800, 1, 1, 2, 11254.203324), -- Recipe: Piece Bone Breastplate
(20012, 6035, 1, 1, 2, 2982.345002), -- Magic Haste Potion
-- Dryad
(20013, 1866, 1, 1, -1, 143423), -- Suede
(20013, 1896, 1, 1, -1, 91159), -- Necklace of Anguish Chain
(20013, 1922, 1, 1, -1, 54881), -- Leather Tunic Pattern
(20013, 57, 113, 160, 0, 700000), -- Adena
(20013, 9, 1, 1, 1, 203.6982), -- Cedar Staff
(20013, 2008, 1, 1, 1, 1648.6036), -- Cedar Staff Head
(20013, 154, 1, 1, 1, 203.6982), -- Dwarven Mace
(20013, 1870, 1, 1, 2, 42365.00815), -- Coal
(20013, 1865, 1, 1, 2, 42365.00815), -- Varnish
(20013, 1792, 1, 1, 2, 3114.9837), -- Recipe: Short Spear
-- Felim Lizardman Warrior
(20014, 2254, 1, 1, -1, 10085), -- Recipe: Composite Bow
(20014, 1867, 1, 1, -1, 328104), -- Animal Skin
(20014, 57, 120, 193, 0, 700000), -- Adena
(20014, 2, 1, 1, 1, 69.237785), -- Long Sword
(20014, 120, 1, 1, 1, 69.237785), -- Sword of Reflection
(20014, 2012, 1, 1, 1, 757.286645), -- Sword of Reflection Blade
(20014, 121, 1, 1, 1, 69.237785), -- Sword of Watershadow
(20014, 1867, 1, 1, 2, 64611.193477), -- Animal Skin
(20014, 1872, 1, 1, 2, 64611.193477), -- Animal Bone
(20014, 1800, 1, 1, 2, 15238.613046), -- Recipe: Piece Bone Breastplate
-- Marsh Zombie
(20015, 1798, 1, 1, -1, 237113), -- Recipe: Leather Helmet
(20015, 1871, 1, 1, -1, 241855), -- Charcoal
(20015, 1864, 1, 1, -1, 483710), -- Stem
(20015, 57, 127, 180, 0, 700000), -- Adena
(20015, 9, 1, 1, 1, 228.962325), -- Cedar Staff
(20015, 2008, 1, 1, 1, 1853.07535), -- Cedar Staff Head
(20015, 154, 1, 1, 1, 228.962325), -- Dwarven Mace
(20015, 1864, 1, 1, 2, 95253.418299), -- Stem
(20015, 1869, 1, 1, 2, 47626.803936), -- Iron Ore
(20015, 1798, 1, 1, 2, 46692.777765), -- Recipe: Leather Helmet
-- Stone Golem
(20016, 1865, 1, 1, -1, 241855), -- Varnish
(20016, 37, 1, 1, -1, 23711), -- Leather Shoes
(20016, 1833, 1, 1, -1, 644946), -- Bandage
(20016, 57, 127, 180, 0, 700000), -- Adena
(20016, 271, 1, 1, 1, 687), -- Hunting Bow
(20016, 1871, 1, 1, 2, 47626.567758), -- Charcoal
(20016, 1866, 1, 1, 2, 31751.045172), -- Suede
(20016, 736, 1, 1, 2, 23813.38707), -- Scroll of Escape
-- Vuku Orc Fighter
(20017, 1870, 1, 1, -1, 251000), -- Coal
(20017, 1897, 1, 1, -1, 59762), -- Necklace of Wisdom Chain
(20017, 57, 122, 197, 0, 700000), -- Adena
(20017, 2, 1, 1, 1, 70.601016), -- Long Sword
(20017, 120, 1, 1, 1, 70.601016), -- Sword of Reflection
(20017, 2012, 1, 1, 1, 772.196952), -- Sword of Reflection Blade
(20017, 121, 1, 1, 1, 70.601016), -- Sword of Watershadow
(20017, 1870, 1, 1, 2, 37070.571302), -- Coal
(20017, 1865, 1, 1, 2, 37070.571302), -- Varnish
(20017, 1817, 1, 1, 2, 7414.130868), -- Recipe: Cord
(20017, 5268, 1, 1, 2, 1482.726528), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Dryad Elder
(20019, 1864, 1, 1, -1, 445764), -- Stem
(20019, 1923, 1, 1, -1, 91345), -- Leather Stockings Pattern
(20019, 1792, 1, 1, -1, 16388), -- Recipe: Short Spear
(20019, 57, 114, 168, 0, 700000), -- Adena
(20019, 429, 1, 1, 1, 1075.736025), -- Leather Tunic
(20019, 1922, 1, 1, 1, 8397.233676), -- Leather Tunic Pattern
(20019, 464, 1, 1, 1, 1723.39947), -- Leather Stockings
(20019, 1923, 1, 1, 1, 13490.630829), -- Leather Stockings Pattern
(20019, 1871, 1, 1, 2, 43890.464944), -- Charcoal
(20019, 1866, 1, 1, 2, 29260.335422), -- Suede
(20019, 1793, 1, 1, 2, 3227.199634), -- Recipe: Sword of Reflection
-- Marsh Zombie Lord
(20020, 1831, 1, 1, -1, 668170), -- Antidote
(20020, 1799, 1, 1, -1, 371205), -- Recipe: Leather Gloves
(20020, 1896, 1, 1, -1, 106171), -- Necklace of Anguish Chain
(20020, 57, 128, 189, 0, 700000), -- Adena
(20020, 37, 1, 1, 1, 4837.383828), -- Leather Shoes
(20020, 1921, 1, 1, 1, 31833.190836), -- Leather Shoes Texture
(20020, 49, 1, 1, 1, 4837.425336), -- Gloves
(20020, 1865, 1, 1, 2, 49341.52597), -- Varnish
(20020, 1870, 1, 1, 2, 49341.52597), -- Coal
(20020, 1794, 1, 1, 2, 3627.94806), -- Recipe: Forest Bow
-- Red Bear
(20021, 1792, 1, 1, -1, 16388), -- Recipe: Short Spear
(20021, 1921, 1, 1, -1, 143795), -- Leather Shoes Texture
(20021, 1793, 1, 1, -1, 16388), -- Recipe: Sword of Reflection
(20021, 57, 114, 168, 0, 700000), -- Adena
(20021, 9, 1, 1, 1, 211.02975), -- Cedar Staff
(20021, 2008, 1, 1, 1, 1707.9405), -- Cedar Staff Head
(20021, 154, 1, 1, 1, 211.02975), -- Dwarven Mace
(20021, 1865, 1, 1, 2, 32917.863649), -- Varnish
(20021, 1870, 1, 1, 2, 32917.863649), -- Coal
(20021, 1798, 1, 1, 2, 32272.388478), -- Recipe: Leather Helmet
(20021, 1060, 1, 1, 2, 73150.884224), -- Lesser Healing Potion
-- Misery Skeleton
(20022, 1872, 1, 1, -1, 252599), -- Animal Bone
(20022, 1831, 1, 1, -1, 505199), -- Antidote
(20022, 1921, 1, 1, -1, 122225), -- Leather Shoes Texture
(20022, 57, 97, 143, 0, 700000), -- Adena
(20022, 20, 1, 1, 1, 5229.661794), -- Buckler
(20022, 43, 1, 1, 1, 3657.338206), -- Wooden Helmet
(20022, 1864, 1, 1, 2, 74614.166671), -- Stem
(20022, 1869, 1, 1, 2, 37306.99974), -- Iron Ore
(20022, 1799, 1, 1, 2, 55269.833589), -- Recipe: Leather Gloves
-- Shadow Beast
(20023, 1868, 1, 1, -1, 463226), -- Thread
(20023, 1922, 1, 1, -1, 59085), -- Leather Tunic Pattern
(20023, 1831, 1, 1, -1, 617635), -- Antidote
(20023, 57, 116, 177, 0, 700000), -- Adena
(20023, 429, 1, 1, 1, 1117.87305), -- Leather Tunic
(20023, 1922, 1, 1, 1, 8726.156792), -- Leather Tunic Pattern
(20023, 464, 1, 1, 1, 1790.90574), -- Leather Stockings
(20023, 1923, 1, 1, 1, 14019.064418), -- Leather Stockings Pattern
(20023, 1868, 1, 1, 2, 68414.79603), -- Thread
(20023, 1873, 1, 1, 2, 13682.959206), -- Silver Nugget
(20023, 1803, 1, 1, 2, 28745.708796), -- Recipe: Necklace of Wisdom
(20023, 735, 1, 1, 2, 2850.535968), -- Alacrity Potion
-- Langk Lizardman Warrior
(20024, 1864, 1, 1, -1, 501999), -- Stem
(20024, 734, 1, 1, -1, 41833), -- Haste Potion
(20024, 1897, 1, 1, -1, 59762), -- Necklace of Wisdom Chain
(20024, 57, 122, 197, 0, 700000), -- Adena
(20024, 2, 1, 1, 1, 70.601016), -- Long Sword
(20024, 120, 1, 1, 1, 70.601016), -- Sword of Reflection
(20024, 2012, 1, 1, 1, 772.196952), -- Sword of Reflection Blade
(20024, 121, 1, 1, 1, 70.601016), -- Sword of Watershadow
(20024, 1864, 1, 1, 2, 98855.505408), -- Stem
(20024, 1869, 1, 1, 2, 49427.752704), -- Iron Ore
(20024, 1801, 1, 1, 2, 24900.741888), -- Recipe: Piece Bone Gaiters
-- Lesser Dark Horror
(20025, 1799, 1, 1, -1, 349993), -- Recipe: Leather Gloves
(20025, 1869, 1, 1, -1, 236245), -- Iron Ore
(20025, 1866, 1, 1, -1, 157497), -- Suede
(20025, 57, 119, 180, 0, 700000), -- Adena
(20025, 429, 1, 1, 1, 1140.2706), -- Leather Tunic
(20025, 1922, 1, 1, 1, 8900.992864), -- Leather Tunic Pattern
(20025, 464, 1, 1, 1, 1826.78808), -- Leather Stockings
(20025, 1923, 1, 1, 1, 14299.948456), -- Leather Stockings Pattern
(20025, 1866, 1, 1, 2, 31014.738216), -- Suede
(20025, 1871, 1, 1, 2, 46522.107324), -- Charcoal
(20025, 736, 1, 1, 2, 23261.15446), -- Scroll of Escape
-- Ruin Zombie
(20026, 1866, 1, 1, -1, 173586), -- Suede
(20026, 1923, 1, 1, -1, 106713), -- Leather Stockings Pattern
(20026, 1865, 1, 1, -1, 260379), -- Varnish
(20026, 57, 131, 199, 0, 700000), -- Adena
(20026, 37, 1, 1, 1, 5026.879494), -- Leather Shoes
(20026, 1921, 1, 1, 1, 33080.197878), -- Leather Shoes Texture
(20026, 49, 1, 1, 1, 5026.922628), -- Gloves
(20026, 1870, 1, 1, 2, 51274.9464), -- Coal
(20026, 1865, 1, 1, 2, 51274.9464), -- Varnish
(20026, 1792, 1, 1, 2, 3770.1072), -- Recipe: Short Spear
-- Langk Lizardman Scout
(20027, 1800, 1, 1, -1, 74706), -- Recipe: Piece Bone Breastplate
(20027, 1924, 1, 1, -1, 76634), -- Leather Helmet Design
(20027, 1801, 1, 1, -1, 119680), -- Recipe: Piece Bone Gaiters
(20027, 57, 118, 183, 0, 700000), -- Adena
(20027, 176, 1, 1, 1, 133.5), -- Apprentice's Staff
(20027, 2501, 1, 1, 1, 133.5), -- Bone Club
(20027, 1865, 1, 1, 2, 35086.53225), -- Varnish
(20027, 1870, 1, 1, 2, 35086.53225), -- Coal
(20027, 1800, 1, 1, 2, 11033.47421), -- Recipe: Piece Bone Breastplate
(20027, 5158, 1, 1, 2, 1403.46129), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Pincher
(20028, 1801, 1, 1, -1, 119680), -- Recipe: Piece Bone Gaiters
(20028, 1868, 1, 1, -1, 475131), -- Thread
(20028, 734, 1, 1, -1, 39594), -- Haste Potion
(20028, 57, 118, 183, 0, 700000), -- Adena
(20028, 845, 1, 1, 1, 1025.902512), -- Cat's Eye Earring
(20028, 908, 1, 1, 1, 769.432728), -- Necklace of Wisdom
(20028, 1897, 1, 1, 1, 8353.810992), -- Necklace of Wisdom Chain
(20028, 877, 1, 1, 1, 1538.853768), -- Ring of Wisdom
(20028, 1869, 1, 1, 2, 46782.1875), -- Iron Ore
(20028, 1864, 1, 1, 2, 93564.375), -- Stem
(20028, 1817, 1, 1, 2, 9356.4375), -- Recipe: Cord
-- Ruin Zombie Leader
(20029, 1864, 1, 1, -1, 534142), -- Stem
(20029, 2013, 1, 1, -1, 5764), -- Forest Bow Shaft
(20029, 1897, 1, 1, -1, 63588), -- Necklace of Wisdom Chain
(20029, 57, 132, 206, 0, 700000), -- Adena
(20029, 15, 1, 1, 1, 150.26895), -- Short Spear
(20029, 2011, 1, 1, 1, 1799.73105), -- Short Spear Edge
(20029, 1870, 1, 1, 2, 39444.234295), -- Coal
(20029, 1865, 1, 1, 2, 39444.234295), -- Varnish
(20029, 2139, 1, 1, 2, 7888.86453), -- Recipe: Steel Mold
(20029, 5268, 1, 1, 2, 1577.66688), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Langk Lizardman
(20030, 1831, 1, 1, -1, 617635), -- Antidote
(20030, 1798, 1, 1, -1, 227072), -- Recipe: Leather Helmet
(20030, 1794, 1, 1, -1, 17030), -- Recipe: Forest Bow
(20030, 57, 116, 177, 0, 700000), -- Adena
(20030, 216, 1, 1, 1, 328.91945), -- Dirk
(20030, 2009, 1, 1, 1, 2426.08055), -- Dirk Blade
(20030, 1870, 1, 1, 2, 45610.20298), -- Coal
(20030, 1865, 1, 1, 2, 45610.20298), -- Varnish
(20030, 1793, 1, 1, 2, 3353.59404), -- Recipe: Sword of Reflection
-- Omen Beast
(20031, 1865, 1, 1, -1, 205065), -- Varnish
(20031, 24, 1, 1, -1, 2629), -- Bone Breastplate
(20031, 1924, 1, 1, -1, 66150), -- Leather Helmet Design
(20031, 57, 100, 161, 0, 700000), -- Adena
(20031, 24, 1, 1, 1, 388.37335), -- Bone Breastplate
(20031, 390, 1, 1, 1, 388.37335), -- Cotton Shirt
(20031, 31, 1, 1, 1, 620.12665), -- Bone Gaiters
(20031, 412, 1, 1, 1, 620.12665), -- Cotton Pants
(20031, 1865, 1, 1, 2, 30286.636218), -- Varnish
(20031, 1870, 1, 1, 2, 30286.636218), -- Coal
(20031, 2140, 1, 1, 2, 6057.340812), -- Recipe: High-Grade Suede
(20031, 5273, 1, 1, 2, 1211.386752), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Pinrul
(20032, 734, 1, 1, -1, 41013), -- Haste Potion
(20032, 1868, 1, 1, -1, 492156), -- Thread
(20032, 1800, 1, 1, -1, 77383), -- Recipe: Piece Bone Breastplate
(20032, 57, 120, 193, 0, 700000), -- Adena
(20032, 24, 1, 1, 1, 465.971), -- Bone Breastplate
(20032, 390, 1, 1, 1, 465.971), -- Cotton Shirt
(20032, 31, 1, 1, 1, 744.029), -- Bone Gaiters
(20032, 412, 1, 1, 1, 744.029), -- Cotton Pants
(20032, 1870, 1, 1, 2, 48458.587905), -- Coal
(20032, 1865, 1, 1, 2, 48458.587905), -- Varnish
(20032, 2141, 1, 1, 2, 9691.82419), -- Recipe: Silver Mold
-- Shade Horror
(20033, 2139, 1, 1, -1, 41013), -- Recipe: Steel Mold
(20033, 1924, 1, 1, -1, 66150), -- Leather Helmet Design
(20033, 1925, 1, 1, -1, 134469), -- Leather Gloves Lining
(20033, 57, 100, 161, 0, 700000), -- Adena
(20033, 845, 1, 1, 1, 885.551886), -- Cat's Eye Earring
(20033, 908, 1, 1, 1, 664.168959), -- Necklace of Wisdom
(20033, 1897, 1, 1, 1, 7210.951326), -- Necklace of Wisdom Chain
(20033, 877, 1, 1, 1, 1328.327829), -- Ring of Wisdom
(20033, 1870, 1, 1, 2, 30286.636218), -- Coal
(20033, 1865, 1, 1, 2, 30286.636218), -- Varnish
(20033, 2142, 1, 1, 2, 6057.340812), -- Recipe: Varnish of Purity
(20033, 5158, 1, 1, 2, 1211.386752), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Prowler
(20034, 1868, 1, 1, -1, 501999), -- Thread
(20034, 2254, 1, 1, -1, 10287), -- Recipe: Composite Bow
(20034, 1873, 1, 1, -1, 100400), -- Silver Nugget
(20034, 57, 122, 197, 0, 700000), -- Adena
(20034, 256, 1, 1, 1, 282), -- Cestus
(20034, 1873, 1, 1, 2, 14828.241164), -- Silver Nugget
(20034, 1868, 1, 1, 2, 74141.404766), -- Thread
(20034, 2143, 1, 1, 2, 7414.120582), -- Recipe: Synthetic Cokes
(20034, 6035, 1, 1, 2, 3089.233488), -- Magic Haste Potion
-- Skeleton Tracker
(20035, 2140, 1, 1, -1, 49216), -- Recipe: High-Grade Suede
(20035, 1925, 1, 1, -1, 161363), -- Leather Gloves Lining
(20035, 1868, 1, 1, -1, 492156), -- Thread
(20035, 57, 120, 193, 0, 700000), -- Adena
(20035, 38, 1, 1, 1, 1860.220285), -- Low Boots
(20035, 50, 1, 1, 1, 1860.220285), -- Leather Gloves
(20035, 1925, 1, 1, 1, 31776.55943), -- Leather Gloves Lining
(20035, 1868, 1, 1, 2, 72687.902048), -- Thread
(20035, 1873, 1, 1, 2, 14537.56122), -- Silver Nugget
(20035, 1817, 1, 1, 2, 7268.828584), -- Recipe: Cord
(20035, 5268, 1, 1, 2, 1453.708148), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Lirein
(20036, 1873, 1, 1, -1, 103328), -- Silver Nugget
(20036, 2175, 1, 1, -1, 210017), -- Recipe: Boots
(20036, 735, 1, 1, -1, 21527), -- Alacrity Potion
(20036, 57, 124, 204, 0, 700000), -- Adena
(20036, 845, 1, 1, 1, 1115.519766), -- Cat's Eye Earring
(20036, 908, 1, 1, 1, 836.646179), -- Necklace of Wisdom
(20036, 1897, 1, 1, 1, 9083.554406), -- Necklace of Wisdom Chain
(20036, 877, 1, 1, 1, 1673.279649), -- Ring of Wisdom
(20036, 1864, 1, 1, 2, 76303.90936), -- Stem
(20036, 1869, 1, 1, 2, 38151.95468), -- Iron Ore
(20036, 1878, 1, 1, 2, 15260.781872), -- Braided Hemp
(20036, 2173, 1, 1, 2, 10339.354088), -- Recipe: Hard Leather Shirt
-- Venomous Spider
(20038, 2174, 1, 1, -1, 121122), -- Recipe: Hard Leather Gaiters
(20038, 1868, 1, 1, -1, 557163), -- Thread
(20038, 2011, 1, 1, -1, 6355), -- Short Spear Edge
(20038, 57, 133, 220, 0, 700000), -- Adena
(20038, 217, 1, 1, 1, 156.5), -- Shining Knife
(20038, 218, 1, 1, 1, 156.5), -- Throwing Knife
(20038, 1869, 1, 1, 2, 20572.111932), -- Iron Ore
(20038, 1870, 1, 1, 2, 20572.111932), -- Coal
(20038, 1871, 1, 1, 2, 20572.111932), -- Charcoal
(20038, 1872, 1, 1, 2, 27429.482576), -- Animal Bone
(20038, 1867, 1, 1, 2, 27429.482576), -- Animal Skin
(20038, 2174, 1, 1, 2, 8944.443762), -- Recipe: Hard Leather Gaiters
(20038, 5273, 1, 1, 2, 822.833741), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(20038, 1831, 1, 1, 2, 54858.421549), -- Antidote
-- Scavenger Wererat
(20039, 1872, 1, 1, -1, 337674), -- Animal Bone
(20039, 2011, 1, 1, -1, 5777), -- Short Spear Edge
(20039, 1801, 1, 1, -1, 127585), -- Recipe: Piece Bone Gaiters
(20039, 57, 121, 200, 0, 700000), -- Adena
(20039, 945, 1, 1, 1, 2833.69248), -- Skeleton Buckler
(20039, 102, 1, 1, 1, 1367.637272), -- Round Shield
(20039, 44, 1, 1, 1, 956.638184), -- Leather Helmet
(20039, 1924, 1, 1, 1, 12066.032064), -- Leather Helmet Design
(20039, 1864, 1, 1, 2, 42747.3024), -- Stem
(20039, 1865, 1, 1, 2, 21373.6512), -- Varnish
(20039, 1866, 1, 1, 2, 14249.1008), -- Suede
(20039, 1873, 1, 1, 2, 8549.40095), -- Silver Nugget
(20039, 1868, 1, 1, 2, 42747.3024), -- Thread
(20039, 2175, 1, 1, 2, 17376.955825), -- Recipe: Boots
(20039, 735, 1, 1, 2, 1781.286425), -- Alacrity Potion
-- Sukar Wererat
(20040, 2175, 1, 1, -1, 171583), -- Recipe: Boots
(20040, 2140, 1, 1, -1, 42209), -- Recipe: High-Grade Suede
(20040, 2012, 1, 1, -1, 4397), -- Sword of Reflection Blade
(20040, 57, 101, 167, 0, 700000), -- Adena
(20040, 945, 1, 1, 1, 2361.35556), -- Skeleton Buckler
(20040, 102, 1, 1, 1, 1139.671259), -- Round Shield
(20040, 44, 1, 1, 1, 797.179973), -- Leather Helmet
(20040, 1924, 1, 1, 1, 10054.793208), -- Leather Helmet Design
(20040, 1868, 1, 1, 2, 62339.799824), -- Thread
(20040, 1873, 1, 1, 2, 12467.929032), -- Silver Nugget
(20040, 2252, 1, 1, 2, 1277.447308), -- Recipe: Iron Hammer
(20040, 5158, 1, 1, 2, 1246.823836), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Tainted Zombie
(20041, 1880, 1, 1, -1, 23726), -- Steel
(20041, 2012, 1, 1, -1, 4943), -- Sword of Reflection Blade
(20041, 1817, 1, 1, -1, 47452), -- Recipe: Cord
(20041, 57, 114, 187, 0, 700000), -- Adena
(20041, 217, 1, 1, 1, 133.5), -- Shining Knife
(20041, 218, 1, 1, 1, 133.5), -- Throwing Knife
(20041, 1866, 1, 1, 2, 31147.6736), -- Suede
(20041, 1871, 1, 1, 2, 46721.5104), -- Charcoal
(20041, 2253, 1, 1, 2, 1914.816), -- Recipe: Sword Breaker
-- Skeleton Tracker Leader
(20042, 734, 1, 1, -1, 43053), -- Haste Potion
(20042, 2013, 1, 1, -1, 5575), -- Forest Bow Shaft
(20042, 57, 124, 204, 0, 700000), -- Adena
(20042, 309, 1, 1, 1, 145.5), -- Tears of Eva
(20042, 310, 1, 1, 1, 145.5), -- Relic of the Saints
(20042, 1867, 1, 1, 2, 40695.344685), -- Animal Skin
(20042, 1872, 1, 1, 2, 40695.344685), -- Animal Bone
(20042, 1882, 1, 1, 2, 6782.60277), -- Leather
(20042, 2254, 1, 1, 2, 1250.901), -- Recipe: Composite Bow
(20042, 5268, 1, 1, 2, 1220.80686), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Arachnid Tracker
(20043, 1817, 1, 1, -1, 58608), -- Recipe: Cord
(20043, 1924, 1, 1, -1, 94529), -- Leather Helmet Design
(20043, 1864, 1, 1, -1, 586082), -- Stem
(20043, 57, 137, 234, 0, 700000), -- Adena
(20043, 2, 1, 1, 1, 82.439601), -- Long Sword
(20043, 120, 1, 1, 1, 82.439601), -- Sword of Reflection
(20043, 2012, 1, 1, 1, 901.681197), -- Sword of Reflection Blade
(20043, 121, 1, 1, 1, 82.439601), -- Sword of Watershadow
(20043, 1864, 1, 1, 2, 43279.866706), -- Stem
(20043, 1865, 1, 1, 2, 21639.836262), -- Varnish
(20043, 1866, 1, 1, 2, 14426.557508), -- Suede
(20043, 1873, 1, 1, 2, 8656.051014), -- Silver Nugget
(20043, 1868, 1, 1, 2, 43279.866706), -- Thread
(20043, 2143, 1, 1, 2, 4327.928416), -- Recipe: Synthetic Cokes
(20043, 5158, 1, 1, 2, 865.663356), -- Recipe: Spiritshot (D) Compressed Package (100%)
(20043, 1831, 1, 1, 2, 57706.230032), -- Antidote
-- Lirein Elder
(20044, 1865, 1, 1, -1, 266401), -- Varnish
(20044, 2142, 1, 1, -1, 53280), -- Recipe: Varnish of Purity
(20044, 1872, 1, 1, -1, 355202), -- Animal Bone
(20044, 57, 125, 213, 0, 700000), -- Adena
(20044, 309, 1, 1, 1, 150), -- Tears of Eva
(20044, 310, 1, 1, 1, 150), -- Relic of the Saints
(20044, 1872, 1, 1, 2, 52460.391984), -- Animal Bone
(20044, 1867, 1, 1, 2, 52460.391984), -- Animal Skin
(20044, 1881, 1, 1, 2, 5245.991984), -- Coarse Bone Powder
(20044, 2144, 1, 1, 2, 7869.224048), -- Recipe: Compound Braid
-- Skeleton Scout
(20045, 734, 1, 1, -1, 44835), -- Haste Potion
(20045, 1925, 1, 1, -1, 176402), -- Leather Gloves Lining
(20045, 57, 126, 215, 0, 700000), -- Adena
(20045, 217, 1, 1, 1, 151.5), -- Shining Knife
(20045, 218, 1, 1, 1, 151.5), -- Throwing Knife
(20045, 1871, 1, 1, 2, 39731.163947), -- Charcoal
(20045, 1866, 1, 1, 2, 26487.413811), -- Suede
(20045, 2150, 1, 1, 2, 18653.09614), -- Recipe: Blue Diamond Necklace
(20045, 5268, 1, 1, 2, 1589.326102), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Stink Zombie
(20046, 2139, 1, 1, -1, 48936), -- Recipe: Steel Mold
(20046, 735, 1, 1, -1, 20390), -- Alacrity Potion
(20046, 1897, 1, 1, -1, 58257), -- Necklace of Wisdom Chain
(20046, 57, 115, 195, 0, 700000), -- Adena
(20046, 845, 1, 1, 1, 1056.623412), -- Cat's Eye Earring
(20046, 908, 1, 1, 1, 792.473578), -- Necklace of Wisdom
(20046, 1897, 1, 1, 1, 8603.967892), -- Necklace of Wisdom Chain
(20046, 877, 1, 1, 1, 1584.935118), -- Ring of Wisdom
(20046, 1867, 1, 1, 2, 48183.04145), -- Animal Skin
(20046, 1872, 1, 1, 2, 48183.04145), -- Animal Bone
(20046, 1882, 1, 1, 2, 8030.52594), -- Leather
(20046, 2173, 1, 1, 2, 9793.39116), -- Recipe: Hard Leather Shirt
-- Sukar Wererat Leader
(20047, 1869, 1, 1, -1, 222001), -- Iron Ore
(20047, 38, 1, 1, -1, 8522), -- Low Boots
(20047, 2139, 1, 1, -1, 44400), -- Recipe: Steel Mold
(20047, 57, 104, 177, 0, 700000), -- Adena
(20047, 24, 1, 1, 1, 420.33665), -- Bone Breastplate
(20047, 390, 1, 1, 1, 420.33665), -- Cotton Shirt
(20047, 31, 1, 1, 1, 671.16335), -- Bone Gaiters
(20047, 412, 1, 1, 1, 671.16335), -- Cotton Pants
(20047, 1864, 1, 1, 2, 43716.99248), -- Stem
(20047, 1869, 1, 1, 2, 21858.49624), -- Iron Ore
(20047, 1878, 1, 1, 2, 8743.36316), -- Braided Hemp
(20047, 2174, 1, 1, 2, 9503.70554), -- Recipe: Hard Leather Gaiters
(20047, 5273, 1, 1, 2, 874.30098), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(20047, 734, 1, 1, 2, 3643.1416), -- Haste Potion
-- Lesser Succubus
(20048, 2144, 1, 1, -1, 45937), -- Recipe: Compound Braid
(20048, 50, 1, 1, -1, 8817), -- Leather Gloves
(20048, 1924, 1, 1, -1, 74091), -- Leather Helmet Design
(20048, 57, 106, 184, 0, 700000), -- Adena
(20048, 256, 1, 1, 1, 258), -- Cestus
(20048, 1868, 1, 1, 2, 90460.027138), -- Thread
(20048, 1873, 1, 1, 2, 18091.981908), -- Silver Nugget
(20048, 2142, 1, 1, 2, 9045.990954), -- Recipe: Varnish of Purity
-- Lycanthrope
(20049, 1882, 1, 1, -1, 61249), -- Leather
(20049, 1924, 1, 1, -1, 88910), -- Leather Helmet Design
(20049, 2140, 1, 1, -1, 55124), -- Recipe: High-Grade Suede
(20049, 57, 127, 221, 0, 700000), -- Adena
(20049, 256, 1, 1, 1, 310), -- Cestus
(20049, 1872, 1, 1, 2, 43420.565404), -- Animal Bone
(20049, 1867, 1, 1, 2, 43420.565404), -- Animal Skin
(20049, 1881, 1, 1, 2, 4342.09614), -- Coarse Bone Powder
(20049, 2143, 1, 1, 2, 6513.045211), -- Recipe: Synthetic Cokes
(20049, 5158, 1, 1, 2, 1302.727841), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Arachnid Predator
(20050, 735, 1, 1, -1, 25265), -- Alacrity Potion
(20050, 1866, 1, 1, -1, 202121), -- Suede
(20050, 1925, 1, 1, -1, 198808), -- Leather Gloves Lining
(20050, 57, 140, 243, 0, 700000), -- Adena
(20050, 15, 1, 1, 1, 170.613054), -- Short Spear
(20050, 2011, 1, 1, 1, 2043.386946), -- Short Spear Edge
(20050, 1866, 1, 1, 2, 29851.800528), -- Suede
(20050, 1871, 1, 1, 2, 44777.599296), -- Charcoal
(20050, 2144, 1, 1, 2, 8955.601056), -- Recipe: Compound Braid
(20050, 1831, 1, 1, 2, 119406.99912), -- Antidote
-- Skeleton Bowman
(20051, 2254, 1, 1, -1, 11407), -- Recipe: Composite Bow
(20051, 1925, 1, 1, -1, 182506), -- Leather Gloves Lining
(20051, 1867, 1, 1, -1, 371096), -- Animal Skin
(20051, 57, 129, 223, 0, 700000), -- Adena
(20051, 272, 1, 1, 1, 156.6041), -- Forest Bow
(20051, 2013, 1, 1, 1, 1774.3959), -- Forest Bow Shaft
(20051, 1872, 1, 1, 2, 43846.562656), -- Animal Bone
(20051, 1867, 1, 1, 2, 43846.562656), -- Animal Skin
(20051, 1881, 1, 1, 2, 4384.623616), -- Coarse Bone Powder
(20051, 2150, 1, 1, 2, 15438.90752), -- Recipe: Blue Diamond Necklace
(20051, 5268, 1, 1, 2, 1315.343552), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Lesser Succubus Turen
(20052, 1866, 1, 1, -1, 193642), -- Suede
(20052, 1868, 1, 1, -1, 580926), -- Thread
(20052, 1869, 1, 1, -1, 290463), -- Iron Ore
(20052, 57, 132, 236, 0, 700000), -- Adena
(20052, 219, 1, 1, 1, 91.30743), -- Sword Breaker
(20052, 2015, 1, 1, 1, 1046.69257), -- Sword Breaker Edge
(20052, 1869, 1, 1, 2, 34319.45224), -- Iron Ore
(20052, 1864, 1, 1, 2, 68639.013616), -- Stem
(20052, 1880, 1, 1, 2, 3431.999792), -- Steel
(20052, 1804, 1, 1, 2, 1372.821744), -- Recipe: Soulshot (D-Grade)
(20052, 5158, 1, 1, 2, 1372.712608), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Ol Mahum Patrol
(20053, 2015, 1, 1, -1, 4292), -- Sword Breaker Edge
(20053, 1926, 1, 1, -1, 35553), -- Piece Bone Breastplate Fragment
(20053, 1898, 1, 1, -1, 36155), -- Blue Diamond Necklace Gem
(20053, 57, 160, 286, 0, 700000), -- Adena
(20053, 39, 1, 1, 1, 1459.212084), -- Boots
(20053, 1930, 1, 1, 1, 17772.555141), -- Boot Lining
(20053, 51, 1, 1, 1, 1459.232775), -- Bracer
(20053, 1864, 1, 1, 2, 83174.087694), -- Stem
(20053, 1869, 1, 1, 2, 41587.043847), -- Iron Ore
(20053, 1878, 1, 1, 2, 16634.75594), -- Braided Hemp
(20053, 2151, 1, 1, 2, 11584.116331), -- Recipe: Necklace of Devotion
(20053, 5437, 1, 1, 2, 1016.996188), -- Recipe: Heavy Sword(100%)
-- Ruin Spartoi
(20054, 1880, 1, 1, -1, 34172), -- Steel
(20054, 3032, 1, 1, -1, 13669), -- Recipe: Spiritshot D
(20054, 1804, 1, 1, -1, 13669), -- Recipe: Soulshot (D-Grade)
(20054, 57, 156, 278, 0, 700000), -- Adena
(20054, 39, 1, 1, 1, 1416.686112), -- Boots
(20054, 1930, 1, 1, 1, 17254.607688), -- Boot Lining
(20054, 51, 1, 1, 1, 1416.7062), -- Bracer
(20054, 1867, 1, 1, 2, 53834.08194), -- Animal Skin
(20054, 1872, 1, 1, 2, 53834.08194), -- Animal Bone
(20054, 1882, 1, 1, 2, 8972.301132), -- Leather
(20054, 2176, 1, 1, 2, 19318.416228), -- Recipe: Leather Boots
(20054, 5268, 1, 1, 2, 1615.11876), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Wandering Eye
(20055, 2176, 1, 1, -1, 163503), -- Recipe: Leather Boots
(20055, 1928, 1, 1, -1, 49777), -- Piece Bone Gaiters Fragment
(20055, 1926, 1, 1, -1, 34517), -- Piece Bone Breastplate Fragment
(20055, 57, 156, 278, 0, 700000), -- Adena
(20055, 219, 1, 1, 1, 107.35443), -- Sword Breaker
(20055, 2015, 1, 1, 1, 1230.64557), -- Sword Breaker Edge
(20055, 1869, 1, 1, 2, 40375.716636), -- Iron Ore
(20055, 1864, 1, 1, 2, 80751.433272), -- Stem
(20055, 1880, 1, 1, 2, 4037.515092), -- Steel
(20055, 2177, 1, 1, 2, 12899.597661), -- Recipe: Bone Helmet
(20055, 735, 1, 1, 2, 3364.737339), -- Alacrity Potion
-- Dre Vanul Disposer
(20056, 1926, 1, 1, -1, 34201), -- Piece Bone Breastplate Fragment
(20056, 5163, 1, 1, -1, 13543), -- Recipe: Blessed Spiritshot (D) Compressed Package (100%)
(20056, 2151, 1, 1, -1, 94314), -- Recipe: Necklace of Devotion
(20056, 57, 154, 276, 0, 700000), -- Adena
(20056, 27, 1, 1, 1, 352.163077), -- Hard Leather Shirt
(20056, 1927, 1, 1, 1, 3989.348954), -- Hard Leather Shirt Pattern
(20056, 33, 1, 1, 1, 565.042096), -- Hard Leather Gaiters
(20056, 1929, 1, 1, 1, 6452.445873), -- Hard Leather Gaiters Material
(20056, 1868, 1, 1, 2, 100013.252364), -- Thread
(20056, 1873, 1, 1, 2, 20002.702302), -- Silver Nugget
(20056, 2256, 1, 1, 2, 1222.650828), -- Recipe: Assassin Knife
(20056, 734, 1, 1, 2, 8334.394506), -- Haste Potion
-- Lesser Succubus Tilfo
(20057, 2176, 1, 1, -1, 147276), -- Recipe: Leather Boots
(20057, 2258, 1, 1, -1, 7526), -- Recipe: Temptation of Abyss
(20057, 1927, 1, 1, -1, 24556), -- Hard Leather Shirt Pattern
(20057, 57, 140, 251, 0, 700000), -- Adena
(20057, 1102, 1, 1, 1, 640.425264), -- Tunic of Magic
(20057, 1105, 1, 1, 1, 1027.574736), -- Stockings of Magic
(20057, 1870, 1, 1, 2, 45460.579741), -- Coal
(20057, 1865, 1, 1, 2, 45460.579741), -- Varnish
(20057, 2257, 1, 1, 2, 1111.477393), -- Recipe: Trident
(20057, 5273, 1, 1, 2, 1818.363125), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Ol Mahum Guard
(20058, 1873, 1, 1, -1, 144850), -- Silver Nugget
(20058, 1926, 1, 1, -1, 36578), -- Piece Bone Breastplate Fragment
(20058, 1865, 1, 1, -1, 362125), -- Varnish
(20058, 57, 164, 295, 0, 700000), -- Adena
(20058, 16, 1, 1, 1, 228), -- Great Spear
(20058, 1865, 1, 1, 2, 53483.196944), -- Varnish
(20058, 1870, 1, 1, 2, 53483.196944), -- Coal
(20058, 1879, 1, 1, 2, 8913.90522), -- Cokes
(20058, 2258, 1, 1, 2, 1307.700892), -- Recipe: Temptation of Abyss
-- Hungry Eye
(20059, 2177, 1, 1, -1, 115695), -- Recipe: Bone Helmet
(20059, 32, 1, 1, -1, 4734), -- Piece Bone Gaiters
(20059, 1879, 1, 1, -1, 60354), -- Cokes
(20059, 57, 164, 295, 0, 700000), -- Adena
(20059, 625, 1, 1, 1, 2160.640404), -- Bone Shield
(20059, 1148, 1, 1, 1, 1506.359596), -- Hard Leather Helmet
(20059, 1870, 1, 1, 2, 53483.147405), -- Coal
(20059, 1865, 1, 1, 2, 53483.147405), -- Varnish
(20059, 3032, 1, 1, 2, 2139.352595), -- Recipe: Spiritshot D
(20059, 5158, 1, 1, 2, 2139.352595), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Raging Spartoi
(20060, 1869, 1, 1, -1, 369368), -- Iron Ore
(20060, 1928, 1, 1, -1, 53805), -- Piece Bone Gaiters Fragment
(20060, 57, 168, 301, 0, 700000), -- Adena
(20060, 87, 1, 1, 1, 58.02444), -- Iron Hammer
(20060, 2014, 1, 1, 1, 626.927481), -- Iron Hammer Head
(20060, 155, 1, 1, 1, 58.02444), -- Flanged Mace
(20060, 177, 1, 1, 1, 58.023639), -- Mage Staff
(20060, 1870, 1, 1, 2, 43642.188839), -- Coal
(20060, 1865, 1, 1, 2, 43642.188839), -- Varnish
(20060, 3953, 1, 1, 2, 1745.709363), -- Recipe: Blessed Spiritshot D
(20060, 6666, 1, 1, 2, 43642.188839), -- Deluxe Chest Key - Grade 2
(20060, 735, 1, 1, 2, 3636.72412), -- Alacrity Potion
-- Ol Mahum Straggler
(20061, 1880, 1, 1, -1, 38571), -- Steel
(20061, 1927, 1, 1, -1, 30770), -- Hard Leather Shirt Pattern
(20061, 2176, 1, 1, -1, 184549), -- Recipe: Leather Boots
(20061, 57, 177, 312, 0, 700000), -- Adena
(20061, 273, 1, 1, 1, 121.177056), -- Composite Bow
(20061, 2016, 1, 1, 1, 1334.822944); -- Composite Bow Shaft

INSERT INTO `droplist` VALUES
(20061, 1866, 1, 1, 2, 30381.9065), -- Suede
(20061, 1871, 1, 1, 2, 45572.984215), -- Charcoal
(20061, 2257, 1, 1, 2, 1114.21068), -- Recipe: Trident
(20061, 5268, 1, 1, 2, 1822.91439), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20061, 6666, 1, 1, 2, 45572.984215), -- Deluxe Chest Key - Grade 2
-- Tumran Bugbear
(20062, 2257, 1, 1, -1, 9246), -- Recipe: Trident
(20062, 27, 1, 1, -1, 2663), -- Hard Leather Shirt
(20062, 1929, 1, 1, -1, 48793), -- Hard Leather Gaiters Material
(20062, 57, 173, 305, 0, 700000), -- Adena
(20062, 219, 1, 1, 1, 118.828035), -- Sword Breaker
(20062, 2015, 1, 1, 1, 1362.171965), -- Sword Breaker Edge
(20062, 1872, 1, 1, 2, 59572.137482), -- Animal Bone
(20062, 1867, 1, 1, 2, 59572.137482), -- Animal Skin
(20062, 1881, 1, 1, 2, 5957.145399), -- Coarse Bone Powder
(20062, 2258, 1, 1, 2, 1092.391089), -- Recipe: Temptation of Abyss
(20062, 6666, 1, 1, 2, 44679.188548), -- Deluxe Chest Key - Grade 2
-- Ol Mahum Shooter
(20063, 2176, 1, 1, -1, 196828), -- Recipe: Leather Boots
(20063, 34, 1, 1, -1, 3486), -- Bronze Gaiters
(20063, 2177, 1, 1, -1, 131428), -- Recipe: Bone Helmet
(20063, 57, 183, 337, 0, 700000), -- Adena
(20063, 273, 1, 1, 1, 129.249978), -- Composite Bow
(20063, 2016, 1, 1, 1, 1423.750022), -- Composite Bow Shaft
(20063, 1867, 1, 1, 2, 54005.375768), -- Animal Skin
(20063, 1872, 1, 1, 2, 54005.375768), -- Animal Bone
(20063, 1882, 1, 1, 2, 9000.842586), -- Leather
(20063, 1804, 1, 1, 2, 1620.154868), -- Recipe: Soulshot (D-Grade)
(20063, 6666, 1, 1, 2, 40504.031826), -- Deluxe Chest Key - Grade 2
(20063, 8294, 1, 1, 2, 990.219184), -- Recipe: Steel Sword (100%)
-- Tumran Bugbear Warrior
(20064, 1873, 1, 1, -1, 162950), -- Silver Nugget
(20064, 1926, 1, 1, -1, 41149), -- Piece Bone Breastplate Fragment
(20064, 1930, 1, 1, -1, 104455), -- Boot Lining
(20064, 57, 181, 334, 0, 700000), -- Adena
(20064, 27, 1, 1, 1, 423.718001), -- Hard Leather Shirt
(20064, 1927, 1, 1, 1, 4799.932402), -- Hard Leather Shirt Pattern
(20064, 33, 1, 1, 1, 679.851248), -- Hard Leather Gaiters
(20064, 1929, 1, 1, 1, 7763.498349), -- Hard Leather Gaiters Material
(20064, 1866, 1, 1, 2, 32088.633729), -- Suede
(20064, 1871, 1, 1, 2, 48132.893994), -- Charcoal
(20064, 2179, 1, 1, 2, 23030.110152), -- Recipe: Crafted Leather Gloves
(20064, 5273, 1, 1, 2, 1925.288592), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(20064, 734, 1, 1, 2, 8022.073533), -- Haste Potion
-- Ol Mahum Captain
(20066, 1865, 1, 1, -1, 445204), -- Varnish
(20066, 347, 1, 1, -1, 1387), -- Ring Mail Breastplate
(20066, 1873, 1, 1, -1, 178082), -- Silver Nugget
(20066, 57, 196, 367, 0, 700000), -- Adena
(20066, 347, 1, 1, 1, 389.044172), -- Ring Mail Breastplate
(20066, 376, 1, 1, 1, 622.955828), -- Iron Plate Gaiters
(20066, 1868, 1, 1, 2, 99945.297768), -- Thread
(20066, 1873, 1, 1, 2, 19989.005894), -- Silver Nugget
(20066, 5549, 1, 1, 2, 4997.318548), -- Metallic Thread
(20066, 2178, 1, 1, 2, 7995.682847), -- Recipe: Dark Stockings
(20066, 8294, 1, 1, 2, 1221.694943), -- Recipe: Steel Sword (100%)
-- Monster Eye Watcher
(20067, 2180, 1, 1, -1, 31555), -- Recipe: Scale Mail
(20067, 2020, 1, 1, -1, 7347), -- Temptation of Abyss Piece
(20067, 1869, 1, 1, -1, 419687), -- Iron Ore
(20067, 57, 185, 346, 0, 700000), -- Adena
(20067, 847, 1, 1, 1, 568.9424), -- Red Crescent Earring
(20067, 910, 1, 1, 1, 426.7068), -- Necklace of Devotion
(20067, 1899, 1, 1, 1, 9200.92615), -- Necklace of Devotion Chain
(20067, 890, 1, 1, 1, 853.42465), -- Ring of Devotion
(20067, 1864, 1, 1, 2, 117770.806104), -- Stem
(20067, 1869, 1, 1, 2, 58885.403052), -- Iron Ore
(20067, 1878, 1, 1, 2, 23554.243076), -- Braided Hemp
(20067, 2180, 1, 1, 2, 4427.547768), -- Recipe: Scale Mail
-- Monster Eye Destroyer
(20068, 2261, 1, 1, -1, 7002), -- Recipe: Conjuror's Staff
(20068, 391, 1, 1, -1, 1871), -- Puma Skin Shirt
(20068, 1899, 1, 1, -1, 70456), -- Necklace of Devotion Chain
(20068, 57, 196, 374, 0, 700000), -- Adena
(20068, 101, 1, 1, 1, 32.150125), -- Scroll of Wisdom
(20068, 312, 1, 1, 1, 32.150125), -- Branch of Life
(20068, 313, 1, 1, 1, 32.150125), -- Temptation of Abyss
(20068, 2020, 1, 1, 1, 886.40153), -- Temptation of Abyss Piece
(20068, 314, 1, 1, 1, 32.148095), -- Proof of Revenge
(20068, 1864, 1, 1, 2, 126533.87649), -- Stem
(20068, 1869, 1, 1, 2, 63267.04629), -- Iron Ore
(20068, 1878, 1, 1, 2, 25306.73208), -- Braided Hemp
(20068, 2262, 1, 1, 2, 982.34514), -- Recipe: Elven Bow
-- Lesser Basilisk
(20070, 1872, 1, 1, -1, 621523), -- Animal Bone
(20070, 2182, 1, 1, -1, 55959), -- Recipe: Scale Gaiters
(20070, 2152, 1, 1, -1, 82067), -- Recipe: Enchanted Necklace
(20070, 57, 201, 388, 0, 700000), -- Adena
(20070, 40, 1, 1, 1, 812.471808), -- Leather Boots
(20070, 1931, 1, 1, 1, 8549.528192), -- Leather Boots Lining
(20070, 604, 1, 1, 1, 812.471808), -- Crafted Leather Gloves
(20070, 1934, 1, 1, 1, 8549.528192), -- Crafted Leather Gloves Lining
(20070, 1872, 1, 1, 2, 69763.43844), -- Animal Bone
(20070, 1867, 1, 1, 2, 69763.43844), -- Animal Skin
(20070, 1881, 1, 1, 2, 6976.343844), -- Coarse Bone Powder
(20070, 1875, 1, 1, 2, 3488.247324), -- Stone of Purity
(20070, 2263, 1, 1, 2, 812.531952), -- Recipe: Dwarven Trident
-- Basilisk
(20072, 2263, 1, 1, -1, 7608), -- Recipe: Dwarven Trident
(20072, 3953, 1, 1, -1, 19599), -- Recipe: Blessed Spiritshot D
(20072, 1931, 1, 1, -1, 64050), -- Leather Boots Lining
(20072, 57, 210, 411, 0, 700000), -- Adena
(20072, 626, 1, 1, 1, 1084.75878), -- Bronze Shield
(20072, 45, 1, 1, 1, 760.678815), -- Bone Helmet
(20072, 1932, 1, 1, 1, 14549.562405), -- Bone Helmet Design
(20072, 1866, 1, 1, 2, 26189.970019), -- Suede
(20072, 1871, 1, 1, 2, 39285.011773), -- Charcoal
(20072, 5220, 1, 1, 2, 1571.368694), -- Metal Hardener
(20072, 1885, 1, 1, 2, 3273.703694), -- High-Grade Suede
(20072, 2262, 1, 1, 2, 610.003375), -- Recipe: Elven Bow
(20072, 6666, 1, 1, 2, 39285.011773), -- Deluxe Chest Key - Grade 2
(20072, 6035, 1, 1, 2, 3273.930672), -- Magic Haste Potion
-- Androscorpio
(20074, 1869, 1, 1, -1, 507790), -- Iron Ore
(20074, 1061, 1, 1, -1, 307751), -- Greater Healing Potion
(20074, 1900, 1, 1, -1, 55557), -- Enchanted Necklace Chain
(20074, 57, 215, 426, 0, 700000), -- Adena
(20074, 1123, 1, 1, 1, 1084), -- Blue Buckskin Boots
(20074, 605, 1, 1, 1, 1084), -- Leather Gauntlets
(20074, 1869, 1, 1, 2, 46247.94342), -- Iron Ore
(20074, 1864, 1, 1, 2, 92495.88684), -- Stem
(20074, 1880, 1, 1, 2, 4624.83948), -- Steel
(20074, 5550, 1, 1, 2, 616.58508), -- Durable Metal Plate
(20074, 737, 1, 1, 2, 4624.83948), -- Scroll of Resurrection
(20074, 6387, 1, 1, 2, 1849.9057), -- Blessed Scroll of Resurrection for Pets
-- Ant Larva
(20075, 1061, 1, 1, -1, 282105), -- Greater Healing Potion
(20075, 348, 1, 1, -1, 908), -- Scale Mail
(20075, 2153, 1, 1, -1, 72391), -- Recipe: Tiger's Eye Earring
(20075, 57, 197, 391, 0, 700000), -- Adena
(20075, 848, 1, 1, 1, 387.77028), -- Enchanted Earring
(20075, 911, 1, 1, 1, 291.04554), -- Enchanted Necklace
(20075, 1900, 1, 1, 1, 6957.75324), -- Enchanted Necklace Chain
(20075, 879, 1, 1, 1, 583.43094), -- Enchanted Ring
(20075, 1871, 1, 1, 2, 42393.94416), -- Charcoal
(20075, 1866, 1, 1, 2, 28262.62944), -- Suede
(20075, 1877, 1, 1, 2, 1695.796016), -- Adamantite Nugget
(20075, 955, 1, 1, 2, 169.636976), -- Scroll: Enchant Weapon (D-Grade)
(20075, 2193, 1, 1, 2, 5675.2844), -- Recipe: Boots of Power
(20075, 1831, 1, 1, 2, 113050.709008), -- Antidote
-- Ol Mahum Commander
(20076, 2250, 1, 1, -1, 134666), -- Recipe: Bone Arrow
(20076, 1880, 1, 1, -1, 53866), -- Steel
(20076, 1900, 1, 1, -1, 58935), -- Enchanted Necklace Chain
(20076, 57, 228, 452, 0, 700000), -- Adena
(20076, 1123, 1, 1, 1, 1150), -- Blue Buckskin Boots
(20076, 605, 1, 1, 1, 1150), -- Leather Gauntlets
(20076, 1869, 1, 1, 2, 49059.738825), -- Iron Ore
(20076, 1864, 1, 1, 2, 98119.47765), -- Stem
(20076, 1880, 1, 1, 2, 4906.0203), -- Steel
(20076, 5550, 1, 1, 2, 654.1773), -- Durable Metal Plate
(20076, 956, 1, 1, 2, 1635.288525), -- Scroll: Enchant Armor (D-Grade)
(20076, 2274, 1, 1, 2, 350.2974), -- Recipe: Skull Breaker
-- Androscorpio Hunter
(20077, 2153, 1, 1, -1, 82578), -- Recipe: Tiger's Eye Earring
(20077, 1933, 1, 1, -1, 62468), -- Dark Stockings Fabric
(20077, 2183, 1, 1, -1, 34933), -- Recipe: Mithril Banded Mail
(20077, 57, 224, 448, 0, 700000), -- Adena
(20077, 627, 1, 1, 1, 1078.49287), -- Aspis
(20077, 46, 1, 1, 1, 755.50713), -- Bronze Helmet
(20077, 1870, 1, 1, 2, 72539.884816), -- Coal
(20077, 1865, 1, 1, 2, 72539.884816), -- Varnish
(20077, 1874, 1, 1, 2, 4836.032376), -- Oriharukon Ore
(20077, 955, 1, 1, 2, 290.197992), -- Scroll: Enchant Weapon (D-Grade)
-- Whispering Wind
(20078, 2024, 1, 1, -1, 7564), -- Elven Bow Shaft
(20078, 2023, 1, 1, -1, 6580), -- Conjuror's Staff Head
(20078, 1900, 1, 1, -1, 58094), -- Enchanted Necklace Chain
(20078, 57, 224, 448, 0, 700000), -- Adena
(20078, 433, 1, 1, 1, 94.332676), -- Elven Tunic
(20078, 434, 1, 1, 1, 94.332676), -- White Tunic
(20078, 1936, 1, 1, 1, 2968.270564), -- White Tunic Pattern
(20078, 435, 1, 1, 1, 94.332676), -- Mystic's Tunic
(20078, 466, 1, 1, 1, 151.133176), -- Elven Stockings
(20078, 467, 1, 1, 1, 151.133176), -- Dark Stockings
(20078, 1933, 1, 1, 1, 4267.323908), -- Dark Stockings Fabric
(20078, 468, 1, 1, 1, 151.141148), -- Mystic's Stockings
(20078, 1868, 1, 1, 2, 116063.493736), -- Thread
(20078, 1873, 1, 1, 2, 23212.73434), -- Silver Nugget
(20078, 5549, 1, 1, 2, 5803.228076), -- Metallic Thread
(20078, 1889, 1, 1, 2, 3868.759396), -- Compound Braid
(20078, 736, 1, 1, 2, 29015.784452), -- Scroll of Escape
-- Ant
(20079, 1866, 1, 1, -1, 353985), -- Suede
(20079, 2266, 1, 1, -1, 5491), -- Recipe: Shilen Knife
(20079, 1881, 1, 1, -1, 70797), -- Coarse Bone Powder
(20079, 57, 224, 448, 0, 700000), -- Adena
(20079, 848, 1, 1, 1, 442.303424), -- Enchanted Earring
(20079, 911, 1, 1, 1, 331.976032), -- Enchanted Necklace
(20079, 1900, 1, 1, 1, 7936.240192), -- Enchanted Necklace Chain
(20079, 879, 1, 1, 1, 665.480352), -- Enchanted Ring
(20079, 1872, 1, 1, 2, 55268.379684), -- Animal Bone
(20079, 1867, 1, 1, 2, 55268.379684), -- Animal Skin
(20079, 1881, 1, 1, 2, 5526.88206), -- Coarse Bone Powder
(20079, 1875, 1, 1, 2, 2763.367544), -- Stone of Purity
(20079, 2183, 1, 1, 2, 2727.06546), -- Recipe: Mithril Banded Mail
(20079, 2278, 1, 1, 2, 296.14858), -- Recipe: Reinforced Long Bow
(20079, 1061, 1, 1, 2, 25121.776988), -- Greater Healing Potion
-- Ant Captain
(20080, 2268, 1, 1, -1, 5950), -- Recipe: Tome of Blood
(20080, 2021, 1, 1, -1, 7264), -- Spinebone Sword Blade
(20080, 1878, 1, 1, -1, 230138), -- Braided Hemp
(20080, 57, 243, 485, 0, 700000), -- Adena
(20080, 259, 1, 1, 1, 127), -- Single-Edged Jamadhr
(20080, 1864, 1, 1, 2, 104801.321735), -- Stem
(20080, 1869, 1, 1, 2, 52400.76974), -- Iron Ore
(20080, 1878, 1, 1, 2, 20960.351445), -- Braided Hemp
(20080, 1884, 1, 1, 2, 32246.510285), -- Cord
(20080, 737, 1, 1, 2, 5240.033425), -- Scroll of Resurrection
(20080, 6387, 1, 1, 2, 2096.01337), -- Blessed Scroll of Resurrection for Pets
-- Ant Overseer
(20081, 1061, 1, 1, -1, 583400), -- Greater Healing Potion
(20081, 1933, 1, 1, -1, 113248), -- Dark Stockings Fabric
(20081, 57, 406, 814, 0, 700000), -- Adena
(20081, 848, 1, 1, 1, 801.863652), -- Enchanted Earring
(20081, 911, 1, 1, 1, 601.848186), -- Enchanted Necklace
(20081, 1900, 1, 1, 1, 14387.821116), -- Enchanted Necklace Chain
(20081, 879, 1, 1, 1, 1206.467046), -- Enchanted Ring
(20081, 1874, 1, 1, 2, 5009.78334), -- Oriharukon Ore
(20081, 1878, 1, 1, 2, 30058.609398), -- Braided Hemp
(20081, 1884, 1, 1, 2, 46244.098128), -- Cord
(20081, 1889, 1, 1, 2, 5009.78334), -- Compound Braid
(20081, 5220, 1, 1, 2, 3005.870004), -- Metal Hardener
(20081, 2267, 1, 1, 2, 777.073866), -- Recipe: Gastraphetes
(20081, 2274, 1, 1, 2, 536.781924), -- Recipe: Skull Breaker
-- Ant Recruit
(20082, 1884, 1, 1, -1, 357298), -- Cord
(20082, 2275, 1, 1, -1, 4147), -- Recipe: Heavy Bone Club
(20082, 1901, 1, 1, -1, 80195), -- Tiger's Eye Earring Stone
(20082, 57, 245, 491, 0, 700000), -- Adena
(20082, 553, 1, 1, 1, 225.588736), -- Iron Boots
(20082, 1940, 1, 1, 1, 6582.467584), -- Iron Boots Design
(20082, 2422, 1, 1, 1, 225.588736), -- Reinforced Leather Boots
(20082, 2423, 1, 1, 1, 225.588736), -- Boots of Knowledge
(20082, 63, 1, 1, 1, 225.588736), -- Gauntlets
(20082, 2446, 1, 1, 1, 225.588736), -- Reinforced Leather Gloves
(20082, 2447, 1, 1, 1, 225.588736), -- Gloves of Knowledge
(20082, 1875, 1, 1, 2, 2572.555764), -- Stone of Purity
(20082, 1879, 1, 1, 2, 6431.289876), -- Cokes
(20082, 1885, 1, 1, 2, 3215.678116), -- High-Grade Suede
(20082, 5550, 1, 1, 2, 514.524424), -- Durable Metal Plate
(20082, 5549, 1, 1, 2, 3858.800468), -- Metallic Thread
(20082, 2154, 1, 1, 2, 4131.457272), -- Recipe: Elven Earring
(20082, 2190, 1, 1, 2, 2756.295528), -- Recipe: Mithril Stockings
(20082, 1832, 1, 1, 2, 42875.398552), -- Greater Antidote
-- Granite Golem
(20083, 2987, 1, 1, -1, 69132), -- Recipe: Plate Shield
(20083, 2975, 1, 1, -1, 63577), -- Recipe: Brigandine Helmet
(20083, 2154, 1, 1, -1, 76237), -- Recipe: Elven Earring
(20083, 57, 301, 602, 0, 700000), -- Adena
(20083, 393, 1, 1, 1, 107.856888), -- Mithril Banded Mail
(20083, 1938, 1, 1, 1, 4241.629608), -- Mithril Banded Mail Material
(20083, 394, 1, 1, 1, 107.856888), -- Reinforced Leather Shirt
(20083, 415, 1, 1, 1, 172.393104), -- Mithril Banded Gaiters
(20083, 1939, 1, 1, 1, 5541.880752), -- Mithril Banded Gaiters Material
(20083, 416, 1, 1, 1, 172.38276), -- Reinforced Leather Gaiters
(20083, 1874, 1, 1, 2, 3154.944515), -- Oriharukon Ore
(20083, 1878, 1, 1, 2, 18929.66709), -- Braided Hemp
(20083, 1884, 1, 1, 2, 29122.575362), -- Cord
(20083, 1889, 1, 1, 2, 3154.944515), -- Compound Braid
(20083, 5220, 1, 1, 2, 1892.966709), -- Metal Hardener
(20083, 2155, 1, 1, 2, 7596.138292), -- Recipe: Elven Ring
(20083, 2286, 1, 1, 2, 262.917789), -- Recipe: Bonebreaker
(20083, 2985, 1, 1, 2, 4838.845728), -- Recipe: Plate Boots
-- Ant Patrol
(20084, 1885, 1, 1, -1, 55207), -- High-Grade Suede
(20084, 2978, 1, 1, -1, 88686), -- Recipe: Elven Mithril Boots
(20084, 1938, 1, 1, -1, 44537), -- Mithril Banded Mail Material
(20084, 57, 280, 558, 0, 700000), -- Adena
(20084, 628, 1, 1, 1, 858.99538), -- Hoplon
(20084, 47, 1, 1, 1, 601.00462), -- Helmet
(20084, 1876, 1, 1, 2, 8805.965454), -- Mithril Ore
(20084, 1880, 1, 1, 2, 4402.982727), -- Steel
(20084, 1877, 1, 1, 2, 1761.157079), -- Adamantite Nugget
(20084, 1881, 1, 1, 2, 5870.643636), -- Coarse Bone Powder
(20084, 1882, 1, 1, 2, 9784.40606), -- Leather
(20084, 2269, 1, 1, 2, 314.563073), -- Recipe: Morning Star
(20084, 2971, 1, 1, 2, 2354.451484), -- Recipe: Mithril Scale Gaiters
(20084, 1341, 10, 30, 2, 146764.830487), -- Bone Arrow
-- Puncher
(20085, 2278, 1, 1, -1, 5472), -- Recipe: Reinforced Long Bow
(20085, 2422, 1, 1, -1, 3918), -- Reinforced Leather Boots
(20085, 2155, 1, 1, -1, 122961), -- Recipe: Elven Ring
(20085, 57, 324, 645, 0, 700000), -- Adena
(20085, 553, 1, 1, 1, 297.62022), -- Iron Boots
(20085, 1940, 1, 1, 1, 8684.27868), -- Iron Boots Design
(20085, 2422, 1, 1, 1, 297.62022), -- Reinforced Leather Boots
(20085, 2423, 1, 1, 1, 297.62022), -- Boots of Knowledge
(20085, 63, 1, 1, 1, 297.62022), -- Gauntlets
(20085, 2446, 1, 1, 1, 297.62022), -- Reinforced Leather Gloves
(20085, 2447, 1, 1, 1, 297.62022), -- Gloves of Knowledge
(20085, 1870, 1, 1, 2, 67883.652096), -- Coal
(20085, 1865, 1, 1, 2, 67883.652096), -- Varnish
(20085, 1874, 1, 1, 2, 4525.517568), -- Oriharukon Ore
(20085, 2270, 1, 1, 2, 484.866304), -- Recipe: Goat Head Staff
(20085, 2293, 1, 1, 2, 377.200512), -- Recipe: Glaive
(20085, 2986, 1, 1, 2, 6941.111424), -- Recipe: Sage's Worn Gloves
-- Ant Guard
(20086, 1868, 1, 3, -1, 588224), -- Thread
(20086, 469, 1, 1, -1, 1607), -- Stockings of Knowledge
(20086, 1939, 1, 1, -1, 51667), -- Mithril Banded Gaiters Material
(20086, 57, 248, 496, 0, 700000), -- Adena
(20086, 436, 1, 1, 1, 267.47631), -- Tunic of Knowledge
(20086, 469, 1, 1, 1, 427.52369), -- Stockings of Knowledge
(20086, 1874, 1, 1, 2, 2978.613478), -- Oriharukon Ore
(20086, 1878, 1, 1, 2, 17871.56923), -- Braided Hemp
(20086, 1884, 1, 1, 2, 27494.709011), -- Cord
(20086, 1889, 1, 1, 2, 2978.613478), -- Compound Braid
(20086, 5220, 1, 1, 2, 1787.156923), -- Metal Hardener
(20086, 2972, 1, 1, 2, 2389.220657), -- Recipe: Brigandine Gaiters
(20086, 8307, 1, 1, 2, 319.117223), -- Recipe: Priest Mace (100%)
-- Ant Soldier
(20087, 2191, 1, 1, -1, 188912), -- Recipe: RIP Gauntlets
(20087, 1940, 1, 1, -1, 210623), -- Iron Boots Design
(20087, 1866, 1, 1, -1, 940782), -- Suede
(20087, 57, 596, 1189, 0, 700000), -- Adena
(20087, 393, 1, 1, 1, 213.763927), -- Mithril Banded Mail
(20087, 1938, 1, 1, 1, 8406.578557), -- Mithril Banded Mail Material
(20087, 394, 1, 1, 1, 213.763927), -- Reinforced Leather Shirt
(20087, 415, 1, 1, 1, 341.669666), -- Mithril Banded Gaiters
(20087, 1939, 1, 1, 1, 10983.574758), -- Mithril Banded Gaiters Material
(20087, 416, 1, 1, 1, 341.649165), -- Reinforced Leather Gaiters
(20087, 1871, 1, 1, 2, 93788.817808), -- Charcoal
(20087, 1866, 1, 1, 2, 62525.7801), -- Suede
(20087, 1877, 1, 1, 2, 3751.694464), -- Adamantite Nugget
(20087, 2975, 1, 1, 2, 8373.980496), -- Recipe: Brigandine Helmet
(20087, 2984, 1, 1, 2, 9589.796468), -- Recipe: Salamander Skin Boots
(20087, 3020, 1, 1, 2, 520.937424), -- Recipe: Elven Long Sword
(20087, 2980, 1, 1, 2, 12555.35974), -- Recipe: Brigandine Gauntlets
(20087, 1832, 1, 1, 2, 104209.6335), -- Greater Antidote
-- Ant Warrior Captain
(20088, 2149, 1, 1, -1, 112102), -- Recipe: Metallic Fiber
(20088, 1895, 1, 1, -1, 448410), -- Metallic Fiber
(20088, 1875, 1, 1, -1, 104629), -- Stone of Purity
(20088, 57, 662, 1326, 0, 700000), -- Adena
(20088, 293, 1, 1, 1, 112), -- War Hammer
(20088, 296, 1, 1, 1, 112), -- Dwarven Pike
(20088, 1872, 1, 1, 2, 185434.842315), -- Animal Bone
(20088, 1867, 1, 1, 2, 185434.842315), -- Animal Skin
(20088, 1881, 1, 1, 2, 18543.684457), -- Coarse Bone Powder
(20088, 1875, 1, 1, 2, 9271.642003), -- Stone of Purity
(20088, 2270, 1, 1, 2, 993.518931), -- Recipe: Goat Head Staff
(20088, 2288, 1, 1, 2, 772.469979), -- Recipe: Ghost Staff
-- Noble Ant
(20089, 1884, 1, 1, -1, 402384), -- Cord
(20089, 2159, 1, 1, -1, 40363), -- Recipe: Necklace of Darkness
(20089, 1902, 1, 1, -1, 66249), -- Elven Earring Beads
(20089, 57, 276, 551, 0, 700000), -- Adena
(20089, 395, 1, 1, 1, 98.256501), -- Manticore Skin Shirt
(20089, 1942, 1, 1, 1, 4310.137062), -- Manticore Skin Shirt Texture
(20089, 417, 1, 1, 1, 156.919455), -- Manticore Skin Gaiters
(20089, 1943, 1, 1, 1, 6711.686982), -- Manticore Skin Gaiters Pattern
(20089, 1875, 1, 1, 2, 2816.692902), -- Stone of Purity
(20089, 1879, 1, 1, 2, 7041.719876), -- Cokes
(20089, 1885, 1, 1, 2, 3520.859938), -- High-Grade Suede
(20089, 5550, 1, 1, 2, 563.343532), -- Durable Metal Plate
(20089, 5549, 1, 1, 2, 4225.026974), -- Metallic Thread
(20089, 1825, 1, 1, 2, 3017.87641), -- Recipe: Oriharukon
(20089, 2205, 1, 1, 2, 1337.031032), -- Recipe: Chain Gaiters
(20089, 2989, 1, 1, 2, 2235.449336), -- Recipe: Chain Hood
-- Noble Ant Leader
(20090, 2197, 1, 1, -1, 30160), -- Recipe: Salamander Skin Mail
(20090, 1868, 1, 7, -1, 719317), -- Thread
(20090, 1825, 1, 1, -1, 102760), -- Recipe: Oriharukon
(20090, 57, 608, 1214, 0, 700000), -- Adena
(20090, 352, 1, 1, 1, 107.918108), -- Brigandine Tunic
(20090, 1941, 1, 1, 1, 4929.057129), -- Brigandine Temper
(20090, 2377, 1, 1, 1, 172.624777), -- Mithril Scale Gaiters
(20090, 2918, 1, 1, 1, 7353.397649), -- Mithril Scale Gaiters Material
(20090, 2378, 1, 1, 1, 172.624777), -- Brigandine Gaiters
(20090, 2919, 1, 1, 1, 7353.37756), -- Brigandine Gaiters Material
(20090, 1876, 1, 1, 2, 18591.570984), -- Mithril Ore
(20090, 1880, 1, 1, 2, 9295.785492), -- Steel
(20090, 1877, 1, 1, 2, 3718.47126), -- Adamantite Nugget
(20090, 1881, 1, 1, 2, 12394.24977), -- Coarse Bone Powder
(20090, 1882, 1, 1, 2, 20656.952064), -- Leather
(20090, 2158, 1, 1, 2, 11504.486742), -- Recipe: Mithril Ring
(20090, 5472, 1, 1, 2, 6639.84678), -- Recipe: Metallic Thread(100%)
(20090, 1341, 10, 30, 2, 309856.636908), -- Bone Arrow
-- Monster Eye
(20092, 1666, 1, 1, -1, 49062), -- Recipe: Wooden Arrow
(20092, 1866, 1, 1, -1, 98124), -- Suede
(20092, 2005, 1, 1, -1, 10513), -- Broadsword Blade
(20092, 57, 79, 107, 0, 700000), -- Adena
(20092, 113, 1, 1, 1, 9349.784408), -- Mystic's Earring
(20092, 906, 1, 1, 1, 6984.16868), -- Necklace of Knowledge
(20092, 875, 1, 1, 1, 13802.046912), -- Ring of Knowledge
(20092, 1869, 1, 1, 2, 14492.038992), -- Iron Ore
(20092, 1870, 1, 1, 2, 14492.038992), -- Coal
(20092, 1871, 1, 1, 2, 14492.038992), -- Charcoal
(20092, 1872, 1, 1, 2, 19322.718656), -- Animal Bone
(20092, 1867, 1, 1, 2, 19322.718656), -- Animal Skin
(20092, 2137, 1, 1, 2, 4262.445712), -- Recipe: Steel
-- Orc Fighter
(20093, 1867, 1, 1, -1, 242609), -- Animal Skin
(20093, 2007, 1, 1, -1, 12997), -- Bow Shaft
(20093, 1666, 1, 1, -1, 60652), -- Recipe: Wooden Arrow
(20093, 57, 98, 132, 0, 700000), -- Adena
(20093, 3, 1, 1, 1, 1119.771954), -- Broadsword
(20093, 2005, 1, 1, 1, 3839.228046), -- Broadsword Blade
(20093, 1872, 1, 1, 2, 35831.462786), -- Animal Bone
(20093, 1867, 1, 1, 2, 35831.462786), -- Animal Skin
(20093, 2138, 1, 1, 2, 7904.062642), -- Recipe: Coarse Bone Powder (100%)
(20093, 1060, 1, 1, 2, 59719.011786), -- Lesser Healing Potion
-- Vampire Bat
(20095, 1864, 1, 1, -1, 297315), -- Stem
(20095, 2006, 1, 1, -1, 10618), -- Willow Staff Head
(20095, 57, 80, 108, 0, 700000), -- Adena
(20095, 428, 1, 1, 1, 2348.272102), -- Feriotic Tunic
(20095, 1100, 1, 1, 1, 2348.272102), -- Cotton Tunic
(20095, 463, 1, 1, 1, 3753.227898), -- Feriotic Stockings
(20095, 1103, 1, 1, 1, 3753.227898), -- Cotton Stockings
(20095, 1864, 1, 1, 2, 58547.899942), -- Stem
(20095, 1869, 1, 1, 2, 29273.949971), -- Iron Ore
(20095, 1789, 1, 1, 2, 5411.150087), -- Recipe: Cedar Staff
-- Orc Lieutenant
(20096, 1799, 1, 1, -1, 298635), -- Recipe: Leather Gloves
(20096, 1921, 1, 1, -1, 130051), -- Leather Shoes Texture
(20096, 1792, 1, 1, -1, 14822), -- Recipe: Short Spear
(20096, 57, 109, 147, 0, 700000), -- Adena
(20096, 37, 1, 1, 1, 3891.653613), -- Leather Shoes
(20096, 1921, 1, 1, 1, 25609.659381), -- Leather Shoes Texture
(20096, 49, 1, 1, 1, 3891.687006), -- Gloves
(20096, 1869, 1, 1, 2, 19847.655828), -- Iron Ore
(20096, 1870, 1, 1, 2, 19847.655828), -- Coal
(20096, 1871, 1, 1, 2, 19847.655828), -- Charcoal
(20096, 1872, 1, 1, 2, 26463.541104), -- Animal Bone
(20096, 1867, 1, 1, 2, 26463.541104), -- Animal Skin
(20096, 736, 1, 1, 2, 9923.950308), -- Scroll of Escape
-- Drill Bat
(20097, 1864, 1, 1, -1, 335964), -- Stem
(20097, 1793, 1, 1, -1, 12352), -- Recipe: Sword of Reflection
(20097, 1872, 1, 1, -1, 223976), -- Animal Bone
(20097, 57, 91, 122, 0, 700000), -- Adena
(20097, 23, 1, 1, 1, 1081.06461), -- Wooden Breastplate
(20097, 30, 1, 1, 1, 1731.967695), -- Hard Leather Pants
(20097, 2386, 1, 1, 1, 1731.967695), -- Wooden Gaiters
(20097, 1872, 1, 1, 2, 44105.829452), -- Animal Bone
(20097, 1867, 1, 1, 2, 44105.829452), -- Animal Skin
(20097, 1792, 1, 1, 2, 2432.341096), -- Recipe: Short Spear
-- Orc Fighter Leader
(20098, 1867, 1, 1, -1, 292047), -- Animal Skin
(20098, 1870, 1, 1, -1, 219036), -- Coal
(20098, 1896, 1, 1, -1, 92812), -- Necklace of Anguish Chain
(20098, 57, 117, 161, 0, 700000), -- Adena
(20098, 66, 1, 1, 1, 207.363975), -- Gladius
(20098, 1333, 1, 1, 1, 207.363975), -- Brandish
(20098, 2010, 1, 1, 1, 1678.27205), -- Brandish Blade
(20098, 1865, 1, 1, 2, 43133.26426), -- Varnish
(20098, 1870, 1, 1, 2, 43133.26426), -- Coal
(20098, 1793, 1, 1, 2, 3171.47148), -- Recipe: Sword of Reflection
-- Skeleton
(20099, 2009, 1, 1, -1, 6303), -- Dirk Blade
(20099, 1831, 1, 1, -1, 473949), -- Antidote
(20099, 1896, 1, 1, -1, 75310), -- Necklace of Anguish Chain
(20099, 57, 95, 131, 0, 700000), -- Adena
(20099, 66, 1, 1, 1, 168.22935), -- Gladius
(20099, 1333, 1, 1, 1, 168.22935), -- Brandish
(20099, 2010, 1, 1, 1, 1361.5413), -- Brandish Blade
(20099, 1864, 1, 1, 2, 34999.480344), -- Stem
(20099, 1865, 1, 1, 2, 17499.740172), -- Varnish
(20099, 1866, 1, 1, 2, 11666.493448), -- Suede
(20099, 1873, 1, 1, 2, 6999.853088), -- Silver Nugget
(20099, 1868, 1, 1, 2, 34999.480344), -- Thread
(20099, 1794, 1, 1, 2, 1286.952604), -- Recipe: Forest Bow
-- Skeleton Archer
(20100, 1833, 1, 1, -1, 502269), -- Bandage
(20100, 1866, 1, 1, -1, 125567), -- Suede
(20100, 1792, 1, 1, -1, 13849), -- Recipe: Short Spear
(20100, 57, 99, 140, 0, 700000), -- Adena
(20100, 271, 1, 1, 1, 535), -- Hunting Bow
(20100, 1866, 1, 1, 2, 24727.163755), -- Suede
(20100, 1871, 1, 1, 2, 37090.687249), -- Charcoal
(20100, 1799, 1, 1, 2, 54949.148996), -- Recipe: Leather Gloves
-- Crasher
(20101, 20, 1, 1, -1, 23417), -- Buckler
(20101, 1921, 1, 1, -1, 161654), -- Leather Shoes Texture
(20101, 1793, 1, 1, -1, 18424), -- Recipe: Sword of Reflection
(20101, 57, 128, 189, 0, 700000), -- Adena
(20101, 114, 1, 1, 1, 2192.993905), -- Earring of Strength
(20101, 115, 1, 1, 1, 2192.993905), -- Earring of Wisdom
(20101, 907, 1, 1, 1, 1644.750895), -- Necklace of Anguish
(20101, 1896, 1, 1, 1, 12544.73764), -- Necklace of Anguish Chain
(20101, 876, 1, 1, 1, 3289.523655), -- Ring of Anguish
(20101, 1864, 1, 1, 2, 49341.773522), -- Stem
(20101, 1865, 1, 1, 2, 24670.971962), -- Varnish
(20101, 1866, 1, 1, 2, 16447.20104), -- Suede
(20101, 1873, 1, 1, 2, 9868.320624), -- Silver Nugget
(20101, 1868, 1, 1, 2, 49341.773522), -- Thread
(20101, 1803, 1, 1, 2, 20731.95933), -- Recipe: Necklace of Wisdom
-- Skeleton Marksman
(20102, 1866, 1, 1, -1, 127538), -- Suede
(20102, 1922, 1, 1, -1, 48803), -- Leather Tunic Pattern
(20102, 1793, 1, 1, -1, 14067), -- Recipe: Sword of Reflection
(20102, 57, 98, 145, 0, 700000), -- Adena
(20102, 271, 1, 1, 1, 543), -- Hunting Bow
(20102, 1864, 1, 1, 2, 75345.199366), -- Stem
(20102, 1869, 1, 1, 2, 37672.533756), -- Iron Ore
(20102, 736, 1, 1, 2, 18836.266878), -- Scroll of Escape
-- Giant Spider
(20103, 1803, 1, 1, -1, 198526), -- Recipe: Necklace of Wisdom
(20103, 1871, 1, 1, -1, 236245), -- Charcoal
(20103, 1921, 1, 1, -1, 152416), -- Leather Shoes Texture
(20103, 57, 119, 180, 0, 700000), -- Adena
(20103, 37, 1, 1, 1, 4560.948576), -- Leather Shoes
(20103, 1921, 1, 1, 1, 30014.063712), -- Leather Shoes Texture
(20103, 49, 1, 1, 1, 4560.987712), -- Gloves
(20103, 1867, 1, 1, 2, 46522.183748), -- Animal Skin
(20103, 1872, 1, 1, 2, 46522.183748), -- Animal Bone
(20103, 1794, 1, 1, 2, 2565.646), -- Recipe: Forest Bow
(20103, 17, 10, 30, 2, 174457.986504), -- Wooden Arrow
-- Skeleton Lord
(20104, 1869, 1, 1, -1, 193011), -- Iron Ore
(20104, 1868, 1, 1, -1, 386022), -- Thread
(20104, 57, 97, 147, 0, 700000), -- Adena
(20104, 271, 1, 1, 1, 548), -- Hunting Bow
(20104, 1873, 1, 1, 2, 11402.500967), -- Silver Nugget
(20104, 1868, 1, 1, 2, 57012.504835), -- Thread
(20104, 736, 1, 1, 2, 14253.069909), -- Scroll of Escape
(20104, 17, 10, 30, 2, 142530.924289), -- Wooden Arrow
-- Dark Horror
(20105, 734, 1, 1, -1, 39986), -- Haste Potion
(20105, 1801, 1, 1, -1, 120865), -- Recipe: Piece Bone Gaiters
(20105, 1872, 1, 1, -1, 319890), -- Animal Bone
(20105, 57, 119, 185, 0, 700000), -- Adena
(20105, 15, 1, 1, 1, 135.010872), -- Short Spear
(20105, 2011, 1, 1, 1, 1616.989128), -- Short Spear Edge
(20105, 1867, 1, 1, 2, 47245.15581), -- Animal Skin
(20105, 1872, 1, 1, 2, 47245.15581), -- Animal Bone
(20105, 2140, 1, 1, 2, 7086.82041), -- Recipe: High-Grade Suede
(20105, 735, 1, 1, 2, 2952.86797), -- Alacrity Potion
-- Talon Spider
(20106, 2150, 1, 1, -1, 111533), -- Recipe: Blue Diamond Necklace
(20106, 1897, 1, 1, -1, 56563), -- Necklace of Wisdom Chain
(20106, 734, 1, 1, -1, 39594), -- Haste Potion
(20106, 57, 118, 183, 0, 700000), -- Adena
(20106, 38, 1, 1, 1, 1795.866945), -- Low Boots
(20106, 50, 1, 1, 1, 1795.866945), -- Leather Gloves
(20106, 1925, 1, 1, 1, 30677.26611), -- Leather Gloves Lining
(20106, 1867, 1, 1, 2, 46782.15126), -- Animal Skin
(20106, 1872, 1, 1, 2, 46782.15126), -- Animal Bone
(20106, 2141, 1, 1, 2, 7017.281895), -- Recipe: Silver Mold
(20106, 5273, 1, 1, 2, 1403.415585), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Wererat
(20107, 1869, 1, 1, -1, 197971), -- Iron Ore
(20107, 734, 1, 1, -1, 32995), -- Haste Potion
(20107, 1897, 1, 1, -1, 47136), -- Necklace of Wisdom Chain
(20107, 57, 98, 153, 0, 700000), -- Adena
(20107, 217, 1, 1, 1, 111.5), -- Shining Knife
(20107, 218, 1, 1, 1, 111.5), -- Throwing Knife
(20107, 1865, 1, 1, 2, 29238.818472), -- Varnish
(20107, 1870, 1, 1, 2, 29238.818472), -- Coal
(20107, 2142, 1, 1, 2, 5847.750342), -- Recipe: Varnish of Purity
(20107, 6035, 1, 1, 2, 2436.612714), -- Magic Haste Potion
-- Blade Spider
(20108, 1866, 1, 1, -1, 167333), -- Suede
(20108, 734, 1, 1, -1, 41833), -- Haste Potion
(20108, 1800, 1, 1, -1, 78931), -- Recipe: Piece Bone Breastplate
(20108, 57, 122, 197, 0, 700000), -- Adena
(20108, 38, 1, 1, 1, 1897.427835), -- Low Boots
(20108, 50, 1, 1, 1, 1897.427835), -- Leather Gloves
(20108, 1925, 1, 1, 1, 32412.14433), -- Leather Gloves Lining
(20108, 1872, 1, 1, 2, 49427.752743), -- Animal Bone
(20108, 1867, 1, 1, 2, 49427.752743), -- Animal Skin
(20108, 2144, 1, 1, 2, 7414.212123), -- Recipe: Compound Braid
(20108, 735, 1, 1, 2, 3089.282391), -- Alacrity Potion
-- Salamander
(20109, 1865, 1, 1, -1, 401928), -- Varnish
(20109, 845, 1, 1, -1, 11752), -- Cat's Eye Earring
(20109, 1924, 1, 1, -1, 129654), -- Leather Helmet Design
(20109, 57, 196, 315, 0, 700000), -- Adena
(20109, 24, 1, 1, 1, 760.9576), -- Bone Breastplate
(20109, 390, 1, 1, 1, 760.9576), -- Cotton Shirt
(20109, 31, 1, 1, 1, 1215.0424), -- Bone Gaiters
(20109, 412, 1, 1, 1, 1215.0424), -- Cotton Pants
(20109, 1864, 1, 1, 2, 67841.751901), -- Stem
(20109, 1865, 1, 1, 2, 33920.987485), -- Varnish
(20109, 1866, 1, 1, 2, 22613.842944), -- Suede
(20109, 1873, 1, 1, 2, 13568.394994), -- Silver Nugget
(20109, 1868, 1, 1, 2, 67841.751901), -- Thread
(20109, 2150, 1, 1, 2, 15925.342048), -- Recipe: Blue Diamond Necklace
(20109, 5273, 1, 1, 2, 1356.928727), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Undine
(20110, 734, 1, 1, -1, 64842), -- Haste Potion
(20110, 1897, 1, 1, -1, 92631), -- Necklace of Wisdom Chain
(20110, 1801, 1, 1, -1, 195995), -- Recipe: Piece Bone Gaiters
(20110, 57, 190, 305, 0, 700000), -- Adena
(20110, 24, 1, 1, 1, 736.6963), -- Bone Breastplate
(20110, 390, 1, 1, 1, 736.6963), -- Cotton Shirt
(20110, 31, 1, 1, 1, 1176.3037), -- Bone Gaiters
(20110, 412, 1, 1, 1, 1176.3037), -- Cotton Pants
(20110, 1871, 1, 1, 2, 76612.6698), -- Charcoal
(20110, 1866, 1, 1, 2, 51075.1132), -- Suede
(20110, 2173, 1, 1, 2, 20762.217), -- Recipe: Hard Leather Shirt
-- Salamander Elder
(20112, 1800, 1, 1, -1, 123442), -- Recipe: Piece Bone Breastplate
(20112, 1924, 1, 1, -1, 126628), -- Leather Helmet Design
(20112, 1801, 1, 1, -1, 197756), -- Recipe: Piece Bone Gaiters
(20112, 57, 188, 310, 0, 700000), -- Adena
(20112, 1101, 1, 1, 1, 1486.48986), -- Tunic of Devotion
(20112, 1104, 1, 1, 1, 2373.51014), -- Stockings of Devotion
(20112, 1864, 1, 1, 2, 92761.67314), -- Stem
(20112, 1869, 1, 1, 2, 46380.83657), -- Iron Ore
(20112, 1878, 1, 1, 2, 18552.37063), -- Braided Hemp
(20112, 1800, 1, 1, 2, 14585.13024), -- Recipe: Piece Bone Breastplate
(20112, 734, 1, 1, 2, 7729.98942), -- Haste Potion
-- Undine Elder
(20113, 1925, 1, 1, -1, 262556), -- Leather Gloves Lining
(20113, 1870, 1, 1, -1, 400397), -- Coal
(20113, 1879, 1, 1, -1, 66733), -- Cokes
(20113, 57, 192, 316, 0, 700000), -- Adena
(20113, 24, 1, 1, 1, 758.06935), -- Bone Breastplate
(20113, 390, 1, 1, 1, 758.06935), -- Cotton Shirt
(20113, 31, 1, 1, 1, 1210.43065), -- Bone Gaiters
(20113, 412, 1, 1, 1, 1210.43065), -- Cotton Pants
(20113, 1865, 1, 1, 2, 47308.454061), -- Varnish
(20113, 1870, 1, 1, 2, 47308.454061), -- Coal
(20113, 1879, 1, 1, 2, 7884.806457), -- Cokes
(20113, 1801, 1, 1, 2, 23833.039582), -- Recipe: Piece Bone Gaiters
(20113, 5273, 1, 1, 2, 1892.245839), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Salamander Noble
(20114, 735, 1, 1, -1, 33735), -- Alacrity Potion
(20114, 2011, 1, 1, -1, 9235), -- Short Spear Edge
(20114, 1817, 1, 1, -1, 80965), -- Recipe: Cord
(20114, 57, 190, 323, 0, 700000), -- Adena
(20114, 845, 1, 1, 1, 1748.194758), -- Cat's Eye Earring
(20114, 908, 1, 1, 1, 1311.156027), -- Necklace of Wisdom
(20114, 1897, 1, 1, 1, 14235.357078), -- Necklace of Wisdom Chain
(20114, 877, 1, 1, 1, 2622.292137), -- Ring of Wisdom
(20114, 1866, 1, 1, 2, 39859.7892), -- Suede
(20114, 1871, 1, 1, 2, 59789.80039), -- Charcoal
(20114, 1817, 1, 1, 2, 11957.93676), -- Recipe: Cord
(20114, 6035, 1, 1, 2, 4982.47365), -- Magic Haste Potion
-- Undine Noble
(20115, 2012, 1, 1, -1, 8603), -- Sword of Reflection Blade
(20115, 2139, 1, 1, -1, 82584), -- Recipe: Steel Mold
(20115, 2013, 1, 1, -1, 8912), -- Forest Bow Shaft
(20115, 57, 194, 330, 0, 700000), -- Adena
(20115, 38, 1, 1, 1, 3121.45142), -- Low Boots
(20115, 50, 1, 1, 1, 3121.45142), -- Leather Gloves
(20115, 1925, 1, 1, 1, 53321.09716), -- Leather Gloves Lining
(20115, 1869, 1, 1, 2, 34848.712), -- Iron Ore
(20115, 1870, 1, 1, 2, 34848.712), -- Coal
(20115, 1871, 1, 1, 2, 34848.712), -- Charcoal
(20115, 1872, 1, 1, 2, 46465.08656), -- Animal Bone
(20115, 1867, 1, 1, 2, 46465.08656), -- Animal Skin
(20115, 2139, 1, 1, 2, 6969.7424), -- Recipe: Steel Mold
(20115, 5158, 1, 1, 2, 1393.94848), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Dre Vanul
(20117, 1868, 1, 1, -1, 505303), -- Thread
(20117, 734, 1, 1, -1, 42109), -- Haste Potion
(20117, 1925, 1, 1, -1, 165673), -- Leather Gloves Lining
(20117, 57, 117, 203, 0, 700000), -- Adena
(20117, 176, 1, 1, 1, 142), -- Apprentice's Staff
(20117, 2501, 1, 1, 1, 142), -- Bone Club
(20117, 1867, 1, 1, 2, 39802.316208), -- Animal Skin
(20117, 1872, 1, 1, 2, 39802.316208), -- Animal Bone
(20117, 1882, 1, 1, 2, 6633.735504), -- Leather
(20117, 2173, 1, 1, 2, 8089.94496), -- Recipe: Hard Leather Shirt
(20117, 735, 1, 1, 2, 2487.68712), -- Alacrity Potion
-- Dre Vanul Scout
(20118, 1866, 1, 1, -1, 193642), -- Suede
(20118, 846, 1, 1, -1, 4723), -- Coral Earring
(20118, 5549, 1, 1, -1, 29046), -- Metallic Thread
(20118, 57, 132, 236, 0, 700000), -- Adena
(20118, 87, 1, 1, 1, 45.6372), -- Iron Hammer
(20118, 2014, 1, 1, 1, 493.08903), -- Iron Hammer Head
(20118, 155, 1, 1, 1, 45.6372), -- Flanged Mace
(20118, 177, 1, 1, 1, 45.63657), -- Mage Staff
(20118, 1868, 1, 1, 2, 85798.4332), -- Thread
(20118, 1873, 1, 1, 2, 17159.6616), -- Silver Nugget
(20118, 2179, 1, 1, 2, 20525.914), -- Recipe: Crafted Leather Gloves
(20118, 5273, 1, 1, 2, 1715.9912), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Wolf
(20120, 1787, 1, 1, -1, 30885), -- Recipe: Willow Staff
(20120, 1864, 1, 1, -1, 77212), -- Stem
(20120, 1874, 1, 1, -1, 2574), -- Oriharukon Ore
(20120, 57, 19, 29, 0, 700000), -- Adena
(20120, 13, 1, 1, 1, 13530), -- Short Bow
(20120, 1870, 1, 1, 2, 9978.249995), -- Coal
(20120, 1865, 1, 1, 2, 9978.249995), -- Varnish
(20120, 1786, 1, 1, 2, 7982.599996), -- Recipe: Broad Sword
(20120, 1060, 1, 1, 2, 22173.900014), -- Lesser Healing Potion
-- Giant Toad
(20121, 1788, 1, 1, -1, 45293), -- Recipe: Bow
(20121, 1864, 1, 1, -1, 113233), -- Stem
(20121, 1786, 1, 1, -1, 45293), -- Recipe: Broad Sword
(20121, 57, 30, 42, 0, 700000), -- Adena
(20121, 4, 1, 1, 1, 9921), -- Club
(20121, 7, 1, 1, 1, 9921), -- Apprentice's Rod
(20121, 1871, 1, 1, 2, 14633.216469), -- Charcoal
(20121, 1866, 1, 1, 2, 9755.477646), -- Suede
(20121, 1786, 1, 1, 2, 11706.551323), -- Recipe: Broad Sword
(20121, 17, 10, 30, 2, 73165.754562), -- Wooden Arrow
-- Orc
(20130, 1666, 1, 1, -1, 25914), -- Recipe: Wooden Arrow
(20130, 1060, 1, 1, -1, 172757), -- Lesser Healing Potion
(20130, 2005, 1, 1, -1, 5553), -- Broadsword Blade
(20130, 57, 41, 58, 0, 700000), -- Adena
(20130, 1122, 1, 1, 1, 6514.326819), -- Cotton Shoes
(20130, 1129, 1, 1, 1, 6514.326819), -- Crude Leather Shoes
(20130, 1119, 1, 1, 1, 6514.346362), -- Short Leather Gloves
(20130, 1864, 1, 1, 2, 30618), -- Stem
(20130, 1869, 1, 1, 2, 15309), -- Iron Ore
(20130, 1666, 1, 1, 2, 5103), -- Recipe: Wooden Arrow
-- Orc Grunt
(20131, 1789, 1, 1, -1, 17988), -- Recipe: Cedar Staff
(20131, 2006, 1, 1, -1, 6951), -- Willow Staff Head
(20131, 1666, 1, 1, -1, 32439), -- Recipe: Wooden Arrow
(20131, 57, 51, 72, 0, 700000), -- Adena
(20131, 19, 1, 1, 1, 11732.93531), -- Small Shield
(20131, 42, 1, 1, 1, 8213.06469), -- Leather Cap
(20131, 1865, 1, 1, 2, 19163.735248), -- Varnish
(20131, 1870, 1, 1, 2, 19163.735248), -- Coal
(20131, 1797, 1, 1, 2, 38714.529504), -- Recipe: Leather Stockings
-- Werewolf
(20132, 1060, 1, 1, -1, 330759), -- Lesser Healing Potion
(20132, 2006, 1, 1, -1, 10632), -- Willow Staff Head
(20132, 57, 80, 108, 0, 700000), -- Adena
(20132, 254, 1, 1, 1, 1832), -- Iron Gloves
(20132, 1872, 1, 1, 2, 29310.335516), -- Animal Bone
(20132, 1867, 1, 1, 2, 29310.335516), -- Animal Skin
(20132, 1797, 1, 1, 2, 44409.563702), -- Recipe: Leather Stockings
(20132, 734, 1, 1, 2, 3663.765266), -- Haste Potion
-- Cave Maiden
(20134, 947, 1, 1, -1, 832), -- Scroll: Enchant Weapon (B-Grade)
(20134, 356, 1, 1, -1, 233), -- Full Plate Armor
(20134, 1871, 1, 5, -1, 693087), -- Charcoal
(20134, 57, 821, 1673, 0, 700000), -- Adena
(20134, 357, 1, 1, 1, 9.6201), -- Zubei's Breastplate
(20134, 4056, 1, 1, 1, 1389.919174), -- Zubei's Breastplate Part
(20134, 2376, 1, 1, 1, 9.6201), -- Avadon Breastplate
(20134, 4064, 1, 1, 1, 1389.919174), -- Avadon Breastplate Part
(20134, 383, 1, 1, 1, 15.39216), -- Zubei's Gaiters
(20134, 4057, 1, 1, 1, 2148.06144), -- Zubei's Gaiter Material
(20134, 2379, 1, 1, 1, 15.39216), -- Avadon Gaiters
(20134, 4065, 1, 1, 1, 2148.075692), -- Avadon Gaiters Material
(20134, 1866, 1, 1, 2, 34121.337873), -- Suede
(20134, 1871, 1, 1, 2, 51182.053734), -- Charcoal
(20134, 5220, 1, 1, 2, 2047.315935), -- Metal Hardener
(20134, 1885, 1, 1, 2, 4265.155503), -- High-Grade Suede
(20134, 4041, 1, 1, 2, 445.031958), -- Mold Hardener
(20134, 947, 1, 1, 2, 20.459082), -- Scroll: Enchant Weapon (B-Grade)
(20134, 4993, 1, 1, 2, 636.577767), -- Recipe: Sealed Doom Gloves (60%)
(20134, 4192, 1, 1, 2, 39.041184), -- Recipe: Sword of Damascus (100%)
(20134, 8728, 1, 1, 2, 852.993561), -- Life Stone - Level 61
(20134, 8738, 1, 1, 2, 213.224928), -- Mid-Grade Life Stone - Level 61
(20134, 8748, 1, 1, 2, 21.303723), -- High-Grade Life Stone - Level 61
(20134, 8758, 1, 1, 2, 4.504752), -- Top-Grade Life Stone - Level 61
-- Alligator
(20135, 2038, 1, 1, -1, 9877), -- Maingauche Edge
(20135, 5231, 1, 1, -1, 66770), -- Recipe: Metal Hardener (100%)
(20135, 1882, 1, 1, -1, 207728), -- Leather
(20135, 57, 390, 779, 0, 700000), -- Adena
(20135, 261, 1, 1, 1, 44.994933), -- Bich'Hwa
(20135, 2039, 1, 1, 1, 2446.005067), -- Bich'Hwa Edge
(20135, 1867, 1, 1, 2, 92039.390346), -- Animal Skin
(20135, 1872, 1, 1, 2, 92039.390346), -- Animal Bone
(20135, 1882, 1, 1, 2, 15340.003224), -- Leather
(20135, 1894, 1, 1, 2, 2422.061632), -- Crafted Leather
(20135, 2296, 1, 1, 2, 383.479114), -- Recipe: Atuba Mace
(20135, 2286, 1, 1, 2, 383.479114), -- Recipe: Bonebreaker
(20135, 2985, 1, 1, 2, 7058.196224), -- Recipe: Plate Boots
-- Death Knight
(20136, 1914, 1, 1, -1, 257308), -- Earring of Seal Gemstone
(20136, 4601, 1, 1, -1, 10178), -- Greater Dye of STR (Str+3 Con-3)
(20136, 1539, 1, 3, -1, 508898), -- Greater Healing Potion
(20136, 57, 1812, 3683, 0, 700000), -- Adena
(20136, 75, 1, 1, 1, 9.554158), -- Caliburs
(20136, 2089, 1, 1, 1, 860.114248), -- Caliburs Edge
(20136, 76, 1, 1, 1, 9.554158), -- Sword of Delusion
(20136, 2090, 1, 1, 1, 860.114248), -- Delusional Blade
(20136, 77, 1, 1, 1, 9.554158), -- Tsurugi
(20136, 2091, 1, 1, 1, 860.114248), -- Tsurugi Blade
(20136, 84, 1, 1, 1, 9.554158), -- Homunkulus's Sword
(20136, 2092, 1, 1, 1, 860.114248), -- Homunkulus's Sword Blade
(20136, 134, 1, 1, 1, 9.554158), -- Sword of Nightmare
(20136, 2095, 1, 1, 1, 860.114248), -- Sword of Nightmare Blade
(20136, 145, 1, 1, 1, 9.554158), -- Sword of Whispering Death
(20136, 2096, 1, 1, 1, 860.103812), -- Sword of Whispering Death Blade
(20136, 1869, 1, 1, 2, 172185.330568), -- Iron Ore
(20136, 1864, 1, 3, 2, 172185.330568), -- Stem
(20136, 1880, 1, 1, 2, 17218.646992), -- Steel
(20136, 5550, 1, 1, 2, 2295.79428), -- Durable Metal Plate
(20136, 4043, 1, 1, 2, 5739.675592), -- Asofe
(20136, 2169, 1, 1, 2, 3047.386816), -- Recipe: Necklace of Seal
(20136, 2232, 1, 1, 2, 989.717104), -- Recipe: Drake Leather Armor
(20136, 8725, 1, 1, 2, 4782.999696), -- Life Stone - Level 52
(20136, 8735, 1, 1, 2, 1195.560032), -- Mid-Grade Life Stone - Level 52
(20136, 8745, 1, 1, 2, 119.63196), -- High-Grade Life Stone - Level 52
(20136, 8755, 1, 1, 2, 23.926392), -- Top-Grade Life Stone - Level 52
-- Drake
(20137, 2961, 1, 1, -1, 106305), -- Full Plate Boots Part
(20137, 1877, 1, 1, -1, 78092), -- Adamantite Nugget
(20137, 4049, 1, 1, -1, 102402), -- Adamantite Earring Gemstone
(20137, 57, 770, 1572, 0, 700000), -- Adena
(20137, 11889, 1, 1, 1, 55.00082), -- Common Item - Great Sword
(20137, 4104, 1, 1, 1, 550.013594), -- Great Sword Blade
(20137, 11916, 1, 1, 1, 55.00082), -- Common Item - Keshanberk
(20137, 4107, 1, 1, 1, 541.491074), -- Keshanberk Blade
(20137, 11900, 1, 1, 1, 55.00082), -- Common Item - Sword of Valhalla
(20137, 4108, 1, 1, 1, 541.492872), -- Sword of Valhalla Blade
(20137, 1869, 1, 1, 2, 44359.859222), -- Iron Ore
(20137, 1864, 1, 1, 2, 88719.565991), -- Stem
(20137, 1880, 1, 1, 2, 4435.924941), -- Steel
(20137, 5550, 1, 1, 2, 591.51764), -- Durable Metal Plate
(20137, 4043, 1, 1, 2, 1478.641647), -- Asofe
(20137, 4952, 1, 1, 2, 570.17422), -- Recipe: Avadon Circlet (60%)
(20137, 4999, 1, 1, 2, 551.727407), -- Recipe: Sealed Doom Boots (60%)
(20137, 4163, 1, 1, 2, 293.776931), -- Recipe: Blue Wolf Stockings (100%)
(20137, 6669, 1, 1, 2, 10316.189604), -- Deluxe Chest Key - Grade 5
(20137, 8727, 1, 1, 2, 887.124007), -- Life Stone - Level 58
(20137, 8737, 1, 1, 2, 221.819115), -- Mid-Grade Life Stone - Level 58
(20137, 8747, 1, 1, 2, 22.105685), -- High-Grade Life Stone - Level 58
(20137, 8757, 1, 1, 2, 4.57359), -- Top-Grade Life Stone - Level 58
-- Grizzly
(20143, 1872, 1, 1, -1, 284370), -- Animal Bone
(20143, 1867, 1, 1, -1, 284370), -- Animal Skin
(20143, 1792, 1, 1, -1, 15682), -- Recipe: Short Spear
(20143, 57, 114, 157, 0, 700000), -- Adena
(20143, 20, 1, 1, 1, 5887.56231), -- Buckler
(20143, 43, 1, 1, 1, 4117.43769), -- Wooden Helmet
(20143, 1866, 1, 1, 2, 20999.590341), -- Suede
(20143, 1871, 1, 1, 2, 31499.505951), -- Charcoal
(20143, 1798, 1, 1, 2, 30881.892195), -- Recipe: Leather Helmet
(20143, 17, 10, 30, 2, 157498.011513), -- Wooden Arrow
-- Hangman Tree
(20144, 1880, 1, 1, -1, 71999), -- Steel
(20144, 2272, 1, 1, -1, 5143), -- Recipe: Sword of Revolution
(20144, 1901, 1, 1, -1, 99446), -- Tiger's Eye Earring Stone
(20144, 57, 304, 607, 0, 700000), -- Adena
(20144, 393, 1, 1, 1, 109.06642), -- Mithril Banded Mail
(20144, 1938, 1, 1, 1, 4289.19622), -- Mithril Banded Mail Material
(20144, 394, 1, 1, 1, 109.06642), -- Reinforced Leather Shirt
(20144, 415, 1, 1, 1, 174.32636), -- Mithril Banded Gaiters
(20144, 1939, 1, 1, 1, 5604.02868), -- Mithril Banded Gaiters Material
(20144, 416, 1, 1, 1, 174.3159), -- Reinforced Leather Gaiters
(20144, 1875, 1, 1, 2, 2552.070594), -- Stone of Purity
(20144, 1879, 1, 1, 2, 6380.176485), -- Cokes
(20144, 1885, 1, 1, 2, 3189.999592), -- High-Grade Suede
(20144, 5550, 1, 1, 2, 510.449579), -- Durable Metal Plate
(20144, 5549, 1, 1, 2, 3828.105891), -- Metallic Thread
(20144, 2976, 1, 1, 2, 5124.530803), -- Recipe: Manticore Skin Boots
(20144, 2274, 1, 1, 2, 273.398142), -- Recipe: Skull Breaker
(20144, 2985, 1, 1, 2, 3914.274177), -- Recipe: Plate Boots
(20144, 6667, 1, 1, 2, 23925.528843), -- Deluxe Chest Key - Grade 3
(20144, 1341, 10, 30, 2, 127602.465894), -- Bone Arrow
-- Harpy
(20145, 2183, 1, 1, -1, 39675), -- Recipe: Mithril Banded Mail
(20145, 2268, 1, 1, -1, 6236), -- Recipe: Tome of Blood
(20145, 2153, 1, 1, -1, 93789), -- Recipe: Tiger's Eye Earring
(20145, 57, 254, 510, 0, 700000), -- Adena
(20145, 848, 1, 1, 1, 502.355926), -- Enchanted Earring
(20145, 911, 1, 1, 1, 377.049143), -- Enchanted Necklace
(20145, 1900, 1, 1, 1, 9013.760858), -- Enchanted Necklace Chain
(20145, 879, 1, 1, 1, 755.834073), -- Enchanted Ring
(20145, 1868, 1, 1, 2, 109850.451315), -- Thread
(20145, 1873, 1, 1, 2, 21970.11865), -- Silver Nugget
(20145, 5549, 1, 1, 2, 5492.458695), -- Metallic Thread
(20145, 1889, 1, 1, 2, 3661.63913), -- Compound Braid
(20145, 2268, 1, 1, 2, 568.02387), -- Recipe: Tome of Blood
(20145, 2276, 1, 1, 2, 392.30834), -- Recipe: Maingauche
-- Headless Knight
(20146, 1915, 1, 1, -1, 130858), -- Ring of Ages Gemstone
(20146, 1869, 1, 3, -1, 742616), -- Iron Ore
(20146, 1914, 1, 1, -1, 83440), -- Earring of Seal Gemstone
(20146, 57, 587, 1194, 0, 700000), -- Adena
(20146, 103, 1, 1, 1, 77.434918), -- Tower Shield
(20146, 1978, 1, 1, 1, 4921.495953), -- Tower Shield Fragment
(20146, 107, 1, 1, 1, 77.434918), -- Composite Shield
(20146, 4055, 1, 1, 1, 4921.495953), -- Composite Shield Fragment
(20146, 517, 1, 1, 1, 54.22802), -- Composite Helmet
(20146, 2957, 1, 1, 1, 3367.341109), -- Composite Helmet Design
(20146, 1149, 1, 1, 1, 54.22802), -- Shining Circlet
(20146, 1983, 1, 1, 1, 3367.341109), -- Shining Circlet Pattern
(20146, 1871, 1, 1, 2, 47246.417626), -- Charcoal
(20146, 1866, 1, 1, 2, 31497.640505), -- Suede
(20146, 1877, 1, 1, 2, 1889.849804), -- Adamantite Nugget
(20146, 4041, 1, 1, 2, 410.870669), -- Mold Hardener
(20146, 4040, 1, 1, 2, 944.924902), -- Mold Lubricant
(20146, 2170, 1, 1, 2, 1114.345434), -- Recipe: Nassen's Earring
(20146, 4609, 1, 1, 2, 104.982071), -- Greater Dye of MEN (Men+3 Int-3)
(20146, 3014, 1, 1, 2, 1319.737637), -- Recipe: Full Plate Boots
(20146, 4188, 1, 1, 2, 54.431953), -- Recipe: Hell Knife (100%)
(20146, 8725, 1, 1, 2, 1312.405282), -- Life Stone - Level 52
(20146, 8735, 1, 1, 2, 328.058189), -- Mid-Grade Life Stone - Level 52
(20146, 8745, 1, 1, 2, 32.77994), -- High-Grade Life Stone - Level 52
(20146, 8755, 1, 1, 2, 6.555988), -- Top-Grade Life Stone - Level 52
-- Hobgoblin
(20147, 1870, 1, 1, -1, 341721), -- Coal
(20147, 1876, 1, 1, -1, 68344), -- Mithril Ore
(20147, 57, 156, 278, 0, 700000), -- Adena
(20147, 27, 1, 1, 1, 355.418392), -- Hard Leather Shirt
(20147, 1927, 1, 1, 1, 4026.225584), -- Hard Leather Shirt Pattern
(20147, 33, 1, 1, 1, 570.265216), -- Hard Leather Gaiters
(20147, 1929, 1, 1, 1, 6512.090808), -- Hard Leather Gaiters Material
(20147, 1873, 1, 1, 2, 20187.870617), -- Silver Nugget
(20147, 1868, 1, 1, 2, 100939.353085), -- Thread
(20147, 2255, 1, 1, 2, 1234.01334), -- Recipe: Saber
(20147, 6666, 1, 1, 2, 50469.762958), -- Deluxe Chest Key - Grade 2
-- Magical Weaver
(20153, 1831, 1, 1, -1, 537542), -- Antidote
(20153, 30, 1, 1, -1, 10554), -- Hard Leather Pants
(20153, 1867, 1, 1, -1, 268771), -- Animal Skin
(20153, 57, 109, 147, 0, 700000), -- Adena
(20153, 429, 1, 1, 1, 972.9426), -- Leather Tunic
(20153, 1922, 1, 1, 1, 7594.824544), -- Leather Tunic Pattern
(20153, 464, 1, 1, 1, 1558.71768), -- Leather Stockings
(20153, 1923, 1, 1, 1, 12201.515176), -- Leather Stockings Pattern
(20153, 1867, 1, 1, 2, 52927.092659), -- Animal Skin
(20153, 1872, 1, 1, 2, 52927.092659), -- Animal Bone
(20153, 1793, 1, 1, 2, 2918.814682), -- Recipe: Sword of Reflection
-- Mandragora Sprout
(20154, 2178, 1, 1, -1, 54675), -- Recipe: Dark Stockings
(20154, 1929, 1, 1, -1, 44093), -- Hard Leather Gaiters Material
(20154, 1898, 1, 1, -1, 35102), -- Blue Diamond Necklace Gem
(20154, 57, 156, 278, 0, 700000), -- Adena
(20154, 846, 1, 1, 1, 820.594371), -- Coral Earring
(20154, 909, 1, 1, 1, 615.447741), -- Blue Diamond Necklace
(20154, 1898, 1, 1, 1, 5184.054555), -- Blue Diamond Necklace Gem
(20154, 878, 1, 1, 1, 1230.903333), -- Blue Coral Ring
(20154, 1868, 1, 1, 2, 100939.3452), -- Thread
(20154, 1873, 1, 1, 2, 20187.86904), -- Silver Nugget
(20154, 2256, 1, 1, 2, 1233.97398), -- Recipe: Assassin Knife
(20154, 5158, 1, 1, 2, 2018.81178), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Mandragora Sapling
(20155, 1865, 1, 1, -1, 385707), -- Varnish
(20155, 1898, 1, 1, -1, 39621), -- Blue Diamond Necklace Gem
(20155, 1804, 1, 1, -1, 15428), -- Recipe: Soulshot (D-Grade)
(20155, 57, 177, 312, 0, 700000), -- Adena
(20155, 846, 1, 1, 1, 926.265102), -- Coral Earring
(20155, 909, 1, 1, 1, 694.701042), -- Blue Diamond Necklace
(20155, 1898, 1, 1, 1, 5851.62291), -- Blue Diamond Necklace Gem
(20155, 878, 1, 1, 1, 1389.410946), -- Blue Coral Ring
(20155, 1869, 1, 1, 2, 32551.95924), -- Iron Ore
(20155, 1864, 1, 1, 2, 65103.91848), -- Stem
(20155, 1880, 1, 1, 2, 3255.22368), -- Steel
(20155, 3032, 1, 1, 2, 1302.03396), -- Recipe: Spiritshot D
(20155, 5273, 1, 1, 2, 1302.03396), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(20155, 6666, 1, 1, 2, 32551.95924), -- Deluxe Chest Key - Grade 2
(20155, 735, 1, 1, 2, 2712.87144), -- Alacrity Potion
-- Mandragora Blossom
(20156, 2181, 1, 1, -1, 42851), -- Recipe: White Tunic
(20156, 1899, 1, 1, -1, 66888), -- Necklace of Devotion Chain
(20156, 57, 188, 353, 0, 700000), -- Adena
(20156, 847, 1, 1, 1, 580.321248), -- Red Crescent Earring
(20156, 910, 1, 1, 1, 435.240936), -- Necklace of Devotion
(20156, 1899, 1, 1, 1, 9384.944673), -- Necklace of Devotion Chain
(20156, 890, 1, 1, 1, 870.493143), -- Ring of Devotion
(20156, 1876, 1, 1, 2, 6864.288338), -- Mithril Ore
(20156, 1880, 1, 1, 2, 3432.144169), -- Steel
(20156, 1877, 1, 1, 2, 1372.838424), -- Adamantite Nugget
(20156, 1881, 1, 1, 2, 4576.176189), -- Coarse Bone Powder
(20156, 1882, 1, 1, 2, 7627.008424), -- Leather
(20156, 2181, 1, 1, 2, 3435.608017), -- Recipe: White Tunic
(20156, 1061, 1, 1, 2, 20800.936439), -- Greater Healing Potion
-- Marsh Stakato
(20157, 1879, 1, 1, -1, 102726), -- Cokes
(20157, 2024, 1, 1, -1, 8780), -- Elven Bow Shaft
(20157, 2153, 1, 1, -1, 95856), -- Recipe: Tiger's Eye Earring
(20157, 57, 261, 517, 0, 700000), -- Adena
(20157, 86, 1, 1, 1, 13.597838), -- Tomahawk
(20157, 179, 1, 1, 1, 13.597838), -- Mace of Prayer
(20157, 180, 1, 1, 1, 13.597838), -- Mace of Judgment
(20157, 2022, 1, 1, 1, 524.75379), -- Mace of Judgment Head
(20157, 181, 1, 1, 1, 13.597838), -- Mace of Miracle
(20157, 182, 1, 1, 1, 13.597838), -- Doom Hammer
(20157, 183, 1, 1, 1, 13.597838), -- Mystic Staff
(20157, 184, 1, 1, 1, 13.597838), -- Conjuror's Staff
(20157, 2023, 1, 1, 1, 417.462455), -- Conjuror's Staff Head
(20157, 185, 1, 1, 1, 13.598889), -- Staff of Mana
(20157, 1864, 1, 1, 2, 84203.507106), -- Stem
(20157, 1869, 1, 1, 2, 42101.753553), -- Iron Ore
(20157, 1878, 1, 1, 2, 16840.616616), -- Braided Hemp
(20157, 1884, 1, 1, 2, 25908.836652), -- Cord
(20157, 1829, 1, 1, 2, 16840.616616), -- Scroll of Escape: Clan Hall
(20157, 2274, 1, 1, 2, 300.634434), -- Recipe: Skull Breaker
(20157, 2282, 1, 1, 2, 300.634434), -- Recipe: Cursed Maingauche
(20157, 1061, 1, 1, 2, 25516.400589), -- Greater Healing Potion
-- Medusa
(20158, 1876, 1, 1, -1, 136283), -- Mithril Ore
(20158, 1939, 1, 1, -1, 59852), -- Mithril Banded Gaiters Material
(20158, 1901, 1, 1, -1, 94118), -- Tiger's Eye Earring Stone
(20158, 57, 288, 574, 0, 700000), -- Adena
(20158, 436, 1, 1, 1, 309.81069), -- Tunic of Knowledge
(20158, 469, 1, 1, 1, 495.18931), -- Stockings of Knowledge
(20158, 1869, 1, 1, 2, 60383.782575), -- Iron Ore
(20158, 1864, 1, 1, 2, 120767.373495), -- Stem
(20158, 1880, 1, 1, 2, 6038.28243), -- Steel
(20158, 5550, 1, 1, 2, 805.142655), -- Durable Metal Plate
(20158, 2271, 1, 1, 2, 431.22375), -- Recipe: Winged Spear
(20158, 2972, 1, 1, 2, 3229.195095), -- Recipe: Brigandine Gaiters
-- Neer Crawler
(20160, 2152, 1, 1, -1, 87127), -- Recipe: Enchanted Necklace
(20160, 2261, 1, 1, -1, 7685), -- Recipe: Conjuror's Staff
(20160, 1874, 1, 1, -1, 32992), -- Oriharukon Ore
(20160, 57, 212, 415, 0, 700000), -- Adena
(20160, 258, 1, 1, 1, 176), -- Bagh-Nakh
(20160, 1874, 1, 1, 2, 3086.021248), -- Oriharukon Ore
(20160, 1878, 1, 1, 2, 18516.190664), -- Braided Hemp
(20160, 1884, 1, 1, 2, 28486.437456), -- Cord
(20160, 1889, 1, 1, 2, 3086.021248), -- Compound Braid
(20160, 5220, 1, 1, 2, 1851.625384), -- Metal Hardener
(20160, 2152, 1, 1, 2, 8149.704), -- Recipe: Enchanted Necklace
-- Oel Mahum
(20161, 1984, 1, 1, -1, 34800), -- Theca Leather Armor Pattern
(20161, 1806, 1, 1, -1, 3247), -- Recipe: Soulshot (B-Grade)
(20161, 1872, 1, 5, -1, 721517), -- Animal Bone
(20161, 57, 643, 1305, 0, 700000), -- Adena
(20161, 266, 1, 1, 1, 12.713712), -- Great Pata
(20161, 2120, 1, 1, 1, 1439.286288), -- Great Pata Blade
(20161, 1867, 1, 1, 2, 53281.330256), -- Animal Skin
(20161, 1872, 1, 1, 2, 53281.330256), -- Animal Bone
(20161, 1882, 1, 1, 2, 8880.17746), -- Leather
(20161, 1894, 1, 1, 2, 1402.084376), -- Crafted Leather
(20161, 4042, 1, 1, 2, 665.996716), -- Enria
(20161, 1806, 1, 1, 2, 79.914296), -- Recipe: Soulshot (B-Grade)
(20161, 5165, 1, 1, 2, 79.914296), -- Recipe: Blessed Spiritshot (B) Compressed Package (100%)
(20161, 4180, 1, 1, 2, 4440.155104), -- Recipe: Silver Arrow (100%)
(20161, 3955, 1, 1, 2, 79.914296), -- Recipe: Blessed Spiritshot B
(20161, 5280, 1, 1, 2, 79.914296), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(20161, 6669, 1, 1, 2, 9293.289236), -- Deluxe Chest Key - Grade 5
(20161, 8726, 1, 1, 2, 924.988064), -- Life Stone - Level 55
(20161, 8736, 1, 1, 2, 231.247016), -- Mid-Grade Life Stone - Level 55
(20161, 8746, 1, 1, 2, 23.098152), -- High-Grade Life Stone - Level 55
(20161, 8756, 1, 1, 2, 4.64618), -- Top-Grade Life Stone - Level 55
-- Silenos
(20168, 1877, 1, 1, -1, 21239), -- Adamantite Nugget
(20168, 1061, 1, 1, -1, 321804), -- Greater Healing Potion
(20168, 955, 1, 1, -1, 2124), -- Scroll: Enchant Weapon (D-Grade)
(20168, 57, 224, 448, 0, 700000), -- Adena
(20168, 627, 1, 1, 1, 1078.49287), -- Aspis
(20168, 46, 1, 1, 1, 755.50713), -- Bronze Helmet
(20168, 1865, 1, 1, 2, 48359.887005), -- Varnish
(20168, 1870, 1, 1, 2, 48359.887005), -- Coal
(20168, 1879, 1, 1, 2, 8060.037882), -- Cokes
(20168, 1875, 1, 1, 2, 3223.992467), -- Stone of Purity
(20168, 2184, 1, 1, 2, 5079.804336), -- Recipe: Mithril Banded Gaiters
(20168, 2274, 1, 1, 2, 345.391305), -- Recipe: Skull Breaker
-- Specter
(20171, 1880, 1, 1, -1, 45092), -- Steel
(20171, 2019, 1, 1, -1, 9697), -- Trident Edge
(20171, 1899, 1, 1, -1, 70456), -- Necklace of Devotion Chain
(20171, 57, 196, 374, 0, 700000), -- Adena
(20171, 101, 1, 1, 1, 32.150125), -- Scroll of Wisdom
(20171, 312, 1, 1, 1, 32.150125), -- Branch of Life
(20171, 313, 1, 1, 1, 32.150125), -- Temptation of Abyss
(20171, 2020, 1, 1, 1, 886.40153), -- Temptation of Abyss Piece
(20171, 314, 1, 1, 1, 32.148095), -- Proof of Revenge
(20171, 1875, 1, 1, 2, 2811.846308), -- Stone of Purity
(20171, 1879, 1, 1, 2, 7029.61577), -- Cokes
(20171, 5549, 1, 1, 2, 4217.769462), -- Metallic Thread
(20171, 2263, 1, 1, 2, 654.932122), -- Recipe: Dwarven Trident
(20171, 6666, 1, 1, 2, 42177.612166), -- Deluxe Chest Key - Grade 2
(20171, 1061, 1, 1, 2, 25562.224172), -- Greater Healing Potion
-- Wyrm
(20176, 1873, 1, 1, -1, 287994), -- Silver Nugget
(20176, 2273, 1, 1, -1, 5143), -- Recipe: Tarbar
(20176, 2154, 1, 1, -1, 77086), -- Recipe: Elven Earring
(20176, 57, 304, 607, 0, 700000), -- Adena
(20176, 553, 1, 1, 1, 279.740266), -- Iron Boots
(20176, 1940, 1, 1, 1, 8162.558404), -- Iron Boots Design
(20176, 2422, 1, 1, 1, 279.740266), -- Reinforced Leather Boots
(20176, 2423, 1, 1, 1, 279.740266), -- Boots of Knowledge
(20176, 63, 1, 1, 1, 279.740266), -- Gauntlets
(20176, 2446, 1, 1, 1, 279.740266), -- Reinforced Leather Gloves
(20176, 2447, 1, 1, 1, 279.740266), -- Gloves of Knowledge
(20176, 1867, 1, 1, 2, 72916.469689), -- Animal Skin
(20176, 1872, 1, 1, 2, 72916.469689), -- Animal Bone
(20176, 1882, 1, 1, 2, 12152.774702), -- Leather
(20176, 2977, 1, 1, 2, 7320.871184), -- Recipe: Brigandine Boots
(20176, 2286, 1, 1, 2, 303.846146), -- Recipe: Bonebreaker
(20176, 2985, 1, 1, 2, 5591.697406), -- Recipe: Plate Boots
(20176, 2981, 1, 1, 2, 7320.871184), -- Recipe: Mithril Gloves
-- Skeleton Marauder
(20190, 1864, 1, 3, -1, 533484), -- Stem
(20190, 2025, 1, 1, -1, 7389), -- Dwarven Trident Edge
(20190, 1900, 1, 1, -1, 58368), -- Enchanted Necklace Chain
(20190, 57, 226, 448, 0, 700000), -- Adena
(20190, 275, 1, 1, 1, 39.230345), -- Long Bow
(20190, 276, 1, 1, 1, 39.230345), -- Elven Bow
(20190, 2024, 1, 1, 1, 1384.53931), -- Elven Bow Shaft
(20190, 1866, 1, 1, 2, 38870.431145), -- Suede
(20190, 1871, 1, 1, 2, 58305.703435), -- Charcoal
(20190, 5220, 1, 1, 2, 2332.2236), -- Metal Hardener
(20190, 1885, 1, 1, 2, 4858.761355), -- High-Grade Suede
(20190, 2153, 1, 1, 2, 9067.880465), -- Recipe: Tiger's Eye Earring
-- Skeleton Raider
(20191, 2264, 1, 1, -1, 5601), -- Recipe: Two-handed Sword
(20191, 1900, 1, 1, -1, 59256), -- Enchanted Necklace Chain
(20191, 2153, 1, 1, -1, 84230), -- Recipe: Tiger's Eye Earring
(20191, 57, 228, 457, 0, 700000), -- Adena
(20191, 1123, 1, 1, 1, 1156), -- Blue Buckskin Boots
(20191, 605, 1, 1, 1, 1156), -- Leather Gauntlets
(20191, 1867, 1, 1, 2, 56373.602805), -- Animal Skin
(20191, 1872, 1, 1, 2, 56373.602805), -- Animal Bone
(20191, 1882, 1, 1, 2, 9395.679215), -- Leather
(20191, 2185, 1, 1, 2, 8322.823275), -- Recipe: Iron Boots
(20191, 2274, 1, 1, 2, 302.07541), -- Recipe: Skull Breaker
(20191, 2279, 1, 1, 2, 302.07541), -- Recipe: War Pick
(20191, 6667, 1, 1, 2, 26425.14108), -- Deluxe Chest Key - Grade 3
-- Tyrant
(20192, 2146, 1, 1, -1, 50419), -- Recipe: Artisan's frame
(20192, 2447, 1, 1, -1, 3611), -- Gloves of Knowledge
(20192, 1901, 1, 1, -1, 97496), -- Tiger's Eye Earring Stone
(20192, 57, 298, 595, 0, 700000), -- Adena
(20192, 223, 1, 1, 1, 20.19948), -- Kukuri
(20192, 238, 1, 1, 1, 20.19948), -- Dagger of Mana
(20192, 239, 1, 1, 1, 20.19948), -- Mystic Knife
(20192, 241, 1, 1, 1, 20.19948), -- Shilen Knife
(20192, 2028, 1, 1, 1, 892.20208), -- Shilen Knife Edge
(20192, 1864, 1, 1, 2, 107229.801952), -- Stem
(20192, 1869, 1, 1, 2, 53614.900976), -- Iron Ore
(20192, 1878, 1, 1, 2, 21446.062932), -- Braided Hemp
(20192, 1884, 1, 1, 2, 32993.785216), -- Cord
(20192, 2978, 1, 1, 2, 7177.399292), -- Recipe: Elven Mithril Boots
(20192, 6667, 1, 1, 2, 33509.31311), -- Deluxe Chest Key - Grade 3
(20192, 8307, 1, 1, 2, 382.736522), -- Recipe: Priest Mace (100%)
-- Tyrant Kingpin
(20193, 1874, 1, 1, -1, 50678), -- Oriharukon Ore
(20193, 2027, 1, 1, -1, 9958), -- Spiked Club Head
(20193, 1882, 1, 1, -1, 168925), -- Leather
(20193, 57, 320, 642, 0, 700000), -- Adena
(20193, 628, 1, 1, 1, 986.079628), -- Hoplon
(20193, 47, 1, 1, 1, 689.920372), -- Helmet
(20193, 1867, 1, 1, 2, 76985.489672), -- Animal Skin
(20193, 1872, 1, 1, 2, 76985.489672), -- Animal Bone
(20193, 1882, 1, 1, 2, 12830.854608), -- Leather
(20193, 1894, 1, 1, 2, 2025.886304), -- Crafted Leather
(20193, 2271, 1, 1, 2, 412.345336), -- Recipe: Winged Spear
(20193, 2286, 1, 1, 2, 320.753264), -- Recipe: Bonebreaker
(20193, 1341, 10, 30, 2, 192463.181144), -- Bone Arrow
-- Sorrow Maiden
(20197, 2259, 1, 1, -1, 7096), -- Recipe: Spinebone Sword
(20197, 2020, 1, 1, -1, 8000), -- Temptation of Abyss Piece
(20197, 1876, 1, 1, -1, 91400), -- Mithril Ore
(20197, 57, 197, 380, 0, 700000), -- Adena
(20197, 847, 1, 1, 1, 619.503616), -- Red Crescent Earring
(20197, 910, 1, 1, 1, 464.627712), -- Necklace of Devotion
(20197, 1899, 1, 1, 1, 10018.601216), -- Necklace of Devotion Chain
(20197, 890, 1, 1, 1, 929.267456), -- Ring of Devotion
(20197, 1876, 1, 1, 2, 6412.072376), -- Mithril Ore
(20197, 1880, 1, 1, 2, 3206.036188), -- Steel
(20197, 1877, 1, 1, 2, 1282.468508), -- Adamantite Nugget
(20197, 1881, 1, 1, 2, 4274.804972), -- Coarse Bone Powder
(20197, 1882, 1, 1, 2, 7124.629926), -- Leather
(20197, 2178, 1, 1, 2, 5129.73895), -- Recipe: Dark Stockings
(20197, 8294, 1, 1, 2, 783.880846), -- Recipe: Steel Sword (100%)
(20197, 1341, 10, 30, 2, 106868.368234), -- Bone Arrow
-- Neer Ghoul Berserker
(20198, 1832, 1, 1, -1, 575495), -- Greater Antidote
(20198, 57, 220, 435, 0, 700000), -- Adena
(20198, 259, 1, 1, 1, 114), -- Single-Edged Jamadhr
(20198, 1874, 1, 1, 2, 2358.65935), -- Oriharukon Ore
(20198, 1878, 1, 1, 2, 14152.00525), -- Braided Hemp
(20198, 1884, 1, 1, 2, 21772.31955), -- Cord
(20198, 1889, 1, 1, 2, 2358.65935), -- Compound Braid
(20198, 5220, 1, 1, 2, 1415.2251), -- Metal Hardener
(20198, 2183, 1, 1, 2, 2327.6457), -- Recipe: Mithril Banded Mail
(20198, 2274, 1, 1, 2, 252.7293), -- Recipe: Skull Breaker
(20198, 2982, 1, 1, 2, 4512.7564), -- Recipe: Brigandine Shield
-- Amber Basilisk
(20199, 1882, 1, 1, -1, 140414), -- Leather
(20199, 1834, 1, 1, -1, 702070), -- Emergency Dressing
(20199, 1900, 1, 1, -1, 69132), -- Enchanted Necklace Chain
(20199, 57, 267, 533, 0, 700000), -- Adena
(20199, 1123, 1, 1, 1, 1349), -- Blue Buckskin Boots
(20199, 605, 1, 1, 1, 1349), -- Leather Gauntlets
(20199, 1867, 1, 1, 2, 92076.804567), -- Animal Skin
(20199, 1872, 1, 1, 2, 92076.804567), -- Animal Bone
(20199, 1882, 1, 1, 2, 15346.245354), -- Leather
(20199, 2250, 1, 1, 2, 17264.359134), -- Recipe: Bone Arrow
(20199, 6035, 1, 1, 2, 5754.786378), -- Magic Haste Potion
-- Strain
(20200, 1877, 1, 1, -1, 22339), -- Adamantite Nugget
(20200, 1061, 1, 1, -1, 338473), -- Greater Healing Potion
(20200, 2183, 1, 1, -1, 36742), -- Recipe: Mithril Banded Mail
(20200, 57, 236, 471, 0, 700000), -- Adena
(20200, 433, 1, 1, 1, 99.219705), -- Elven Tunic
(20200, 434, 1, 1, 1, 99.219705), -- White Tunic
(20200, 1936, 1, 1, 1, 3122.045745), -- White Tunic Pattern
(20200, 435, 1, 1, 1, 99.219705), -- Mystic's Tunic
(20200, 466, 1, 1, 1, 158.96283), -- Elven Stockings
(20200, 467, 1, 1, 1, 158.96283), -- Dark Stockings
(20200, 1933, 1, 1, 1, 4488.398265), -- Dark Stockings Fabric
(20200, 468, 1, 1, 1, 158.971215), -- Mystic's Stockings
(20200, 1875, 1, 1, 2, 2260.643151), -- Stone of Purity
(20200, 1879, 1, 1, 2, 5651.721894), -- Cokes
(20200, 1885, 1, 1, 2, 2825.860947), -- High-Grade Suede
(20200, 5550, 1, 1, 2, 452.113428), -- Durable Metal Plate
(20200, 5549, 1, 1, 2, 3391.002732), -- Metallic Thread
(20200, 955, 1, 1, 2, 135.603624), -- Scroll: Enchant Weapon (D-Grade)
(20200, 2188, 1, 1, 2, 2422.166526), -- Recipe: Manticore Skin Gaiters
(20200, 6667, 1, 1, 2, 21193.843086), -- Deluxe Chest Key - Grade 3
(20200, 1834, 1, 1, 2, 37678.044612), -- Emergency Dressing
-- Ghoul
(20201, 1870, 1, 1, -1, 664672), -- Coal
(20201, 466, 1, 1, -1, 2769), -- Elven Stockings
(20201, 1933, 1, 1, -1, 78197), -- Dark Stockings Fabric
(20201, 57, 280, 562, 0, 700000), -- Adena
(20201, 392, 1, 1, 1, 472.313303), -- Lion Skin Shirt
(20201, 414, 1, 1, 1, 756.686697), -- Lion Skin Gaiters
(20201, 1876, 1, 1, 2, 10377.53951), -- Mithril Ore
(20201, 1880, 1, 1, 2, 5188.769755), -- Steel
(20201, 1877, 1, 1, 2, 2075.49056), -- Adamantite Nugget
(20201, 1881, 1, 1, 2, 6918.33077), -- Coarse Bone Powder
(20201, 1882, 1, 1, 2, 11530.565735), -- Leather
(20201, 737, 1, 1, 2, 5188.769755), -- Scroll of Resurrection
(20201, 6387, 1, 1, 2, 2075.533915), -- Blessed Scroll of Resurrection for Pets
-- Dead Seeker
(20202, 2198, 1, 1, -1, 13867), -- Recipe: Sage's Rag
(20202, 1872, 1, 1, -1, 881920), -- Animal Bone
(20202, 2154, 1, 1, -1, 70818), -- Recipe: Elven Earring
(20202, 57, 279, 557, 0, 700000), -- Adena
(20202, 849, 1, 1, 1, 355.947735), -- Tiger's Eye Earring
(20202, 1901, 1, 1, 1, 12143.396694), -- Tiger's Eye Earring Stone
(20202, 912, 1, 1, 1, 266.817837), -- Near Forest Necklace
(20202, 880, 1, 1, 1, 532.837734), -- Black Pearl Ring
(20202, 1874, 1, 1, 2, 3349.348063), -- Oriharukon Ore
(20202, 1878, 1, 1, 2, 20096.027939), -- Braided Hemp
(20202, 1884, 1, 1, 2, 30916.96606), -- Cord
(20202, 1889, 1, 1, 2, 3349.348063), -- Compound Braid
(20202, 5220, 1, 1, 2, 2009.59675), -- Metal Hardener
(20202, 2272, 1, 1, 2, 358.886782), -- Recipe: Sword of Revolution
(20202, 2274, 1, 1, 2, 358.826343), -- Recipe: Skull Breaker
-- Dion Grizzly
(20203, 1882, 1, 1, -1, 59453), -- Leather
(20203, 1897, 1, 1, -1, 63700), -- Necklace of Wisdom Chain
(20203, 57, 124, 215, 0, 700000), -- Adena
(20203, 176, 1, 1, 1, 150.5), -- Apprentice's Staff
(20203, 2501, 1, 1, 1, 150.5), -- Bone Club
(20203, 1867, 1, 1, 2, 42147.964968), -- Animal Skin
(20203, 1872, 1, 1, 2, 42147.964968), -- Animal Bone
(20203, 1882, 1, 1, 2, 7024.625385), -- Leather
(20203, 2174, 1, 1, 2, 13743.873882), -- Recipe: Hard Leather Gaiters
(20203, 5273, 1, 1, 2, 1264.570797), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Bloody Bee
(20204, 1868, 1, 1, -1, 823680), -- Thread
(20204, 2014, 1, 1, -1, 4734), -- Iron Hammer Head
(20204, 1867, 1, 1, -1, 549120), -- Animal Skin
(20204, 57, 188, 333, 0, 700000), -- Adena
(20204, 846, 1, 1, 1, 989.082223), -- Coral Earring
(20204, 909, 1, 1, 1, 741.814033), -- Blue Diamond Necklace
(20204, 1898, 1, 1, 1, 6248.466215), -- Blue Diamond Necklace Gem
(20204, 878, 1, 1, 1, 1483.637529), -- Blue Coral Ring
(20204, 1867, 1, 1, 2, 64880.682372), -- Animal Skin
(20204, 1872, 1, 1, 2, 64880.682372), -- Animal Bone
(20204, 1882, 1, 1, 2, 10813.447062), -- Leather
(20204, 3953, 1, 1, 2, 1946.551167), -- Recipe: Blessed Spiritshot D
(20204, 1831, 1, 1, 2, 129761.637027), -- Antidote
-- Dire Wolf
(20205, 1871, 1, 1, -1, 407376), -- Charcoal
(20205, 1928, 1, 1, -1, 59341), -- Piece Bone Gaiters Fragment
(20205, 1868, 1, 1, -1, 814752), -- Thread
(20205, 57, 181, 334, 0, 700000), -- Adena
(20205, 257, 1, 1, 1, 256), -- Viper Fang
(20205, 1868, 1, 1, 2, 120332.806902), -- Thread
(20205, 1873, 1, 1, 2, 24066.614621), -- Silver Nugget
(20205, 2255, 1, 1, 2, 1471.037778), -- Recipe: Saber
(20205, 6037, 1, 1, 2, 120332.540699), -- Waking Scroll
-- Kadif Werewolf
(20206, 2182, 1, 1, -1, 49884), -- Recipe: Scale Gaiters
(20206, 376, 1, 1, -1, 2072), -- Iron Plate Gaiters
(20206, 1899, 1, 1, -1, 64927), -- Necklace of Devotion Chain
(20206, 57, 183, 343, 0, 700000), -- Adena
(20206, 391, 1, 1, 1, 483.983521), -- Puma Skin Shirt
(20206, 413, 1, 1, 1, 775.016479), -- Puma Skin Gaiters
(20206, 1869, 1, 1, 2, 46641.861084), -- Iron Ore
(20206, 1864, 1, 1, 2, 93283.722168), -- Stem
(20206, 1880, 1, 1, 2, 4664.107376), -- Steel
(20206, 2182, 1, 1, 2, 5599.251457), -- Recipe: Scale Gaiters
(20206, 6666, 1, 1, 2, 46642.057915), -- Deluxe Chest Key - Grade 2
-- Ol Mahum Guerilla
(20207, 2263, 1, 1, -1, 12768), -- Recipe: Dwarven Trident
(20207, 2181, 1, 1, -1, 82308), -- Recipe: White Tunic
(20207, 2152, 1, 1, -1, 144764), -- Recipe: Enchanted Necklace
(20207, 57, 357, 682, 0, 700000), -- Adena
(20207, 220, 1, 1, 1, 293), -- Crafted Dagger
(20207, 1865, 1, 1, 2, 92295.187125), -- Varnish
(20207, 1870, 1, 1, 2, 92295.187125), -- Coal
(20207, 1879, 1, 1, 2, 15382.56825), -- Cokes
(20207, 1875, 1, 1, 2, 6153.11625), -- Stone of Purity
(20207, 2152, 1, 1, 2, 16248.94125), -- Recipe: Enchanted Necklace
-- Ol Mahum Raider
(20208, 1869, 1, 1, -1, 858524), -- Iron Ore
(20208, 1872, 1, 3, -1, 572349), -- Animal Bone
(20208, 1931, 1, 1, -1, 112225), -- Leather Boots Lining
(20208, 57, 371, 714, 0, 700000), -- Adena
(20208, 626, 1, 1, 1, 1900.693228), -- Bronze Shield
(20208, 45, 1, 1, 1, 1332.846619), -- Bone Helmet
(20208, 1932, 1, 1, 1, 25493.460153), -- Bone Helmet Design
(20208, 1866, 1, 1, 2, 53536.648342), -- Suede
(20208, 1871, 1, 1, 2, 80304.972513), -- Charcoal
(20208, 5220, 1, 1, 2, 3212.272529), -- Metal Hardener
(20208, 1885, 1, 1, 2, 6692.138565), -- High-Grade Suede
(20208, 2180, 1, 1, 2, 6037.995538), -- Recipe: Scale Mail
(20208, 6666, 1, 1, 2, 80304.972513), -- Deluxe Chest Key - Grade 2
-- Ol Mahum Marksman
(20209, 1889, 1, 1, -1, 61967), -- Compound Braid
(20209, 45, 1, 1, -1, 7714), -- Bone Helmet
(20209, 2178, 1, 1, -1, 148721), -- Recipe: Dark Stockings
(20209, 57, 398, 780, 0, 700000), -- Adena
(20209, 274, 1, 1, 1, 331), -- Reinforced Bow
(20209, 1867, 1, 1, 2, 139111.405868), -- Animal Skin
(20209, 1872, 1, 1, 2, 139111.405868), -- Animal Bone
(20209, 1882, 1, 1, 2, 23185.1072), -- Leather
(20209, 2178, 1, 1, 2, 16693.277184), -- Recipe: Dark Stockings
(20209, 1061, 1, 1, 2, 63232.80388), -- Greater Healing Potion
-- Ol Mahum Sergeant
(20210, 2183, 1, 1, -1, 62137), -- Recipe: Mithril Banded Mail
(20210, 377, 1, 1, -1, 2947), -- Scale Gaiters
(20210, 1900, 1, 1, -1, 103336), -- Enchanted Necklace Chain
(20210, 57, 400, 793, 0, 700000), -- Adena
(20210, 348, 1, 1, 1, 251.775363), -- Scale Mail
(20210, 1935, 1, 1, 1, 7208.843866), -- Scale Mail Fragment
(20210, 377, 1, 1, 1, 402.609403), -- Scale Gaiters
(20210, 1937, 1, 1, 1, 11085.771368), -- Scale Gaiters Fragment
(20210, 1868, 1, 1, 2, 172042.475982), -- Thread
(20210, 1873, 1, 1, 2, 34408.541284), -- Silver Nugget
(20210, 5549, 1, 1, 2, 8602.020102), -- Metallic Thread
(20210, 1889, 1, 1, 2, 5734.680068), -- Compound Braid
(20210, 2184, 1, 1, 2, 9035.934856), -- Recipe: Mithril Banded Gaiters
(20210, 2274, 1, 1, 2, 614.347708), -- Recipe: Skull Breaker
-- Ol Mahum Captain
(20211, 1869, 1, 3, -1, 503685), -- Iron Ore
(20211, 1865, 1, 3, -1, 503685), -- Varnish
(20211, 57, 425, 850, 0, 700000), -- Adena
(20211, 86, 1, 1, 1, 22.214546), -- Tomahawk
(20211, 179, 1, 1, 1, 22.214546), -- Mace of Prayer
(20211, 180, 1, 1, 1, 22.214546), -- Mace of Judgment
(20211, 2022, 1, 1, 1, 857.28093), -- Mace of Judgment Head
(20211, 181, 1, 1, 1, 22.214546), -- Mace of Miracle
(20211, 182, 1, 1, 1, 22.214546), -- Doom Hammer
(20211, 183, 1, 1, 1, 22.214546), -- Mystic Staff
(20211, 184, 1, 1, 1, 22.214546), -- Conjuror's Staff
(20211, 2023, 1, 1, 1, 682.000985), -- Conjuror's Staff Head
(20211, 185, 1, 1, 1, 22.216263), -- Staff of Mana
(20211, 1869, 1, 1, 2, 91748.128035), -- Iron Ore
(20211, 1864, 1, 1, 2, 183496.543317), -- Stem
(20211, 1880, 1, 1, 2, 9174.956427), -- Steel
(20211, 5550, 1, 1, 2, 1223.384973), -- Durable Metal Plate
(20211, 2264, 1, 1, 2, 948.776841), -- Recipe: Two-handed Sword
(20211, 2280, 1, 1, 2, 655.210407), -- Recipe: Crucifix of Blood
-- Porta
(20213, 2292, 1, 1, -1, 18643), -- Recipe: Light Crossbow
(20213, 1894, 1, 1, -1, 117742), -- Crafted Leather
(20213, 1884, 1, 5, -1, 688339), -- Cord
(20213, 57, 1401, 2796, 0, 700000), -- Adena
(20213, 352, 1, 1, 1, 251.721176), -- Brigandine Tunic
(20213, 1941, 1, 1, 1, 11497.125738), -- Brigandine Temper
(20213, 2377, 1, 1, 1, 402.650794), -- Mithril Scale Gaiters
(20213, 2918, 1, 1, 1, 17151.949178), -- Mithril Scale Gaiters Material
(20213, 2378, 1, 1, 1, 402.650794), -- Brigandine Gaiters
(20213, 2919, 1, 1, 1, 17151.90232), -- Brigandine Gaiters Material
(20213, 1864, 9, 27, 2, 24091.834679), -- Stem
(20213, 1869, 2, 6, 2, 43365.144373), -- Iron Ore
(20213, 1878, 1, 1, 2, 86730.683869), -- Braided Hemp
(20213, 1884, 1, 1, 2, 133431.851731), -- Cord
(20213, 2983, 1, 1, 2, 14749.94159), -- Recipe: Plate Helmet
(20213, 2286, 1, 1, 2, 1204.730027), -- Recipe: Bonebreaker
(20213, 2290, 1, 1, 2, 1204.730027), -- Recipe: Mithril Dagger
(20213, 1341, 80, 240, 2, 90344.083704), -- Bone Arrow
-- Excuro
(20214, 1877, 1, 1, -1, 87132), -- Adamantite Nugget
(20214, 2997, 1, 1, -1, 172880), -- Recipe: Karmian Gloves
(20214, 1879, 1, 1, -1, 363049), -- Cokes
(20214, 57, 883, 1766, 0, 700000), -- Adena
(20214, 851, 1, 1, 1, 390.795928), -- Omen Beast's Eye Earring
(20214, 1905, 1, 1, 1, 17733.578136), -- Omen Beast's Eye Earring Gemstone
(20214, 914, 1, 1, 1, 293.08276), -- Necklace of Darkness
(20214, 1907, 1, 1, 1, 12681.830048), -- Necklace of Darkness Gem
(20214, 882, 1, 1, 1, 586.16552), -- Mithril Ring
(20214, 1906, 1, 1, 1, 25058.547608), -- Mithril Ring Wire
(20214, 1865, 1, 1, 2, 182306.425014), -- Varnish
(20214, 1870, 1, 1, 2, 182306.425014), -- Coal
(20214, 1879, 1, 1, 2, 30384.47223), -- Cokes
(20214, 1875, 1, 1, 2, 12153.788892), -- Stone of Purity
(20214, 1805, 1, 1, 2, 607.648608), -- Recipe: Soulshot (C-Grade)
(20214, 5269, 1, 1, 2, 607.240242), -- Recipe: Greater Soulshot (C) Compressed Package(100%)
-- Mordeo
(20215, 1872, 1, 7, -1, 839007), -- Animal Bone
(20215, 2206, 1, 1, -1, 66412), -- Recipe: Mithril Shirt
(20215, 4469, 1, 1, -1, 14383), -- Dye of STR (Str+1 Con-1)
(20215, 57, 1014, 2049, 0, 700000), -- Adena
(20215, 297, 1, 1, 1, 91.13338), -- Glaive
(20215, 2055, 1, 1, 1, 5225.86662), -- Glaive Edge
(20215, 1866, 1, 1, 2, 105327.600752), -- Suede
(20215, 1871, 1, 1, 2, 157991.098612), -- Charcoal
(20215, 5220, 1, 1, 2, 6319.55924), -- Metal Hardener
(20215, 1885, 1, 1, 2, 13165.798836), -- High-Grade Suede
(20215, 2212, 1, 1, 2, 5662.797004), -- Recipe: Plated Leather Gaiters
(20215, 2205, 1, 1, 2, 4999.681932), -- Recipe: Chain Gaiters
(20215, 2989, 1, 1, 2, 8359.424628), -- Recipe: Chain Hood
(20215, 2299, 1, 1, 2, 690.038996), -- Recipe: Big Hammer
-- Ricenseo
(20216, 2297, 1, 1, -1, 9822), -- Recipe: Flamberge
(20216, 2933, 1, 1, -1, 251030), -- Sage's Worn Gloves Lining
(20216, 1905, 1, 1, -1, 218797), -- Omen Beast's Eye Earring Gemstone
(20216, 57, 889, 1806, 0, 700000), -- Adena
(20216, 1125, 1, 1, 1, 250.323507), -- Assault Boots
(20216, 1957, 1, 1, 1, 10505.133471), -- Assault Boots Part
(20216, 2427, 1, 1, 1, 250.323507), -- Salamander Skin Boots
(20216, 2931, 1, 1, 1, 10505.133471), -- Salamander Skin Boot Lining
(20216, 2428, 1, 1, 1, 250.323507), -- Plate Boots
(20216, 2932, 1, 1, 1, 10505.133471), -- Plate Boots Design
(20216, 61, 1, 1, 1, 250.323507), -- Mithril Plate Gloves
(20216, 1949, 1, 1, 1, 10505.133471), -- Mithril Gloves Design
(20216, 607, 1, 1, 1, 250.323507), -- Ogre Power Gauntlets
(20216, 1963, 1, 1, 1, 10505.133471), -- Ogre Power Gauntlets Part
(20216, 2451, 1, 1, 1, 250.323507), -- Sage's Worn Gloves
(20216, 2933, 1, 1, 1, 10505.391603), -- Sage's Worn Gloves Lining
(20216, 1867, 1, 3, 2, 125495.644209), -- Animal Skin
(20216, 1872, 1, 1, 2, 250991.288418), -- Animal Bone
(20216, 1882, 1, 1, 2, 41831.881403), -- Leather
(20216, 1894, 1, 1, 2, 6604.944143), -- Crafted Leather
(20216, 2314, 1, 1, 2, 822.047144), -- Recipe: Body Slasher
(20216, 5269, 1, 1, 2, 627.194683), -- Recipe: Greater Soulshot (C) Compressed Package(100%)
-- Krator
(20217, 1873, 1, 3, -1, 524276), -- Silver Nugget
(20217, 2075, 1, 1, -1, 20560), -- Orcish Glaive Blade
(20217, 2163, 1, 1, -1, 133744), -- Recipe: Earring of Protection
(20217, 57, 1032, 2115, 0, 700000), -- Adena
(20217, 62, 1, 1, 1, 141.768462), -- Reinforced Mithril Boots
(20217, 1958, 1, 1, 1, 6186.891876), -- Reinforced Mithril Boots Design
(20217, 2429, 1, 1, 1, 141.768462), -- Chain Boots
(20217, 2937, 1, 1, 1, 6186.891876), -- Chain Boots Part
(20217, 2430, 1, 1, 1, 141.768462), -- Karmian Boots
(20217, 2938, 1, 1, 1, 6186.891876), -- Karmian Boots Fabric
(20217, 2431, 1, 1, 1, 141.768462), -- Plated Leather Boots
(20217, 2939, 1, 1, 1, 6186.891876), -- Plate Leather Boots Lining
(20217, 2432, 1, 1, 1, 141.768462), -- Dwarven Chain Boots
(20217, 2940, 1, 1, 1, 6186.891876), -- Dwarven Chain Boots Part
(20217, 2433, 1, 1, 1, 141.768462), -- Boots of Seal
(20217, 2941, 1, 1, 1, 6186.891876), -- Boots of Seal Pattern
(20217, 2452, 1, 1, 1, 141.768462), -- Reinforced Mithril Gloves
(20217, 2942, 1, 1, 1, 6186.891876), -- Reinforced Mithril Gloves Design
(20217, 2453, 1, 1, 1, 141.768462), -- Chain Gloves
(20217, 2943, 1, 1, 1, 6186.891876), -- Chain Gloves Design
(20217, 2454, 1, 1, 1, 141.768462), -- Karmian Gloves
(20217, 2944, 1, 1, 1, 6186.948834), -- Karmian Gloves Fabric
(20217, 1868, 1, 1, 2, 206484.46107), -- Thread
(20217, 1873, 1, 1, 2, 41297.00361), -- Silver Nugget
(20217, 5549, 1, 1, 2, 10324.18128), -- Metallic Thread
(20217, 1889, 1, 1, 2, 6882.88035), -- Compound Braid
(20217, 2163, 1, 1, 2, 5267.35986), -- Recipe: Earring of Protection
(20217, 2225, 1, 1, 2, 2244.35091), -- Recipe: Demon's Stockings
(20217, 2321, 1, 1, 2, 359.80908), -- Recipe: Stiletto
(20217, 5279, 1, 1, 2, 344.21364), -- Recipe: Greater Blessed Spiritshot (C) Compressed Package(100%)
(20217, 8723, 1, 1, 2, 4129.72821), -- Life Stone - Level 46
(20217, 8733, 1, 1, 2, 1032.36243), -- Mid-Grade Life Stone - Level 46
(20217, 8743, 1, 1, 2, 103.31979), -- High-Grade Life Stone - Level 46
(20217, 8753, 1, 1, 2, 20.32977), -- Top-Grade Life Stone - Level 46
-- Premo
(20218, 1876, 1, 1, -1, 545172), -- Mithril Ore
(20218, 2073, 1, 1, -1, 21069), -- Chakram Edge
(20218, 1908, 1, 1, -1, 258131), -- Moonstone Earring Wire
(20218, 57, 1078, 2190, 0, 700000), -- Adena
(20218, 631, 1, 1, 1, 421.00704), -- Eldarake
(20218, 1964, 1, 1, 1, 17349.669162), -- Eldarake Temper
(20218, 2495, 1, 1, 1, 421.00704), -- Chain Shield
(20218, 2945, 1, 1, 1, 17349.669162), -- Chain Shield Fragment
(20218, 2413, 1, 1, 1, 294.704928), -- Chain Hood
(20218, 2936, 1, 1, 1, 15757.942668), -- Chain Hood Pattern
(20218, 1864, 1, 1, 2, 214713.70785), -- Stem
(20218, 1869, 1, 1, 2, 107356.853925), -- Iron Ore
(20218, 1878, 1, 1, 2, 42942.74157), -- Braided Hemp
(20218, 1884, 1, 1, 2, 66065.82507), -- Cord
(20218, 4039, 1, 1, 2, 3578.487255), -- Mold Glue
(20218, 2320, 1, 1, 2, 373.90518), -- Recipe: Cursed Staff
(20218, 2319, 1, 1, 2, 373.90518), -- Recipe: Raid Sword
(20218, 2217, 1, 1, 2, 6352.362765), -- Recipe: Knight's Shield
(20218, 8723, 1, 1, 2, 4294.095255), -- Life Stone - Level 46
(20218, 8733, 1, 1, 2, 1073.412), -- Mid-Grade Life Stone - Level 46
(20218, 8743, 1, 1, 2, 107.3412), -- High-Grade Life Stone - Level 46
(20218, 8753, 1, 1, 2, 22.36275), -- Top-Grade Life Stone - Level 46
-- Validus
(20219, 1873, 1, 3, -1, 614037), -- Silver Nugget
(20219, 2060, 1, 1, -1, 24378), -- Stormbringer Blade
(20219, 2164, 1, 1, -1, 236168), -- Recipe: Ring of Protection
(20219, 57, 1209, 2473, 0, 700000), -- Adena
(20219, 281, 1, 1, 1, 82.309065), -- Crystallized Ice Bow
(20219, 2074, 1, 1, 1, 5138.690935), -- Crystallized Ice Bow Shaft
(20219, 1870, 1, 1, 2, 131910.492938), -- Coal
(20219, 1865, 1, 1, 2, 131910.492938), -- Varnish
(20219, 1874, 1, 1, 2, 8793.896979), -- Oriharukon Ore
(20219, 4043, 1, 1, 2, 4397.094079), -- Asofe
(20219, 4039, 1, 1, 2, 4397.094079), -- Mold Glue
(20219, 2230, 1, 1, 2, 2556.260441), -- Recipe: Theca Leather Gaiters
(20219, 2326, 1, 1, 2, 459.480462), -- Recipe: Horn of Glory
(20219, 8723, 1, 1, 2, 5276.454659), -- Life Stone - Level 46
(20219, 8733, 1, 1, 2, 1319.04087), -- Mid-Grade Life Stone - Level 46
(20219, 8743, 1, 1, 2, 131.904087), -- High-Grade Life Stone - Level 46
(20219, 8753, 1, 1, 2, 26.788468), -- Top-Grade Life Stone - Level 46
-- Dicor
(20220, 1895, 1, 1, -1, 883618), -- Metallic Fiber
(20220, 2944, 1, 1, -1, 277992), -- Karmian Gloves Fabric
(20220, 1911, 1, 1, -1, 230023), -- Earring of Protection Gemstone
(20220, 57, 1221, 2490, 0, 700000), -- Adena
(20220, 1126, 1, 1, 1, 184.3264), -- Crimson Boots
(20220, 1974, 1, 1, 1, 9603.23888), -- Crimson Boot Fabric
(20220, 2434, 1, 1, 1, 184.3264), -- Rind Leather Boots
(20220, 2948, 1, 1, 1, 9603.23888), -- Rind Leather Boots Lining
(20220, 2455, 1, 1, 1, 199.5944), -- Plated Leather Gloves
(20220, 2946, 1, 1, 1, 6382.46816), -- Plate Leather Gloves Design
(20220, 2456, 1, 1, 1, 184.3264), -- Dwarven Chain Gloves
(20220, 2949, 1, 1, 1, 9603.23888), -- Dwarven Chain Gloves Design
(20220, 2457, 1, 1, 1, 184.3264), -- Gloves of Seal
(20220, 2950, 1, 1, 1, 9603.23888), -- Gloves of Seal Pattern
(20220, 2458, 1, 1, 1, 184.3264), -- Rind Leather Gloves
(20220, 2951, 1, 1, 1, 9603.34992), -- Rind Leather Gloves Design
(20220, 1871, 1, 1, 2, 114190.721286), -- Charcoal
(20220, 1866, 1, 1, 2, 76127.147524), -- Suede
(20220, 1877, 1, 1, 2, 4567.571795), -- Adamantite Nugget
(20220, 4041, 1, 1, 2, 992.985829), -- Mold Hardener
(20220, 4040, 1, 1, 2, 2283.887784), -- Mold Lubricant
(20220, 951, 1, 1, 2, 207.644687), -- Scroll: Enchant Weapon (C-Grade)
(20220, 2343, 1, 1, 2, 265.516219), -- Recipe: Mace of Underworld
(20220, 2345, 1, 1, 2, 265.516219), -- Recipe: Dark Screamer
(20220, 8724, 1, 1, 2, 3806.275867), -- Life Stone - Level 49
(20220, 8734, 1, 1, 2, 951.61991), -- Mid-Grade Life Stone - Level 49
(20220, 8744, 1, 1, 2, 95.161991), -- High-Grade Life Stone - Level 49
(20220, 8754, 1, 1, 2, 18.950889), -- Top-Grade Life Stone - Level 49
-- Perum
(20221, 2352, 1, 1, -1, 9326), -- Recipe: Widow Maker
(20221, 2073, 1, 1, -1, 34456), -- Chakram Edge
(20221, 951, 1, 1, -1, 8105), -- Scroll: Enchant Weapon (C-Grade)
(20221, 57, 1763, 3583, 0, 700000), -- Adena
(20221, 1126, 1, 1, 1, 265.68964), -- Crimson Boots
(20221, 1974, 1, 1, 1, 13842.190163), -- Crimson Boot Fabric
(20221, 2434, 1, 1, 1, 265.68964), -- Rind Leather Boots
(20221, 2948, 1, 1, 1, 13842.190163), -- Rind Leather Boots Lining
(20221, 2455, 1, 1, 1, 287.697065), -- Plated Leather Gloves
(20221, 2946, 1, 1, 1, 9199.743866), -- Plate Leather Gloves Design
(20221, 2456, 1, 1, 1, 265.68964), -- Dwarven Chain Gloves
(20221, 2949, 1, 1, 1, 13842.190163), -- Dwarven Chain Gloves Design
(20221, 2457, 1, 1, 1, 265.68964), -- Gloves of Seal
(20221, 2950, 1, 1, 1, 13842.190163), -- Gloves of Seal Pattern
(20221, 2458, 1, 1, 1, 265.68964), -- Rind Leather Gloves
(20221, 2951, 1, 1, 1, 13842.350217), -- Rind Leather Gloves Design
(20221, 1872, 1, 1, 2, 188107.597296), -- Animal Bone
(20221, 1867, 1, 1, 2, 188107.597296), -- Animal Skin
(20221, 1881, 1, 1, 2, 18810.859689), -- Coarse Bone Powder
(20221, 1875, 1, 1, 2, 9405.179946), -- Stone of Purity
(20221, 4041, 1, 1, 2, 1227.001635), -- Mold Hardener
(20221, 2334, 1, 1, 2, 327.866832), -- Recipe: Sword of Whispering Death
(20221, 2351, 1, 1, 2, 295.380027), -- Recipe: Scorpion
(20221, 3005, 1, 1, 2, 5758.161237), -- Recipe: Demon's Boots
(20221, 6668, 1, 1, 2, 50386.034961), -- Deluxe Chest Key - Grade 4
(20221, 8724, 1, 1, 2, 4702.589973), -- Life Stone - Level 49
(20221, 8734, 1, 1, 2, 1175.522544), -- Mid-Grade Life Stone - Level 49
(20221, 8744, 1, 1, 2, 117.452295), -- High-Grade Life Stone - Level 49
(20221, 8754, 1, 1, 2, 23.490459), -- Top-Grade Life Stone - Level 49
(20221, 1539, 1, 1, 2, 31352.26581), -- Greater Healing Potion
-- Torfe
(20222, 1876, 1, 1, -1, 679016), -- Mithril Ore
(20222, 2168, 1, 1, -1, 86389), -- Recipe: Necklace of Mermaid
(20222, 1895, 1, 3, -1, 485011), -- Metallic Fiber
(20222, 57, 1340, 2733, 0, 700000), -- Adena
(20222, 2496, 1, 1, 1, 417.505968), -- Dwarven Chain Shield
(20222, 2947, 1, 1, 1, 17907.400368), -- Dwarven Chain Shield Fragment
(20222, 632, 1, 1, 1, 385.419408), -- Knight's Shield
(20222, 1972, 1, 1, 1, 20056.27536), -- Knight's Shield Fragment
(20222, 500, 1, 1, 1, 269.853408), -- Great Helmet
(20222, 1971, 1, 1, 1, 15347.545488), -- Great Helmet Material
(20222, 1873, 1, 1, 2, 50142.783922), -- Silver Nugget
(20222, 1868, 1, 1, 2, 250714.725492), -- Thread
(20222, 1876, 1, 1, 2, 25071.391961), -- Mithril Ore
(20222, 1895, 1, 1, 2, 35816.216667), -- Metallic Fiber
(20222, 4042, 1, 1, 2, 2089.249085), -- Enria
(20222, 3006, 1, 1, 2, 5116.544818), -- Recipe: Demon's Gloves
(20222, 2222, 1, 1, 2, 783.317304), -- Recipe: Composite Armor
(20222, 8724, 1, 1, 2, 4178.49817), -- Life Stone - Level 49
(20222, 8734, 1, 1, 2, 1044.826013), -- Mid-Grade Life Stone - Level 49
(20222, 8744, 1, 1, 2, 104.361719), -- High-Grade Life Stone - Level 49
(20222, 8754, 1, 1, 2, 20.952932), -- Top-Grade Life Stone - Level 49
(20222, 1539, 1, 1, 2, 27858.131917), -- Greater Healing Potion
-- Mandragora Sprout
(20223, 734, 1, 1, -1, 49539), -- Haste Potion
(20223, 2011, 1, 1, -1, 6781), -- Short Spear Edge
(20223, 1864, 1, 1, -1, 594474), -- Stem
(20223, 57, 137, 239, 0, 700000), -- Adena
(20223, 845, 1, 1, 1, 1283.606976), -- Cat's Eye Earring
(20223, 908, 1, 1, 1, 962.712544), -- Necklace of Wisdom
(20223, 1897, 1, 1, 1, 10452.270016), -- Necklace of Wisdom Chain
(20223, 877, 1, 1, 1, 1925.410464), -- Ring of Wisdom
(20223, 1864, 1, 1, 2, 87798.98928), -- Stem
(20223, 1869, 1, 1, 2, 43899.49464), -- Iron Ore
(20223, 1878, 1, 1, 2, 17559.797856), -- Braided Hemp
(20223, 2175, 1, 1, 2, 35690.718224), -- Recipe: Boots
-- Ol Mahum Ranger
(20224, 2178, 1, 1, -1, 74717), -- Recipe: Dark Stockings
(20224, 1865, 1, 1, -1, 466983), -- Varnish
(20224, 1898, 1, 1, -1, 47969), -- Blue Diamond Necklace Gem
(20224, 57, 212, 381, 0, 700000), -- Adena
(20224, 27, 1, 1, 1, 485.692998), -- Hard Leather Shirt
(20224, 1927, 1, 1, 1, 5501.993196), -- Hard Leather Shirt Pattern
(20224, 33, 1, 1, 1, 779.289504), -- Hard Leather Gaiters
(20224, 1929, 1, 1, 1, 8899.024302), -- Hard Leather Gaiters Material
(20224, 1872, 1, 1, 2, 73567.598478), -- Animal Bone
(20224, 1867, 1, 1, 2, 73567.598478), -- Animal Skin
(20224, 1881, 1, 1, 2, 7356.712176), -- Coarse Bone Powder
(20224, 5153, 1, 1, 2, 2207.045434), -- Recipe: Soulshot (D) Compressed Package (100%)
(20224, 5268, 1, 1, 2, 2207.045434), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Giant Mist Leech
(20225, 2259, 1, 1, -1, 6517), -- Recipe: Spinebone Sword
(20225, 1931, 1, 1, -1, 54861), -- Leather Boots Lining
(20225, 2152, 1, 1, -1, 73889), -- Recipe: Enchanted Necklace
(20225, 57, 185, 346, 0, 700000), -- Adena
(20225, 40, 1, 1, 1, 731.502336), -- Leather Boots
(20225, 1931, 1, 1, 1, 7697.497664), -- Leather Boots Lining
(20225, 604, 1, 1, 1, 731.502336), -- Crafted Leather Gloves
(20225, 1934, 1, 1, 1, 7697.497664), -- Crafted Leather Gloves Lining
(20225, 1865, 1, 1, 2, 39256.835541), -- Varnish
(20225, 1870, 1, 1, 2, 39256.835541), -- Coal
(20225, 1879, 1, 1, 2, 6542.761302), -- Cokes
(20225, 1875, 1, 1, 2, 2617.140218), -- Stone of Purity
(20225, 2259, 1, 1, 2, 609.618933), -- Recipe: Spinebone Sword
(20225, 5437, 1, 1, 2, 959.808465), -- Recipe: Heavy Sword(100%)
-- Gray Ant
(20226, 1868, 1, 1, -1, 884148), -- Thread
(20226, 413, 1, 1, -1, 2937), -- Puma Skin Gaiters
(20226, 1899, 1, 1, -1, 69074), -- Necklace of Devotion Chain
(20226, 57, 192, 367, 0, 700000), -- Adena
(20226, 123, 1, 1, 1, 39.373776), -- Saber
(20226, 2017, 1, 1, 1, 824.082984), -- Saber Blade
(20226, 5285, 1, 1, 1, 39.373776), -- Heavy Sword
(20226, 5531, 1, 1, 1, 1041.169464), -- Heavy Sword Edge
(20226, 1866, 1, 1, 2, 41351.087969), -- Suede
(20226, 1871, 1, 1, 2, 62026.574062), -- Charcoal
(20226, 5220, 1, 1, 2, 2481.113907), -- Metal Hardener
(20226, 2178, 1, 1, 2, 9924.224062), -- Recipe: Dark Stockings
-- Horror Mist Ripper
(20227, 2260, 1, 1, -1, 7238), -- Recipe: Mace of Judgment
(20227, 1899, 1, 1, -1, 72835), -- Necklace of Devotion Chain
(20227, 2178, 1, 1, -1, 74583), -- Recipe: Dark Stockings
(20227, 57, 201, 388, 0, 700000), -- Adena
(20227, 391, 1, 1, 1, 542.799628), -- Puma Skin Shirt
(20227, 413, 1, 1, 1, 869.200372), -- Puma Skin Gaiters
(20227, 1867, 1, 1, 2, 69763.474464), -- Animal Skin
(20227, 1872, 1, 1, 2, 69763.474464), -- Animal Bone
(20227, 1882, 1, 1, 2, 11627.19216), -- Leather
(20227, 2181, 1, 1, 2, 5237.460912), -- Recipe: White Tunic
(20227, 6035, 1, 1, 2, 4360.398), -- Magic Haste Potion
-- Giant Crimson Ant
(20228, 2180, 1, 1, -1, 40128), -- Recipe: Scale Mail
(20228, 1884, 1, 1, -1, 328429), -- Cord
(20228, 1931, 1, 1, -1, 69764), -- Leather Boots Lining
(20228, 57, 229, 448, 0, 700000), -- Adena
(20228, 847, 1, 1, 1, 723.509376), -- Red Crescent Earring
(20228, 910, 1, 1, 1, 542.632032), -- Necklace of Devotion
(20228, 1899, 1, 1, 1, 11700.580476), -- Necklace of Devotion Chain
(20228, 890, 1, 1, 1, 1085.278116), -- Ring of Devotion
(20228, 1868, 1, 1, 2, 99842.559024), -- Thread
(20228, 1873, 1, 1, 2, 19968.617808), -- Silver Nugget
(20228, 5549, 1, 1, 2, 4992.220704), -- Metallic Thread
(20228, 1889, 1, 1, 2, 3327.970464), -- Compound Braid
(20228, 2180, 1, 1, 2, 3753.573312), -- Recipe: Scale Mail
(20228, 1831, 1, 1, 2, 133123.058688), -- Antidote
-- Stinger Wasp
(20229, 1061, 1, 1, -1, 357490), -- Greater Healing Potion
(20229, 414, 1, 1, -1, 2458), -- Lion Skin Gaiters
(20229, 1864, 1, 3, -1, 589858), -- Stem
(20229, 57, 249, 498, 0, 700000), -- Adena
(20229, 848, 1, 1, 1, 491.364384), -- Enchanted Earring
(20229, 911, 1, 1, 1, 368.799312), -- Enchanted Necklace
(20229, 1900, 1, 1, 1, 8816.539872), -- Enchanted Necklace Chain
(20229, 879, 1, 1, 1, 739.296432), -- Enchanted Ring
(20229, 1869, 1, 1, 2, 46047.720602), -- Iron Ore
(20229, 1864, 1, 1, 2, 92095.441204), -- Stem
(20229, 1880, 1, 1, 2, 4604.732994), -- Steel
(20229, 5550, 1, 1, 2, 613.925333), -- Durable Metal Plate
(20229, 2265, 1, 1, 2, 476.216978), -- Recipe: Spiked Club
(20229, 2274, 1, 1, 2, 328.937404), -- Recipe: Skull Breaker
(20229, 1832, 1, 1, 2, 51164.025485), -- Greater Antidote
-- Marsh Stakato Worker
(20230, 1834, 1, 1, -1, 745819), -- Emergency Dressing
(20230, 434, 1, 1, -1, 1746), -- White Tunic
(20230, 1870, 1, 1, -1, 671237), -- Coal
(20230, 57, 284, 566, 0, 700000), -- Adena
(20230, 292, 1, 1, 1, 148), -- Pike
(20230, 1870, 1, 1, 2, 91701.33687), -- Coal
(20230, 1865, 1, 1, 2, 91701.33687), -- Varnish
(20230, 1874, 1, 1, 2, 6113.422458), -- Oriharukon Ore
(20230, 956, 1, 1, 2, 3056.903802), -- Scroll: Enchant Armor (D-Grade)
-- Toad Lord
(20231, 1832, 1, 1, -1, 722627), -- Greater Antidote
(20231, 2282, 1, 1, -1, 4645), -- Recipe: Cursed Maingauche
(20231, 1877, 1, 1, -1, 26015), -- Adamantite Nugget
(20231, 57, 274, 550, 0, 700000), -- Adena
(20231, 1123, 1, 1, 1, 1388.5), -- Blue Buckskin Boots
(20231, 605, 1, 1, 1, 1388.5), -- Leather Gauntlets
(20231, 1871, 1, 1, 2, 59233.240472), -- Charcoal
(20231, 1866, 1, 1, 2, 39488.771126), -- Suede
(20231, 1877, 1, 1, 2, 2369.38324), -- Adamantite Nugget
(20231, 955, 1, 1, 2, 236.938324), -- Scroll: Enchant Weapon (D-Grade)
(20231, 2277, 1, 1, 2, 423.10415), -- Recipe: Bich'hwa
(20231, 1832, 1, 1, 2, 65814.562688), -- Greater Antidote
-- Marsh Stakato Soldier
(20232, 2147, 1, 1, -1, 45242), -- Recipe: Blacksmith's frame
(20232, 2027, 1, 1, -1, 8298), -- Spiked Club Head
(20232, 1901, 1, 1, -1, 87485), -- Tiger's Eye Earring Stone
(20232, 57, 268, 535, 0, 700000), -- Adena
(20232, 628, 1, 1, 1, 821.340788), -- Hoplon
(20232, 47, 1, 1, 1, 574.659212), -- Helmet
(20232, 1872, 1, 1, 2, 74837.606625), -- Animal Bone
(20232, 1867, 1, 1, 2, 74837.606625), -- Animal Skin
(20232, 1881, 1, 1, 2, 7483.847115), -- Coarse Bone Powder
(20232, 1875, 1, 1, 2, 3741.837105), -- Stone of Purity
(20232, 2156, 1, 1, 2, 4490.34285), -- Recipe: Elven Necklace
(20232, 2191, 1, 1, 2, 7513.75968), -- Recipe: RIP Gauntlets
-- Marsh Spider
(20233, 2280, 1, 1, -1, 5301), -- Recipe: Crucifix of Blood
(20233, 955, 1, 1, -1, 2969), -- Scroll: Enchant Weapon (D-Grade)
(20233, 2154, 1, 1, -1, 79458), -- Recipe: Elven Earring
(20233, 57, 313, 625, 0, 700000), -- Adena
(20233, 849, 1, 1, 1, 399.38733), -- Tiger's Eye Earring
(20233, 1901, 1, 1, 1, 13625.367732), -- Tiger's Eye Earring Stone
(20233, 912, 1, 1, 1, 299.380086), -- Near Forest Necklace
(20233, 880, 1, 1, 1, 597.864852), -- Black Pearl Ring
(20233, 1873, 1, 1, 2, 22547.825456), -- Silver Nugget
(20233, 1868, 1, 1, 2, 112739.12728), -- Thread
(20233, 1876, 1, 1, 2, 11273.912728), -- Mithril Ore
(20233, 2273, 1, 1, 2, 402.539904), -- Recipe: Tarbar
(20233, 2274, 1, 1, 2, 402.539904), -- Recipe: Skull Breaker
(20233, 2975, 1, 1, 2, 5033.038992), -- Recipe: Brigandine Helmet
(20233, 1832, 1, 1, 2, 62633.015736), -- Greater Antidote
-- Marsh Stakato Drone
(20234, 1879, 1, 1, -1, 124798), -- Cokes
(20234, 2971, 1, 1, -1, 40042), -- Recipe: Mithril Scale Gaiters
(20234, 1938, 1, 1, -1, 50339), -- Mithril Banded Mail Material
(20234, 57, 316, 631, 0, 700000), -- Adena
(20234, 293, 1, 1, 1, 53.5), -- War Hammer
(20234, 296, 1, 1, 1, 53.5), -- Dwarven Pike
(20234, 1873, 1, 1, 2, 31849.943364), -- Silver Nugget
(20234, 1868, 1, 1, 2, 159250.163564), -- Thread
(20234, 1876, 1, 1, 2, 15925.083368), -- Mithril Ore
(20234, 2979, 1, 1, 2, 10659.31184), -- Recipe: Manticore Skin Gloves
(20234, 2188, 1, 1, 2, 5687.497864), -- Recipe: Manticore Skin Gaiters
-- Shackle
(20235, 2074, 1, 1, -1, 8417), -- Crystallized Ice Bow Shaft
(20235, 2340, 1, 1, -1, 2764), -- Recipe: Pa'agrian Hammer
(20235, 2163, 1, 1, -1, 60630), -- Recipe: Earring of Protection
(20235, 57, 470, 955, 0, 700000), -- Adena
(20235, 96, 1, 1, 1, 10.618202), -- Scythe
(20235, 2062, 1, 1, 1, 734.04772), -- Scythe Edge
(20235, 298, 1, 1, 1, 10.618202), -- Orcish Glaive
(20235, 2075, 1, 1, 1, 734.04772), -- Orcish Glaive Blade
(20235, 302, 1, 1, 1, 10.618202), -- Body Slasher
(20235, 2076, 1, 1, 1, 734.049954), -- Body Slasher Blade
(20235, 1870, 1, 1, 2, 56163.066915), -- Coal
(20235, 1865, 1, 1, 2, 56163.066915), -- Varnish
(20235, 1874, 1, 1, 2, 3744.204461), -- Oriharukon Ore
(20235, 4043, 1, 1, 2, 1872.164736), -- Asofe
(20235, 4039, 1, 1, 2, 1872.164736), -- Mold Glue
(20235, 2216, 1, 1, 2, 2320.829215), -- Recipe: Great Helmet
(20235, 8723, 1, 1, 2, 2246.572681), -- Life Stone - Level 46
(20235, 8733, 1, 1, 2, 561.674423), -- Mid-Grade Life Stone - Level 46
(20235, 8743, 1, 1, 2, 56.129939), -- High-Grade Life Stone - Level 46
(20235, 8753, 1, 1, 2, 11.125979), -- Top-Grade Life Stone - Level 46
-- Cave Servant
(20236, 2219, 1, 1, -1, 76370), -- Recipe: Crimson Boots
(20236, 3021, 1, 1, -1, 4284), -- Recipe: Dwarven War Hammer
(20236, 1908, 1, 1, -1, 116435), -- Moonstone Earring Wire
(20236, 57, 484, 990, 0, 700000), -- Adena
(20236, 62, 1, 1, 1, 66.496124), -- Reinforced Mithril Boots
(20236, 1958, 1, 1, 1, 2901.945352), -- Reinforced Mithril Boots Design
(20236, 2429, 1, 1, 1, 66.496124), -- Chain Boots
(20236, 2937, 1, 1, 1, 2901.945352), -- Chain Boots Part
(20236, 2430, 1, 1, 1, 66.496124), -- Karmian Boots
(20236, 2938, 1, 1, 1, 2901.945352), -- Karmian Boots Fabric
(20236, 2431, 1, 1, 1, 66.496124), -- Plated Leather Boots
(20236, 2939, 1, 1, 1, 2901.945352), -- Plate Leather Boots Lining
(20236, 2432, 1, 1, 1, 66.496124), -- Dwarven Chain Boots
(20236, 2940, 1, 1, 1, 2901.945352), -- Dwarven Chain Boots Part
(20236, 2433, 1, 1, 1, 66.496124), -- Boots of Seal
(20236, 2941, 1, 1, 1, 2901.945352), -- Boots of Seal Pattern
(20236, 2452, 1, 1, 1, 66.496124), -- Reinforced Mithril Gloves
(20236, 2942, 1, 1, 1, 2901.945352), -- Reinforced Mithril Gloves Design
(20236, 2453, 1, 1, 1, 66.496124), -- Chain Gloves
(20236, 2943, 1, 1, 1, 2901.945352), -- Chain Gloves Design
(20236, 2454, 1, 1, 1, 66.496124), -- Karmian Gloves
(20236, 2944, 1, 1, 1, 2901.972068), -- Karmian Gloves Fabric
(20236, 1870, 1, 1, 2, 58110.63069), -- Coal
(20236, 1865, 1, 1, 2, 58110.63069), -- Varnish
(20236, 1874, 1, 1, 2, 3874.042046), -- Oriharukon Ore
(20236, 4043, 1, 1, 2, 1937.085696), -- Asofe
(20236, 4039, 1, 1, 2, 1937.085696), -- Mold Glue
(20236, 2216, 1, 1, 2, 2401.30849), -- Recipe: Great Helmet
(20236, 8723, 1, 1, 2, 2324.476966), -- Life Stone - Level 46
(20236, 8733, 1, 1, 2, 581.151578), -- Mid-Grade Life Stone - Level 46
(20236, 8743, 1, 1, 2, 58.076354), -- High-Grade Life Stone - Level 46
(20236, 8753, 1, 1, 2, 11.511794), -- Top-Grade Life Stone - Level 46
-- Cave Servant Archer
(20237, 2329, 1, 1, -1, 3846), -- Recipe: Tsurugi
(20237, 3010, 1, 1, -1, 44939), -- Recipe: Composite Helmet
(20237, 951, 1, 1, -1, 3007), -- Scroll: Enchant Weapon (C-Grade)
(20237, 57, 653, 1332, 0, 700000), -- Adena
(20237, 282, 1, 1, 1, 16.581576), -- Elemental Bow
(20237, 2085, 1, 1, 1, 1267.418424), -- Crossbow Shaft
(20237, 285, 1, 1, 1, 16.581576), -- Noble Elven Bow
(20237, 2086, 1, 1, 1, 1267.418424), -- Noble Elven Bow Shaft
(20237, 1869, 1, 1, 2, 61061.755032), -- Iron Ore
(20237, 1864, 1, 1, 2, 122123.510064), -- Stem
(20237, 1880, 1, 1, 2, 6106.30305), -- Steel
(20237, 5550, 1, 1, 2, 814.067451), -- Durable Metal Plate
(20237, 4043, 1, 1, 2, 2035.328061), -- Asofe
(20237, 952, 1, 1, 2, 814.067451), -- Scroll: Enchant Armor (C-Grade)
(20237, 2230, 1, 1, 2, 1183.315437), -- Recipe: Theca Leather Gaiters
(20237, 8724, 1, 1, 2, 2035.328061), -- Life Stone - Level 49
(20237, 8734, 1, 1, 2, 508.911732), -- Mid-Grade Life Stone - Level 49
(20237, 8744, 1, 1, 2, 51.01872), -- High-Grade Life Stone - Level 49
(20237, 8754, 1, 1, 2, 10.203744), -- Top-Grade Life Stone - Level 49
(20237, 1342, 10, 30, 2, 122123.191197), -- Steel Arrow
-- Cave Servant Warrior
(20238, 2357, 1, 1, -1, 2599), -- Recipe: Crystal Dagger
(20238, 1877, 1, 1, -1, 63734), -- Adamantite Nugget
(20238, 4041, 1, 1, -1, 13855), -- Mold Hardener
(20238, 57, 630, 1281, 0, 700000), -- Adena
(20238, 355, 1, 1, 1, 71.23571), -- Dwarven Chain Mail Shirt
(20238, 1968, 1, 1, 1, 4252.67124), -- Dwarven Chain Mail Shirt Material
(20238, 382, 1, 1, 1, 113.977136), -- Dwarven Chain Gaiters
(20238, 1969, 1, 1, 1, 6745.115914), -- Dwarven Chain Gaiters Material
(20238, 1871, 1, 1, 2, 58830.987264), -- Charcoal
(20238, 1866, 1, 1, 2, 39220.658176), -- Suede
(20238, 1877, 1, 1, 2, 2353.224384), -- Adamantite Nugget
(20238, 4041, 1, 1, 2, 511.608832), -- Mold Hardener
(20238, 4040, 1, 1, 2, 1176.675136), -- Mold Lubricant
(20238, 2335, 1, 1, 2, 136.840256), -- Recipe: War Axe
(20238, 2348, 1, 1, 2, 136.840256), -- Recipe: Heathen's Book
(20238, 6668, 1, 1, 2, 21011.084864), -- Deluxe Chest Key - Grade 4
(20238, 8724, 1, 1, 2, 1961.083264), -- Life Stone - Level 49
(20238, 8734, 1, 1, 2, 490.207872), -- Mid-Grade Life Stone - Level 49
(20238, 8744, 1, 1, 2, 48.970432), -- High-Grade Life Stone - Level 49
(20238, 8754, 1, 1, 2, 9.819264), -- Top-Grade Life Stone - Level 49
-- Cave Servant Captain
(20239, 3007, 1, 1, -1, 61644), -- Recipe: Theca Leather Boots
(20239, 2079, 1, 1, -1, 11647), -- Bec De Corbin Blade
(20239, 1867, 1, 5, -1, 753426), -- Animal Skin
(20239, 57, 669, 1365, 0, 700000), -- Adena
(20239, 73, 1, 1, 1, 8.49744), -- Shamshir
(20239, 2077, 1, 1, 1, 623.75256), -- Shamshir Blade
(20239, 74, 1, 1, 1, 8.49744), -- Katana
(20239, 2078, 1, 1, 1, 623.75256), -- Katana Blade
(20239, 131, 1, 1, 1, 8.49744), -- Spirit Sword
(20239, 2080, 1, 1, 1, 623.75256), -- Spirit Sword Blade
(20239, 133, 1, 1, 1, 8.49744), -- Raid Sword
(20239, 2081, 1, 1, 1, 623.75256), -- Raid Sword Blade
(20239, 1872, 1, 1, 2, 83456.462368), -- Animal Bone
(20239, 1867, 1, 1, 2, 83456.462368), -- Animal Skin
(20239, 1881, 1, 1, 2, 8345.627648), -- Coarse Bone Powder
(20239, 1875, 1, 1, 2, 4172.813824), -- Stone of Purity
(20239, 4041, 1, 1, 2, 544.280064), -- Mold Hardener
(20239, 3007, 1, 1, 2, 2276.012672), -- Recipe: Theca Leather Boots
(20239, 2351, 1, 1, 2, 130.865152), -- Recipe: Scorpion
(20239, 952, 1, 1, 2, 834.63712), -- Scroll: Enchant Armor (C-Grade)
(20239, 8724, 1, 1, 2, 2086.406912), -- Life Stone - Level 49
(20239, 8734, 1, 1, 2, 521.601728), -- Mid-Grade Life Stone - Level 49
(20239, 8744, 1, 1, 2, 52.234528), -- High-Grade Life Stone - Level 49
(20239, 8754, 1, 1, 2, 10.595616), -- Top-Grade Life Stone - Level 49
-- Royal Cave Servant
(20240, 2092, 1, 1, -1, 9934), -- Homunkulus's Sword Blade
(20240, 2353, 1, 1, -1, 2974), -- Recipe: Samurai Longsword
(20240, 4601, 1, 1, -1, 4051), -- Greater Dye of STR (Str+3 Con-3)
(20240, 57, 722, 1466, 0, 700000), -- Adena
(20240, 265, 1, 1, 1, 22.817308), -- Fisted Blade
(20240, 2108, 1, 1, 1, 2019.182692), -- Fisted Blade Piece
(20240, 1864, 1, 1, 2, 137054.470422), -- Stem
(20240, 1869, 1, 1, 2, 68527.235211), -- Iron Ore
(20240, 1878, 1, 1, 2, 27410.950449), -- Braided Hemp
(20240, 1884, 1, 1, 2, 42170.584605), -- Cord
(20240, 4039, 1, 1, 2, 2284.175415), -- Mold Glue
(20240, 3022, 1, 1, 2, 111.883731), -- Recipe: Yaksa Mace
(20240, 3019, 1, 1, 2, 1827.340332), -- Recipe: Full Plate Shield
(20240, 8725, 1, 1, 2, 1903.432542), -- Life Stone - Level 52
(20240, 8735, 1, 1, 2, 475.999047), -- Mid-Grade Life Stone - Level 52
(20240, 8745, 1, 1, 2, 47.628087), -- High-Grade Life Stone - Level 52
(20240, 8755, 1, 1, 2, 9.300159), -- Top-Grade Life Stone - Level 52
-- Hunter Gargoyle
(20241, 2100, 1, 1, -1, 10217), -- Paradia Staff Head
(20241, 3015, 1, 1, -1, 50627), -- Recipe: Drake Leather Gloves
(20241, 1539, 1, 1, -1, 402767), -- Greater Healing Potion
(20241, 57, 720, 1455, 0, 700000), -- Adena
(20241, 854, 1, 1, 1, 110.257488), -- Earring of Seal
(20241, 1914, 1, 1, 1, 7017.33344), -- Earring of Seal Gemstone
(20241, 917, 1, 1, 1, 82.69904), -- Necklace of Mermaid
(20241, 1916, 1, 1, 1, 5315.24976), -- Necklace of Mermaid Teardrop
(20241, 885, 1, 1, 1, 165.326992), -- Ring of Ages
(20241, 1915, 1, 1, 1, 11005.13328), -- Ring of Ages Gemstone
(20241, 1872, 1, 1, 2, 76873.44124), -- Animal Bone
(20241, 1867, 1, 1, 2, 76873.44124), -- Animal Skin
(20241, 1881, 1, 1, 2, 7687.41204), -- Coarse Bone Powder
(20241, 1875, 1, 1, 2, 3843.70602), -- Stone of Purity
(20241, 4041, 1, 1, 2, 501.38987), -- Mold Hardener
(20241, 4604, 1, 1, 2, 128.19145), -- Greater Dye of CON (Con+3 Dex-3)
(20241, 4609, 1, 1, 2, 128.19145), -- Greater Dye of MEN (Men+3 Int-3)
(20241, 3014, 1, 1, 2, 1610.45815), -- Recipe: Full Plate Boots
(20241, 2359, 1, 1, 2, 94.06366), -- Recipe: Eminence Bow
(20241, 8725, 1, 1, 2, 1601.45928), -- Life Stone - Level 52
(20241, 8735, 1, 1, 2, 400.36482), -- Mid-Grade Life Stone - Level 52
(20241, 8745, 1, 1, 2, 40.07044), -- High-Grade Life Stone - Level 52
(20241, 8755, 1, 1, 2, 7.81034), -- Top-Grade Life Stone - Level 52
-- Dustwind Gargoyle
(20242, 1985, 1, 1, -1, 66727), -- Theca Leather Gaiters Pattern
(20242, 1868, 1, 9, -1, 774035), -- Thread
(20242, 1918, 1, 1, -1, 83806), -- Nassen's Earring Gemstone
(20242, 57, 766, 1556, 0, 700000), -- Adena
(20242, 400, 1, 1, 1, 37.508306), -- Theca Leather Armor
(20242, 1984, 1, 1, 1, 2552.652421), -- Theca Leather Armor Pattern
(20242, 401, 1, 1, 1, 17.757597), -- Drake Leather Armor
(20242, 1987, 1, 1, 1, 1816.790316), -- Drake Leather Armor Texture
(20242, 420, 1, 1, 1, 60.033908), -- Theca Leather Gaiters
(20242, 1985, 1, 1, 1, 4106.257452), -- Theca Leather Gaiters Pattern
(20242, 1872, 1, 1, 2, 68047.178448), -- Animal Bone
(20242, 1867, 1, 1, 2, 68047.178448), -- Animal Skin
(20242, 1881, 1, 1, 2, 6804.750186), -- Coarse Bone Powder
(20242, 1875, 1, 1, 2, 3402.29424), -- Stone of Purity
(20242, 4041, 1, 1, 2, 443.721264), -- Mold Hardener
(20242, 3034, 1, 1, 2, 102.036486), -- Recipe: Spiritshot B
(20242, 5270, 1, 1, 2, 102.036486), -- Recipe: Greater Soulshot (B) Compressed Package(100%)
(20242, 4959, 1, 1, 2, 983.334186), -- Recipe: Sealed Avadon Boots (60%)
(20242, 4941, 1, 1, 2, 392.622168), -- Recipe: Zubei's Gaiters (60%)
(20242, 6669, 1, 1, 2, 11868.735282), -- Deluxe Chest Key - Grade 5
(20242, 8726, 1, 1, 2, 1181.424036), -- Life Stone - Level 55
(20242, 8736, 1, 1, 2, 295.275156), -- Mid-Grade Life Stone - Level 55
(20242, 8746, 1, 1, 2, 29.592198), -- High-Grade Life Stone - Level 55
(20242, 8756, 1, 1, 2, 5.821416), -- Top-Grade Life Stone - Level 55
-- Thunder Wyrm
(20243, 4599, 1, 1, -1, 5751), -- Greater Dye of WIT (Wit+2 Int-2)
(20243, 1873, 1, 1, -1, 690175), -- Silver Nugget
(20243, 1806, 1, 1, -1, 3451), -- Recipe: Soulshot (B-Grade)
(20243, 57, 682, 1388, 0, 700000), -- Adena
(20243, 203, 1, 1, 1, 3.463976), -- Pa'agrian Axe
(20243, 2112, 1, 1, 1, 308.507784), -- Pa'agrian Axe Blade
(20243, 204, 1, 1, 1, 2.703032), -- Deadman's Staff
(20243, 2116, 1, 1, 1, 299.73248), -- Deadman's Staff Head
(20243, 205, 1, 1, 1, 2.703032), -- Ghoul's Staff
(20243, 2117, 1, 1, 1, 299.73248), -- Ghoul's Staff Head
(20243, 206, 1, 1, 1, 2.703032), -- Demon's Staff
(20243, 2118, 1, 1, 1, 299.73248), -- Demon's Staff Head
(20243, 2503, 1, 1, 1, 2.703032), -- Yaksa Mace
(20243, 2969, 1, 1, 1, 306.018672), -- Yaksa Mace Head
(20243, 1869, 1, 1, 2, 53090.529408), -- Iron Ore
(20243, 1864, 1, 1, 2, 106180.889472), -- Stem
(20243, 1880, 1, 1, 2, 5309.103744), -- Steel
(20243, 5550, 1, 1, 2, 707.85792), -- Durable Metal Plate
(20243, 4043, 1, 1, 2, 1769.6448), -- Asofe
(20243, 4144, 1, 1, 2, 545.626368), -- Recipe: Zubei's Leather Gaiters (100%)
(20243, 4184, 1, 1, 2, 61.133184), -- Recipe: Sprite's Staff (100%)
(20243, 5155, 1, 1, 2, 106.178688), -- Recipe: Soulshot (B) Compressed Package (100%)
(20243, 8726, 1, 1, 2, 1228.929408), -- Life Stone - Level 55
(20243, 8736, 1, 1, 2, 307.190016), -- Mid-Grade Life Stone - Level 55
(20243, 8746, 1, 1, 2, 30.651264), -- High-Grade Life Stone - Level 55
(20243, 8756, 1, 1, 2, 6.265728), -- Top-Grade Life Stone - Level 55
-- Maluk Succubus
(20244, 3955, 1, 1, -1, 3548), -- Recipe: Blessed Spiritshot B
(20244, 2117, 1, 1, -1, 8346), -- Ghoul's Staff Head
(20244, 4592, 1, 1, -1, 5913), -- Greater Dye of CON (Con+2 Dex-2)
(20244, 57, 701, 1428, 0, 700000), -- Adena
(20244, 400, 1, 1, 1, 34.38225), -- Theca Leather Armor
(20244, 1984, 1, 1, 1, 2339.906625), -- Theca Leather Armor Pattern
(20244, 401, 1, 1, 1, 16.277625), -- Drake Leather Armor
(20244, 1987, 1, 1, 1, 1665.3735), -- Drake Leather Armor Texture
(20244, 420, 1, 1, 1, 55.0305), -- Theca Leather Gaiters
(20244, 1985, 1, 1, 1, 3764.0295), -- Theca Leather Gaiters Pattern
(20244, 1872, 1, 1, 2, 72778.24202), -- Animal Bone
(20244, 1867, 1, 1, 2, 72778.24202), -- Animal Skin
(20244, 1881, 1, 1, 2, 7277.84008), -- Coarse Bone Powder
(20244, 1875, 1, 1, 2, 3638.92004), -- Stone of Purity
(20244, 4041, 1, 1, 2, 474.59342), -- Mold Hardener
(20244, 4185, 1, 1, 2, 62.87688), -- Recipe: Keshanberk (100%)
(20244, 5436, 1, 1, 2, 89.07558), -- Recipe: Berserker Blade(100%)
(20244, 8322, 1, 1, 2, 62.87688), -- Recipe: Ice Storm Hammer (60%)
(20244, 8726, 1, 1, 2, 1263.57124), -- Life Stone - Level 55
(20244, 8736, 1, 1, 2, 315.81342), -- Mid-Grade Life Stone - Level 55
(20244, 8746, 1, 1, 2, 31.59722), -- High-Grade Life Stone - Level 55
(20244, 8756, 1, 1, 2, 6.3512), -- Top-Grade Life Stone - Level 55
-- Maluk Succubus Turen
(20245, 1895, 1, 1, -1, 526594), -- Metallic Fiber
(20245, 4071, 1, 1, -1, 33383), -- Avadon Robe Fabric
(20245, 4129, 1, 1, -1, 19947), -- Recipe: Earrings of Black Ore (100%)
(20245, 57, 727, 1485, 0, 700000), -- Adena
(20245, 12159, 1, 1, 1, 621.488992), -- Common Item - Zubei's Shield
(20245, 4101, 1, 1, 1, 3945.07984), -- Zubei's Shield Fragment
(20245, 12171, 1, 1, 1, 621.488992), -- Common Item - Avadon Shield
(20245, 4439, 1, 1, 1, 4693.284928), -- Avadon Shield Fragment
(20245, 12160, 1, 1, 1, 434.83824), -- Common Item - Zubei's Helmet
(20245, 4102, 1, 1, 1, 3056.481952), -- Zubei's Helmet Design
(20245, 12170, 1, 1, 1, 434.83824), -- Common Item - Avadon Circlet
(20245, 4072, 1, 1, 1, 3056.498816), -- Avadon Circlet Pattern
(20245, 1864, 1, 1, 2, 83756.319034), -- Stem
(20245, 1869, 1, 1, 2, 41878.159517), -- Iron Ore
(20245, 1878, 1, 1, 2, 16751.298423), -- Braided Hemp
(20245, 1884, 1, 1, 2, 25771.241657), -- Cord
(20245, 4039, 1, 1, 2, 1395.898265), -- Mold Glue
(20245, 4945, 1, 1, 2, 322.103741), -- Recipe: Avadon Gaiters (60%)
(20245, 4999, 1, 1, 2, 520.800729), -- Recipe: Sealed Doom Boots (60%)
(20245, 8322, 1, 1, 2, 48.289599), -- Recipe: Ice Storm Hammer (60%)
(20245, 8726, 1, 1, 2, 969.426681), -- Life Stone - Level 55
(20245, 8736, 1, 1, 2, 242.3134), -- Mid-Grade Life Stone - Level 55
(20245, 8746, 1, 1, 2, 24.23134), -- High-Grade Life Stone - Level 55
(20245, 8756, 1, 1, 2, 4.846268), -- Top-Grade Life Stone - Level 55
(20245, 6036, 1, 1, 2, 1396.071346), -- Greater Magic Haste Potion
-- Cave Keeper
(20246, 2964, 1, 1, -1, 128620), -- Divine Gloves Pattern
(20246, 4049, 1, 1, -1, 123897), -- Adamantite Earring Gemstone
(20246, 947, 1, 1, -1, 945), -- Scroll: Enchant Weapon (B-Grade)
(20246, 57, 933, 1900, 0, 700000), -- Adena
(20246, 12338, 1, 1, 1, 953.195154), -- Common Item - Adamantite Earring
(20246, 4049, 1, 1, 1, 6099.582939), -- Adamantite Earring Gemstone
(20246, 12339, 1, 1, 1, 715.618071), -- Common Item - Adamantite Necklace
(20246, 4051, 1, 1, 1, 4509.92721), -- Adamantite Necklace Chain
(20246, 12340, 1, 1, 1, 1435.67097), -- Common Item - Adamantite Ring
(20246, 4050, 1, 1, 1, 7205.005656), -- Adamantite Ring Wire
(20246, 1869, 1, 1, 2, 58144.104144), -- Iron Ore
(20246, 1864, 1, 1, 2, 116288.208288), -- Stem
(20246, 1880, 1, 1, 2, 5814.44752), -- Steel
(20246, 5550, 1, 1, 2, 775.321512), -- Durable Metal Plate
(20246, 4043, 1, 1, 2, 1938.211016), -- Asofe
(20246, 4969, 1, 1, 2, 66.975608), -- Recipe: Hell Knife (60%)
(20246, 4176, 1, 1, 2, 723.188144), -- Recipe: Sealed Doom Boots (100%)
(20246, 4157, 1, 1, 2, 289.238152), -- Recipe: Blue Wolf Gaiters (100%)
(20246, 8727, 1, 1, 2, 1162.889504), -- Life Stone - Level 58
(20246, 8737, 1, 1, 2, 290.722376), -- Mid-Grade Life Stone - Level 58
(20246, 8747, 1, 1, 2, 29.127896), -- High-Grade Life Stone - Level 58
(20246, 8757, 1, 1, 2, 5.56584), -- Top-Grade Life Stone - Level 58
-- Turak Bugbear
(20248, 2250, 1, 1, -1, 141016), -- Recipe: Bone Arrow
(20248, 955, 1, 1, -1, 2256), -- Scroll: Enchant Weapon (D-Grade)
(20248, 1865, 1, 1, -1, 564065), -- Varnish
(20248, 57, 239, 476, 0, 700000), -- Adena
(20248, 86, 1, 1, 1, 12.446356), -- Tomahawk
(20248, 179, 1, 1, 1, 12.446356), -- Mace of Prayer
(20248, 180, 1, 1, 1, 12.446356), -- Mace of Judgment
(20248, 2022, 1, 1, 1, 480.31698), -- Mace of Judgment Head
(20248, 181, 1, 1, 1, 12.446356), -- Mace of Miracle
(20248, 182, 1, 1, 1, 12.446356), -- Doom Hammer
(20248, 183, 1, 1, 1, 12.446356), -- Mystic Staff
(20248, 184, 1, 1, 1, 12.446356), -- Conjuror's Staff
(20248, 2023, 1, 1, 1, 382.11121), -- Conjuror's Staff Head
(20248, 185, 1, 1, 1, 12.447318), -- Staff of Mana
(20248, 1870, 1, 1, 2, 51373.471374), -- Coal
(20248, 1865, 1, 1, 2, 51373.471374), -- Varnish
(20248, 1874, 1, 1, 2, 3424.951548), -- Oriharukon Ore
(20248, 1829, 1, 1, 2, 20549.442006), -- Scroll of Escape: Clan Hall
(20248, 2274, 1, 1, 2, 366.978186), -- Recipe: Skull Breaker
(20248, 2192, 1, 1, 2, 6552.685512), -- Recipe: Kite Shield
-- Turak Bugbear Warrior
(20249, 1873, 1, 1, -1, 480668), -- Silver Nugget
(20249, 1865, 1, 3, -1, 600835), -- Varnish
(20249, 57, 508, 1015, 0, 700000), -- Adena
(20249, 260, 1, 1, 1, 172), -- Triple-Edged Jamadhr
(20249, 1868, 1, 1, 2, 182548.216557), -- Thread
(20249, 1873, 1, 1, 2, 36509.73261), -- Silver Nugget
(20249, 5549, 1, 1, 2, 9127.209906), -- Metallic Thread
(20249, 1889, 1, 1, 2, 6084.806604), -- Compound Braid
(20249, 2186, 1, 1, 2, 3052.672641), -- Recipe: Brigandine Tunic
(20249, 6667, 1, 1, 2, 57046.178145), -- Deluxe Chest Key - Grade 3
(20249, 1341, 20, 60, 2, 152124.183537), -- Bone Arrow
-- Glass Jaguar
(20250, 1884, 1, 1, -1, 281232), -- Cord
(20250, 2259, 1, 1, -1, 7096), -- Recipe: Spinebone Sword
(20250, 1899, 1, 1, -1, 71407), -- Necklace of Devotion Chain
(20250, 57, 197, 380, 0, 700000), -- Adena
(20250, 847, 1, 1, 1, 619.503616), -- Red Crescent Earring
(20250, 910, 1, 1, 1, 464.627712), -- Necklace of Devotion
(20250, 1899, 1, 1, 1, 10018.601216), -- Necklace of Devotion Chain
(20250, 890, 1, 1, 1, 929.267456), -- Ring of Devotion
(20250, 1870, 1, 1, 2, 51296.9085), -- Coal
(20250, 1865, 1, 1, 2, 51296.9085), -- Varnish
(20250, 1874, 1, 1, 2, 3419.7939), -- Oriharukon Ore
(20250, 2182, 1, 1, 2, 6158.124392), -- Recipe: Scale Gaiters
(20250, 5437, 1, 1, 2, 1254.264708), -- Recipe: Heavy Sword(100%)
-- Delu Lizardman
(20251, 1880, 1, 1, -1, 48038), -- Steel
(20251, 2017, 1, 1, -1, 6384), -- Saber Blade
(20251, 2152, 1, 1, -1, 84573), -- Recipe: Enchanted Necklace
(20251, 57, 206, 403, 0, 700000), -- Adena
(20251, 123, 1, 1, 1, 42.796702), -- Saber
(20251, 2017, 1, 1, 1, 895.723943), -- Saber Blade
(20251, 5285, 1, 1, 1, 42.796702), -- Heavy Sword
(20251, 5531, 1, 1, 1, 1131.682653), -- Heavy Sword Edge
(20251, 1871, 1, 1, 2, 67400.525075), -- Charcoal
(20251, 1866, 1, 1, 2, 44933.642791), -- Suede
(20251, 1877, 1, 1, 2, 2696.021003), -- Adamantite Nugget
(20251, 2181, 1, 1, 2, 6746.811131), -- Recipe: White Tunic
-- Delu Lizardman Scout
(20252, 1865, 1, 1, -1, 502762), -- Varnish
(20252, 1900, 1, 1, -1, 55007), -- Enchanted Necklace Chain
(20252, 1061, 1, 1, -1, 304704), -- Greater Healing Potion
(20252, 57, 213, 422, 0, 700000), -- Adena
(20252, 1123, 1, 1, 1, 1073), -- Blue Buckskin Boots
(20252, 605, 1, 1, 1, 1073), -- Leather Gauntlets
(20252, 1872, 1, 1, 2, 45790.07202), -- Animal Bone
(20252, 1867, 1, 1, 2, 45790.07202), -- Animal Skin
(20252, 1881, 1, 1, 2, 4578.95067), -- Coarse Bone Powder
(20252, 1875, 1, 1, 2, 2289.546), -- Stone of Purity
(20252, 2185, 1, 1, 2, 6760.37922), -- Recipe: Iron Boots
(20252, 2274, 1, 1, 2, 245.34888), -- Recipe: Skull Breaker
(20252, 2187, 1, 1, 2, 1533.14784), -- Recipe: Manticore Skin Shirt
(20252, 6666, 1, 1, 2, 34342.48335), -- Deluxe Chest Key - Grade 2
-- Delu Lizardman Warrior
(20253, 2265, 1, 1, -1, 5545), -- Recipe: Spiked Club
(20253, 2153, 1, 1, -1, 83396), -- Recipe: Tiger's Eye Earring
(20253, 1900, 1, 1, -1, 58669), -- Enchanted Necklace Chain
(20253, 57, 226, 452, 0, 700000), -- Adena
(20253, 348, 1, 1, 1, 142.941546), -- Scale Mail
(20253, 1935, 1, 1, 1, 4092.708972), -- Scale Mail Fragment
(20253, 377, 1, 1, 1, 228.575226), -- Scale Gaiters
(20253, 1937, 1, 1, 1, 6293.774256), -- Scale Gaiters Fragment
(20253, 1873, 1, 1, 2, 23442.52872), -- Silver Nugget
(20253, 1868, 1, 1, 2, 117212.955834), -- Thread
(20253, 1876, 1, 1, 2, 11721.26436), -- Mithril Ore
(20253, 2266, 1, 1, 2, 606.046194), -- Recipe: Shilen Knife
(20253, 2971, 1, 1, 2, 3134.204892), -- Recipe: Mithril Scale Gaiters
-- Skeleton Axeman
(20254, 2181, 1, 1, -1, 49538), -- Recipe: White Tunic
(20254, 2262, 1, 1, -1, 7685), -- Recipe: Elven Bow
(20254, 1899, 1, 1, -1, 77326), -- Necklace of Devotion Chain
(20254, 57, 212, 415, 0, 700000), -- Adena
(20254, 291, 1, 1, 1, 88.181775), -- Trident
(20254, 2019, 1, 1, 1, 2986.818225), -- Trident Edge
(20254, 1876, 1, 1, 2, 9258.167835), -- Mithril Ore
(20254, 1880, 1, 1, 2, 4629.102795), -- Steel
(20254, 1877, 1, 1, 2, 1851.618465), -- Adamantite Nugget
(20254, 1881, 1, 1, 2, 6172.11189), -- Coarse Bone Powder
(20254, 1882, 1, 1, 2, 10286.87832), -- Leather
(20254, 2182, 1, 1, 2, 5557.120695), -- Recipe: Scale Gaiters
-- Monster Eye Searcher
(20265, 1866, 1, 1, -1, 449035), -- Suede
(20265, 2015, 1, 1, -1, 8214), -- Sword Breaker Edge
(20265, 1872, 1, 1, -1, 898071), -- Animal Bone
(20265, 57, 306, 549, 0, 700000), -- Adena
(20265, 219, 1, 1, 1, 211.65993), -- Sword Breaker
(20265, 2015, 1, 1, 1, 2426.34007), -- Sword Breaker Edge
(20265, 1867, 1, 1, 2, 106110.762776), -- Animal Skin
(20265, 1872, 1, 1, 2, 106110.762776), -- Animal Bone
(20265, 1882, 1, 1, 2, 17685.048784); -- Leather

INSERT INTO `droplist` VALUES
(20265, 5158, 1, 1, 2, 3183.327584), -- Recipe: Spiritshot (D) Compressed Package (100%)
(20265, 8294, 1, 1, 2, 1946.09808), -- Recipe: Steel Sword (100%)
-- Monster Eye Gazer
(20266, 1866, 1, 1, -1, 279792), -- Suede
(20266, 2180, 1, 1, -1, 31555), -- Recipe: Scale Mail
(20266, 1878, 1, 1, -1, 167875), -- Braided Hemp
(20266, 57, 185, 346, 0, 700000), -- Adena
(20266, 432, 1, 1, 1, 488.596549), -- Cursed Tunic
(20266, 465, 1, 1, 1, 782.403451), -- Cursed Stockings
(20266, 1874, 1, 1, 2, 3925.7295), -- Oriharukon Ore
(20266, 1878, 1, 1, 2, 23554.4385), -- Braided Hemp
(20266, 5220, 1, 1, 2, 2355.45), -- Metal Hardener
(20266, 2260, 1, 1, 2, 914.382), -- Recipe: Mace of Judgment
-- Breka Orc
(20267, 2203, 1, 1, -1, 122890), -- Recipe: Reinforced Mithril Boots
(20267, 1882, 1, 1, -1, 125348), -- Leather
(20267, 1061, 1, 1, -1, 341857), -- Greater Healing Potion
(20267, 57, 239, 476, 0, 700000), -- Adena
(20267, 69, 1, 1, 1, 24.885154), -- Bastard Sword
(20267, 125, 1, 1, 1, 24.885154), -- Spinebone Sword
(20267, 2021, 1, 1, 1, 778.457628), -- Spinebone Sword Blade
(20267, 126, 1, 1, 1, 24.885154), -- Artisan's Sword
(20267, 128, 1, 1, 1, 24.88691), -- Knight's Sword
(20267, 1873, 1, 1, 2, 24659.133856), -- Silver Nugget
(20267, 1868, 1, 1, 2, 123295.498968), -- Thread
(20267, 1876, 1, 1, 2, 12329.566928), -- Mithril Ore
(20267, 2153, 1, 1, 2, 9587.543728), -- Recipe: Tiger's Eye Earring
(20267, 2274, 1, 1, 2, 440.25652), -- Recipe: Skull Breaker
-- Breka Orc Archer
(20268, 1878, 1, 1, -1, 308026), -- Braided Hemp
(20268, 1900, 1, 1, -1, 84252), -- Enchanted Necklace Chain
(20268, 57, 324, 651, 0, 700000), -- Adena
(20268, 275, 1, 1, 1, 56.606465), -- Long Bow
(20268, 276, 1, 1, 1, 56.606465), -- Elven Bow
(20268, 2024, 1, 1, 1, 1997.78707), -- Elven Bow Shaft
(20268, 1872, 1, 1, 2, 112216.0639), -- Animal Bone
(20268, 1867, 1, 1, 2, 112216.0639), -- Animal Skin
(20268, 1881, 1, 1, 2, 11221.60639), -- Coarse Bone Powder
(20268, 1875, 1, 1, 2, 5610.92523), -- Stone of Purity
(20268, 956, 1, 1, 2, 2805.34058), -- Scroll: Enchant Armor (D-Grade)
-- Breka Orc Shaman
(20269, 1879, 1, 1, -1, 111342), -- Cokes
(20269, 2029, 1, 1, -1, 7969), -- Gastraphetes Shaft
(20269, 2154, 1, 1, -1, 71526), -- Recipe: Elven Earring
(20269, 57, 282, 563, 0, 700000), -- Adena
(20269, 157, 1, 1, 1, 31.85426), -- Spiked Club
(20269, 2027, 1, 1, 1, 1551.29148), -- Spiked Club Head
(20269, 186, 1, 1, 1, 31.85426), -- Staff of Magic
(20269, 1875, 1, 1, 2, 2959.9682), -- Stone of Purity
(20269, 1879, 1, 1, 2, 7399.873095), -- Cokes
(20269, 1885, 1, 1, 2, 3699.96025), -- High-Grade Suede
(20269, 5550, 1, 1, 2, 591.99364), -- Durable Metal Plate
(20269, 5549, 1, 1, 2, 4439.904895), -- Metallic Thread
(20269, 2275, 1, 1, 2, 317.13945), -- Recipe: Heavy Bone Club
(20269, 2286, 1, 1, 2, 246.648215), -- Recipe: Bonebreaker
(20269, 6667, 1, 1, 2, 27749.512255), -- Deluxe Chest Key - Grade 3
-- Breka Orc Overlord
(20270, 2972, 1, 1, -1, 50438), -- Recipe: Brigandine Gaiters
(20270, 2976, 1, 1, -1, 126263), -- Recipe: Manticore Skin Boots
(20270, 1901, 1, 1, -1, 130274), -- Tiger's Eye Earring Stone
(20270, 57, 398, 795, 0, 700000), -- Adena
(20270, 393, 1, 1, 1, 142.870754), -- Mithril Banded Mail
(20270, 1938, 1, 1, 1, 5618.601014), -- Mithril Banded Mail Material
(20270, 394, 1, 1, 1, 142.870754), -- Reinforced Leather Shirt
(20270, 415, 1, 1, 1, 228.357532), -- Mithril Banded Gaiters
(20270, 1939, 1, 1, 1, 7340.956116), -- Mithril Banded Gaiters Material
(20270, 416, 1, 1, 1, 228.34383), -- Reinforced Leather Gaiters
(20270, 1870, 1, 1, 2, 100296.588195), -- Coal
(20270, 1865, 1, 1, 2, 100296.588195), -- Varnish
(20270, 1874, 1, 1, 2, 6686.439213), -- Oriharukon Ore
(20270, 2980, 1, 1, 2, 13426.404072), -- Recipe: Brigandine Gauntlets
(20270, 1341, 20, 60, 2, 167160.980325), -- Bone Arrow
-- Breka Orc Warrior
(20271, 1882, 1, 1, -1, 170847), -- Leather
(20271, 2271, 1, 1, -1, 5492), -- Recipe: Winged Spear
(20271, 2155, 1, 1, -1, 123405), -- Recipe: Elven Ring
(20271, 57, 325, 650, 0, 700000), -- Adena
(20271, 849, 1, 1, 1, 413.73337), -- Tiger's Eye Earring
(20271, 1901, 1, 1, 1, 14114.792548), -- Tiger's Eye Earring Stone
(20271, 912, 1, 1, 1, 310.133854), -- Near Forest Necklace
(20271, 880, 1, 1, 1, 619.340228), -- Black Pearl Ring
(20271, 1874, 1, 1, 2, 3406.418838), -- Oriharukon Ore
(20271, 1878, 1, 1, 2, 20438.513028), -- Braided Hemp
(20271, 1884, 1, 1, 2, 31443.890685), -- Cord
(20271, 1889, 1, 1, 2, 3406.418838), -- Compound Braid
(20271, 5220, 1, 1, 2, 2043.838569), -- Metal Hardener
(20271, 2187, 1, 1, 2, 2281.069263), -- Recipe: Manticore Skin Shirt
(20271, 2293, 1, 1, 2, 283.900071), -- Recipe: Glaive
(20271, 2269, 1, 1, 2, 364.950708), -- Recipe: Morning Star
-- Enku Orc Champion
(20291, 1879, 1, 1, -1, 69130), -- Cokes
(20291, 2255, 1, 1, -1, 10141), -- Recipe: Saber
(20291, 1898, 1, 1, -1, 42607), -- Blue Diamond Necklace Gem
(20291, 57, 189, 337, 0, 700000), -- Adena
(20291, 27, 1, 1, 1, 431.406745), -- Hard Leather Shirt
(20291, 1927, 1, 1, 1, 4887.03149), -- Hard Leather Shirt Pattern
(20291, 33, 1, 1, 1, 692.18776), -- Hard Leather Gaiters
(20291, 1929, 1, 1, 1, 7904.374005), -- Hard Leather Gaiters Material
(20291, 1864, 1, 1, 2, 98016.33842), -- Stem
(20291, 1869, 1, 1, 2, 49008.16921), -- Iron Ore
(20291, 1878, 1, 1, 2, 19603.267684), -- Braided Hemp
(20291, 2257, 1, 1, 2, 1198.167152), -- Recipe: Trident
(20291, 734, 1, 1, 2, 8168.057534), -- Haste Potion
-- Enku Orc Shaman
(20292, 2150, 1, 1, -1, 144749), -- Recipe: Blue Diamond Necklace
(20292, 2139, 1, 1, -1, 61663), -- Recipe: Steel Mold
(20292, 5220, 1, 1, -1, 12333), -- Metal Hardener
(20292, 57, 142, 248, 0, 700000), -- Adena
(20292, 845, 1, 1, 1, 1331.443806), -- Cat's Eye Earring
(20292, 908, 1, 1, 1, 998.590439), -- Necklace of Wisdom
(20292, 1897, 1, 1, 1, 10841.800046), -- Necklace of Wisdom Chain
(20292, 877, 1, 1, 1, 1997.165709), -- Ring of Wisdom
(20292, 1871, 1, 1, 2, 45536.009457), -- Charcoal
(20292, 1866, 1, 1, 2, 30357.366165), -- Suede
(20292, 2252, 1, 1, 2, 1866.254031), -- Recipe: Iron Hammer
(20292, 5158, 1, 1, 2, 1821.370347), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Garum Werewolf
(20307, 2137, 1, 1, -1, 43777), -- Recipe: Steel
(20307, 1867, 1, 1, -1, 198456), -- Animal Skin
(20307, 1060, 1, 1, -1, 330759), -- Lesser Healing Potion
(20307, 57, 80, 108, 0, 700000), -- Adena
(20307, 152, 1, 1, 1, 709.063155), -- Heavy Chisel
(20307, 5, 1, 1, 1, 457.936155), -- Mace
(20307, 8, 1, 1, 1, 457.936155), -- Willow Staff
(20307, 2006, 1, 1, 1, 1570.064535), -- Willow Staff Head
(20307, 1864, 1, 1, 2, 29310.4816), -- Stem
(20307, 1865, 1, 1, 2, 14655.2408), -- Varnish
(20307, 1866, 1, 1, 2, 9770.200675), -- Suede
(20307, 1873, 1, 1, 2, 5862.04815), -- Silver Nugget
(20307, 1868, 1, 1, 2, 29310.4816), -- Thread
(20307, 1802, 1, 1, 2, 31516.547175), -- Recipe: Necklace of Anguish
-- Hook Spider
(20308, 1868, 1, 1, -1, 475131), -- Thread
(20308, 1924, 1, 1, -1, 76634), -- Leather Helmet Design
(20308, 1897, 1, 1, -1, 56563), -- Necklace of Wisdom Chain
(20308, 57, 118, 183, 0, 700000), -- Adena
(20308, 38, 1, 1, 1, 1795.866945), -- Low Boots
(20308, 50, 1, 1, 1, 1795.866945), -- Leather Gloves
(20308, 1925, 1, 1, 1, 30677.26611), -- Leather Gloves Lining
(20308, 1868, 1, 1, 2, 70173.507304), -- Thread
(20308, 1873, 1, 1, 2, 14034.682935), -- Silver Nugget
(20308, 2143, 1, 1, 2, 7017.387782), -- Recipe: Synthetic Cokes
(20308, 5158, 1, 1, 2, 1403.421979), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Brown Bear
(20310, 735, 1, 1, -1, 19993), -- Alacrity Potion
(20310, 1872, 1, 1, -1, 319890), -- Animal Bone
(20310, 1800, 1, 1, -1, 75446), -- Recipe: Piece Bone Breastplate
(20310, 57, 119, 185, 0, 700000), -- Adena
(20310, 38, 1, 1, 1, 1813.63224), -- Low Boots
(20310, 50, 1, 1, 1, 1813.63224), -- Leather Gloves
(20310, 1925, 1, 1, 1, 30980.73552), -- Leather Gloves Lining
(20310, 1865, 1, 1, 2, 47245.4073), -- Varnish
(20310, 1870, 1, 1, 2, 47245.4073), -- Coal
(20310, 2144, 1, 1, 2, 9449.1854), -- Recipe: Compound Braid
-- Rakeclaw Imp
(20311, 1060, 1, 1, -1, 172757), -- Lesser Healing Potion
(20311, 2005, 1, 1, -1, 5553), -- Broadsword Blade
(20311, 57, 41, 58, 0, 700000), -- Adena
(20311, 1122, 1, 1, 1, 6514.326819), -- Cotton Shoes
(20311, 1129, 1, 1, 1, 6514.326819), -- Crude Leather Shoes
(20311, 1119, 1, 1, 1, 6514.346362), -- Short Leather Gloves
(20311, 1873, 1, 1, 2, 4592.664723), -- Silver Nugget
(20311, 1868, 1, 1, 2, 22963.268422), -- Thread
(20311, 1789, 1, 1, 2, 2122.281236), -- Recipe: Cedar Staff
(20311, 1060, 1, 1, 2, 25514.785619), -- Lesser Healing Potion
-- Rakeclaw Imp Hunter
(20312, 1866, 1, 1, -1, 64878), -- Suede
(20312, 2136, 1, 1, -1, 28622), -- Recipe: Cokes
(20312, 1666, 1, 1, -1, 32439), -- Recipe: Wooden Arrow
(20312, 57, 51, 72, 0, 700000), -- Adena
(20312, 19, 1, 1, 1, 11732.93531), -- Small Shield
(20312, 42, 1, 1, 1, 8213.06469), -- Leather Cap
(20312, 1869, 1, 1, 2, 14372.985256), -- Iron Ore
(20312, 1864, 1, 1, 2, 28745.970512), -- Stem
(20312, 1802, 1, 1, 2, 30909.610376), -- Recipe: Necklace of Anguish
(20312, 734, 1, 1, 2, 2395.433856), -- Haste Potion
-- Rakeclaw Imp Chieftain
(20313, 1814, 1, 1, -1, 95767), -- Recipe: Leather
(20313, 22, 1, 1, -1, 19461), -- Leather Shirt
(20313, 2006, 1, 1, -1, 12997), -- Willow Staff Head
(20313, 57, 98, 132, 0, 700000), -- Adena
(20313, 428, 1, 1, 1, 2874.194224), -- Feriotic Tunic
(20313, 1100, 1, 1, 1, 2874.194224), -- Cotton Tunic
(20313, 463, 1, 1, 1, 4593.805776), -- Feriotic Stockings
(20313, 1103, 1, 1, 1, 4593.805776), -- Cotton Stockings
(20313, 1864, 1, 1, 2, 53747.0829), -- Stem
(20313, 1869, 1, 1, 2, 26873.54145), -- Iron Ore
(20313, 1790, 1, 1, 2, 4967.432085), -- Recipe: Dirk
(20313, 6037, 1, 1, 2, 53746.943565), -- Waking Scroll
-- Great White Shark
(20314, 1874, 1, 1, -1, 57718), -- Oriharukon Ore
(20314, 4472, 1, 1, -1, 4947), -- Dye of CON (Con+1 Dex-1)
(20314, 1869, 1, 1, -1, 865765), -- Iron Ore
(20314, 57, 349, 705, 0, 700000), -- Adena
(20314, 70, 1, 1, 1, 15.669267), -- Claymore
(20314, 2047, 1, 1, 1, 955.292883), -- Claymore Blade
(20314, 2499, 1, 1, 1, 15.669267), -- Elven Long Sword
(20314, 2967, 1, 1, 1, 942.368583), -- Elven Long Sword Blade
(20314, 1864, 1, 1, 2, 124213.539318), -- Stem
(20314, 1869, 1, 1, 2, 62106.769659), -- Iron Ore
(20314, 1878, 1, 1, 2, 24842.605348), -- Braided Hemp
(20314, 1884, 1, 1, 2, 38219.609703), -- Cord
(20314, 2205, 1, 1, 2, 1965.480341), -- Recipe: Chain Gaiters
(20314, 2299, 1, 1, 2, 271.153762), -- Recipe: Big Hammer
(20314, 2209, 1, 1, 2, 4669.841869), -- Recipe: Eldarake
-- Darkwing Bat
(20316, 1803, 1, 1, -1, 169394), -- Recipe: Necklace of Wisdom
(20316, 1864, 1, 1, -1, 403157), -- Stem
(20316, 1792, 1, 1, -1, 14822), -- Recipe: Short Spear
(20316, 57, 109, 147, 0, 700000), -- Adena
(20316, 23, 1, 1, 1, 1297.277532), -- Wooden Breastplate
(20316, 30, 1, 1, 1, 2078.361234), -- Hard Leather Pants
(20316, 2386, 1, 1, 1, 2078.361234), -- Wooden Gaiters
(20316, 1865, 1, 1, 2, 29771.467966), -- Varnish
(20316, 1870, 1, 1, 2, 29771.467966), -- Coal
(20316, 1794, 1, 1, 2, 2189.097162), -- Recipe: Forest Bow
(20316, 734, 1, 1, 2, 4961.966906), -- Haste Potion
-- Black Wolf
(20317, 1867, 1, 1, -1, 51475), -- Animal Skin
(20317, 1786, 1, 1, -1, 30885), -- Recipe: Broad Sword
(20317, 57, 19, 29, 0, 700000), -- Adena
(20317, 1, 1, 1, 1, 13530), -- Short Sword
(20317, 1869, 1, 1, 2, 6652.105863), -- Iron Ore
(20317, 1870, 1, 1, 2, 6652.105863), -- Coal
(20317, 1871, 1, 1, 2, 6652.105863), -- Charcoal
(20317, 1872, 1, 1, 2, 8869.503162), -- Animal Bone
(20317, 1867, 1, 1, 2, 8869.503162), -- Animal Skin
(20317, 1787, 1, 1, 2, 5321.676087), -- Recipe: Willow Staff
-- Black Timber Wolf
(20318, 1866, 1, 1, -1, 51314), -- Suede
(20318, 1060, 1, 1, -1, 171046), -- Lesser Healing Potion
(20318, 2005, 1, 1, -1, 5498), -- Broadsword Blade
(20318, 57, 41, 58, 0, 700000), -- Adena
(20318, 3, 1, 1, 1, 473.740988), -- Broadsword
(20318, 2005, 1, 1, 1, 1624.259012), -- Broadsword Blade
(20318, 1866, 1, 1, 2, 15157.2), -- Suede
(20318, 1871, 1, 1, 2, 22735.8), -- Charcoal
-- Goblin Grave Robber
(20319, 1865, 1, 1, -1, 56617), -- Varnish
(20319, 1787, 1, 1, -1, 45293), -- Recipe: Willow Staff
(20319, 57, 30, 42, 0, 700000), -- Adena
(20319, 112, 1, 1, 1, 102689.2683), -- Apprentice's Earring
(20319, 118, 1, 1, 1, 76513.51329), -- Necklace of Magic
(20319, 116, 1, 1, 1, 156087.21841), -- Magic Ring
(20319, 1864, 1, 1, 2, 19511.058856), -- Stem
(20319, 1865, 1, 1, 2, 9755.529428), -- Varnish
(20319, 1866, 1, 1, 2, 6503.663956), -- Suede
(20319, 1873, 1, 1, 2, 3902.184976), -- Silver Nugget
(20319, 1868, 1, 1, 2, 19511.058856), -- Thread
(20319, 1787, 1, 1, 2, 7804.503928), -- Recipe: Willow Staff
-- Goblin Tomb Raider Leader
(20320, 1831, 1, 1, -1, 557587), -- Antidote
(20320, 2010, 1, 1, -1, 8136), -- Brandish Blade
(20320, 1867, 1, 1, -1, 278794), -- Animal Skin
(20320, 57, 112, 154, 0, 700000), -- Adena
(20320, 216, 1, 1, 1, 296.92293), -- Dirk
(20320, 2009, 1, 1, 1, 2190.07707), -- Dirk Blade
(20320, 1867, 1, 1, 2, 54901.037487), -- Animal Skin
(20320, 1872, 1, 1, 2, 54901.037487), -- Animal Bone
(20320, 1799, 1, 1, 2, 61000.925026), -- Recipe: Leather Gloves
-- Goblin Thief
(20321, 1870, 1, 1, -1, 178389), -- Coal
(20321, 2005, 1, 1, -1, 12742), -- Broadsword Blade
(20321, 1060, 1, 1, -1, 396420), -- Lesser Healing Potion
(20321, 57, 96, 130, 0, 700000), -- Adena
(20321, 152, 1, 1, 1, 849.98807), -- Heavy Chisel
(20321, 5, 1, 1, 1, 548.95007), -- Mace
(20321, 8, 1, 1, 1, 548.95007), -- Willow Staff
(20321, 2006, 1, 1, 1, 1882.11179), -- Willow Staff Head
(20321, 1864, 1, 1, 2, 30110.403165), -- Stem
(20321, 1865, 1, 1, 2, 15055.268715), -- Varnish
(20321, 1866, 1, 1, 2, 10036.84581), -- Suede
(20321, 1873, 1, 1, 2, 6022.05378), -- Silver Nugget
(20321, 1868, 1, 1, 2, 30110.403165), -- Thread
(20321, 1791, 1, 1, 2, 2782.910655), -- Recipe: Brandish
(20321, 1833, 1, 1, 2, 40147.11471), -- Bandage
-- Goblin Brigand
(20322, 1796, 1, 1, -1, 156757), -- Recipe: Leather Tunic
(20322, 1870, 1, 1, -1, 124622), -- Coal
(20322, 2005, 1, 1, -1, 8902), -- Broadsword Blade
(20322, 57, 67, 91, 0, 700000), -- Adena
(20322, 12, 1, 1, 1, 767), -- Knife
(20322, 215, 1, 1, 1, 767), -- Doom Dagger
(20322, 1872, 1, 1, 2, 24540.844224), -- Animal Bone
(20322, 1867, 1, 1, 2, 24540.844224), -- Animal Skin
(20322, 2137, 1, 1, 2, 5413.438758), -- Recipe: Steel
(20322, 17, 10, 30, 2, 92027.872794), -- Wooden Arrow
-- Goblin Brigand Leader
(20323, 1869, 1, 1, -1, 227339), -- Iron Ore
(20323, 1865, 1, 1, -1, 227339), -- Varnish
(20323, 1792, 1, 1, -1, 16716), -- Recipe: Short Spear
(20323, 57, 116, 172, 0, 700000), -- Adena
(20323, 216, 1, 1, 1, 322.83056), -- Dirk
(20323, 2009, 1, 1, 1, 2381.16944), -- Dirk Blade
(20323, 1871, 1, 1, 2, 33576.357012), -- Charcoal
(20323, 1866, 1, 1, 2, 22384.238008), -- Suede
(20323, 1792, 1, 1, 2, 2468.816538), -- Recipe: Short Spear
(20323, 6037, 1, 1, 2, 67152.588442), -- Waking Scroll
-- Goblin Brigand Lieutenant
(20324, 1791, 1, 1, -1, 33633), -- Recipe: Brandish
(20324, 1871, 1, 1, -1, 181957), -- Charcoal
(20324, 2006, 1, 1, -1, 12997), -- Willow Staff Head
(20324, 57, 98, 132, 0, 700000), -- Adena
(20324, 152, 1, 1, 1, 866.854674), -- Heavy Chisel
(20324, 5, 1, 1, 1, 559.843074), -- Mace
(20324, 8, 1, 1, 1, 559.843074), -- Willow Staff
(20324, 2006, 1, 1, 1, 1919.459178), -- Willow Staff Head
(20324, 1869, 1, 1, 2, 17915.77177), -- Iron Ore
(20324, 1870, 1, 1, 2, 17915.77177), -- Coal
(20324, 1871, 1, 1, 2, 17915.77177), -- Charcoal
(20324, 1872, 1, 1, 2, 23887.75207), -- Animal Bone
(20324, 1867, 1, 1, 2, 23887.75207), -- Animal Skin
(20324, 1795, 1, 1, 2, 67607.18055), -- Recipe: Leather Shoes
-- Goblin Raider
(20325, 1787, 1, 1, -1, 45293), -- Recipe: Willow Staff
(20325, 118, 1, 1, -1, 222026), -- Necklace of Magic
(20325, 1786, 1, 1, -1, 45293), -- Recipe: Broad Sword
(20325, 57, 30, 42, 0, 700000), -- Adena
(20325, 112, 1, 1, 1, 102689.2683), -- Apprentice's Earring
(20325, 118, 1, 1, 1, 76513.51329), -- Necklace of Magic
(20325, 116, 1, 1, 1, 156087.21841), -- Magic Ring
(20325, 1865, 1, 1, 2, 11706.54543), -- Varnish
(20325, 1870, 1, 1, 2, 11706.54543), -- Coal
(20325, 1788, 1, 1, 2, 9365.236344), -- Recipe: Bow
(20325, 6037, 1, 1, 2, 23413.09086), -- Waking Scroll
(20325, 1060, 1, 1, 2, 26014.581936), -- Lesser Healing Potion
-- Goblin Scout
(20326, 2135, 1, 1, -1, 36653), -- Recipe: Braided Hemp
(20326, 2006, 1, 1, -1, 8902), -- Willow Staff Head
(20326, 2007, 1, 1, -1, 8902), -- Bow Shaft
(20326, 57, 67, 91, 0, 700000), -- Adena
(20326, 22, 1, 1, 1, 3937.19964), -- Leather Shirt
(20326, 29, 1, 1, 1, 6292.80036), -- Leather Pants
(20326, 1864, 1, 1, 2, 24541.02735), -- Stem
(20326, 1865, 1, 1, 2, 12270.47465), -- Varnish
(20326, 1866, 1, 1, 2, 8180.34245), -- Suede
(20326, 1873, 1, 1, 2, 4908.17425), -- Silver Nugget
(20326, 1868, 1, 1, 2, 24541.02735), -- Thread
(20326, 2138, 1, 1, 2, 3608.95395), -- Recipe: Coarse Bone Powder (100%)
-- Goblin Snooper
(20327, 1870, 1, 1, -1, 56617), -- Coal
(20327, 1865, 1, 1, -1, 56617), -- Varnish
(20327, 1872, 1, 1, -1, 75489), -- Animal Bone
(20327, 57, 30, 42, 0, 700000), -- Adena
(20327, 112, 1, 1, 1, 102689.2683), -- Apprentice's Earring
(20327, 118, 1, 1, 1, 76513.51329), -- Necklace of Magic
(20327, 116, 1, 1, 1, 156087.21841), -- Magic Ring
(20327, 1867, 1, 1, 2, 26014.58937), -- Animal Skin
(20327, 1872, 1, 1, 2, 26014.58937), -- Animal Bone
(20327, 1786, 1, 1, 2, 15608.82126), -- Recipe: Broad Sword
-- Goblin Lookout
(20328, 1865, 1, 1, -1, 124622), -- Varnish
(20328, 2137, 1, 1, -1, 36653), -- Recipe: Steel
(20328, 1869, 1, 1, -1, 124622), -- Iron Ore
(20328, 57, 67, 91, 0, 700000), -- Adena
(20328, 12, 1, 1, 1, 767), -- Knife
(20328, 215, 1, 1, 1, 767), -- Doom Dagger
(20328, 1869, 1, 1, 2, 10517.505694), -- Iron Ore
(20328, 1870, 1, 1, 2, 10517.505694), -- Coal
(20328, 1871, 1, 1, 2, 10517.505694), -- Charcoal
(20328, 1872, 1, 1, 2, 14023.283274), -- Animal Bone
(20328, 1867, 1, 1, 2, 14023.283274), -- Animal Skin
(20328, 1666, 1, 1, 2, 3505.864057), -- Recipe: Wooden Arrow
(20328, 1060, 1, 1, 2, 23372.052313), -- Lesser Healing Potion
-- Ghost Guardian
(20329, 1869, 1, 1, -1, 287587), -- Iron Ore
(20329, 1880, 1, 1, -1, 28759), -- Steel
(20329, 1898, 1, 1, -1, 29542), -- Blue Diamond Necklace Gem
(20329, 57, 131, 234, 0, 700000), -- Adena
(20329, 16, 1, 1, 1, 181), -- Great Spear
(20329, 1869, 1, 1, 2, 24271.177086), -- Iron Ore
(20329, 1870, 1, 1, 2, 24271.177086), -- Coal
(20329, 1871, 1, 1, 2, 24271.177086), -- Charcoal
(20329, 1872, 1, 1, 2, 32361.569448), -- Animal Bone
(20329, 1867, 1, 1, 2, 32361.569448), -- Animal Skin
(20329, 2258, 1, 1, 2, 593.404866), -- Recipe: Temptation of Abyss
(20329, 5268, 1, 1, 2, 970.92498), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Mineshaft Bat
(20330, 1866, 1, 1, -1, 111988), -- Suede
(20330, 1896, 1, 1, -1, 71179), -- Necklace of Anguish Chain
(20330, 1792, 1, 1, -1, 12352), -- Recipe: Short Spear
(20330, 57, 91, 122, 0, 700000), -- Adena
(20330, 37, 1, 1, 1, 3243.102948), -- Leather Shoes
(20330, 1921, 1, 1, 1, 21341.766276), -- Leather Shoes Texture
(20330, 49, 1, 1, 1, 3243.130776), -- Gloves
(20330, 1864, 1, 1, 2, 66158.800747), -- Stem
(20330, 1869, 1, 1, 2, 33079.466208), -- Iron Ore
(20330, 1798, 1, 1, 2, 32430.733045), -- Recipe: Leather Helmet
-- Monster Eye Tracker
(20331, 1871, 1, 1, -1, 148657), -- Charcoal
(20331, 2007, 1, 1, -1, 10618), -- Bow Shaft
(20331, 2005, 1, 1, -1, 10618), -- Broadsword Blade
(20331, 57, 80, 108, 0, 700000), -- Adena
(20331, 113, 1, 1, 1, 9443.170561), -- Mystic's Earring
(20331, 906, 1, 1, 1, 7053.926935), -- Necklace of Knowledge
(20331, 875, 1, 1, 1, 13939.902504), -- Ring of Knowledge
(20331, 1865, 1, 1, 2, 21955.431057), -- Varnish
(20331, 1870, 1, 1, 2, 21955.431057), -- Coal
(20331, 1796, 1, 1, 2, 27616.861783), -- Recipe: Leather Tunic
(20331, 734, 1, 1, 2, 3659.276103), -- Haste Potion
-- Greystone Golem
(20333, 1792, 1, 1, -1, 17783), -- Recipe: Short Spear
(20333, 2008, 1, 1, -1, 9411), -- Cedar Staff Head
(20333, 1798, 1, 1, -1, 237113), -- Recipe: Leather Helmet
(20333, 57, 127, 180, 0, 700000), -- Adena
(20333, 2371, 1, 1, 1, 732.595676), -- Fist of Butcher
(20333, 255, 1, 1, 1, 343.404324), -- Fox Claw Gloves
(20333, 1868, 1, 1, 2, 71439.890148), -- Thread
(20333, 1873, 1, 1, 2, 14287.95369), -- Silver Nugget
(20333, 1803, 1, 1, 2, 30016.8117), -- Recipe: Necklace of Wisdom
(20333, 734, 1, 1, 2, 5953.344462), -- Haste Potion
-- Grizzly Bear
(20335, 1867, 1, 1, -1, 324856), -- Animal Skin
(20335, 734, 1, 1, -1, 40607), -- Haste Potion
(20335, 1897, 1, 1, -1, 58010), -- Necklace of Wisdom Chain
(20335, 57, 119, 191, 0, 700000), -- Adena
(20335, 2, 1, 1, 1, 68.520295), -- Long Sword
(20335, 120, 1, 1, 1, 68.520295), -- Sword of Reflection
(20335, 2012, 1, 1, 1, 749.439115), -- Sword of Reflection Blade
(20335, 121, 1, 1, 1, 68.520295), -- Sword of Watershadow
(20335, 1867, 1, 1, 2, 47978.755186), -- Animal Skin
(20335, 1872, 1, 1, 2, 47978.755186), -- Animal Bone
(20335, 2174, 1, 1, 2, 15645.238884), -- Recipe: Hard Leather Gaiters
(20335, 5158, 1, 1, 2, 1439.250744), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Green Dryad
(20336, 1802, 1, 1, -1, 268004), -- Recipe: Necklace of Anguish
(20336, 29, 1, 1, -1, 21303), -- Leather Pants
(20336, 1060, 1, 1, -1, 276937), -- Lesser Healing Potion
(20336, 57, 67, 91, 0, 700000), -- Adena
(20336, 428, 1, 1, 1, 1968.59982), -- Feriotic Tunic
(20336, 1100, 1, 1, 1, 1968.59982), -- Cotton Tunic
(20336, 463, 1, 1, 1, 3146.40018), -- Feriotic Stockings
(20336, 1103, 1, 1, 1, 3146.40018), -- Cotton Stockings
(20336, 1864, 1, 1, 2, 24540.973407), -- Stem
(20336, 1865, 1, 1, 2, 12270.448349), -- Varnish
(20336, 1866, 1, 1, 2, 8180.324469), -- Suede
(20336, 1873, 1, 1, 2, 4908.225365), -- Silver Nugget
(20336, 1868, 1, 1, 2, 24540.973407), -- Thread
(20336, 1789, 1, 1, 2, 2268.055003), -- Recipe: Cedar Staff
-- Nightmare Weaver
(20338, 3032, 1, 1, -1, 12654), -- Recipe: Spiritshot D
(20338, 1927, 1, 1, -1, 25237), -- Hard Leather Shirt Pattern
(20338, 1898, 1, 1, -1, 32496), -- Blue Diamond Necklace Gem
(20338, 57, 144, 257, 0, 700000), -- Adena
(20338, 16, 1, 1, 1, 199), -- Great Spear
(20338, 1868, 1, 1, 2, 93443.755485), -- Thread
(20338, 1873, 1, 1, 2, 18688.751097), -- Silver Nugget
(20338, 3032, 1, 1, 2, 1868.898969), -- Recipe: Spiritshot D
(20338, 1831, 1, 1, 2, 124591.594449), -- Antidote
-- Slave Skeleton
(20340, 1792, 1, 1, -1, 13068), -- Recipe: Short Spear
(20340, 57, 95, 131, 0, 700000), -- Adena
(20340, 2371, 1, 1, 1, 538.553141), -- Fist of Butcher
(20340, 255, 1, 1, 1, 252.446859), -- Fox Claw Gloves
(20340, 1870, 1, 1, 2, 34999.37811), -- Coal
(20340, 1865, 1, 1, 2, 34999.37811), -- Varnish
(20340, 1803, 1, 1, 2, 29411.24378), -- Recipe: Necklace of Wisdom
-- Undead Slave
(20341, 2141, 1, 1, -1, 48936), -- Recipe: Silver Mold
(20341, 2143, 1, 1, -1, 48936), -- Recipe: Synthetic Cokes
(20341, 1897, 1, 1, -1, 58257), -- Necklace of Wisdom Chain
(20341, 57, 115, 195, 0, 700000), -- Adena
(20341, 945, 1, 1, 1, 2737.6128), -- Skeleton Buckler
(20341, 102, 1, 1, 1, 1321.26592), -- Round Shield
(20341, 44, 1, 1, 1, 924.20224), -- Leather Helmet
(20341, 1924, 1, 1, 1, 11656.91904), -- Leather Helmet Design
(20341, 1866, 1, 1, 2, 32122.168108), -- Suede
(20341, 1871, 1, 1, 2, 48183.371641), -- Charcoal
(20341, 2175, 1, 1, 2, 39173.460251), -- Recipe: Boots
-- Werewolf Chieftain
(20342, 1870, 1, 1, -1, 213277), -- Coal
(20342, 429, 1, 1, -1, 6970), -- Leather Tunic
(20342, 1793, 1, 1, -1, 15682), -- Recipe: Sword of Reflection
(20342, 57, 114, 157, 0, 700000), -- Adena
(20342, 2371, 1, 1, 1, 646.127599), -- Fist of Butcher
(20342, 255, 1, 1, 1, 302.872401), -- Fox Claw Gloves
(20342, 1869, 1, 1, 2, 41999.100858), -- Iron Ore
(20342, 1864, 1, 1, 2, 83998.348713), -- Stem
(20342, 736, 1, 1, 2, 20999.550429), -- Scroll of Escape
-- Werewolf Hunter
(20343, 1060, 1, 1, -1, 404348), -- Lesser Healing Potion
(20343, 1795, 1, 1, -1, 686629), -- Recipe: Leather Shoes
(20343, 2005, 1, 1, -1, 12997), -- Broadsword Blade
(20343, 57, 98, 132, 0, 700000), -- Adena
(20343, 113, 1, 1, 1, 11558.475515), -- Mystic's Earring
(20343, 906, 1, 1, 1, 8634.032525), -- Necklace of Knowledge
(20343, 875, 1, 1, 1, 17062.49196), -- Ring of Knowledge
(20343, 1869, 1, 1, 2, 35831.395795), -- Iron Ore
(20343, 1864, 1, 1, 2, 71662.79159), -- Stem
(20343, 1797, 1, 1, 2, 72386.812615), -- Recipe: Leather Stockings
-- Dark Terror
(20345, 2174, 1, 1, -1, 96576), -- Recipe: Hard Leather Gaiters
(20345, 1925, 1, 1, -1, 145655), -- Leather Gloves Lining
(20345, 5220, 1, 1, -1, 8885), -- Metal Hardener
(20345, 57, 110, 171, 0, 700000), -- Adena
(20345, 24, 1, 1, 1, 420.5292), -- Bone Breastplate
(20345, 390, 1, 1, 1, 420.5292), -- Cotton Shirt
(20345, 31, 1, 1, 1, 671.4708), -- Bone Gaiters
(20345, 412, 1, 1, 1, 671.4708), -- Cotton Pants
(20345, 1866, 1, 1, 2, 17496.46539), -- Suede
(20345, 1871, 1, 1, 2, 26244.7596), -- Charcoal
(20345, 1800, 1, 1, 2, 8253.09846), -- Recipe: Piece Bone Breastplate
(20345, 5268, 1, 1, 2, 1049.81499), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20345, 1831, 1, 1, 2, 69985.86156), -- Antidote
-- Darkstone Golem
(20346, 1869, 1, 1, -1, 201546), -- Iron Ore
(20346, 1803, 1, 1, -1, 169366), -- Recipe: Necklace of Wisdom
(20346, 1831, 1, 1, -1, 537455), -- Antidote
(20346, 57, 106, 150, 0, 700000), -- Adena
(20346, 20, 1, 1, 1, 5563.90821), -- Buckler
(20346, 43, 1, 1, 1, 3891.09179), -- Wooden Helmet
(20346, 1866, 1, 1, 2, 26459.358156), -- Suede
(20346, 1871, 1, 1, 2, 39689.037234), -- Charcoal
(20346, 736, 1, 1, 2, 19844.60461), -- Scroll of Escape
-- Cave Spider
(20348, 1794, 1, 1, -1, 14192), -- Recipe: Forest Bow
(20348, 1831, 1, 1, -1, 514696), -- Antidote
(20348, 1896, 1, 1, -1, 81784), -- Necklace of Anguish Chain
(20348, 57, 97, 147, 0, 700000), -- Adena
(20348, 66, 1, 1, 1, 182.6943), -- Gladius
(20348, 1333, 1, 1, 1, 182.6943), -- Brandish
(20348, 2010, 1, 1, 1, 1478.6114), -- Brandish Blade
(20348, 1871, 1, 1, 2, 38008.369432), -- Charcoal
(20348, 1866, 1, 1, 2, 25338.95284), -- Suede
(20348, 1799, 1, 1, 2, 56308.677728), -- Recipe: Leather Gloves
-- Cave Bat
(20349, 2009, 1, 1, -1, 6357), -- Dirk Blade
(20349, 1794, 1, 1, -1, 13182), -- Recipe: Forest Bow
(20349, 1921, 1, 1, -1, 115664), -- Leather Shoes Texture
(20349, 57, 94, 133, 0, 700000), -- Adena
(20349, 23, 1, 1, 1, 1153.849158), -- Wooden Breastplate
(20349, 30, 1, 1, 1, 1848.575421), -- Hard Leather Pants
(20349, 2386, 1, 1, 1, 1848.575421), -- Wooden Gaiters
(20349, 1872, 1, 1, 2, 47072.526003), -- Animal Bone
(20349, 1867, 1, 1, 2, 47072.526003), -- Animal Skin
(20349, 1792, 1, 1, 2, 2595.947994), -- Recipe: Short Spear
-- Cave Fang Spider
(20350, 1866, 1, 1, -1, 134620), -- Suede
(20350, 2150, 1, 1, -1, 94803), -- Recipe: Blue Diamond Necklace
(20350, 1800, 1, 1, -1, 63500), -- Recipe: Piece Bone Breastplate
(20350, 57, 100, 156, 0, 700000), -- Adena
(20350, 845, 1, 1, 1, 872.03469), -- Cat's Eye Earring
(20350, 908, 1, 1, 1, 654.030985), -- Necklace of Wisdom
(20350, 1897, 1, 1, 1, 7100.88229), -- Necklace of Wisdom Chain
(20350, 877, 1, 1, 1, 1308.052035), -- Ring of Wisdom
(20350, 1873, 1, 1, 2, 11929.468554), -- Silver Nugget
(20350, 1868, 1, 1, 2, 59647.252221), -- Thread
(20350, 2150, 1, 1, 2, 14001.682419), -- Recipe: Blue Diamond Necklace
(20350, 734, 1, 1, 2, 4970.596806), -- Haste Potion
-- Dre Vanul Tracker
(20351, 2173, 1, 1, -1, 62245), -- Recipe: Hard Leather Shirt
(20351, 735, 1, 1, -1, 19140), -- Alacrity Potion
(20351, 1897, 1, 1, -1, 54686), -- Necklace of Wisdom Chain
(20351, 57, 106, 184, 0, 700000), -- Adena
(20351, 272, 1, 1, 1, 129.1923), -- Forest Bow
(20351, 2013, 1, 1, 1, 1463.8077), -- Forest Bow Shaft
(20351, 1864, 1, 1, 2, 67845.117483), -- Stem
(20351, 1869, 1, 1, 2, 33922.617105), -- Iron Ore
(20351, 1878, 1, 1, 2, 13569.046842), -- Braided Hemp
(20351, 2253, 1, 1, 2, 1390.21857), -- Recipe: Sword Breaker
-- Dre Vanul Slayer
(20352, 1878, 1, 1, -1, 135435), -- Braided Hemp
(20352, 26, 1, 1, -1, 1791), -- Bronze Breastplate
(20352, 57, 154, 276, 0, 700000), -- Adena
(20352, 68, 1, 1, 1, 106.5), -- Falchion
(20352, 5284, 1, 1, 1, 106.5), -- Zweihander
(20352, 1864, 1, 1, 2, 80010.969147), -- Stem
(20352, 1869, 1, 1, 2, 40005.414964), -- Iron Ore
(20352, 1878, 1, 1, 2, 16002.249517), -- Braided Hemp
(20352, 5163, 1, 1, 2, 1600.183186), -- Recipe: Blessed Spiritshot (D) Compressed Package (100%)
(20352, 5273, 1, 1, 2, 1600.183186), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Dre Vanul Beholder
(20353, 1878, 1, 1, -1, 116185), -- Braided Hemp
(20353, 2256, 1, 1, -1, 7102), -- Recipe: Assassin Knife
(20353, 1864, 1, 1, -1, 580926), -- Stem
(20353, 57, 132, 236, 0, 700000), -- Adena
(20353, 16, 1, 1, 1, 183), -- Great Spear
(20353, 1864, 1, 1, 2, 68638.548303), -- Stem
(20353, 1869, 1, 1, 2, 34319.214436), -- Iron Ore
(20353, 1878, 1, 1, 2, 13727.757433), -- Braided Hemp
(20353, 3953, 1, 1, 2, 1372.739914), -- Recipe: Blessed Spiritshot D
(20353, 5273, 1, 1, 2, 1372.739914), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Langk Lizardman Leader
(20356, 1899, 1, 1, -1, 66888), -- Necklace of Devotion Chain
(20356, 1868, 1, 1, -1, 856162), -- Thread
(20356, 1873, 1, 1, -1, 171232), -- Silver Nugget
(20356, 57, 188, 353, 0, 700000), -- Adena
(20356, 220, 1, 1, 1, 153), -- Crafted Dagger
(20356, 1868, 1, 1, 2, 120126.36384), -- Thread
(20356, 1873, 1, 1, 2, 24025.272768), -- Silver Nugget
(20356, 5549, 1, 1, 2, 6006.318192), -- Metallic Thread
(20356, 2178, 1, 1, 2, 9610.0452), -- Recipe: Dark Stockings
-- Langk Lizardman Lieutenant
(20357, 1898, 1, 1, -1, 37198), -- Blue Diamond Necklace Gem
(20357, 1804, 1, 1, -1, 14485), -- Recipe: Soulshot (D-Grade)
(20357, 1926, 1, 1, -1, 36578), -- Piece Bone Breastplate Fragment
(20357, 57, 164, 295, 0, 700000), -- Adena
(20357, 68, 1, 1, 1, 114), -- Falchion
(20357, 5284, 1, 1, 1, 114), -- Zweihander
(20357, 1869, 1, 1, 2, 53483.185212), -- Iron Ore
(20357, 1864, 1, 1, 2, 106966.370424), -- Stem
(20357, 1880, 1, 1, 2, 5348.33766), -- Steel
(20357, 2176, 1, 1, 2, 25590.106704), -- Recipe: Leather Boots
-- Ratman Hunter
(20358, 2140, 1, 1, -1, 50651), -- Recipe: High-Grade Suede
(20358, 1924, 1, 1, -1, 81695), -- Leather Helmet Design
(20358, 2141, 1, 1, -1, 50651), -- Recipe: Silver Mold
(20358, 57, 121, 200, 0, 700000), -- Adena
(20358, 217, 1, 1, 1, 142.5), -- Shining Knife
(20358, 218, 1, 1, 1, 142.5), -- Throwing Knife
(20358, 1871, 1, 1, 2, 49871.999886), -- Charcoal
(20358, 1866, 1, 1, 2, 33247.999924), -- Suede
(20358, 1800, 1, 1, 2, 15683.00019), -- Recipe: Piece Bone Breastplate
-- Ratman Warrior
(20359, 1872, 1, 1, -1, 348237), -- Animal Bone
(20359, 44, 1, 1, -1, 6680), -- Leather Helmet
(20359, 1924, 1, 1, -1, 84251), -- Leather Helmet Design
(20359, 57, 122, 208, 0, 700000), -- Adena
(20359, 176, 1, 1, 1, 147), -- Apprentice's Staff
(20359, 2501, 1, 1, 1, 147), -- Bone Club
(20359, 1870, 1, 1, 2, 38574.067424), -- Coal
(20359, 1865, 1, 1, 2, 38574.067424), -- Varnish
(20359, 2252, 1, 1, 2, 1580.876768), -- Recipe: Iron Hammer
(20359, 5268, 1, 1, 2, 1542.988384), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Ratman Spy
(20360, 2175, 1, 1, -1, 193143), -- Recipe: Boots
(20360, 908, 1, 1, -1, 5210), -- Necklace of Wisdom
(20360, 1801, 1, 1, -1, 119680), -- Recipe: Piece Bone Gaiters
(20360, 57, 118, 183, 0, 700000), -- Adena
(20360, 945, 1, 1, 1, 2658.14964), -- Skeleton Buckler
(20360, 102, 1, 1, 1, 1282.914271), -- Round Shield
(20360, 44, 1, 1, 1, 897.375937), -- Leather Helmet
(20360, 1924, 1, 1, 1, 11318.560152), -- Leather Helmet Design
(20360, 1872, 1, 1, 2, 46781.949852), -- Animal Bone
(20360, 1867, 1, 1, 2, 46781.949852), -- Animal Skin
(20360, 2173, 1, 1, 2, 9508.569712), -- Recipe: Hard Leather Shirt
(20360, 5273, 1, 1, 2, 1403.530584), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Tunath Orc Marksman
(20361, 1790, 1, 1, -1, 28303), -- Recipe: Dirk
(20361, 42, 1, 1, -1, 43748), -- Leather Cap
(20361, 2005, 1, 1, -1, 10937), -- Broadsword Blade
(20361, 57, 82, 111, 0, 700000), -- Adena
(20361, 14, 1, 1, 1, 942.288438), -- Bow
(20361, 2007, 1, 1, 1, 3230.711562), -- Bow Shaft
(20361, 1864, 1, 1, 2, 45228.43336), -- Stem
(20361, 1869, 1, 1, 2, 22614.21668), -- Iron Ore
(20361, 1802, 1, 1, 2, 48632.82204), -- Recipe: Necklace of Anguish
(20361, 735, 1, 1, 2, 1884.52792), -- Alacrity Potion
-- Tunath Orc Warrior
(20362, 1799, 1, 1, -1, 263305), -- Recipe: Leather Gloves
(20362, 1867, 1, 1, -1, 236975), -- Animal Skin
(20362, 1792, 1, 1, -1, 13068), -- Recipe: Short Spear
(20362, 57, 95, 131, 0, 700000), -- Adena
(20362, 37, 1, 1, 1, 3431.316663), -- Leather Shoes
(20362, 1921, 1, 1, 1, 22580.337231), -- Leather Shoes Texture
(20362, 49, 1, 1, 1, 3431.346106), -- Gloves
(20362, 1869, 1, 1, 2, 26249.586141), -- Iron Ore
(20362, 1864, 1, 1, 2, 52499.033271), -- Stem
(20362, 1792, 1, 1, 2, 1930.167735), -- Recipe: Short Spear
(20362, 1060, 1, 1, 2, 58332.212853), -- Lesser Healing Potion
-- Maraku Werewolf
(20363, 1867, 1, 1, -1, 198456), -- Animal Skin
(20363, 2005, 1, 1, -1, 10632), -- Broadsword Blade
(20363, 2006, 1, 1, -1, 10632), -- Willow Staff Head
(20363, 57, 80, 108, 0, 700000), -- Adena
(20363, 254, 1, 1, 1, 1832), -- Iron Gloves
(20363, 1869, 1, 1, 2, 21982.72725), -- Iron Ore
(20363, 1864, 1, 1, 2, 43965.4545), -- Stem
(20363, 1814, 1, 1, 2, 11569.8648), -- Recipe: Leather
(20363, 735, 1, 1, 2, 1831.95345), -- Alacrity Potion
-- Maraku Werewolf Chieftain
(20364, 1867, 1, 1, -1, 303119), -- Animal Skin
(20364, 2008, 1, 1, -1, 8846), -- Cedar Staff Head
(20364, 1896, 1, 1, -1, 96330), -- Necklace of Anguish Chain
(20364, 57, 116, 172, 0, 700000), -- Adena
(20364, 2371, 1, 1, 1, 689.021212), -- Fist of Butcher
(20364, 255, 1, 1, 1, 322.978788), -- Fox Claw Gloves
(20364, 1870, 1, 1, 2, 44768.15956), -- Coal
(20364, 1865, 1, 1, 2, 44768.15956), -- Varnish
(20364, 1793, 1, 1, 2, 3291.68088), -- Recipe: Sword of Reflection
-- Mountain Fungus
(20365, 1866, 1, 1, -1, 83081), -- Suede
(20365, 1864, 1, 1, -1, 249244), -- Stem
(20365, 1871, 1, 1, -1, 124622), -- Charcoal
(20365, 57, 67, 91, 0, 700000), -- Adena
(20365, 22, 1, 1, 1, 3937.19964), -- Leather Shirt
(20365, 29, 1, 1, 1, 6292.80036), -- Leather Pants
(20365, 1871, 1, 1, 2, 24541), -- Charcoal
(20365, 1866, 1, 1, 2, 16360.650306), -- Suede
(20365, 1666, 1, 1, 2, 8180.349694), -- Recipe: Wooden Arrow
-- Merkenis' Escort
(20367, 1864, 1, 1, -1, 459366), -- Stem
(20367, 1831, 1, 1, -1, 612488), -- Antidote
(20367, 1896, 1, 1, -1, 97323), -- Necklace of Anguish Chain
(20367, 57, 106, 184, 0, 700000), -- Adena
(20367, 945, 1, 1, 1, 2569.8024), -- Skeleton Buckler
(20367, 102, 1, 1, 1, 1240.27486), -- Round Shield
(20367, 44, 1, 1, 1, 867.55042), -- Leather Helmet
(20367, 1924, 1, 1, 1, 10942.37232), -- Leather Helmet Design
(20367, 1864, 1, 1, 2, 54275.848704), -- Stem
(20367, 1869, 1, 1, 2, 27137.924352), -- Iron Ore
(20367, 1878, 1, 1, 2, 10855.188864), -- Braided Hemp
(20367, 5153, 1, 1, 2, 1085.528448), -- Recipe: Soulshot (D) Compressed Package (100%)
(20367, 735, 1, 1, 2, 2261.509632), -- Alacrity Potion
-- Grave Keeper
(20368, 1873, 1, 1, -1, 80618), -- Silver Nugget
(20368, 1833, 1, 1, -1, 537455), -- Bandage
(20368, 1793, 1, 1, -1, 14820), -- Recipe: Sword of Reflection
(20368, 57, 106, 150, 0, 700000), -- Adena
(20368, 271, 1, 1, 1, 572), -- Hunting Bow
(20368, 1866, 1, 1, 2, 26459.498633), -- Suede
(20368, 1871, 1, 1, 2, 39689.213416), -- Charcoal
(20368, 1793, 1, 1, 2, 2918.287951), -- Recipe: Sword of Reflection
-- Moonstone Beast
(20369, 2143, 1, 1, -1, 48728), -- Recipe: Synthetic Cokes
(20369, 390, 1, 1, -1, 3124), -- Cotton Shirt
(20369, 1897, 1, 1, -1, 58010), -- Necklace of Wisdom Chain
(20369, 57, 119, 191, 0, 700000), -- Adena
(20369, 1101, 1, 1, 1, 922.701996), -- Tunic of Devotion
(20369, 1104, 1, 1, 1, 1473.298004), -- Stockings of Devotion
(20369, 1868, 1, 1, 2, 95957.48532), -- Thread
(20369, 1873, 1, 1, 2, 19191.497064), -- Silver Nugget
(20369, 2175, 1, 1, 2, 39007.017616), -- Recipe: Boots
-- Barbed Bat
(20370, 1864, 1, 1, -1, 418191), -- Stem
(20370, 1922, 1, 1, -1, 53341), -- Leather Tunic Pattern
(20370, 1794, 1, 1, -1, 15375), -- Recipe: Forest Bow
(20370, 57, 112, 154, 0, 700000), -- Adena
(20370, 23, 1, 1, 1, 1345.562706), -- Wooden Breastplate
(20370, 30, 1, 1, 1, 2155.718647), -- Hard Leather Pants
(20370, 2386, 1, 1, 1, 2155.718647), -- Wooden Gaiters
(20370, 1864, 1, 1, 2, 82351.61649), -- Stem
(20370, 1869, 1, 1, 2, 41175.808245), -- Iron Ore
(20370, 1793, 1, 1, 2, 3027.575265), -- Recipe: Sword of Reflection
-- Mist Terror
(20371, 1869, 1, 1, -1, 196871), -- Iron Ore
(20371, 114, 1, 1, -1, 14583), -- Earring of Strength
(20371, 1896, 1, 1, -1, 83420), -- Necklace of Anguish Chain
(20371, 57, 99, 150, 0, 700000), -- Adena
(20371, 429, 1, 1, 1, 950.19645), -- Leather Tunic
(20371, 1922, 1, 1, 1, 7417.267288), -- Leather Tunic Pattern
(20371, 464, 1, 1, 1, 1522.27686), -- Leather Stockings
(20371, 1923, 1, 1, 1, 11916.259402), -- Leather Stockings Pattern
(20371, 1866, 1, 1, 2, 25845.756946), -- Suede
(20371, 1871, 1, 1, 2, 38768.635419), -- Charcoal
(20371, 1803, 1, 1, 2, 32578.607635), -- Recipe: Necklace of Wisdom
-- Baraq Orc Fighter
(20372, 1870, 1, 1, -1, 151631), -- Coal
(20372, 1864, 1, 1, -1, 303261), -- Stem
(20372, 57, 81, 110, 0, 700000), -- Adena
(20372, 3, 1, 1, 1, 933.030392), -- Broadsword
(20372, 2005, 1, 1, 1, 3198.969608), -- Broadsword Blade
(20372, 1869, 1, 1, 2, 29859.483108), -- Iron Ore
(20372, 1864, 1, 1, 2, 59718.966216), -- Stem
(20372, 1814, 1, 1, 2, 15715.550676), -- Recipe: Leather
-- Baraq Orc Warrior Leader
(20373, 1793, 1, 1, -1, 12352), -- Recipe: Sword of Reflection
(20373, 1871, 1, 1, -1, 167982), -- Charcoal
(20373, 1869, 1, 1, -1, 167982), -- Iron Ore
(20373, 57, 91, 122, 0, 700000), -- Adena
(20373, 2371, 1, 1, 1, 508.595697), -- Fist of Butcher
(20373, 255, 1, 1, 1, 238.404303), -- Fox Claw Gloves
(20373, 1869, 1, 1, 2, 33079.61244), -- Iron Ore
(20373, 1864, 1, 1, 2, 66159.373126), -- Stem
(20373, 1799, 1, 1, 2, 49007.014434), -- Recipe: Leather Gloves
-- Varangka's Guard
(20374, 2255, 1, 1, -1, 9821), -- Recipe: Saber
(20374, 1871, 1, 1, -1, 401688), -- Charcoal
(20374, 1898, 1, 1, -1, 41262), -- Blue Diamond Necklace Gem
(20374, 57, 182, 327, 0, 700000), -- Adena
(20374, 257, 1, 1, 1, 252), -- Viper Fang
(20374, 1873, 1, 1, 2, 23730.43641), -- Silver Nugget
(20374, 1868, 1, 1, 2, 118652.476308), -- Thread
(20374, 5273, 1, 1, 2, 2373.043641), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(20374, 5158, 1, 1, 2, 2373.043641), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Varangka's Escort
(20375, 2257, 1, 1, -1, 7102), -- Recipe: Trident
(20375, 2014, 1, 1, -1, 3339), -- Iron Hammer Head
(20375, 1804, 1, 1, -1, 11619), -- Recipe: Soulshot (D-Grade)
(20375, 57, 132, 236, 0, 700000), -- Adena
(20375, 16, 1, 1, 1, 183), -- Great Spear
(20375, 1865, 1, 1, 2, 34319.298816), -- Varnish
(20375, 1870, 1, 1, 2, 34319.298816), -- Coal
(20375, 1879, 1, 1, 2, 5719.883136), -- Cokes
(20375, 5158, 1, 1, 2, 1372.759616), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Stone Giant
(20378, 1831, 1, 1, -1, 537455), -- Antidote
(20378, 49, 1, 1, -1, 19759), -- Gloves
(20378, 1896, 1, 1, -1, 85401), -- Necklace of Anguish Chain
(20378, 57, 106, 150, 0, 700000), -- Adena
(20378, 114, 1, 1, 1, 1763.923339), -- Earring of Strength
(20378, 115, 1, 1, 1, 1763.923339), -- Earring of Wisdom
(20378, 907, 1, 1, 1, 1322.946901), -- Necklace of Anguish
(20378, 1896, 1, 1, 1, 10090.295032), -- Necklace of Anguish Chain
(20378, 876, 1, 1, 1, 2645.911389), -- Ring of Anguish
(20378, 1866, 1, 1, 2, 26459.358156), -- Suede
(20378, 1871, 1, 1, 2, 39689.037234), -- Charcoal
(20378, 736, 1, 1, 2, 19844.60461), -- Scroll of Escape
-- Stone Soldier
(20379, 1792, 1, 1, -1, 18424), -- Recipe: Short Spear
(20379, 1871, 1, 1, -1, 250564), -- Charcoal
(20379, 1872, 1, 1, -1, 334085), -- Animal Bone
(20379, 57, 128, 189, 0, 700000), -- Adena
(20379, 114, 1, 1, 1, 2192.993905), -- Earring of Strength
(20379, 115, 1, 1, 1, 2192.993905), -- Earring of Wisdom
(20379, 907, 1, 1, 1, 1644.750895), -- Necklace of Anguish
(20379, 1896, 1, 1, 1, 12544.73764), -- Necklace of Anguish Chain
(20379, 876, 1, 1, 1, 3289.523655), -- Ring of Anguish
(20379, 1872, 1, 1, 2, 65788.941098), -- Animal Bone
(20379, 1867, 1, 1, 2, 65788.941098), -- Animal Skin
(20379, 1794, 1, 1, 2, 3628.117804), -- Recipe: Forest Bow
-- Stone Guardian
(20380, 1869, 1, 1, -1, 267071), -- Iron Ore
(20380, 1873, 1, 1, -1, 106828), -- Silver Nugget
(20380, 1866, 1, 1, -1, 178047), -- Suede
(20380, 57, 132, 206, 0, 700000), -- Adena
(20380, 176, 1, 1, 1, 150.5), -- Apprentice's Staff
(20380, 2501, 1, 1, 1, 150.5), -- Bone Club
(20380, 1871, 1, 1, 2, 52592.26824), -- Charcoal
(20380, 1866, 1, 1, 2, 35061.47532), -- Suede
(20380, 2174, 1, 1, 2, 22866.25644), -- Recipe: Hard Leather Gaiters
-- Vaiss Orc
(20381, 1867, 1, 1, -1, 198210), -- Animal Skin
(20381, 2006, 1, 1, -1, 10618), -- Willow Staff Head
(20381, 1875, 1, 1, -1, 9910), -- Stone of Purity
(20381, 57, 80, 108, 0, 700000), -- Adena
(20381, 99, 1, 1, 1, 1830), -- Apprentice's Spellbook
(20381, 1865, 1, 1, 2, 29273.970726), -- Varnish
(20381, 1870, 1, 1, 2, 29273.970726), -- Coal
(20381, 2136, 1, 1, 2, 8610.058548), -- Recipe: Cokes
-- Vaiss Orc Warrior Leader
(20382, 1870, 1, 1, -1, 167982), -- Coal
(20382, 2008, 1, 1, -1, 6536), -- Cedar Staff Head
(20382, 1831, 1, 1, -1, 447952), -- Antidote
(20382, 57, 91, 122, 0, 700000), -- Adena
(20382, 20, 1, 1, 1, 4637.08056), -- Buckler
(20382, 43, 1, 1, 1, 3242.91944), -- Wooden Helmet
(20382, 1866, 1, 1, 2, 22052.91146), -- Suede
(20382, 1871, 1, 1, 2, 33079.36719), -- Charcoal
(20382, 1803, 1, 1, 2, 27797.72135), -- Recipe: Necklace of Wisdom
-- Balor Orc Archer
(20385, 1060, 1, 1, -1, 285245), -- Lesser Healing Potion
(20385, 2005, 1, 1, -1, 9169), -- Broadsword Blade
(20385, 57, 69, 94, 0, 700000), -- Adena
(20385, 14, 1, 1, 1, 789.869388), -- Bow
(20385, 2007, 1, 1, 1, 2708.130612), -- Bow Shaft
(20385, 1873, 1, 1, 2, 10110.924824), -- Silver Nugget
(20385, 1868, 1, 1, 2, 50554.689458), -- Thread
(20385, 1790, 1, 1, 2, 4672.385718), -- Recipe: Dirk
-- Balor Orc Fighter
(20386, 1060, 1, 1, -1, 404348), -- Lesser Healing Potion
(20386, 1796, 1, 1, -1, 228876), -- Recipe: Leather Tunic
(20386, 1666, 1, 1, -1, 60652), -- Recipe: Wooden Arrow
(20386, 57, 98, 132, 0, 700000), -- Adena
(20386, 3, 1, 1, 1, 1119.771954), -- Broadsword
(20386, 2005, 1, 1, 1, 3839.228046), -- Broadsword Blade
(20386, 1869, 1, 1, 2, 26873.64), -- Iron Ore
(20386, 1864, 1, 1, 2, 53747.28), -- Stem
(20386, 1666, 1, 1, 2, 8957.88), -- Recipe: Wooden Arrow
(20386, 17, 10, 30, 2, 134368.2), -- Wooden Arrow
-- Balor Orc Fighter Leader
(20387, 1833, 1, 1, -1, 568739), -- Bandage
(20387, 1794, 1, 1, -1, 15682), -- Recipe: Forest Bow
(20387, 1896, 1, 1, -1, 90372), -- Necklace of Anguish Chain
(20387, 57, 114, 157, 0, 700000), -- Adena
(20387, 66, 1, 1, 1, 201.91485), -- Gladius
(20387, 1333, 1, 1, 1, 201.91485), -- Brandish
(20387, 2010, 1, 1, 1, 1634.1703), -- Brandish Blade
(20387, 1869, 1, 1, 2, 41999.291874), -- Iron Ore
(20387, 1864, 1, 1, 2, 83998.583748), -- Stem
(20387, 1794, 1, 1, 2, 3088.124378), -- Recipe: Forest Bow
-- Balor Orc Lieutenant
(20388, 1833, 1, 1, -1, 537542), -- Bandage
(20388, 1880, 1, 1, -1, 20158), -- Steel
(20388, 57, 109, 147, 0, 700000), -- Adena
(20388, 37, 1, 1, 1, 3891.653613), -- Leather Shoes
(20388, 1921, 1, 1, 1, 25609.659381), -- Leather Shoes Texture
(20388, 49, 1, 1, 1, 3891.687006), -- Gloves
(20388, 1869, 1, 1, 2, 29771.46667), -- Iron Ore
(20388, 1864, 1, 1, 2, 59542.93334), -- Stem
(20388, 736, 1, 1, 2, 14885.733335), -- Scroll of Escape
(20388, 735, 1, 1, 2, 2480.866655), -- Alacrity Potion
-- Boogle Ratman
(20389, 734, 1, 1, -1, 32995), -- Haste Potion
(20389, 2011, 1, 1, -1, 4516), -- Short Spear Edge
(20389, 1872, 1, 1, -1, 263962), -- Animal Bone
(20389, 57, 98, 153, 0, 700000), -- Adena
(20389, 945, 1, 1, 1, 2215.09728), -- Skeleton Buckler
(20389, 102, 1, 1, 1, 1069.081992), -- Round Shield
(20389, 44, 1, 1, 1, 747.804024), -- Leather Helmet
(20389, 1924, 1, 1, 1, 9432.016704), -- Leather Helmet Design
(20389, 1867, 1, 1, 2, 38985.053753), -- Animal Skin
(20389, 1872, 1, 1, 2, 38985.053753), -- Animal Bone
(20389, 2175, 1, 1, 2, 23771.41189), -- Recipe: Boots
(20389, 5158, 1, 1, 2, 1169.480604), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Boogle Ratman Leader
(20390, 1881, 1, 1, -1, 28140), -- Coarse Bone Powder
(20390, 1897, 1, 1, -1, 50249), -- Necklace of Wisdom Chain
(20390, 1873, 1, 1, -1, 84419), -- Silver Nugget
(20390, 57, 101, 167, 0, 700000), -- Adena
(20390, 2, 1, 1, 1, 59.336423), -- Long Sword
(20390, 120, 1, 1, 1, 59.336423), -- Sword of Reflection
(20390, 2012, 1, 1, 1, 648.990731), -- Sword of Reflection Blade
(20390, 121, 1, 1, 1, 59.336423), -- Sword of Watershadow
(20390, 1868, 1, 1, 2, 49871.97819), -- Thread
(20390, 1873, 1, 1, 2, 9974.395638), -- Silver Nugget
(20390, 1801, 1, 1, 2, 12562.174206), -- Recipe: Piece Bone Gaiters
(20390, 5158, 1, 1, 2, 997.44732), -- Recipe: Spiritshot (D) Compressed Package (100%)
(20390, 734, 1, 1, 2, 4156.004646), -- Haste Potion
-- Redeye Bat
(20392, 1798, 1, 1, -1, 227072), -- Recipe: Leather Helmet
(20392, 1833, 1, 1, -1, 617635), -- Bandage
(20392, 1831, 1, 1, -1, 617635), -- Antidote
(20392, 57, 116, 177, 0, 700000), -- Adena
(20392, 23, 1, 1, 1, 1490.418228), -- Wooden Breastplate
(20392, 30, 1, 1, 1, 2387.790886), -- Hard Leather Pants
(20392, 2386, 1, 1, 1, 2387.790886), -- Wooden Gaiters
(20392, 1869, 1, 1, 2, 34207.459451), -- Iron Ore
(20392, 1864, 1, 1, 2, 68415.114645), -- Stem
(20392, 736, 1, 1, 2, 17103.827597), -- Scroll of Escape
(20392, 1060, 1, 1, 2, 76016.598307), -- Lesser Healing Potion
-- Red Scavenger Spider
(20393, 2252, 1, 1, -1, 9736), -- Recipe: Iron Hammer
(20393, 1897, 1, 1, -1, 56563), -- Necklace of Wisdom Chain
(20393, 57, 118, 183, 0, 700000), -- Adena
(20393, 217, 1, 1, 1, 133.5), -- Shining Knife
(20393, 218, 1, 1, 1, 133.5), -- Throwing Knife
(20393, 1867, 1, 1, 2, 62376.36144), -- Animal Skin
(20393, 1872, 1, 1, 2, 62376.36144), -- Animal Bone
(20393, 2252, 1, 1, 2, 1917.27712), -- Recipe: Iron Hammer
-- Blood Fungus
(20400, 1803, 1, 1, -1, 175710), -- Recipe: Necklace of Wisdom
(20400, 1923, 1, 1, -1, 85695), -- Leather Stockings Pattern
(20400, 1921, 1, 1, -1, 134900), -- Leather Shoes Texture
(20400, 57, 112, 154, 0, 700000), -- Adena
(20400, 114, 1, 1, 1, 1830.019062), -- Earring of Strength
(20400, 115, 1, 1, 1, 1830.019062), -- Earring of Wisdom
(20400, 907, 1, 1, 1, 1372.518858), -- Necklace of Anguish
(20400, 1896, 1, 1, 1, 10468.387056), -- Necklace of Anguish Chain
(20400, 876, 1, 1, 1, 2745.055962), -- Ring of Anguish
(20400, 1864, 1, 1, 2, 82351.173385), -- Stem
(20400, 1869, 1, 1, 2, 41175.66864), -- Iron Ore
(20400, 1798, 1, 1, 2, 40368.157975), -- Recipe: Leather Helmet
-- Veelan Bugbear
(20401, 2151, 1, 1, -1, 105333), -- Recipe: Necklace of Devotion
(20401, 1873, 1, 1, -1, 151258), -- Silver Nugget
(20401, 1866, 1, 1, -1, 252096), -- Suede
(20401, 57, 173, 305, 0, 700000), -- Adena
(20401, 87, 1, 1, 1, 59.4008), -- Iron Hammer
(20401, 2014, 1, 1, 1, 641.79842), -- Iron Hammer Head
(20401, 155, 1, 1, 1, 59.4008), -- Flanged Mace
(20401, 177, 1, 1, 1, 59.39998), -- Mage Staff
(20401, 1866, 1, 1, 2, 37232.78645), -- Suede
(20401, 1871, 1, 1, 2, 55849.22845), -- Charcoal
(20401, 5153, 1, 1, 2, 2233.99255), -- Recipe: Soulshot (D) Compressed Package (100%)
(20401, 5158, 1, 1, 2, 2233.99255), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Veelan Bugbear Warrior
(20402, 2179, 1, 1, -1, 194917), -- Recipe: Crafted Leather Gloves
(20402, 1880, 1, 1, -1, 40738), -- Steel
(20402, 1871, 1, 1, -1, 407376), -- Charcoal
(20402, 57, 181, 334, 0, 700000), -- Adena
(20402, 25, 1, 1, 1, 327.716196), -- Piece Bone Breastplate
(20402, 1926, 1, 1, 1, 4051.787503), -- Piece Bone Breastplate Fragment
(20402, 26, 1, 1, 1, 212.127426), -- Bronze Breastplate
(20402, 32, 1, 1, 1, 524.352693), -- Piece Bone Gaiters
(20402, 1928, 1, 1, 1, 5843.074468), -- Piece Bone Gaiters Fragment
(20402, 34, 1, 1, 1, 339.941714), -- Bronze Gaiters
(20402, 1866, 1, 1, 2, 40110.92374), -- Suede
(20402, 1871, 1, 1, 2, 60166.38561), -- Charcoal
(20402, 2256, 1, 1, 2, 1471.08522), -- Recipe: Assassin Knife
(20402, 5158, 1, 1, 2, 2406.60543), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Hunter Tarantula
(20403, 1868, 1, 1, -1, 475131), -- Thread
(20403, 2012, 1, 1, -1, 4949), -- Sword of Reflection Blade
(20403, 734, 1, 1, -1, 39594), -- Haste Potion
(20403, 57, 118, 183, 0, 700000), -- Adena
(20403, 38, 1, 1, 1, 1795.866945), -- Low Boots
(20403, 50, 1, 1, 1, 1795.866945), -- Leather Gloves
(20403, 1925, 1, 1, 1, 30677.26611), -- Leather Gloves Lining
(20403, 1867, 1, 1, 2, 37425.875256), -- Animal Skin
(20403, 1872, 1, 1, 2, 37425.875256), -- Animal Bone
(20403, 2253, 1, 1, 2, 1150.400328), -- Recipe: Sword Breaker
(20403, 5268, 1, 1, 2, 1122.746856), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20403, 735, 1, 1, 2, 2339.102304), -- Alacrity Potion
-- Silent Horror
(20404, 2253, 1, 1, -1, 8276), -- Recipe: Sword Breaker
(20404, 735, 1, 1, -1, 16828), -- Alacrity Potion
(20404, 1897, 1, 1, -1, 48079), -- Necklace of Wisdom Chain
(20404, 57, 100, 156, 0, 700000), -- Adena
(20404, 1101, 1, 1, 1, 764.810586), -- Tunic of Devotion
(20404, 1104, 1, 1, 1, 1221.189414), -- Stockings of Devotion
(20404, 1866, 1, 1, 2, 19882.56029), -- Suede
(20404, 1871, 1, 1, 2, 29823.813728), -- Charcoal
(20404, 2254, 1, 1, 2, 1222.272562), -- Recipe: Composite Bow
(20404, 6035, 1, 1, 2, 2485.35342), -- Magic Haste Potion
-- Scavenger Spider
(20410, 1868, 1, 1, -1, 472491), -- Thread
(20410, 2009, 1, 1, -1, 8377), -- Dirk Blade
(20410, 1792, 1, 1, -1, 17371), -- Recipe: Short Spear
(20410, 57, 119, 180, 0, 700000), -- Adena
(20410, 9, 1, 1, 1, 223.71135), -- Cedar Staff
(20410, 2008, 1, 1, 1, 1810.5773), -- Cedar Staff Head
(20410, 154, 1, 1, 1, 223.71135), -- Dwarven Mace
(20410, 1867, 1, 1, 2, 62029.60084), -- Animal Skin
(20410, 1872, 1, 1, 2, 62029.60084), -- Animal Bone
(20410, 1793, 1, 1, 2, 3420.79832), -- Recipe: Sword of Reflection
-- Scavenger Bat
(20411, 735, 1, 1, -1, 21105), -- Alacrity Potion
(20411, 2141, 1, 1, -1, 50651), -- Recipe: Silver Mold
(20411, 1897, 1, 1, -1, 60299), -- Necklace of Wisdom Chain
(20411, 57, 121, 200, 0, 700000), -- Adena
(20411, 217, 1, 1, 1, 142.5), -- Shining Knife
(20411, 218, 1, 1, 1, 142.5), -- Throwing Knife
(20411, 1864, 1, 1, 2, 59846.45251), -- Stem
(20411, 1869, 1, 1, 2, 29923.14247), -- Iron Ore
(20411, 1878, 1, 1, 2, 11969.35753), -- Braided Hemp
(20411, 1817, 1, 1, 2, 5984.59498), -- Recipe: Cord
(20411, 6037, 1, 1, 2, 59846.45251), -- Waking Scroll
-- Scarlet Salamander
(20415, 2144, 1, 1, -1, 45114), -- Recipe: Compound Braid
(20415, 1865, 1, 1, -1, 225572), -- Varnish
(20415, 735, 1, 1, -1, 18798), -- Alacrity Potion
(20415, 57, 110, 177, 0, 700000), -- Adena
(20415, 309, 1, 1, 1, 127), -- Tears of Eva
(20415, 310, 1, 1, 1, 127), -- Relic of the Saints
(20415, 1864, 1, 1, 2, 44420.332616), -- Stem
(20415, 1865, 1, 1, 2, 22210.166308), -- Varnish
(20415, 1866, 1, 1, 2, 14806.822756), -- Suede
(20415, 1873, 1, 1, 2, 8884.120784), -- Silver Nugget
(20415, 1868, 1, 1, 2, 44420.332616), -- Thread
(20415, 2253, 1, 1, 2, 910.22492), -- Recipe: Sword Breaker
-- Scarlet Salamander Elder
(20416, 2254, 1, 1, -1, 9514), -- Recipe: Composite Bow
(20416, 102, 1, 1, -1, 8488), -- Round Shield
(20416, 1924, 1, 1, -1, 74887), -- Leather Helmet Design
(20416, 57, 111, 183, 0, 700000), -- Adena
(20416, 1101, 1, 1, 1, 879.185583), -- Tunic of Devotion
(20416, 1104, 1, 1, 1, 1403.814417), -- Stockings of Devotion
(20416, 1866, 1, 1, 2, 22858.0191), -- Suede
(20416, 1871, 1, 1, 2, 34287.094024), -- Charcoal
(20416, 2139, 1, 1, 2, 6857.40573), -- Recipe: Steel Mold
(20416, 5268, 1, 1, 2, 1371.481146), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Crystalline Beast
(20418, 1872, 1, 1, -1, 334331), -- Animal Bone
(20418, 1800, 1, 1, -1, 78852), -- Recipe: Piece Bone Breastplate
(20418, 1925, 1, 1, -1, 164425), -- Leather Gloves Lining
(20418, 57, 120, 198, 0, 700000), -- Adena
(20418, 845, 1, 1, 1, 1082.867838), -- Cat's Eye Earring
(20418, 908, 1, 1, 1, 812.157047), -- Necklace of Wisdom
(20418, 1897, 1, 1, 1, 8817.673358), -- Necklace of Wisdom Chain
(20418, 877, 1, 1, 1, 1624.301757), -- Ring of Wisdom
(20418, 1867, 1, 1, 2, 49378.310415), -- Animal Skin
(20418, 1872, 1, 1, 2, 49378.310415), -- Animal Bone
(20418, 1882, 1, 1, 2, 8229.661206), -- Leather
(20418, 2140, 1, 1, 2, 7406.717964), -- Recipe: High-Grade Suede
-- Akaste Succubus Turen
(20420, 1868, 1, 1, -1, 580926), -- Thread
(20420, 1866, 1, 1, -1, 193642), -- Suede
(20420, 1804, 1, 1, -1, 11619), -- Recipe: Soulshot (D-Grade)
(20420, 57, 132, 236, 0, 700000), -- Adena
(20420, 1102, 1, 1, 1, 604.334152), -- Tunic of Magic
(20420, 1105, 1, 1, 1, 969.665848), -- Stockings of Magic
(20420, 1864, 1, 1, 2, 57198.813617), -- Stem
(20420, 1865, 1, 1, 2, 28599.319485), -- Varnish
(20420, 1866, 1, 1, 2, 19066.21299), -- Suede
(20420, 1873, 1, 1, 2, 11439.727794), -- Silver Nugget
(20420, 1868, 1, 1, 2, 57198.813617), -- Thread
(20420, 5163, 1, 1, 2, 1144.112497), -- Recipe: Blessed Spiritshot (D) Compressed Package (100%)
-- Akaste Succubus Tilfo
(20421, 1866, 1, 1, -1, 205204), -- Suede
(20421, 1929, 1, 1, -1, 39717), -- Hard Leather Gaiters Material
(20421, 1898, 1, 1, -1, 31619), -- Blue Diamond Necklace Gem
(20421, 57, 140, 251, 0, 700000), -- Adena
(20421, 273, 1, 1, 1, 96.708612), -- Composite Bow
(20421, 2016, 1, 1, 1, 1065.291388), -- Composite Bow Shaft
(20421, 1869, 1, 1, 2, 30307.070768), -- Iron Ore
(20421, 1870, 1, 1, 2, 30307.070768), -- Coal
(20421, 1871, 1, 1, 2, 30307.070768), -- Charcoal
(20421, 1872, 1, 1, 2, 40409.37004), -- Animal Bone
(20421, 1867, 1, 1, 2, 40409.37004), -- Animal Skin
(20421, 5278, 1, 1, 2, 1212.047616), -- Recipe: Greater Blessed Spiritshot (D) Compressed Package(100%)
-- Akaste Bone Warlord
(20422, 1869, 1, 1, -1, 248908), -- Iron Ore
(20422, 2013, 1, 1, -1, 5372), -- Forest Bow Shaft
(20422, 1864, 1, 1, -1, 497816), -- Stem
(20422, 57, 121, 195, 0, 700000), -- Adena
(20422, 176, 1, 1, 1, 140), -- Apprentice's Staff
(20422, 2501, 1, 1, 1, 140), -- Bone Club
(20422, 1869, 1, 1, 2, 36761.673864), -- Iron Ore
(20422, 1864, 1, 1, 2, 73523.234466), -- Stem
(20422, 2254, 1, 1, 2, 1506.611124), -- Recipe: Composite Bow
(20422, 5273, 1, 1, 2, 1470.480546), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Akaste Bone Archer
(20423, 1792, 1, 1, -1, 14067), -- Recipe: Short Spear
(20423, 1921, 1, 1, -1, 123424), -- Leather Shoes Texture
(20423, 1793, 1, 1, -1, 14067), -- Recipe: Sword of Reflection
(20423, 57, 98, 145, 0, 700000), -- Adena
(20423, 271, 1, 1, 1, 543), -- Hunting Bow
(20423, 1872, 1, 1, 2, 75345.5), -- Animal Bone
(20423, 1867, 1, 1, 2, 75345.5), -- Animal Skin
-- Akaste Bone Lord
(20424, 2142, 1, 1, -1, 45599), -- Recipe: Varnish of Purity
(20424, 1880, 1, 1, -1, 22799), -- Steel
(20424, 1870, 1, 1, -1, 227995), -- Coal
(20424, 57, 107, 182, 0, 700000), -- Adena
(20424, 2, 1, 1, 1, 64.143606), -- Long Sword
(20424, 120, 1, 1, 1, 64.143606), -- Sword of Reflection
(20424, 2012, 1, 1, 1, 701.569182), -- Sword of Reflection Blade
(20424, 121, 1, 1, 1, 64.143606), -- Sword of Watershadow
(20424, 1870, 1, 1, 2, 44897.4846), -- Coal
(20424, 1865, 1, 1, 2, 44897.4846), -- Varnish
(20424, 2253, 1, 1, 2, 1840.0308), -- Recipe: Sword Breaker
-- Akaste Bone Soldier
(20425, 1869, 1, 1, -1, 177731), -- Iron Ore
(20425, 1831, 1, 1, -1, 473949), -- Antidote
(20425, 57, 95, 131, 0, 700000), -- Adena
(20425, 66, 1, 1, 1, 168.22935), -- Gladius
(20425, 1333, 1, 1, 1, 168.22935), -- Brandish
(20425, 2010, 1, 1, 1, 1361.5413), -- Brandish Blade
(20425, 1871, 1, 1, 2, 34999.299401), -- Charcoal
(20425, 1866, 1, 1, 2, 23332.902995), -- Suede
(20425, 1799, 1, 1, 2, 51850.797604), -- Recipe: Leather Gloves
-- Evil Eye
(20426, 1796, 1, 1, -1, 224389), -- Recipe: Leather Tunic
(20426, 2005, 1, 1, -1, 12742), -- Broadsword Blade
(20426, 57, 96, 130, 0, 700000), -- Adena
(20426, 113, 1, 1, 1, 11331.990825), -- Mystic's Earring
(20426, 906, 1, 1, 1, 8464.851375), -- Necklace of Knowledge
(20426, 875, 1, 1, 1, 16728.1578), -- Ring of Knowledge
(20426, 1873, 1, 1, 2, 10538.69033), -- Silver Nugget
(20426, 1868, 1, 1, 2, 52693.71071), -- Thread
(20426, 2137, 1, 1, 2, 7749.13225), -- Recipe: Steel
(20426, 1060, 1, 1, 2, 58548.46671), -- Lesser Healing Potion
-- Evil Eye Watcher
(20427, 1866, 1, 1, -1, 99105), -- Suede
(20427, 1060, 1, 1, -1, 330350), -- Lesser Healing Potion
(20427, 1666, 1, 1, -1, 49552), -- Recipe: Wooden Arrow
(20427, 57, 80, 108, 0, 700000), -- Adena
(20427, 254, 1, 1, 1, 1830), -- Iron Gloves
(20427, 1864, 1, 1, 2, 58548.013776), -- Stem
(20427, 1869, 1, 1, 2, 29273.958672), -- Iron Ore
(20427, 2138, 1, 1, 2, 8610.027552), -- Recipe: Coarse Bone Powder (100%)
-- Evil Eye Patroller
(20428, 1831, 1, 1, -1, 594351), -- Antidote
(20428, 1864, 1, 1, -1, 445764), -- Stem
(20428, 1896, 1, 1, -1, 94441), -- Necklace of Anguish Chain
(20428, 57, 114, 168, 0, 700000), -- Adena
(20428, 114, 1, 1, 1, 1950.676353), -- Earring of Strength
(20428, 115, 1, 1, 1, 1950.676353), -- Earring of Wisdom
(20428, 907, 1, 1, 1, 1463.012127), -- Necklace of Anguish
(20428, 1896, 1, 1, 1, 11158.591464), -- Necklace of Anguish Chain
(20428, 876, 1, 1, 1, 2926.043703), -- Ring of Anguish
(20428, 1864, 1, 1, 2, 37620.446542), -- Stem
(20428, 1865, 1, 1, 2, 18810.223271), -- Varnish
(20428, 1866, 1, 1, 2, 12540.212895), -- Suede
(20428, 1873, 1, 1, 2, 7524.127737), -- Silver Nugget
(20428, 1868, 1, 1, 2, 37620.446542), -- Thread
(20428, 1799, 1, 1, 2, 27867.075719), -- Recipe: Leather Gloves
(20428, 1833, 1, 1, 2, 50160.467294), -- Bandage
-- Evil Eye Lookout
(20429, 2009, 1, 1, -1, 6586), -- Dirk Blade
(20429, 1792, 1, 1, -1, 13657), -- Recipe: Short Spear
(20429, 1921, 1, 1, -1, 119829), -- Leather Shoes Texture
(20429, 57, 95, 140, 0, 700000), -- Adena
(20429, 429, 1, 1, 1, 896.468475), -- Leather Tunic
(20429, 1922, 1, 1, 1, 6997.864804), -- Leather Tunic Pattern
(20429, 464, 1, 1, 1, 1436.20113), -- Leather Stockings
(20429, 1923, 1, 1, 1, 11242.465591), -- Leather Stockings Pattern
(20429, 1868, 1, 1, 2, 73151.06274), -- Thread
(20429, 1873, 1, 1, 2, 14630.212548), -- Silver Nugget
(20429, 1803, 1, 1, 2, 30735.724712), -- Recipe: Necklace of Wisdom
-- Elpy
(20432, 1871, 1, 1, -1, 15920), -- Charcoal
(20432, 1873, 1, 1, -1, 6368), -- Silver Nugget
(20432, 57, 8, 12, 0, 700000), -- Adena
(20432, 11, 1, 1, 1, 5579), -- Bone Dagger
(20432, 1864, 1, 1, 2, 4702.406639), -- Stem
(20432, 1865, 1, 1, 2, 2351.21727), -- Varnish
(20432, 1866, 1, 1, 2, 1567.47818), -- Suede
(20432, 1873, 1, 1, 2, 940.486908), -- Silver Nugget
(20432, 1868, 1, 1, 2, 4702.406639), -- Thread
(20432, 1787, 1, 1, 2, 1880.973816), -- Recipe: Willow Staff
(20432, 17, 10, 30, 2, 11756.030548), -- Wooden Arrow
-- Festering Bat
(20433, 1864, 1, 1, -1, 430270), -- Stem
(20433, 1865, 1, 1, -1, 215135), -- Varnish
(20433, 1921, 1, 1, -1, 138797), -- Leather Shoes Texture
(20433, 57, 113, 160, 0, 700000), -- Adena
(20433, 429, 1, 1, 1, 1038.348675), -- Leather Tunic
(20433, 1922, 1, 1, 1, 8105.386692), -- Leather Tunic Pattern
(20433, 464, 1, 1, 1, 1663.50249), -- Leather Stockings
(20433, 1923, 1, 1, 1, 13021.762143), -- Leather Stockings Pattern
(20433, 1870, 1, 1, 2, 31773.902352), -- Coal
(20433, 1865, 1, 1, 2, 31773.902352), -- Varnish
(20433, 1794, 1, 1, 2, 2336.324412), -- Recipe: Forest Bow
(20433, 735, 1, 1, 2, 2647.870884), -- Alacrity Potion
-- Opal Beast
(20435, 1871, 1, 1, -1, 194922), -- Charcoal
(20435, 1793, 1, 1, -1, 14332), -- Recipe: Sword of Reflection
(20435, 1833, 1, 1, -1, 519792), -- Bandage
(20435, 57, 98, 149, 0, 700000), -- Adena
(20435, 216, 1, 1, 1, 276.86541), -- Dirk
(20435, 2009, 1, 1, 1, 2042.13459), -- Dirk Blade
(20435, 1872, 1, 1, 2, 51179.286523), -- Animal Bone
(20435, 1867, 1, 1, 2, 51179.286523), -- Animal Skin
(20435, 1794, 1, 1, 2, 2822.426954), -- Recipe: Forest Bow
-- Ol Mahum Supplier
(20436, 1869, 1, 1, -1, 378144), -- Iron Ore
(20436, 2016, 1, 1, -1, 4431), -- Composite Bow Shaft
(20436, 1898, 1, 1, -1, 38844), -- Blue Diamond Necklace Gem
(20436, 57, 173, 305, 0, 700000), -- Adena
(20436, 16, 1, 1, 1, 238), -- Great Spear
(20436, 1870, 1, 1, 2, 74465.184164), -- Coal
(20436, 1865, 1, 1, 2, 74465.184164), -- Varnish
(20436, 5158, 1, 1, 2, 2978.631672), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Ol Mahum Recruit
(20437, 2258, 1, 1, -1, 8355), -- Recipe: Temptation of Abyss
(20437, 2016, 1, 1, -1, 4004), -- Composite Bow Shaft
(20437, 1804, 1, 1, -1, 13669), -- Recipe: Soulshot (D-Grade)
(20437, 57, 156, 278, 0, 700000), -- Adena
(20437, 39, 1, 1, 1, 1416.686112), -- Boots
(20437, 1930, 1, 1, 1, 17254.607688), -- Boot Lining
(20437, 51, 1, 1, 1, 1416.7062), -- Bracer
(20437, 1871, 1, 1, 2, 50469.751278), -- Charcoal
(20437, 1866, 1, 1, 2, 33646.500852), -- Suede
(20437, 5268, 1, 1, 2, 2018.748114), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20437, 5437, 1, 1, 2, 1233.999756), -- Recipe: Heavy Sword(100%)
-- Ol Mahum General
(20438, 1865, 1, 1, -1, 450915), -- Varnish
(20438, 1869, 1, 1, -1, 450915), -- Iron Ore
(20438, 1899, 1, 1, -1, 70456), -- Necklace of Devotion Chain
(20438, 57, 196, 374, 0, 700000), -- Adena
(20438, 291, 1, 1, 1, 80.352954), -- Trident
(20438, 2019, 1, 1, 1, 2721.647046), -- Trident Edge
(20438, 1875, 1, 1, 2, 3374.22699), -- Stone of Purity
(20438, 1879, 1, 1, 2, 8435.53183), -- Cokes
(20438, 5549, 1, 1, 2, 5061.30484), -- Metallic Thread
(20438, 2180, 1, 1, 2, 3805.53149), -- Recipe: Scale Mail
(20438, 6666, 1, 1, 2, 50613.40485), -- Deluxe Chest Key - Grade 2
-- Ol Mahum Officer
(20439, 2255, 1, 1, -1, 9765), -- Recipe: Saber
(20439, 2015, 1, 1, -1, 4871), -- Sword Breaker Edge
(20439, 2151, 1, 1, -1, 111250), -- Recipe: Necklace of Devotion
(20439, 57, 177, 327, 0, 700000), -- Adena
(20439, 25, 1, 1, 1, 321.277308), -- Piece Bone Breastplate
(20439, 1926, 1, 1, 1, 3972.178969), -- Piece Bone Breastplate Fragment
(20439, 26, 1, 1, 1, 207.959598), -- Bronze Breastplate
(20439, 32, 1, 1, 1, 514.050339), -- Piece Bone Gaiters
(20439, 1928, 1, 1, 1, 5728.271164), -- Piece Bone Gaiters Fragment
(20439, 34, 1, 1, 1, 333.262622), -- Bronze Gaiters
(20439, 1873, 1, 1, 2, 31459.53048), -- Silver Nugget
(20439, 1868, 1, 1, 2, 157297.46172), -- Thread
(20439, 2257, 1, 1, 2, 1923.0078), -- Recipe: Trident
-- Elder Wolf
(20442, 1786, 1, 1, -1, 44845), -- Recipe: Broad Sword
(20442, 1864, 1, 1, -1, 112112), -- Stem
(20442, 5549, 1, 1, -1, 5606), -- Metallic Thread
(20442, 57, 30, 42, 0, 700000), -- Adena
(20442, 4, 1, 1, 1, 9822.5), -- Club
(20442, 7, 1, 1, 1, 9822.5), -- Apprentice's Rod
(20442, 1868, 1, 1, 2, 28976.533208), -- Thread
(20442, 1873, 1, 1, 2, 5795.25912), -- Silver Nugget
(20442, 1787, 1, 1, 2, 11590.637044), -- Recipe: Willow Staff
(20442, 17, 10, 30, 2, 72441.570628), -- Wooden Arrow
-- Utuku Orc
(20446, 1870, 1, 1, -1, 77741), -- Coal
(20446, 2007, 1, 1, -1, 5553), -- Bow Shaft
(20446, 1869, 1, 1, -1, 77741), -- Iron Ore
(20446, 57, 41, 58, 0, 700000), -- Adena
(20446, 22, 1, 1, 1, 2455.842708), -- Leather Shirt
(20446, 29, 1, 1, 1, 3925.157292), -- Leather Pants
(20446, 1869, 1, 1, 2, 15308.750172), -- Iron Ore
(20446, 1864, 1, 1, 2, 30617.500344), -- Stem
(20446, 1791, 1, 1, 2, 2829.749484), -- Recipe: Brandish
-- Utuku Orc Archer
(20447, 1797, 1, 1, -1, 259314), -- Recipe: Leather Stockings
(20447, 2138, 1, 1, -1, 37753), -- Recipe: Coarse Bone Powder (100%)
(20447, 1060, 1, 1, -1, 285245), -- Lesser Healing Potion
(20447, 57, 69, 94, 0, 700000), -- Adena
(20447, 14, 1, 1, 1, 789.869388), -- Bow
(20447, 2007, 1, 1, 1, 2708.130612), -- Bow Shaft
(20447, 1873, 1, 1, 2, 10110.924824), -- Silver Nugget
(20447, 1868, 1, 1, 2, 50554.689458), -- Thread
(20447, 1791, 1, 1, 2, 4672.385718), -- Recipe: Brandish
-- Utuku Orc Grunt
(20448, 1666, 1, 1, -1, 32439), -- Recipe: Wooden Arrow
(20448, 2006, 1, 1, -1, 6951), -- Willow Staff Head
(20448, 1789, 1, 1, -1, 17988), -- Recipe: Cedar Staff
(20448, 57, 51, 72, 0, 700000), -- Adena
(20448, 3, 1, 1, 1, 598.837512), -- Broadsword
(20448, 2005, 1, 1, 1, 2053.162488), -- Broadsword Blade
(20448, 1866, 1, 1, 2, 19164), -- Suede
(20448, 1871, 1, 1, 2, 28746), -- Charcoal
-- Will-O-Wisp
(20449, 1873, 1, 1, -1, 92414), -- Silver Nugget
(20449, 115, 1, 1, -1, 17114), -- Earring of Wisdom
(20449, 1896, 1, 1, -1, 97896), -- Necklace of Anguish Chain
(20449, 57, 116, 177, 0, 700000), -- Adena
(20449, 429, 1, 1, 1, 1115.08425), -- Leather Tunic
(20449, 1922, 1, 1, 1, 8704.38732), -- Leather Tunic Pattern
(20449, 464, 1, 1, 1, 1786.4379), -- Leather Stockings
(20449, 1923, 1, 1, 1, 13984.09053), -- Leather Stockings Pattern
(20449, 1873, 1, 1, 2, 18198.408555), -- Silver Nugget
(20449, 1868, 1, 1, 2, 90992.350365), -- Thread
(20449, 1798, 1, 1, 2, 44604.24108), -- Recipe: Leather Helmet
-- Relic Werewolf
(20450, 1870, 1, 1, -1, 124035), -- Coal
(20450, 1666, 1, 1, -1, 41345), -- Recipe: Wooden Arrow
(20450, 57, 67, 90, 0, 700000), -- Adena
(20450, 152, 1, 1, 1, 590.996927), -- Heavy Chisel
(20450, 5, 1, 1, 1, 381.685127), -- Mace
(20450, 8, 1, 1, 1, 381.685127), -- Willow Staff
(20450, 2006, 1, 1, 1, 1308.632819), -- Willow Staff Head
(20450, 1869, 1, 1, 2, 24425.32266), -- Iron Ore
(20450, 1864, 1, 1, 2, 48850.72578), -- Stem
(20450, 2135, 1, 1, 2, 7183.95156), -- Recipe: Braided Hemp
-- Doom Soldier
(20455, 1869, 1, 1, -1, 189449), -- Iron Ore
(20455, 1794, 1, 1, -1, 13930), -- Recipe: Forest Bow
(20455, 1896, 1, 1, -1, 80275), -- Necklace of Anguish Chain
(20455, 57, 97, 143, 0, 700000), -- Adena
(20455, 20, 1, 1, 1, 5229.661794), -- Buckler
(20455, 43, 1, 1, 1, 3657.338206), -- Wooden Helmet
(20455, 1868, 1, 1, 2, 74613.77445), -- Thread
(20455, 1873, 1, 1, 2, 14922.75489), -- Silver Nugget
(20455, 736, 1, 1, 2, 18653.47066), -- Scroll of Escape
-- Ashen Wolf
(20456, 1872, 1, 1, -1, 51475), -- Animal Bone
(20456, 1788, 1, 1, -1, 30885), -- Recipe: Bow
(20456, 1868, 1, 1, -1, 77212), -- Thread
(20456, 57, 19, 29, 0, 700000), -- Adena
(20456, 308, 1, 1, 1, 13530), -- Buffalo's Horn
(20456, 1868, 1, 1, 2, 19956.305542), -- Thread
(20456, 1873, 1, 1, 2, 3991.22838), -- Silver Nugget
(20456, 1788, 1, 1, 2, 7982.538581), -- Recipe: Bow
(20456, 17, 10, 30, 2, 49890.927497), -- Wooden Arrow
-- Zombie Soldier
(20457, 1866, 1, 1, -1, 195744), -- Suede
(20457, 2013, 1, 1, -1, 6337), -- Forest Bow Shaft
(20457, 1864, 1, 1, -1, 587232), -- Stem
(20457, 57, 138, 234, 0, 700000), -- Adena
(20457, 15, 1, 1, 1, 165.218784), -- Short Spear
(20457, 2011, 1, 1, 1, 1978.781216), -- Short Spear Edge
(20457, 1869, 1, 1, 2, 34691.766272), -- Iron Ore
(20457, 1864, 1, 1, 2, 69383.532544), -- Stem
(20457, 1880, 1, 1, 2, 3469.198698), -- Steel
(20457, 2254, 1, 1, 2, 1421.800936), -- Recipe: Composite Bow
(20457, 5273, 1, 1, 2, 1387.70155), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Zombie Warrior
(20458, 2256, 1, 1, -1, 10153), -- Recipe: Assassin Knife
(20458, 2176, 1, 1, -1, 198681), -- Recipe: Leather Boots
(20458, 1898, 1, 1, -1, 42655), -- Blue Diamond Necklace Gem
(20458, 57, 188, 339, 0, 700000), -- Adena
(20458, 846, 1, 1, 1, 997.234861), -- Coral Earring
(20458, 909, 1, 1, 1, 747.928531), -- Blue Diamond Necklace
(20458, 1898, 1, 1, 1, 6299.970005), -- Blue Diamond Necklace Gem
(20458, 878, 1, 1, 1, 1495.866603), -- Blue Coral Ring
(20458, 1869, 1, 1, 2, 35044.738992), -- Iron Ore
(20458, 1864, 1, 1, 2, 70089.477984), -- Stem
(20458, 1880, 1, 1, 2, 3504.429696), -- Steel
(20458, 1804, 1, 1, 2, 1401.830816), -- Recipe: Soulshot (D-Grade)
(20458, 5437, 1, 1, 2, 856.80536), -- Recipe: Heavy Sword(100%)
(20458, 5268, 1, 1, 2, 1401.830816), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20458, 6666, 1, 1, 2, 35044.886336), -- Deluxe Chest Key - Grade 2
-- Crimson Spider
(20460, 1833, 1, 1, -1, 629988), -- Bandage
(20460, 1866, 1, 1, -1, 157497), -- Suede
(20460, 1792, 1, 1, -1, 17371), -- Recipe: Short Spear
(20460, 57, 119, 180, 0, 700000), -- Adena
(20460, 66, 1, 1, 1, 223.71135), -- Gladius
(20460, 1333, 1, 1, 1, 223.71135), -- Brandish
(20460, 2010, 1, 1, 1, 1810.5773), -- Brandish Blade
(20460, 1867, 1, 1, 2, 62029.689849), -- Animal Skin
(20460, 1872, 1, 1, 2, 62029.689849), -- Animal Bone
(20460, 1799, 1, 1, 2, 68921.620302), -- Recipe: Leather Gloves
-- Dungeon Spider
(20461, 1803, 1, 1, -1, 165438), -- Recipe: Necklace of Wisdom
(20461, 2010, 1, 1, -1, 7660), -- Brandish Blade
(20461, 1896, 1, 1, -1, 83420), -- Necklace of Anguish Chain
(20461, 57, 99, 150, 0, 700000), -- Adena
(20461, 66, 1, 1, 1, 186.360075), -- Gladius
(20461, 1333, 1, 1, 1, 186.360075), -- Brandish
(20461, 2010, 1, 1, 1, 1508.27985), -- Brandish Blade
(20461, 1867, 1, 1, 2, 51691.284512), -- Animal Skin
(20461, 1872, 1, 1, 2, 51691.284512), -- Animal Bone
(20461, 1803, 1, 1, 2, 32578.430976), -- Recipe: Necklace of Wisdom
-- Cave Blade Spider
(20462, 1865, 1, 1, -1, 209166), -- Varnish
(20462, 1872, 1, 1, -1, 278888), -- Animal Bone
(20462, 1800, 1, 1, -1, 65776), -- Recipe: Piece Bone Breastplate
(20462, 57, 102, 164, 0, 700000), -- Adena
(20462, 256, 1, 1, 1, 235), -- Cestus
(20462, 1867, 1, 1, 2, 54919.581544), -- Animal Skin
(20462, 1872, 1, 1, 2, 54919.581544), -- Animal Bone
(20462, 1800, 1, 1, 2, 12952.836912), -- Recipe: Piece Bone Breastplate
-- Dungeon Skeleton Archer
(20463, 2010, 1, 1, -1, 7185), -- Brandish Blade
(20463, 1921, 1, 1, -1, 119134), -- Leather Shoes Texture
(20463, 1799, 1, 1, -1, 273567), -- Recipe: Leather Gloves
(20463, 57, 97, 137, 0, 700000), -- Adena
(20463, 271, 1, 1, 1, 524), -- Hunting Bow
(20463, 1864, 1, 1, 2, 72726.49462), -- Stem
(20463, 1869, 1, 1, 2, 36363.31968), -- Iron Ore
(20463, 1798, 1, 1, 2, 35650.1857), -- Recipe: Leather Helmet
-- Dungeon Skeleton
(20464, 464, 1, 1, -1, 9305), -- Leather Stockings
(20464, 1874, 1, 1, -1, 11849), -- Oriharukon Ore
(20464, 1870, 1, 1, -1, 177731), -- Coal
(20464, 57, 95, 131, 0, 700000), -- Adena
(20464, 9, 1, 1, 1, 168.22935), -- Cedar Staff
(20464, 2008, 1, 1, 1, 1361.5413), -- Cedar Staff Head
(20464, 154, 1, 1, 1, 168.22935), -- Dwarven Mace
(20464, 1870, 1, 1, 2, 34999.37811), -- Coal
(20464, 1865, 1, 1, 2, 34999.37811), -- Varnish
(20464, 1803, 1, 1, 2, 29411.24378), -- Recipe: Necklace of Wisdom
-- Pincer Spider
(20466, 1868, 1, 1, -1, 501999), -- Thread
(20466, 1897, 1, 1, -1, 59762), -- Necklace of Wisdom Chain
(20466, 734, 1, 1, -1, 41833), -- Haste Potion
(20466, 57, 122, 197, 0, 700000), -- Adena
(20466, 24, 1, 1, 1, 475.2134), -- Bone Breastplate
(20466, 390, 1, 1, 1, 475.2134), -- Cotton Shirt
(20466, 31, 1, 1, 1, 758.7866), -- Bone Gaiters
(20466, 412, 1, 1, 1, 758.7866), -- Cotton Pants
(20466, 1867, 1, 1, 2, 49427.823354), -- Animal Skin
(20466, 1872, 1, 1, 2, 49427.823354), -- Animal Bone
(20466, 1801, 1, 1, 2, 18675.557866), -- Recipe: Piece Bone Gaiters
(20466, 5158, 1, 1, 2, 1482.795426), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Kaboo Orc
(20468, 1814, 1, 1, -1, 40916), -- Recipe: Leather
(20468, 1790, 1, 1, -1, 14370), -- Recipe: Dirk
(20468, 2005, 1, 1, -1, 5553), -- Broadsword Blade
(20468, 57, 41, 58, 0, 700000), -- Adena
(20468, 99, 1, 1, 1, 957), -- Apprentice's Spellbook
(20468, 1869, 1, 1, 2, 15308.847872), -- Iron Ore
(20468, 1864, 1, 1, 2, 30617.79944), -- Stem
(20468, 1795, 1, 1, 2, 57769.352688), -- Recipe: Leather Shoes
-- Kaboo Orc Archer
(20469, 1864, 1, 1, -1, 256721), -- Stem
(20469, 2007, 1, 1, -1, 9169), -- Bow Shaft
(20469, 1666, 1, 1, -1, 42787), -- Recipe: Wooden Arrow
(20469, 57, 69, 94, 0, 700000), -- Adena
(20469, 14, 1, 1, 1, 789.869388), -- Bow
(20469, 2007, 1, 1, 1, 2708.130612), -- Bow Shaft
(20469, 1873, 1, 1, 2, 7583.157568), -- Silver Nugget
(20469, 1868, 1, 1, 2, 37915.452658), -- Thread
(20469, 1795, 1, 1, 2, 71538.564624), -- Recipe: Leather Shoes
(20469, 1833, 1, 1, 2, 50553.82515), -- Bandage
-- Kaboo Orc Grunt
(20470, 1791, 1, 1, -1, 17988), -- Recipe: Brandish
(20470, 1060, 1, 1, -1, 216259), -- Lesser Healing Potion
(20470, 2006, 1, 1, -1, 6951), -- Willow Staff Head
(20470, 57, 51, 72, 0, 700000), -- Adena
(20470, 19, 1, 1, 1, 11732.93531), -- Small Shield
(20470, 42, 1, 1, 1, 8213.06469), -- Leather Cap
(20470, 1869, 1, 1, 2, 14372.956064), -- Iron Ore
(20470, 1864, 1, 1, 2, 28745.960672), -- Stem
(20470, 2135, 1, 1, 2, 4227.357152), -- Recipe: Braided Hemp
(20470, 735, 1, 1, 2, 1197.726112), -- Alacrity Potion
-- Kaboo Orc Fighter
(20471, 1797, 1, 1, -1, 367589), -- Recipe: Leather Stockings
(20471, 428, 1, 1, -1, 19461), -- Feriotic Tunic
(20471, 1869, 1, 1, -1, 181957), -- Iron Ore
(20471, 57, 98, 132, 0, 700000), -- Adena
(20471, 3, 1, 1, 1, 1119.771954), -- Broadsword
(20471, 2005, 1, 1, 1, 3839.228046), -- Broadsword Blade
(20471, 1869, 1, 1, 2, 35831.4), -- Iron Ore
(20471, 1864, 1, 1, 2, 71662.8), -- Stem
(20471, 1666, 1, 1, 2, 11943.8), -- Recipe: Wooden Arrow
-- Kaboo Orc Fighter Leader
(20472, 1867, 1, 1, -1, 284370), -- Animal Skin
(20472, 1864, 1, 1, -1, 426554), -- Stem
(20472, 1922, 1, 1, -1, 54407), -- Leather Tunic Pattern
(20472, 57, 114, 157, 0, 700000), -- Adena
(20472, 66, 1, 1, 1, 201.91485), -- Gladius
(20472, 1333, 1, 1, 1, 201.91485), -- Brandish
(20472, 2010, 1, 1, 1, 1634.1703), -- Brandish Blade
(20472, 1869, 1, 1, 2, 41999.100858), -- Iron Ore
(20472, 1864, 1, 1, 2, 83998.348713), -- Stem
(20472, 736, 1, 1, 2, 20999.550429), -- Scroll of Escape
-- Kaboo Orc Fighter Lieutenant
(20473, 23, 1, 1, -1, 6588), -- Wooden Breastplate
(20473, 1831, 1, 1, -1, 537542), -- Antidote
(20473, 1896, 1, 1, -1, 85415), -- Necklace of Anguish Chain
(20473, 57, 109, 147, 0, 700000), -- Adena
(20473, 9, 1, 1, 1, 190.81845), -- Cedar Staff
(20473, 2008, 1, 1, 1, 1544.3631), -- Cedar Staff Head
(20473, 154, 1, 1, 1, 190.81845), -- Dwarven Mace
(20473, 1869, 1, 1, 2, 39695.424795), -- Iron Ore
(20473, 1864, 1, 1, 2, 79390.84959), -- Stem
(20473, 1792, 1, 1, 2, 2918.725615), -- Recipe: Short Spear
-- Kasha Spider
(20474, 1866, 1, 1, -1, 154409), -- Suede
(20474, 1799, 1, 1, -1, 343131), -- Recipe: Leather Gloves
(20474, 1792, 1, 1, -1, 17030), -- Recipe: Short Spear
(20474, 57, 116, 177, 0, 700000), -- Adena
(20474, 216, 1, 1, 1, 328.91945), -- Dirk
(20474, 2009, 1, 1, 1, 2426.08055), -- Dirk Blade
(20474, 1869, 1, 1, 2, 22805.004222), -- Iron Ore
(20474, 1870, 1, 1, 2, 22805.004222), -- Coal
(20474, 1871, 1, 1, 2, 22805.004222), -- Charcoal
(20474, 1872, 1, 1, 2, 30406.672296), -- Animal Bone
(20474, 1867, 1, 1, 2, 30406.672296), -- Animal Skin
(20474, 736, 1, 1, 2, 11402.642742), -- Scroll of Escape
-- Kasha Wolf
(20475, 426, 1, 1, -1, 68329), -- Tunic
(20475, 1786, 1, 1, -1, 30885), -- Recipe: Broad Sword
(20475, 1873, 1, 1, -1, 15442), -- Silver Nugget
(20475, 57, 19, 29, 0, 700000), -- Adena
(20475, 253, 1, 1, 1, 13530), -- Spiked Gloves
(20475, 1868, 1, 1, 2, 26608.75), -- Thread
(20475, 1873, 1, 1, 2, 5321.75), -- Silver Nugget
(20475, 1786, 1, 1, 2, 10643.5), -- Recipe: Broad Sword
-- Kasha Fang Spider
(20476, 1866, 1, 1, -1, 158377), -- Suede
(20476, 945, 1, 1, -1, 17997), -- Skeleton Buckler
(20476, 5549, 1, 1, -1, 23757), -- Metallic Thread
(20476, 57, 118, 183, 0, 700000), -- Adena
(20476, 2, 1, 1, 1, 66.798319), -- Long Sword
(20476, 120, 1, 1, 1, 66.798319), -- Sword of Reflection
(20476, 2012, 1, 1, 1, 730.605043), -- Sword of Reflection Blade
(20476, 121, 1, 1, 1, 66.798319), -- Sword of Watershadow
(20476, 1868, 1, 1, 2, 70173.35463), -- Thread
(20476, 1873, 1, 1, 2, 14034.690255), -- Silver Nugget
(20476, 1800, 1, 1, 2, 11033.57307), -- Recipe: Piece Bone Breastplate
(20476, 5273, 1, 1, 2, 1403.382045), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Kasha Timber Wolf
(20477, 1872, 1, 1, -1, 102628), -- Animal Bone
(20477, 906, 1, 1, -1, 18547), -- Necklace of Knowledge
(20477, 1060, 1, 1, -1, 171046), -- Lesser Healing Potion
(20477, 57, 41, 58, 0, 700000), -- Adena
(20477, 12, 1, 1, 1, 473.5), -- Knife
(20477, 215, 1, 1, 1, 473.5), -- Doom Dagger
(20477, 1866, 1, 1, 2, 7578.695835), -- Suede
(20477, 1871, 1, 1, 2, 11368.075533), -- Charcoal
(20477, 1796, 1, 1, 2, 14299.445292), -- Recipe: Leather Tunic
(20477, 1833, 1, 1, 2, 30314.78334), -- Bandage
-- Kasha Blade Spider
(20478, 1801, 1, 1, -1, 136366), -- Recipe: Piece Bone Gaiters
(20478, 735, 1, 1, -1, 22557), -- Alacrity Potion
(20478, 1897, 1, 1, -1, 64449), -- Necklace of Wisdom Chain
(20478, 57, 132, 212, 0, 700000), -- Adena
(20478, 217, 1, 1, 1, 152.5), -- Shining Knife
(20478, 218, 1, 1, 1, 152.5), -- Throwing Knife
(20478, 1869, 1, 1, 2, 26652.16661), -- Iron Ore
(20478, 1864, 1, 1, 2, 53304.33322), -- Stem
(20478, 1817, 1, 1, 2, 5330.390945), -- Recipe: Cord
(20478, 6037, 1, 1, 2, 53304.33322), -- Waking Scroll
(20478, 735, 1, 1, 2, 2220.97857), -- Alacrity Potion
(20478, 1831, 1, 1, 2, 71072.797435), -- Antidote
-- Kasha Bear
(20479, 1793, 1, 1, -1, 17199), -- Recipe: Sword of Reflection
(20479, 1922, 1, 1, -1, 59670), -- Leather Tunic Pattern
(20479, 1792, 1, 1, -1, 17199), -- Recipe: Short Spear
(20479, 57, 118, 179, 0, 700000), -- Adena
(20479, 9, 1, 1, 1, 221.432625), -- Cedar Staff
(20479, 2008, 1, 1, 1, 1792.13475), -- Cedar Staff Head
(20479, 154, 1, 1, 1, 221.432625), -- Dwarven Mace
(20479, 1872, 1, 1, 2, 46061.6742), -- Animal Bone
(20479, 1867, 1, 1, 2, 46061.6742), -- Animal Skin
(20479, 1792, 1, 1, 2, 2540.116413), -- Recipe: Short Spear
(20479, 1833, 1, 1, 2, 92123.535187), -- Bandage
-- Blade Bat
(20480, 1864, 1, 1, -1, 356778), -- Stem
(20480, 2007, 1, 1, -1, 12742), -- Bow Shaft
(20480, 2005, 1, 1, -1, 12742), -- Broadsword Blade
(20480, 57, 96, 130, 0, 700000), -- Adena
(20480, 22, 1, 1, 1, 5635.622124), -- Leather Shirt
(20480, 29, 1, 1, 1, 9007.377876), -- Leather Pants
(20480, 1864, 1, 1, 2, 70257.73112), -- Stem
(20480, 1869, 1, 1, 2, 35128.86556), -- Iron Ore
(20480, 1789, 1, 1, 2, 6493.40332), -- Recipe: Cedar Staff
-- Bearded Keltir
(20481, 1788, 1, 1, -1, 12736), -- Recipe: Bow
(20481, 1786, 1, 1, -1, 12736), -- Recipe: Broad Sword
(20481, 1868, 1, 1, -1, 31839), -- Thread
(20481, 57, 8, 12, 0, 700000), -- Adena
(20481, 426, 1, 1, 1, 14565.04902), -- Tunic
(20481, 462, 1, 1, 1, 23180.95098), -- Stockings
(20481, 1868, 1, 1, 2, 8229.25348), -- Thread
(20481, 1873, 1, 1, 2, 1645.8372), -- Silver Nugget
(20481, 1786, 1, 1, 2, 3291.70814), -- Recipe: Broad Sword
(20481, 17, 10, 30, 2, 20573.20118), -- Wooden Arrow
-- Corpse Candle
(20483, 1868, 1, 1, -1, 490926), -- Thread
(20483, 1833, 1, 1, -1, 654568), -- Bandage
(20483, 57, 120, 192, 0, 700000), -- Adena
(20483, 845, 1, 1, 1, 1060.046598), -- Cat's Eye Earring
(20483, 908, 1, 1, 1, 795.040987), -- Necklace of Wisdom
(20483, 1897, 1, 1, 1, 8631.842518), -- Necklace of Wisdom Chain
(20483, 877, 1, 1, 1, 1590.069897), -- Ring of Wisdom
(20483, 1864, 1, 1, 2, 41432.064125), -- Stem
(20483, 1865, 1, 1, 2, 20715.966738), -- Varnish
(20483, 1866, 1, 1, 2, 13810.644492), -- Suede
(20483, 1873, 1, 1, 2, 8286.412825), -- Silver Nugget
(20483, 1868, 1, 1, 2, 41432.064125), -- Thread
(20483, 2139, 1, 1, 2, 4143.141088), -- Recipe: Steel Mold
(20483, 5268, 1, 1, 2, 828.706607), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Kuruka Ratman
(20487, 2136, 1, 1, -1, 58227), -- Recipe: Cokes
(20487, 1060, 1, 1, -1, 439936), -- Lesser Healing Potion
(20487, 1897, 1, 1, -1, 47136), -- Necklace of Wisdom Chain
(20487, 57, 98, 153, 0, 700000), -- Adena
(20487, 217, 1, 1, 1, 111.5), -- Shining Knife
(20487, 218, 1, 1, 1, 111.5), -- Throwing Knife
(20487, 1870, 1, 1, 2, 38985.22495), -- Coal
(20487, 1865, 1, 1, 2, 38985.22495), -- Varnish
(20487, 1800, 1, 1, 2, 12259.5501), -- Recipe: Piece Bone Breastplate
-- Kuruka Ratman Hunter
(20488, 734, 1, 1, -1, 34178), -- Haste Potion
(20488, 412, 1, 1, -1, 4198), -- Cotton Pants
(20488, 1800, 1, 1, -1, 64486), -- Recipe: Piece Bone Breastplate
(20488, 57, 100, 161, 0, 700000), -- Adena
(20488, 256, 1, 1, 1, 231), -- Cestus
(20488, 1869, 1, 1, 2, 40382.1875), -- Iron Ore
(20488, 1864, 1, 1, 2, 80764.375), -- Stem
(20488, 2140, 1, 1, 2, 8076.4375), -- Recipe: High-Grade Suede
-- Quicksilver Beast
(20489, 1060, 1, 1, -1, 433160), -- Lesser Healing Potion
(20489, 1872, 1, 1, -1, 259896), -- Animal Bone
(20489, 1896, 1, 1, -1, 82594), -- Necklace of Anguish Chain
(20489, 57, 98, 149, 0, 700000), -- Adena
(20489, 429, 1, 1, 1, 940.78425), -- Leather Tunic
(20489, 1922, 1, 1, 1, 7343.79532), -- Leather Tunic Pattern
(20489, 464, 1, 1, 1, 1507.1979), -- Leather Stockings
(20489, 1923, 1, 1, 1, 11798.22253), -- Leather Stockings Pattern
(20489, 1868, 1, 1, 2, 76769.632706), -- Thread
(20489, 1873, 1, 1, 2, 15353.907552), -- Silver Nugget
(20489, 1793, 1, 1, 2, 2822.459742), -- Recipe: Sword of Reflection
-- Crypt Horror
(20491, 1794, 1, 1, -1, 14476), -- Recipe: Forest Bow
(20491, 876, 1, 1, -1, 21875), -- Ring of Anguish
(20491, 1803, 1, 1, -1, 165438), -- Recipe: Necklace of Wisdom
(20491, 57, 99, 150, 0, 700000), -- Adena
(20491, 37, 1, 1, 1, 3800.868174), -- Leather Shoes
(20491, 1921, 1, 1, 1, 25012.231038), -- Leather Shoes Texture
(20491, 49, 1, 1, 1, 3800.900788), -- Gloves
(20491, 1866, 1, 1, 2, 25845.774035), -- Suede
(20491, 1871, 1, 1, 2, 38768.62732), -- Charcoal
(20491, 1794, 1, 1, 2, 2850.598645), -- Recipe: Forest Bow
-- Kirunak's Guards
(20492, 1879, 1, 1, -1, 47461), -- Cokes
(20492, 25, 1, 1, -1, 2327), -- Piece Bone Breastplate
(20492, 1865, 1, 1, -1, 284768), -- Varnish
(20492, 57, 130, 231, 0, 700000), -- Adena
(20492, 27, 1, 1, 1, 296.171659), -- Hard Leather Shirt
(20492, 1927, 1, 1, 1, 3355.070918), -- Hard Leather Shirt Pattern
(20492, 33, 1, 1, 1, 475.204432), -- Hard Leather Gaiters
(20492, 1929, 1, 1, 1, 5426.552991), -- Hard Leather Gaiters Material
(20492, 1865, 1, 1, 2, 33646.376214), -- Varnish
(20492, 1870, 1, 1, 2, 33646.376214), -- Coal
(20492, 1879, 1, 1, 2, 5607.729369), -- Cokes
(20492, 5278, 1, 1, 2, 1345.837032), -- Recipe: Greater Blessed Spiritshot (D) Compressed Package(100%)
(20492, 5437, 1, 1, 2, 822.681171), -- Recipe: Heavy Sword(100%)
-- Turek War Hound
(20494, 1881, 1, 1, -1, 99048), -- Coarse Bone Powder
(20494, 2179, 1, 1, -1, 355437), -- Recipe: Crafted Leather Gloves
(20494, 1804, 1, 1, -1, 29714), -- Recipe: Soulshot (D-Grade)
(20494, 57, 330, 609, 0, 700000), -- Adena
(20494, 257, 1, 1, 1, 467), -- Viper Fang
(20494, 1871, 1, 1, 2, 87772.020798), -- Charcoal
(20494, 1866, 1, 1, 2, 58514.733618), -- Suede
(20494, 2258, 1, 1, 2, 2146.00155), -- Recipe: Temptation of Abyss
(20494, 5268, 1, 1, 2, 3510.84261), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20494, 735, 1, 1, 2, 7314.401424), -- Alacrity Potion
-- Turek Orc Warlord
(20495, 2267, 1, 1, -1, 11668), -- Recipe: Gastraphetes
(20495, 1936, 1, 1, -1, 92328), -- White Tunic Pattern
(20495, 1900, 1, 1, -1, 123441), -- Enchanted Necklace Chain
(20495, 57, 476, 952, 0, 700000), -- Adena
(20495, 69, 1, 1, 1, 49.770308), -- Bastard Sword
(20495, 125, 1, 1, 1, 49.770308), -- Spinebone Sword
(20495, 2021, 1, 1, 1, 1556.915256), -- Spinebone Sword Blade
(20495, 126, 1, 1, 1, 49.770308), -- Artisan's Sword
(20495, 128, 1, 1, 1, 49.77382), -- Knight's Sword
(20495, 1875, 1, 1, 2, 4566.991248), -- Stone of Purity
(20495, 1879, 1, 1, 2, 11417.438544), -- Cokes
(20495, 1885, 1, 1, 2, 5708.679696), -- High-Grade Suede
(20495, 5550, 1, 1, 2, 913.41408), -- Durable Metal Plate
(20495, 5549, 1, 1, 2, 6850.447296), -- Metallic Thread
(20495, 955, 1, 1, 2, 274.024224), -- Scroll: Enchant Weapon (D-Grade)
(20495, 2274, 1, 1, 2, 489.317664), -- Recipe: Skull Breaker
(20495, 2975, 1, 1, 2, 6116.4708), -- Recipe: Brigandine Helmet
(20495, 6667, 1, 1, 2, 42815.216448), -- Deluxe Chest Key - Grade 3
-- Turek Orc Archer
(20496, 1885, 1, 1, -1, 74420), -- High-Grade Suede
(20496, 465, 1, 1, -1, 5934), -- Cursed Stockings
(20496, 2152, 1, 1, -1, 157224), -- Recipe: Enchanted Necklace
(20496, 57, 386, 743, 0, 700000), -- Adena
(20496, 274, 1, 1, 1, 318), -- Reinforced Bow
(20496, 1876, 1, 1, 2, 14319.932005), -- Mithril Ore
(20496, 1880, 1, 1, 2, 7160.027259), -- Steel
(20496, 1877, 1, 1, 2, 2863.986401), -- Adamantite Nugget
(20496, 1881, 1, 1, 2, 9546.580499), -- Coarse Bone Powder
(20496, 1882, 1, 1, 2, 15911.008336), -- Leather
(20496, 2260, 1, 1, 2, 1111.805475), -- Recipe: Mace of Judgment
(20496, 6666, 1, 1, 2, 71599.660025), -- Deluxe Chest Key - Grade 2
-- Turek Orc Skirmisher
(20497, 2259, 1, 1, -1, 14293), -- Recipe: Spinebone Sword
(20497, 2018, 1, 1, -1, 12232), -- Assassin Knife Edge
(20497, 1899, 1, 1, -1, 143825), -- Necklace of Devotion Chain
(20497, 57, 395, 773, 0, 700000), -- Adena
(20497, 391, 1, 1, 1, 1071.760172), -- Puma Skin Shirt
(20497, 413, 1, 1, 1, 1716.239828), -- Puma Skin Gaiters
(20497, 1874, 1, 1, 2, 5740.05696), -- Oriharukon Ore
(20497, 1878, 1, 1, 2, 34440.134388), -- Braided Hemp
(20497, 1884, 1, 1, 2, 52984.790232), -- Cord
(20497, 1889, 1, 1, 2, 5740.05696), -- Compound Braid
(20497, 5220, 1, 1, 2, 3444.034176), -- Metal Hardener
(20497, 2261, 1, 1, 2, 1336.927284), -- Recipe: Conjuror's Staff
-- Turek Orc Supplier
(20498, 2262, 1, 1, -1, 13331), -- Recipe: Elven Bow
(20498, 3953, 1, 1, -1, 34341), -- Recipe: Blessed Spiritshot D
(20498, 1885, 1, 1, -1, 71544), -- High-Grade Suede
(20498, 57, 371, 714, 0, 700000), -- Adena
(20498, 626, 1, 1, 1, 1900.693228), -- Bronze Shield
(20498, 45, 1, 1, 1, 1332.846619), -- Bone Helmet
(20498, 1932, 1, 1, 1, 25493.460153), -- Bone Helmet Design
(20498, 1875, 1, 1, 2, 5353.64103), -- Stone of Purity
(20498, 1879, 1, 1, 2, 13384.120464), -- Cokes
(20498, 1885, 1, 1, 2, 6692.060232), -- High-Grade Suede
(20498, 5550, 1, 1, 2, 1070.728206), -- Durable Metal Plate
(20498, 5549, 1, 1, 2, 8030.479434), -- Metallic Thread
(20498, 2261, 1, 1, 2, 1246.970634), -- Recipe: Conjuror's Staff
-- Turek Orc Footman
(20499, 1870, 1, 1, -1, 822258), -- Coal
(20499, 2017, 1, 1, -1, 10927), -- Saber Blade
(20499, 1880, 1, 1, -1, 82226), -- Steel
(20499, 57, 357, 682, 0, 700000), -- Adena
(20499, 40, 1, 1, 1, 1433.150976), -- Leather Boots
(20499, 1931, 1, 1, 1, 15080.849024), -- Leather Boots Lining
(20499, 604, 1, 1, 1, 1433.150976), -- Crafted Leather Gloves
(20499, 1934, 1, 1, 1, 15080.849024), -- Crafted Leather Gloves Lining
(20499, 1876, 1, 1, 2, 15382.46241), -- Mithril Ore
(20499, 1880, 1, 1, 2, 7691.26257), -- Steel
(20499, 1877, 1, 1, 2, 3076.46739), -- Adamantite Nugget
(20499, 1881, 1, 1, 2, 10254.97494), -- Coarse Bone Powder
(20499, 1882, 1, 1, 2, 17091.66672), -- Leather
(20499, 2182, 1, 1, 2, 9233.16597), -- Recipe: Scale Gaiters
-- Turek Orc Sentinel
(20500, 1867, 1, 3, -1, 520412), -- Animal Skin
(20500, 1932, 1, 1, -1, 123908), -- Bone Helmet Design
(20500, 1931, 1, 1, -1, 102042), -- Leather Boots Lining
(20500, 57, 344, 644, 0, 700000), -- Adena
(20500, 847, 1, 1, 1, 1058.232864), -- Red Crescent Earring
(20500, 910, 1, 1, 1, 793.674648), -- Necklace of Devotion
(20500, 1899, 1, 1, 1, 17113.722639), -- Necklace of Devotion Chain
(20500, 890, 1, 1, 1, 1587.369849), -- Ring of Devotion
(20500, 1874, 1, 1, 2, 7301.729204), -- Oriharukon Ore
(20500, 1878, 1, 1, 2, 43810.489612), -- Braided Hemp
(20500, 5220, 1, 1, 2, 4381.0604), -- Metal Hardener
(20500, 2262, 1, 1, 2, 1700.720784), -- Recipe: Elven Bow
-- Turek Orc Shaman
(20501, 1870, 1, 1, -1, 944489), -- Coal
(20501, 1933, 1, 1, -1, 111116), -- Dark Stockings Fabric
(20501, 2153, 1, 1, -1, 146888), -- Recipe: Tiger's Eye Earring
(20501, 57, 400, 793, 0, 700000), -- Adena
(20501, 433, 1, 1, 1, 167.79194), -- Elven Tunic
(20501, 434, 1, 1, 1, 167.79194), -- White Tunic
(20501, 1936, 1, 1, 1, 5279.73866), -- White Tunic Pattern
(20501, 435, 1, 1, 1, 167.79194), -- Mystic's Tunic
(20501, 466, 1, 1, 1, 268.82444), -- Elven Stockings
(20501, 467, 1, 1, 1, 268.82444), -- Dark Stockings
(20501, 1933, 1, 1, 1, 7590.39802), -- Dark Stockings Fabric
(20501, 468, 1, 1, 1, 268.83862), -- Mystic's Stockings
(20501, 1875, 1, 1, 2, 4915.479114), -- Stone of Purity
(20501, 1879, 1, 1, 2, 12288.714282), -- Cokes
(20501, 1885, 1, 1, 2, 6144.340644), -- High-Grade Suede
(20501, 5550, 1, 1, 2, 983.089224), -- Durable Metal Plate
(20501, 5549, 1, 1, 2, 7373.235168), -- Metallic Thread
(20501, 2264, 1, 1, 2, 762.49134), -- Recipe: Two-handed Sword
(20501, 2274, 1, 1, 2, 526.650228), -- Recipe: Skull Breaker
-- Twink Puma
(20502, 1871, 1, 1, -1, 233906), -- Charcoal
(20502, 1896, 1, 1, -1, 99113), -- Necklace of Anguish Chain
(20502, 1923, 1, 1, -1, 95863), -- Leather Stockings Pattern
(20502, 57, 118, 179, 0, 700000), -- Adena
(20502, 23, 1, 1, 1, 1505.165424), -- Wooden Breastplate
(20502, 30, 1, 1, 1, 2411.417288), -- Hard Leather Pants
(20502, 2386, 1, 1, 1, 2411.417288), -- Wooden Gaiters
(20502, 1868, 1, 1, 2, 92122.987782), -- Thread
(20502, 1873, 1, 1, 2, 18424.535274), -- Silver Nugget
(20502, 1798, 1, 1, 2, 45158.476944), -- Recipe: Leather Helmet
-- Dread Soldier
(20504, 2010, 1, 1, -1, 7372), -- Brandish Blade
(20504, 1792, 1, 1, -1, 13930), -- Recipe: Short Spear
(20504, 1921, 1, 1, -1, 122225), -- Leather Shoes Texture
(20504, 57, 97, 143, 0, 700000), -- Adena
(20504, 20, 1, 1, 1, 5229.661794), -- Buckler
(20504, 43, 1, 1, 1, 3657.338206), -- Wooden Helmet
(20504, 1870, 1, 1, 2, 37306.96039), -- Coal
(20504, 1865, 1, 1, 2, 37306.96039), -- Varnish
(20504, 1792, 1, 1, 2, 2743.07922), -- Recipe: Short Spear
-- Ruin Bat
(20505, 734, 1, 1, -1, 45036), -- Haste Potion
(20505, 1800, 1, 1, -1, 84973), -- Recipe: Piece Bone Breastplate
(20505, 1869, 1, 1, -1, 270215), -- Iron Ore
(20505, 57, 125, 217, 0, 700000), -- Adena
(20505, 217, 1, 1, 1, 152), -- Shining Knife
(20505, 218, 1, 1, 1, 152), -- Throwing Knife
(20505, 1864, 1, 1, 2, 63853.898514), -- Stem
(20505, 1869, 1, 1, 2, 31926.89115), -- Iron Ore
(20505, 1878, 1, 1, 2, 12770.75646), -- Braided Hemp
(20505, 1817, 1, 1, 2, 6385.37823), -- Recipe: Cord
(20505, 5273, 1, 1, 2, 1277.075646), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Ruin Imp
(20506, 2150, 1, 1, -1, 115530), -- Recipe: Blue Diamond Necklace
(20506, 1924, 1, 1, -1, 79380), -- Leather Helmet Design
(20506, 1864, 1, 1, -1, 492156), -- Stem
(20506, 57, 120, 193, 0, 700000), -- Adena
(20506, 24, 1, 1, 1, 465.971), -- Bone Breastplate
(20506, 390, 1, 1, 1, 465.971), -- Cotton Shirt
(20506, 31, 1, 1, 1, 744.029), -- Bone Gaiters
(20506, 412, 1, 1, 1, 744.029), -- Cotton Pants
(20506, 1864, 1, 1, 2, 72687.660136), -- Stem
(20506, 1869, 1, 1, 2, 36343.830068), -- Iron Ore
(20506, 2141, 1, 1, 2, 7268.718912), -- Recipe: Silver Mold
(20506, 5273, 1, 1, 2, 1453.790884), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Ruin Imp Elder
(20507, 3032, 1, 1, -1, 13942), -- Recipe: Spiritshot D
(20507, 1866, 1, 1, -1, 232371), -- Suede
(20507, 1898, 1, 1, -1, 35804), -- Blue Diamond Necklace Gem
(20507, 57, 159, 283, 0, 700000), -- Adena
(20507, 273, 1, 1, 1, 109.525416), -- Composite Bow
(20507, 2016, 1, 1, 1, 1206.474584), -- Composite Bow Shaft
(20507, 1864, 1, 1, 2, 82366.143021), -- Stem
(20507, 1869, 1, 1, 2, 41182.999852), -- Iron Ore
(20507, 1878, 1, 1, 2, 16473.285931), -- Braided Hemp
(20507, 1804, 1, 1, 2, 1647.285598), -- Recipe: Soulshot (D-Grade)
(20507, 5273, 1, 1, 2, 1647.285598), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
-- Plunder Tarantula
(20508, 1866, 1, 1, -1, 167333), -- Suede
(20508, 1800, 1, 1, -1, 78931), -- Recipe: Piece Bone Breastplate
(20508, 57, 122, 197, 0, 700000), -- Adena
(20508, 1101, 1, 1, 1, 950.429268), -- Tunic of Devotion
(20508, 1104, 1, 1, 1, 1517.570732), -- Stockings of Devotion
(20508, 1867, 1, 1, 2, 65903.681388), -- Animal Skin
(20508, 1872, 1, 1, 2, 65903.681388), -- Animal Bone
(20508, 2142, 1, 1, 2, 9885.637224), -- Recipe: Varnish of Purity
-- Spore Fungus
(20509, 1060, 1, 1, -1, 330759), -- Lesser Healing Potion
(20509, 1129, 1, 1, -1, 63337), -- Crude Leather Shoes
(20509, 2005, 1, 1, -1, 10632), -- Broadsword Blade
(20509, 57, 80, 108, 0, 700000), -- Adena
(20509, 428, 1, 1, 1, 2351.158612), -- Feriotic Tunic
(20509, 1100, 1, 1, 1, 2351.158612), -- Cotton Tunic
(20509, 463, 1, 1, 1, 3757.841388), -- Feriotic Stockings
(20509, 1103, 1, 1, 1, 3757.841388), -- Cotton Stockings
(20509, 1864, 1, 1, 2, 43965.66228), -- Stem
(20509, 1869, 1, 1, 2, 21982.739976), -- Iron Ore
(20509, 2136, 1, 1, 2, 6465.533208), -- Recipe: Cokes
(20509, 17, 10, 30, 2, 109914.064536), -- Wooden Arrow
-- Puma
(20510, 1798, 1, 1, -1, 202966), -- Recipe: Leather Helmet
(20510, 1923, 1, 1, -1, 84846), -- Leather Stockings Pattern
(20510, 1792, 1, 1, -1, 15222), -- Recipe: Short Spear
(20510, 57, 110, 152, 0, 700000), -- Adena
(20510, 23, 1, 1, 1, 1332.242658), -- Wooden Breastplate
(20510, 30, 1, 1, 1, 2134.378671), -- Hard Leather Pants
(20510, 2386, 1, 1, 1, 2134.378671), -- Wooden Gaiters
(20510, 1868, 1, 1, 2, 81536.099801), -- Thread
(20510, 1873, 1, 1, 2, 16307.199792), -- Silver Nugget
(20510, 1792, 1, 1, 2, 2997.700407), -- Recipe: Short Spear
-- Pitchstone Golem
(20511, 734, 1, 1, -1, 40780), -- Haste Potion
(20511, 2144, 1, 1, -1, 48936), -- Recipe: Compound Braid
(20511, 1897, 1, 1, -1, 58257), -- Necklace of Wisdom Chain
(20511, 57, 115, 195, 0, 700000), -- Adena
(20511, 176, 1, 1, 1, 137.5), -- Apprentice's Staff
(20511, 2501, 1, 1, 1, 137.5), -- Bone Club
(20511, 1869, 1, 1, 2, 20649.965745), -- Iron Ore
(20511, 1870, 1, 1, 2, 20649.965745), -- Coal
(20511, 1871, 1, 1, 2, 20649.965745), -- Charcoal
(20511, 1872, 1, 1, 2, 27533.28766), -- Animal Bone
(20511, 1867, 1, 1, 2, 27533.28766), -- Animal Skin
(20511, 1800, 1, 1, 2, 6493.728274), -- Recipe: Piece Bone Breastplate
(20511, 735, 1, 1, 2, 1720.799171), -- Alacrity Potion
-- Shield Skeleton
(20514, 1872, 1, 1, -1, 308818), -- Animal Bone
(20514, 1870, 1, 1, -1, 231613), -- Coal
(20514, 57, 116, 177, 0, 700000), -- Adena
(20514, 20, 1, 1, 1, 6393.63963), -- Buckler
(20514, 43, 1, 1, 1, 4471.36037), -- Wooden Helmet
(20514, 1870, 1, 1, 2, 34207.532928), -- Coal
(20514, 1865, 1, 1, 2, 34207.532928), -- Varnish
(20514, 1799, 1, 1, 2, 50677.720254), -- Recipe: Leather Gloves
(20514, 734, 1, 1, 2, 5701.21389), -- Haste Potion
-- Skeleton Infantryman
(20515, 735, 1, 1, -1, 19797), -- Alacrity Potion
(20515, 2013, 1, 1, -1, 5127), -- Forest Bow Shaft
(20515, 1865, 1, 1, -1, 237565), -- Varnish
(20515, 57, 118, 183, 0, 700000), -- Adena
(20515, 15, 1, 1, 1, 133.700835), -- Short Spear
(20515, 2011, 1, 1, 1, 1601.299165), -- Short Spear Edge
(20515, 1870, 1, 1, 2, 35086.782348), -- Coal
(20515, 1865, 1, 1, 2, 35086.782348), -- Varnish
(20515, 1801, 1, 1, 2, 17675.931879), -- Recipe: Piece Bone Gaiters
(20515, 5158, 1, 1, 2, 1403.503425), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Skeleton Hunter
(20517, 1831, 1, 1, -1, 473949), -- Antidote
(20517, 1921, 1, 1, -1, 114665), -- Leather Shoes Texture
(20517, 1869, 1, 1, -1, 177731), -- Iron Ore
(20517, 57, 95, 131, 0, 700000), -- Adena
(20517, 271, 1, 1, 1, 505), -- Hunting Bow
(20517, 1869, 1, 1, 2, 26249.44017), -- Iron Ore
(20517, 1864, 1, 1, 2, 52498.88034), -- Stem
(20517, 1793, 1, 1, 2, 1930.17237), -- Recipe: Sword of Reflection
(20517, 1833, 1, 1, 2, 69998.50712), -- Bandage
-- Skeleton Hunter Archer
(20518, 1866, 1, 1, -1, 123105), -- Suede
(20518, 1864, 1, 1, -1, 369315), -- Stem
(20518, 1831, 1, 1, -1, 492420), -- Antidote
(20518, 57, 97, 137, 0, 700000), -- Adena
(20518, 271, 1, 1, 1, 524), -- Hunting Bow
(20518, 1870, 1, 1, 2, 36363.249932), -- Coal
(20518, 1865, 1, 1, 2, 36363.249932), -- Varnish
(20518, 1799, 1, 1, 2, 53871.500136), -- Recipe: Leather Gloves
-- Whinstone Golem
(20521, 2143, 1, 1, -1, 50113), -- Recipe: Synthetic Cokes
(20521, 1897, 1, 1, -1, 59658), -- Necklace of Wisdom Chain
(20521, 1896, 1, 1, -1, 106171), -- Necklace of Anguish Chain
(20521, 57, 128, 189, 0, 700000), -- Adena
(20521, 9, 1, 1, 1, 237.18555), -- Cedar Staff
(20521, 2008, 1, 1, 1, 1919.6289), -- Cedar Staff Head
(20521, 154, 1, 1, 1, 237.18555), -- Dwarven Mace
(20521, 1866, 1, 1, 2, 24670.861524), -- Suede
(20521, 1871, 1, 1, 2, 37006.362852), -- Charcoal
(20521, 1793, 1, 1, 2, 2721.02496), -- Recipe: Sword of Reflection
(20521, 734, 1, 1, 2, 6167.750664), -- Haste Potion
-- Gray Wolf
(20525, 1867, 1, 1, -1, 51475), -- Animal Skin
(20525, 1872, 1, 1, -1, 51475), -- Animal Bone
(20525, 5549, 1, 1, -1, 3861), -- Metallic Thread
(20525, 57, 19, 29, 0, 700000), -- Adena
(20525, 1, 1, 1, 1, 13530), -- Short Sword
(20525, 1868, 1, 1, 2, 19956.368608), -- Thread
(20525, 1873, 1, 1, 2, 3991.25208), -- Silver Nugget
(20525, 1787, 1, 1, 2, 7982.558264), -- Recipe: Willow Staff
(20525, 1060, 1, 1, 2, 22173.821048), -- Lesser Healing Potion
-- Obsidian Golem
(20526, 1833, 1, 1, -1, 694345), -- Bandage
(20526, 1921, 1, 1, -1, 167987), -- Leather Shoes Texture
(20526, 5220, 1, 1, -1, 10415), -- Metal Hardener
(20526, 57, 131, 199, 0, 700000), -- Adena
(20526, 114, 1, 1, 1, 2278.848137), -- Earring of Strength
(20526, 115, 1, 1, 1, 2278.848137), -- Earring of Wisdom
(20526, 907, 1, 1, 1, 1709.141783), -- Necklace of Anguish
(20526, 1896, 1, 1, 1, 13035.855656), -- Necklace of Anguish Chain
(20526, 876, 1, 1, 1, 3418.306287), -- Ring of Anguish
(20526, 1866, 1, 1, 2, 34183.209412), -- Suede
(20526, 1871, 1, 1, 2, 51274.814118), -- Charcoal
(20526, 1803, 1, 1, 2, 43087.97647), -- Recipe: Necklace of Wisdom
-- Goblin Lord
(20528, 1833, 1, 1, -1, 568013), -- Bandage
(20528, 1922, 1, 1, -1, 54338), -- Leather Tunic Pattern
(20528, 57, 112, 158, 0, 700000), -- Adena
(20528, 216, 1, 1, 1, 302.53426), -- Dirk
(20528, 2009, 1, 1, 1, 2231.46574), -- Dirk Blade
(20528, 1865, 1, 1, 2, 41945.73894), -- Varnish
(20528, 1870, 1, 1, 2, 41945.73894), -- Coal
(20528, 1803, 1, 1, 2, 35248.52212), -- Recipe: Necklace of Wisdom
-- Young Brown Keltir
(20529, 1867, 1, 1, -1, 21226), -- Animal Skin
(20529, 1121, 1, 1, -1, 636783), -- Apprentice's Shoes
(20529, 1786, 1, 1, -1, 12736), -- Recipe: Broad Sword
(20529, 57, 8, 12, 0, 700000), -- Adena
(20529, 1121, 1, 1, 1, 164584.052902), -- Apprentice's Shoes
(20529, 35, 1, 1, 1, 29389.982366), -- Cloth Shoes
(20529, 36, 1, 1, 1, 29389.982366), -- Leather Sandals
(20529, 48, 1, 1, 1, 29389.982366), -- Short Gloves
(20529, 1868, 1, 1, 2, 10972.5), -- Thread
(20529, 1873, 1, 1, 2, 2194.5), -- Silver Nugget
(20529, 1788, 1, 1, 2, 4389), -- Recipe: Bow
-- Young Red Keltir
(20530, 1867, 1, 1, -1, 21226), -- Animal Skin
(20530, 1787, 1, 1, -1, 12736), -- Recipe: Willow Staff
(20530, 1868, 1, 1, -1, 31839), -- Thread
(20530, 57, 8, 12, 0, 700000), -- Adena
(20530, 426, 1, 1, 1, 14565.04902), -- Tunic
(20530, 462, 1, 1, 1, 23180.95098), -- Stockings
(20530, 1868, 1, 1, 2, 8229.08812), -- Thread
(20530, 1873, 1, 1, 2, 1645.8087), -- Silver Nugget
(20530, 1786, 1, 1, 2, 3291.63971), -- Recipe: Broad Sword
(20530, 1060, 1, 1, 2, 9143.46347), -- Lesser Healing Potion
-- Young Prairie Keltir
(20531, 1872, 1, 1, -1, 21226), -- Animal Bone
(20531, 1873, 1, 1, -1, 6368), -- Silver Nugget
(20531, 1788, 1, 1, -1, 12736), -- Recipe: Bow
(20531, 57, 8, 12, 0, 700000), -- Adena
(20531, 426, 1, 1, 1, 14565.04902), -- Tunic
(20531, 462, 1, 1, 1, 23180.95098), -- Stockings
(20531, 1868, 1, 1, 2, 10972.5), -- Thread
(20531, 1873, 1, 1, 2, 2194.5), -- Silver Nugget
(20531, 1787, 1, 1, 2, 4389), -- Recipe: Willow Staff
-- Brown Keltir
(20532, 1787, 1, 1, -1, 14332), -- Recipe: Willow Staff
(20532, 35, 1, 1, -1, 127969), -- Cloth Shoes
(20532, 1786, 1, 1, -1, 14332), -- Recipe: Broad Sword
(20532, 57, 8, 13, 0, 700000), -- Adena
(20532, 18, 1, 1, 1, 61739.96472), -- Leather Shield
(20532, 41, 1, 1, 1, 44100.03528), -- Cloth Cap
(20532, 1868, 1, 1, 2, 12348.125), -- Thread
(20532, 1873, 1, 1, 2, 2469.625), -- Silver Nugget
(20532, 1786, 1, 1, 2, 4939.25), -- Recipe: Broad Sword
-- Longtail Keltir
(20533, 1872, 1, 1, -1, 23887), -- Animal Bone
(20533, 5549, 1, 1, -1, 1792), -- Metallic Thread
(20533, 57, 8, 13, 0, 700000), -- Adena
(20533, 13, 1, 1, 1, 6279), -- Short Bow
(20533, 1868, 1, 1, 2, 9261.136016), -- Thread
(20533, 1873, 1, 1, 2, 1852.21716), -- Silver Nugget
(20533, 1787, 1, 1, 2, 3704.459428), -- Recipe: Willow Staff
(20533, 1060, 1, 1, 2, 10290.187396), -- Lesser Healing Potion
-- Red Keltir
(20534, 1786, 1, 1, -1, 14332), -- Recipe: Broad Sword
(20534, 1868, 1, 1, -1, 35831), -- Thread
(20534, 57, 8, 13, 0, 700000), -- Adena
(20534, 21, 1, 1, 1, 16390.98586), -- Shirt
(20534, 28, 1, 1, 1, 26087.01414), -- Pants
(20534, 1868, 1, 1, 2, 12348.125), -- Thread
(20534, 1873, 1, 1, 2, 2469.625), -- Silver Nugget
(20534, 1788, 1, 1, 2, 4939.25), -- Recipe: Bow
-- Prairie Keltir
(20535, 1867, 1, 1, -1, 23887), -- Animal Skin
(20535, 36, 1, 1, -1, 127969), -- Leather Sandals
(20535, 1787, 1, 1, -1, 14332), -- Recipe: Willow Staff
(20535, 57, 8, 13, 0, 700000), -- Adena
(20535, 21, 1, 1, 1, 16390.98586), -- Shirt
(20535, 28, 1, 1, 1, 26087.01414), -- Pants
(20535, 1870, 1, 1, 2, 4630.50819), -- Coal
(20535, 1865, 1, 1, 2, 4630.50819), -- Varnish
(20535, 1786, 1, 1, 2, 3704.406552), -- Recipe: Broad Sword
(20535, 17, 10, 30, 2, 23152.577068), -- Wooden Arrow
-- Elder Brown Keltir
(20536, 1871, 1, 1, -1, 27106), -- Charcoal
(20536, 18, 1, 1, -1, 180709), -- Leather Shield
(20536, 1788, 1, 1, -1, 21685), -- Recipe: Bow
(20536, 57, 13, 20, 0, 700000), -- Adena
(20536, 13, 1, 1, 1, 9500), -- Short Bow
(20536, 1869, 1, 1, 2, 9341.319526), -- Iron Ore
(20536, 1864, 1, 1, 2, 18682.639052), -- Stem
(20536, 1787, 1, 1, 2, 7473.041422), -- Recipe: Willow Staff
-- Elder Red Keltir
(20537, 1788, 1, 1, -1, 21685), -- Recipe: Bow
(20537, 1867, 1, 1, -1, 36142), -- Animal Skin
(20537, 1864, 1, 1, -1, 54213), -- Stem
(20537, 57, 13, 20, 0, 700000), -- Adena
(20537, 308, 1, 1, 1, 9500), -- Buffalo's Horn
(20537, 1869, 1, 1, 2, 7005.899932), -- Iron Ore
(20537, 1864, 1, 1, 2, 14011.757673), -- Stem
(20537, 1788, 1, 1, 2, 5604.694631), -- Recipe: Bow
(20537, 1060, 1, 1, 2, 15568.647764), -- Lesser Healing Potion
-- Elder Prairie Keltir
(20538, 1865, 1, 1, -1, 27106), -- Varnish
(20538, 1786, 1, 1, -1, 21685), -- Recipe: Broad Sword
(20538, 1869, 1, 1, -1, 27106), -- Iron Ore
(20538, 57, 13, 20, 0, 700000), -- Adena
(20538, 1, 1, 1, 1, 9500), -- Short Sword
(20538, 1869, 1, 1, 2, 9341.319526), -- Iron Ore
(20538, 1864, 1, 1, 2, 18682.639052), -- Stem
(20538, 1786, 1, 1, 2, 7473.041422), -- Recipe: Broad Sword
-- Elder Longtail Keltir
(20539, 41, 1, 1, -1, 129078), -- Cloth Cap
(20539, 1786, 1, 1, -1, 21685), -- Recipe: Broad Sword
(20539, 1787, 1, 1, -1, 21685), -- Recipe: Willow Staff
(20539, 57, 13, 20, 0, 700000), -- Adena
(20539, 253, 1, 1, 1, 9500), -- Spiked Gloves
(20539, 1869, 1, 1, 2, 7006.000308), -- Iron Ore
(20539, 1864, 1, 1, 2, 14012.062269), -- Stem
(20539, 1787, 1, 1, 2, 5604.812577), -- Recipe: Willow Staff
(20539, 17, 10, 30, 2, 35030.124846), -- Wooden Arrow
-- Gemstone Beast
(20540, 1873, 1, 1, -1, 69008), -- Silver Nugget
(20540, 1831, 1, 1, -1, 460056), -- Antidote
(20540, 1896, 1, 1, -1, 73102), -- Necklace of Anguish Chain
(20540, 57, 92, 127, 0, 700000), -- Adena
(20540, 23, 1, 1, 1, 1110.321144), -- Wooden Breastplate
(20540, 30, 1, 1, 1, 1778.839428), -- Hard Leather Pants
(20540, 2386, 1, 1, 1, 1778.839428), -- Wooden Gaiters
(20540, 1873, 1, 1, 2, 13589.375913), -- Silver Nugget
(20540, 1868, 1, 1, 2, 67946.879565), -- Thread
(20540, 736, 1, 1, 2, 16986.744522), -- Scroll of Escape
-- Ore Bat
(20541, 2173, 1, 1, -1, 55023), -- Recipe: Hard Leather Shirt
(20541, 1925, 1, 1, -1, 133138), -- Leather Gloves Lining
(20541, 1897, 1, 1, -1, 48342), -- Necklace of Wisdom Chain
(20541, 57, 99, 159, 0, 700000), -- Adena
(20541, 272, 1, 1, 1, 114.2699), -- Forest Bow
(20541, 2013, 1, 1, 1, 1294.7301), -- Forest Bow Shaft
(20541, 1864, 1, 1, 2, 29986.73072), -- Stem
(20541, 1865, 1, 1, 2, 14993.36536), -- Varnish
(20541, 1866, 1, 1, 2, 9995.609259), -- Suede
(20541, 1873, 1, 1, 2, 5997.346144), -- Silver Nugget
(20541, 1868, 1, 1, 2, 29986.73072), -- Thread
(20541, 2143, 1, 1, 2, 2998.673072), -- Recipe: Synthetic Cokes
(20541, 5158, 1, 1, 2, 599.715203), -- Recipe: Spiritshot (D) Compressed Package (100%)
(20541, 734, 1, 1, 2, 2498.829522), -- Haste Potion
-- Skeleton Longbowman
(20542, 1878, 1, 1, -1, 90559), -- Braided Hemp
(20542, 734, 1, 1, -1, 37733), -- Haste Potion
(20542, 1869, 1, 1, -1, 226397), -- Iron Ore
(20542, 57, 106, 181, 0, 700000), -- Adena
(20542, 272, 1, 1, 1, 127.4081), -- Forest Bow
(20542, 2013, 1, 1, 1, 1443.5919), -- Forest Bow Shaft
(20542, 1864, 1, 1, 2, 53499.46836), -- Stem
(20542, 1869, 1, 1, 2, 26749.73418), -- Iron Ore
(20542, 1878, 1, 1, 2, 10699.93587), -- Braided Hemp
(20542, 1801, 1, 1, 2, 13475.9313), -- Recipe: Piece Bone Gaiters
(20542, 5158, 1, 1, 2, 1069.93029), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Ghost
(20543, 2252, 1, 1, -1, 9320), -- Recipe: Iron Hammer
(20543, 908, 1, 1, -1, 4987), -- Necklace of Wisdom
(20543, 1882, 1, 1, -1, 50535), -- Leather
(20543, 57, 105, 183, 0, 700000), -- Adena
(20543, 309, 1, 1, 1, 128), -- Tears of Eva
(20543, 310, 1, 1, 1, 128), -- Relic of the Saints
(20543, 1867, 1, 1, 2, 35825.538606), -- Animal Skin
(20543, 1872, 1, 1, 2, 35825.538606), -- Animal Bone
(20543, 1882, 1, 1, 2, 5970.900312), -- Leather
(20543, 2139, 1, 1, 2, 5373.782934), -- Recipe: Steel Mold
(20543, 6037, 1, 1, 2, 53738.239542), -- Waking Scroll
-- Elder Keltir
(20544, 1870, 1, 1, -1, 27106), -- Coal
(20544, 1872, 1, 1, -1, 36142), -- Animal Bone
(20544, 1788, 1, 1, -1, 21685), -- Recipe: Bow
(20544, 57, 13, 20, 0, 700000), -- Adena
(20544, 21, 1, 1, 1, 24799.8649), -- Shirt
(20544, 28, 1, 1, 1, 39470.1351), -- Pants
(20544, 1869, 1, 1, 2, 9341.319526), -- Iron Ore
(20544, 1864, 1, 1, 2, 18682.639052), -- Stem
(20544, 1788, 1, 1, 2, 7473.041422), -- Recipe: Bow
-- Young Keltir
(20545, 21, 1, 1, -1, 28176), -- Shirt
(20545, 1786, 1, 1, -1, 12736), -- Recipe: Broad Sword
(20545, 1873, 1, 1, -1, 6368), -- Silver Nugget
(20545, 57, 8, 12, 0, 700000), -- Adena
(20545, 18, 1, 1, 1, 54861.301984), -- Leather Shield
(20545, 41, 1, 1, 1, 39186.698016), -- Cloth Cap
(20545, 1868, 1, 1, 2, 6583.31885), -- Thread
(20545, 1873, 1, 1, 2, 1316.6772), -- Silver Nugget
(20545, 1788, 1, 1, 2, 2633.320825), -- Recipe: Bow
(20545, 6037, 1, 1, 2, 6583.31885), -- Waking Scroll
(20545, 17, 10, 30, 2, 16458.364275), -- Wooden Arrow
-- Turek Orc Elder
(20546, 2279, 1, 1, -1, 4867), -- Recipe: War Pick
(20546, 2979, 1, 1, -1, 91220), -- Recipe: Manticore Skin Gloves
(20546, 1877, 1, 1, -1, 27257), -- Adamantite Nugget
(20546, 57, 288, 574, 0, 700000), -- Adena
(20546, 849, 1, 1, 1, 366.707265), -- Tiger's Eye Earring
(20546, 1901, 1, 1, 1, 12510.465306), -- Tiger's Eye Earring Stone
(20546, 912, 1, 1, 1, 274.883163), -- Near Forest Necklace
(20546, 880, 1, 1, 1, 548.944266), -- Black Pearl Ring
(20546, 1876, 1, 1, 2, 9057.60408), -- Mithril Ore
(20546, 1880, 1, 1, 2, 4528.80204), -- Steel
(20546, 1877, 1, 1, 2, 1811.5361), -- Adamantite Nugget
(20546, 1881, 1, 1, 2, 6038.40272), -- Coarse Bone Powder
(20546, 1882, 1, 1, 2, 10064.01727), -- Leather
(20546, 2276, 1, 1, 2, 323.48586), -- Recipe: Maingauche
(20546, 2274, 1, 1, 2, 323.48586), -- Recipe: Skull Breaker
(20546, 2976, 1, 1, 2, 6062.66607), -- Recipe: Manticore Skin Boots
-- Ol Mahum Reserve
(20547, 2151, 1, 1, -1, 105333), -- Recipe: Necklace of Devotion
(20547, 1804, 1, 1, -1, 15126), -- Recipe: Soulshot (D-Grade)
(20547, 1898, 1, 1, -1, 38844), -- Blue Diamond Necklace Gem
(20547, 57, 173, 305, 0, 700000), -- Adena
(20547, 39, 1, 1, 1, 1567.677996), -- Boots
(20547, 1930, 1, 1, 1, 19093.621779), -- Boot Lining
(20547, 51, 1, 1, 1, 1567.700225), -- Bracer
(20547, 1870, 1, 1, 2, 44679.094416), -- Coal
(20547, 1865, 1, 1, 2, 44679.094416), -- Varnish
(20547, 5163, 1, 1, 2, 1787.147716), -- Recipe: Blessed Spiritshot (D) Compressed Package (100%)
(20547, 5268, 1, 1, 2, 1787.147716), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
(20547, 734, 1, 1, 2, 7446.515736), -- Haste Potion
-- Ol Mahum Deserter
(20548, 1865, 1, 1, -1, 385707), -- Varnish
(20548, 1930, 1, 1, -1, 98899), -- Boot Lining
(20548, 1804, 1, 1, -1, 15428), -- Recipe: Soulshot (D-Grade)
(20548, 57, 177, 312, 0, 700000), -- Adena
(20548, 625, 1, 1, 1, 2301.462072), -- Bone Shield
(20548, 1148, 1, 1, 1, 1604.537928), -- Hard Leather Helmet
(20548, 1869, 1, 1, 2, 56965.863183), -- Iron Ore
(20548, 1864, 1, 1, 2, 113931.905239), -- Stem
(20548, 1880, 1, 1, 2, 5696.568431), -- Steel
(20548, 5268, 1, 1, 2, 2278.663147), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Ol Mahum Lord
(20549, 1880, 1, 1, -1, 140167), -- Steel
(20549, 1938, 1, 1, -1, 94230), -- Mithril Banded Mail Material
(20549, 1901, 1, 1, -1, 193601), -- Tiger's Eye Earring Stone
(20549, 57, 592, 1181, 0, 700000), -- Adena
(20549, 83, 1, 1, 1, 45.0906); -- Sword of Magic

INSERT INTO `droplist` VALUES
(20549, 144, 1, 1, 1, 45.0906), -- Sword of Occult
(20549, 124, 1, 1, 1, 33.40344), -- Two-Handed Sword
(20549, 2026, 1, 1, 1, 1494.606795), -- Two-Handed Sword Edge
(20549, 127, 1, 1, 1, 33.40344), -- Crimson Sword
(20549, 130, 1, 1, 1, 33.405125), -- Elven Sword
(20549, 1871, 1, 1, 2, 124209.598502), -- Charcoal
(20549, 1866, 1, 1, 2, 82806.564841), -- Suede
(20549, 1877, 1, 1, 2, 4968.224734), -- Adamantite Nugget
(20549, 2277, 1, 1, 2, 887.076377), -- Recipe: Bich'hwa
(20549, 6667, 1, 1, 2, 77630.874684), -- Deluxe Chest Key - Grade 3
(20549, 1341, 20, 60, 2, 207016.660862), -- Bone Arrow
-- Guardian Basilisk
(20550, 2276, 1, 1, -1, 5536), -- Recipe: Maingauche
(20550, 394, 1, 1, -1, 1325), -- Reinforced Leather Shirt
(20550, 2154, 1, 1, -1, 82984), -- Recipe: Elven Earring
(20550, 57, 327, 655, 0, 700000), -- Adena
(20550, 393, 1, 1, 1, 117.40802), -- Mithril Banded Mail
(20550, 1938, 1, 1, 1, 4617.24182), -- Mithril Banded Mail Material
(20550, 394, 1, 1, 1, 117.40802), -- Reinforced Leather Shirt
(20550, 415, 1, 1, 1, 187.65916), -- Mithril Banded Gaiters
(20550, 1939, 1, 1, 1, 6032.63508), -- Mithril Banded Gaiters Material
(20550, 416, 1, 1, 1, 187.6479), -- Reinforced Leather Gaiters
(20550, 1868, 1, 1, 2, 117742.435811), -- Thread
(20550, 1873, 1, 1, 2, 23548.518392), -- Silver Nugget
(20550, 5549, 1, 1, 2, 5887.129598), -- Metallic Thread
(20550, 1889, 1, 1, 2, 3924.805115), -- Compound Braid
(20550, 2272, 1, 1, 2, 420.509257), -- Recipe: Sword of Revolution
(20550, 2274, 1, 1, 2, 420.509257), -- Recipe: Skull Breaker
(20550, 2148, 1, 1, 2, 4205.09257), -- Recipe: Crafted Leather
-- Road Scavenger
(20551, 1874, 1, 1, -1, 52310), -- Oriharukon Ore
(20551, 2034, 1, 1, -1, 8290), -- Sword of Revolution Blade
(20551, 1902, 1, 1, -1, 79498), -- Elven Earring Beads
(20551, 57, 332, 662, 0, 700000), -- Adena
(20551, 850, 1, 1, 1, 188.03786), -- Elven Earring
(20551, 1902, 1, 1, 1, 6848.930925), -- Elven Earring Beads
(20551, 913, 1, 1, 1, 141.128575), -- Elven Necklace
(20551, 1904, 1, 1, 1, 6308.810455), -- Elven Necklace Beads
(20551, 881, 1, 1, 1, 282.25715), -- Elven Ring
(20551, 1903, 1, 1, 1, 11275.835035), -- Elven Ring Piece
(20551, 1872, 1, 1, 2, 77257.841813), -- Animal Bone
(20551, 1867, 1, 1, 2, 77257.841813), -- Animal Skin
(20551, 1881, 1, 1, 2, 7725.80127), -- Coarse Bone Powder
(20551, 1875, 1, 1, 2, 3862.900635), -- Stone of Purity
(20551, 2145, 1, 1, 2, 4138.88314), -- Recipe: Mithril Alloy
(20551, 2288, 1, 1, 2, 321.951108), -- Recipe: Ghost Staff
(20551, 2287, 1, 1, 2, 321.780221), -- Recipe: Atuba Hammer
-- Fettered Soul
(20552, 1902, 1, 1, -1, 170992), -- Elven Earring Beads
(20552, 1825, 1, 1, -1, 120549), -- Recipe: Oriharukon
(20552, 1903, 1, 1, -1, 281516), -- Elven Ring Piece
(20552, 57, 714, 1424, 0, 700000), -- Adena
(20552, 129, 1, 1, 1, 81.2308), -- Sword of Revolution
(20552, 2034, 1, 1, 1, 4608.7692), -- Sword of Revolution Blade
(20552, 1864, 1, 3, 2, 145400.811275), -- Stem
(20552, 1869, 1, 1, 2, 145400.811275), -- Iron Ore
(20552, 1878, 1, 1, 2, 58160.32451), -- Braided Hemp
(20552, 1884, 1, 1, 2, 89477.457255), -- Cord
(20552, 2285, 1, 1, 2, 807.870585), -- Recipe: Claymore
(20552, 2208, 1, 1, 2, 14867.7251), -- Recipe: Ogre Power Gauntlets
-- Windsus
(20553, 2145, 1, 1, -1, 62124), -- Recipe: Mithril Alloy
(20553, 1904, 1, 1, -1, 81170), -- Elven Necklace Beads
(20553, 1865, 1, 1, -1, 869731), -- Varnish
(20553, 57, 368, 733, 0, 700000), -- Adena
(20553, 318, 1, 1, 1, 41.858726), -- Crucifix of Blood
(20553, 2042, 1, 1, 1, 2077.141274), -- Crucifix of Blood Piece
(20553, 1865, 1, 1, 2, 74930.706489), -- Varnish
(20553, 1870, 1, 1, 2, 74930.706489), -- Coal
(20553, 1879, 1, 1, 2, 12488.36337), -- Cokes
(20553, 1875, 1, 1, 2, 4995.345348), -- Stone of Purity
(20553, 2285, 1, 1, 2, 416.278779), -- Recipe: Claymore
(20553, 2208, 1, 1, 2, 7661.599525), -- Recipe: Ogre Power Gauntlets
-- Grandis
(20554, 1941, 1, 1, -1, 40488), -- Brigandine Temper
(20554, 2146, 1, 1, -1, 72720), -- Recipe: Artisan's frame
(20554, 1902, 1, 1, -1, 103148), -- Elven Earring Beads
(20554, 57, 425, 848, 0, 700000), -- Adena
(20554, 224, 1, 1, 1, 24.49914), -- Maingauche
(20554, 2038, 1, 1, 1, 1390.00086), -- Maingauche Edge
(20554, 1660, 1, 1, 1, 24.49914), -- Cursed Maingauche
(20554, 2044, 1, 1, 1, 1390.00086), -- Cursed Maingauche Edge
(20554, 1869, 1, 1, 2, 75180.860924), -- Iron Ore
(20554, 1864, 1, 1, 2, 150361.472222), -- Stem
(20554, 1880, 1, 1, 2, 7517.986242), -- Steel
(20554, 5550, 1, 1, 2, 1002.498016), -- Durable Metal Plate
(20554, 5473, 1, 1, 2, 5369.954512), -- Recipe: Durable Metal Plate(100%)
(20554, 2208, 1, 1, 2, 7687.23267), -- Recipe: Ogre Power Gauntlets
(20554, 6036, 1, 1, 2, 2505.995414), -- Greater Magic Haste Potion
-- Giant Fungus
(20555, 1903, 1, 1, -1, 152869), -- Elven Ring Piece
(20555, 2296, 1, 1, -1, 5091), -- Recipe: Atuba Mace
(20555, 1878, 1, 1, -1, 366579), -- Braided Hemp
(20555, 57, 383, 764, 0, 700000), -- Adena
(20555, 395, 1, 1, 1, 137.708965), -- Manticore Skin Shirt
(20555, 1942, 1, 1, 1, 6040.76583), -- Manticore Skin Shirt Texture
(20555, 417, 1, 1, 1, 219.926575), -- Manticore Skin Gaiters
(20555, 1943, 1, 1, 1, 9406.59863), -- Manticore Skin Gaiters Pattern
(20555, 1869, 1, 1, 2, 78955.380156), -- Iron Ore
(20555, 1864, 1, 1, 2, 157910.500785), -- Stem
(20555, 1880, 1, 1, 2, 7895.589921), -- Steel
(20555, 5550, 1, 1, 2, 1052.641512), -- Durable Metal Plate
(20555, 5473, 1, 1, 2, 5639.781237), -- Recipe: Durable Metal Plate(100%)
(20555, 2208, 1, 1, 2, 8073.106389), -- Recipe: Ogre Power Gauntlets
-- Giant Monstereye
(20556, 2305, 1, 1, -1, 4246), -- Recipe: Crystal Staff
(20556, 1957, 1, 1, -1, 108518), -- Assault Boots Part
(20556, 1874, 1, 1, -1, 64821), -- Oriharukon Ore
(20556, 57, 394, 788, 0, 700000), -- Adena
(20556, 438, 1, 1, 1, 133.188891), -- Sage's Rag
(20556, 1953, 1, 1, 1, 7819.811109), -- Sage's Rag Lining
(20556, 1870, 1, 1, 2, 81375.725358), -- Coal
(20556, 1865, 1, 1, 2, 81375.725358), -- Varnish
(20556, 1874, 1, 1, 2, 5424.977848), -- Oriharukon Ore
(20556, 2160, 1, 1, 2, 5250.115032), -- Recipe: Moonstone Earring
(20556, 2205, 1, 1, 2, 2575.172257), -- Recipe: Chain Gaiters
(20556, 5154, 1, 1, 2, 271.284147), -- Recipe: Soulshot (C) Compressed Package (100%)
-- Dire Wyrm
(20557, 2055, 1, 1, -1, 8505), -- Glaive Edge
(20557, 3954, 1, 1, -1, 3429), -- Recipe: Blessed Spiritshot C
(20557, 4469, 1, 1, -1, 5878), -- Dye of STR (Str+1 Con-1)
(20557, 57, 414, 837, 0, 700000), -- Adena
(20557, 297, 1, 1, 1, 37.24522), -- Glaive
(20557, 2055, 1, 1, 1, 2135.75478), -- Glaive Edge
(20557, 1871, 1, 1, 2, 73789.958951), -- Charcoal
(20557, 1866, 1, 1, 2, 49193.253063), -- Suede
(20557, 1877, 1, 1, 2, 2951.585661), -- Adamantite Nugget
(20557, 2297, 1, 1, 2, 322.18739), -- Recipe: Flamberge
(20557, 5154, 1, 1, 2, 246.00515), -- Recipe: Soulshot (C) Compressed Package (100%)
(20557, 2994, 1, 1, 2, 5856.350987), -- Recipe: Boots of Seal
(20557, 6668, 1, 1, 2, 26353.658798), -- Deluxe Chest Key - Grade 4
-- Rotting tree
(20558, 2932, 1, 1, -1, 118674), -- Plate Boots Design
(20558, 2310, 1, 1, -1, 4643), -- Recipe: Dark Elven Dagger
(20558, 1905, 1, 1, -1, 103435), -- Omen Beast's Eye Earring Gemstone
(20558, 57, 420, 854, 0, 700000), -- Adena
(20558, 851, 1, 1, 1, 190.763013), -- Omen Beast's Eye Earring
(20558, 1905, 1, 1, 1, 8656.463781), -- Omen Beast's Eye Earring Gemstone
(20558, 914, 1, 1, 1, 143.065335), -- Necklace of Darkness
(20558, 1907, 1, 1, 1, 6190.504908), -- Necklace of Darkness Gem
(20558, 882, 1, 1, 1, 286.13067), -- Mithril Ring
(20558, 1906, 1, 1, 1, 12232.072293), -- Mithril Ring Wire
(20558, 1875, 1, 1, 2, 4449.576105), -- Stone of Purity
(20558, 1879, 1, 1, 2, 11124.02291), -- Cokes
(20558, 1885, 1, 1, 2, 5562.011455), -- High-Grade Suede
(20558, 5550, 1, 1, 2, 889.94828), -- Durable Metal Plate
(20558, 5549, 1, 1, 2, 6674.446805), -- Metallic Thread
(20558, 2988, 1, 1, 2, 2816.130915), -- Recipe: Reinforced Mithril Gaiters
(20558, 2303, 1, 1, 2, 291.415085), -- Recipe: Skull Graver
(20558, 1342, 10, 30, 2, 133487.448445), -- Steel Arrow
-- Rotting Golem
(20559, 2164, 1, 1, -1, 96165), -- Recipe: Ring of Protection
(20559, 1873, 1, 1, -1, 500056), -- Silver Nugget
(20559, 2163, 1, 1, -1, 63783), -- Recipe: Earring of Protection
(20559, 57, 492, 1009, 0, 700000), -- Adena
(20559, 71, 1, 1, 1, 16.754325), -- Flamberge
(20559, 2059, 1, 1, 1, 1096.923506), -- Flamberge Blade
(20559, 72, 1, 1, 1, 16.754325), -- Stormbringer
(20559, 2060, 1, 1, 1, 1172.567844), -- Stormbringer Blade
(20559, 1895, 1, 1, 2, 21101.178213), -- Metallic Fiber
(20559, 2164, 1, 1, 2, 5681.076912), -- Recipe: Ring of Protection
(20559, 5154, 1, 1, 2, 246.186135), -- Recipe: Soulshot (C) Compressed Package (100%)
(20559, 2219, 1, 1, 2, 4587.203421), -- Recipe: Crimson Boots
(20559, 8723, 1, 1, 2, 2954.162826), -- Life Stone - Level 46
(20559, 8733, 1, 1, 2, 738.558405), -- Mid-Grade Life Stone - Level 46
(20559, 8743, 1, 1, 2, 73.838142), -- High-Grade Life Stone - Level 46
(20559, 8753, 1, 1, 2, 14.795946), -- Top-Grade Life Stone - Level 46
-- Trisalim Spider
(20560, 2165, 1, 1, -1, 44638), -- Recipe: Necklace of Protection
(20560, 2320, 1, 1, -1, 4059), -- Recipe: Cursed Staff
(20560, 1908, 1, 1, -1, 110326), -- Moonstone Earring Wire
(20560, 57, 461, 936, 0, 700000), -- Adena
(20560, 852, 1, 1, 1, 153.844505), -- Moonstone Earring
(20560, 1908, 1, 1, 1, 8690.69005), -- Moonstone Earring Wire
(20560, 915, 1, 1, 1, 115.433245), -- Aquastone Necklace
(20560, 1910, 1, 1, 1, 6910.66439), -- Aquastone Necklace Chain
(20560, 883, 1, 1, 1, 230.86649), -- Aquastone Ring
(20560, 1909, 1, 1, 1, 12393.50132), -- Aquastone Ring Wire
(20560, 1864, 1, 1, 2, 84710.585259), -- Stem
(20560, 1865, 1, 1, 2, 42355.424115), -- Varnish
(20560, 1866, 1, 1, 2, 28236.774096), -- Suede
(20560, 1873, 1, 1, 2, 16942.169646), -- Silver Nugget
(20560, 1868, 1, 1, 2, 84710.585259), -- Thread
(20560, 2323, 1, 1, 2, 147.526731), -- Recipe: Elemental Bow
(20560, 2225, 1, 1, 2, 920.661471), -- Recipe: Demon's Stockings
(20560, 2321, 1, 1, 2, 147.526731), -- Recipe: Stiletto
(20560, 3003, 1, 1, 2, 2630.761884), -- Recipe: Gloves of Seal
(20560, 8723, 1, 1, 2, 1694.322153), -- Life Stone - Level 46
(20560, 8733, 1, 1, 2, 423.646281), -- Mid-Grade Life Stone - Level 46
(20560, 8743, 1, 1, 2, 42.338331), -- High-Grade Life Stone - Level 46
(20560, 8753, 1, 1, 2, 8.678043), -- Top-Grade Life Stone - Level 46
-- Trisalim Tarantula
(20561, 1880, 1, 1, -1, 137957), -- Steel
(20561, 2940, 1, 1, -1, 124006), -- Dwarven Chain Boots Part
(20561, 2164, 1, 1, -1, 106120), -- Recipe: Ring of Protection
(20561, 57, 543, 1111, 0, 700000), -- Adena
(20561, 96, 1, 1, 1, 12.329282), -- Scythe
(20561, 2062, 1, 1, 1, 852.33652), -- Scythe Edge
(20561, 298, 1, 1, 1, 12.329282), -- Orcish Glaive
(20561, 2075, 1, 1, 1, 852.33652), -- Orcish Glaive Blade
(20561, 302, 1, 1, 1, 12.329282), -- Body Slasher
(20561, 2076, 1, 1, 1, 852.339114), -- Body Slasher Blade
(20561, 1866, 1, 1, 2, 36222.406578), -- Suede
(20561, 1871, 1, 1, 2, 54333.46539), -- Charcoal
(20561, 5220, 1, 1, 2, 2173.223034), -- Metal Hardener
(20561, 1885, 1, 1, 2, 4527.90918), -- High-Grade Suede
(20561, 4041, 1, 1, 2, 472.43979), -- Mold Hardener
(20561, 6037, 1, 1, 2, 108667.219734), -- Waking Scroll
(20561, 6668, 1, 1, 2, 19404.70587), -- Deluxe Chest Key - Grade 4
(20561, 8723, 1, 1, 2, 2173.223034), -- Life Stone - Level 46
(20561, 8733, 1, 1, 2, 543.23352), -- Mid-Grade Life Stone - Level 46
(20561, 8743, 1, 1, 2, 54.323352), -- High-Grade Life Stone - Level 46
(20561, 8753, 1, 1, 2, 10.980252), -- Top-Grade Life Stone - Level 46
(20561, 1832, 1, 1, 2, 60370.870266), -- Greater Antidote
-- Spore Zombie
(20562, 1867, 1, 3, -1, 885212), -- Animal Skin
(20562, 2346, 1, 1, -1, 3088), -- Recipe: Fisted Blade
(20562, 440, 1, 1, -1, 440), -- Robe of Seal
(20562, 57, 524, 1069, 0, 700000), -- Adena
(20562, 853, 1, 1, 1, 130.303378), -- Earring of Protection
(20562, 1911, 1, 1, 1, 7293.4976), -- Earring of Protection Gemstone
(20562, 916, 1, 1, 1, 97.763904), -- Necklace of Protection
(20562, 1913, 1, 1, 1, 5962.967722), -- Necklace of Protection Gemstone
(20562, 884, 1, 1, 1, 195.527808), -- Ring of Protection
(20562, 1912, 1, 1, 1, 10566.939588), -- Ring of Protection Gemstone
(20562, 1869, 1, 1, 2, 45255.831726), -- Iron Ore
(20562, 1864, 1, 1, 2, 90511.663452), -- Stem
(20562, 1880, 1, 1, 2, 4525.559262), -- Steel
(20562, 5550, 1, 1, 2, 603.503544), -- Durable Metal Plate
(20562, 4043, 1, 1, 2, 1508.519754), -- Asofe
(20562, 2166, 1, 1, 2, 1534.104096), -- Recipe: Earrings of Binding (100%)
(20562, 2230, 1, 1, 2, 877.040808), -- Recipe: Theca Leather Gaiters
(20562, 2226, 1, 1, 2, 1847.09385), -- Recipe: Mithril Gauntlets
(20562, 8724, 1, 1, 2, 1508.519754), -- Life Stone - Level 49
(20562, 8734, 1, 1, 2, 377.070162), -- Mid-Grade Life Stone - Level 49
(20562, 8744, 1, 1, 2, 37.778748), -- High-Grade Life Stone - Level 49
(20562, 8754, 1, 1, 2, 7.651392), -- Top-Grade Life Stone - Level 49
(20562, 1342, 10, 30, 2, 90511.663452), -- Steel Arrow
-- Manashen Gargoyle
(20563, 1825, 1, 1, -1, 77898), -- Recipe: Oriharukon
(20563, 1941, 1, 1, -1, 43371), -- Brigandine Temper
(20563, 1864, 1, 5, -1, 727049), -- Stem
(20563, 57, 455, 909, 0, 700000), -- Adena
(20563, 1124, 1, 1, 1, 122.767366), -- Boots of Power
(20563, 1948, 1, 1, 1, 4761.357634), -- Boots of Power Pattern
(20563, 2424, 1, 1, 1, 122.767366), -- Manticore Skin Boots
(20563, 2923, 1, 1, 1, 4761.357634), -- Manticore Skin Boot Lining
(20563, 2425, 1, 1, 1, 122.767366), -- Brigandine Boots
(20563, 2924, 1, 1, 1, 4761.357634), -- Brigandine Boots Design
(20563, 2426, 1, 1, 1, 122.767366), -- Elven Mithril Boots
(20563, 2925, 1, 1, 1, 4761.357634), -- Elven Mithril Boots Design
(20563, 606, 1, 1, 1, 122.767366), -- Rip Gauntlets
(20563, 1946, 1, 1, 1, 4761.357634), -- Rip Gauntlets Pattern
(20563, 2448, 1, 1, 1, 122.767366), -- Manticore Skin Gloves
(20563, 2926, 1, 1, 1, 4761.357634), -- Manticore Skin Gloves Lining
(20563, 2449, 1, 1, 1, 122.767366), -- Brigandine Gauntlets
(20563, 2927, 1, 1, 1, 4761.357634), -- Brigandine Gauntlets Pattern
(20563, 2450, 1, 1, 1, 122.767366), -- Mithril Gloves
(20563, 2928, 1, 1, 1, 4761.357634), -- Mithril Gloves Design
(20563, 1870, 1, 1, 2, 93956.963796), -- Coal
(20563, 1865, 1, 1, 2, 93956.963796), -- Varnish
(20563, 1874, 1, 1, 2, 6263.716176), -- Oriharukon Ore
(20563, 2160, 1, 1, 2, 6061.818384), -- Recipe: Moonstone Earring
(20563, 2205, 1, 1, 2, 2973.311334), -- Recipe: Chain Gaiters
(20563, 5154, 1, 1, 2, 313.226514), -- Recipe: Soulshot (C) Compressed Package (100%)
-- Enchanted Monstereye
(20564, 1885, 1, 1, -1, 82647), -- High-Grade Suede
(20564, 2306, 1, 1, -1, 4331), -- Recipe: Stick of Faith
(20564, 1864, 1, 5, -1, 661179), -- Stem
(20564, 57, 402, 804, 0, 700000), -- Adena
(20564, 630, 1, 1, 1, 210.139151), -- Square Shield
(20564, 1956, 1, 1, 1, 9421.286455), -- Square Shield Fragment
(20564, 2494, 1, 1, 1, 210.139151), -- Plate Shield
(20564, 2934, 1, 1, 1, 9421.286455), -- Plate Shield Fragment
(20564, 2412, 1, 1, 1, 147.157438), -- Plate Helmet
(20564, 2930, 1, 1, 1, 6690.99135), -- Plate Helmet Design
(20564, 1871, 1, 1, 2, 71145.919102), -- Charcoal
(20564, 1866, 1, 1, 2, 47430.561726), -- Suede
(20564, 1877, 1, 1, 2, 2845.824522), -- Adamantite Nugget
(20564, 2297, 1, 1, 2, 310.64278), -- Recipe: Flamberge
(20564, 5154, 1, 1, 2, 237.1903), -- Recipe: Soulshot (C) Compressed Package (100%)
(20564, 2994, 1, 1, 2, 5646.506374), -- Recipe: Boots of Seal
(20564, 6668, 1, 1, 2, 25409.355196), -- Deluxe Chest Key - Grade 4
-- Enchanted Stone Golem
(20565, 1865, 1, 3, -1, 572525), -- Varnish
(20565, 3954, 1, 1, -1, 3817), -- Recipe: Blessed Spiritshot C
(20565, 4470, 1, 1, -1, 6543), -- Dye of STR (Str+1 Dex-1)
(20565, 57, 461, 932, 0, 700000), -- Adena
(20565, 262, 1, 1, 1, 41.46166), -- Scallop Jamadhr
(20565, 2053, 1, 1, 1, 2377.53834), -- Scallop Jamadhr Edge
(20565, 1875, 1, 1, 2, 5476.173086), -- Stone of Purity
(20565, 1879, 1, 1, 2, 13690.452288), -- Cokes
(20565, 1885, 1, 1, 2, 6845.226144), -- High-Grade Suede
(20565, 5550, 1, 1, 2, 1095.226788), -- Durable Metal Plate
(20565, 5549, 1, 1, 2, 8214.279202), -- Metallic Thread
(20565, 2988, 1, 1, 2, 3465.947694), -- Recipe: Reinforced Mithril Gaiters
(20565, 2303, 1, 1, 2, 358.694798), -- Recipe: Skull Graver
-- Enchanted Iron Golem
(20566, 2995, 1, 1, -1, 95820), -- Recipe: Reinforced Mithril Gloves
(20566, 3000, 1, 1, -1, 77393), -- Recipe: Dwarven Chain Shield
(20566, 1905, 1, 1, -1, 117445), -- Omen Beast's Eye Earring Gemstone
(20566, 57, 477, 970, 0, 700000), -- Adena
(20566, 630, 1, 1, 1, 255.812474), -- Square Shield
(20566, 1956, 1, 1, 1, 11468.98417), -- Square Shield Fragment
(20566, 2494, 1, 1, 1, 255.812474), -- Plate Shield
(20566, 2934, 1, 1, 1, 11468.98417), -- Plate Shield Fragment
(20566, 2412, 1, 1, 1, 179.141812), -- Plate Helmet
(20566, 2930, 1, 1, 1, 8145.2649), -- Plate Helmet Design
(20566, 1895, 1, 1, 2, 21652.597538), -- Metallic Fiber
(20566, 2164, 1, 1, 2, 5829.535712), -- Recipe: Ring of Protection
(20566, 5154, 1, 1, 2, 252.61951), -- Recipe: Soulshot (C) Compressed Package (100%)
(20566, 2219, 1, 1, 2, 4707.076946), -- Recipe: Crimson Boots
(20566, 8723, 1, 1, 2, 3031.361476), -- Life Stone - Level 46
(20566, 8733, 1, 1, 2, 757.85853), -- Mid-Grade Life Stone - Level 46
(20566, 8743, 1, 1, 2, 75.767692), -- High-Grade Life Stone - Level 46
(20566, 8753, 1, 1, 2, 15.182596), -- Top-Grade Life Stone - Level 46
-- Enchanted Gargoyle
(20567, 2061, 1, 1, -1, 10331), -- Big Hammer Head
(20567, 3004, 1, 1, -1, 83015), -- Recipe: Rind Leather Gloves
(20567, 2165, 1, 1, -1, 51209), -- Recipe: Necklace of Protection
(20567, 57, 526, 1078, 0, 700000), -- Adena
(20567, 263, 1, 1, 1, 35.829805), -- Chakram
(20567, 2073, 1, 1, 1, 2441.170195), -- Chakram Edge
(20567, 1864, 1, 1, 2, 97180.198849), -- Stem
(20567, 1865, 1, 1, 2, 48590.250265), -- Varnish
(20567, 1866, 1, 1, 2, 32393.299056), -- Suede
(20567, 1873, 1, 1, 2, 19436.100106), -- Silver Nugget
(20567, 1868, 1, 1, 2, 97180.198849), -- Thread
(20567, 2323, 1, 1, 2, 169.243041), -- Recipe: Elemental Bow
(20567, 2225, 1, 1, 2, 1056.185181), -- Recipe: Demon's Stockings
(20567, 2321, 1, 1, 2, 169.243041), -- Recipe: Stiletto
(20567, 3003, 1, 1, 2, 3018.016724), -- Recipe: Gloves of Seal
(20567, 8723, 1, 1, 2, 1943.730683), -- Life Stone - Level 46
(20567, 8733, 1, 1, 2, 486.008091), -- Mid-Grade Life Stone - Level 46
(20567, 8743, 1, 1, 2, 48.570641), -- High-Grade Life Stone - Level 46
(20567, 8753, 1, 1, 2, 9.955473), -- Top-Grade Life Stone - Level 46
-- Formor
(20568, 1961, 1, 1, -1, 37654), -- Mithril Shirt Fabric
(20568, 1884, 1, 1, -1, 724122), -- Cord
(20568, 1908, 1, 1, -1, 111430), -- Moonstone Earring Wire
(20568, 57, 465, 945, 0, 700000), -- Adena
(20568, 89, 1, 1, 1, 3.942464), -- Big Hammer
(20568, 2061, 1, 1, 1, 268.608336), -- Big Hammer Head
(20568, 160, 1, 1, 1, 3.942464), -- Battle Axe
(20568, 2063, 1, 1, 1, 268.608336), -- Battle Axe Head
(20568, 161, 1, 1, 1, 3.942464), -- Silver Axe
(20568, 2064, 1, 1, 1, 268.608336), -- Silver Axe Head
(20568, 173, 1, 1, 1, 3.942464), -- Skull Graver
(20568, 2065, 1, 1, 1, 268.608336), -- Skull Graver Head
(20568, 191, 1, 1, 1, 3.942464), -- Heavy Doom Hammer
(20568, 2066, 1, 1, 1, 272.557256), -- Heavy Doom Hammer Head
(20568, 192, 1, 1, 1, 3.942464), -- Crystal Staff
(20568, 2067, 1, 1, 1, 250.458368), -- Crystal Staff Head
(20568, 193, 1, 1, 1, 3.942464), -- Stick of Faith
(20568, 2068, 1, 1, 1, 250.458368), -- Stick of Faith Shaft
(20568, 194, 1, 1, 1, 3.942464), -- Heavy Doom Axe
(20568, 2069, 1, 1, 1, 272.552952), -- Heavy Doom Axe Blade
(20568, 1864, 1, 1, 2, 101113.780967), -- Stem
(20568, 1865, 1, 1, 2, 50557.04531), -- Varnish
(20568, 1866, 1, 1, 2, 33704.490438), -- Suede
(20568, 1873, 1, 1, 2, 20222.818124), -- Silver Nugget
(20568, 1868, 1, 1, 2, 101113.780967), -- Thread
(20568, 2324, 1, 1, 2, 176.192557), -- Recipe: Noble Elven Bow
(20568, 2321, 1, 1, 2, 176.192557), -- Recipe: Stiletto
(20568, 8723, 1, 1, 2, 2022.343743), -- Life Stone - Level 46
(20568, 8733, 1, 1, 2, 505.663349), -- Mid-Grade Life Stone - Level 46
(20568, 8743, 1, 1, 2, 50.473439), -- High-Grade Life Stone - Level 46
(20568, 8753, 1, 1, 2, 10.218549), -- Top-Grade Life Stone - Level 46
-- Formor Elder
(20569, 3001, 1, 1, -1, 79425), -- Recipe: Rind Leather Boots
(20569, 1961, 1, 1, -1, 40920), -- Mithril Shirt Fabric
(20569, 2213, 1, 1, -1, 19856), -- Recipe: Dwarven Chain Mail Shirt
(20569, 57, 504, 1030, 0, 700000), -- Adena
(20569, 631, 1, 1, 1, 197.50464), -- Eldarake
(20569, 1964, 1, 1, 1, 8139.151692), -- Eldarake Temper
(20569, 2495, 1, 1, 1, 197.50464), -- Chain Shield
(20569, 2945, 1, 1, 1, 8139.151692), -- Chain Shield Fragment
(20569, 2413, 1, 1, 1, 138.253248), -- Chain Hood
(20569, 2936, 1, 1, 1, 7392.434088), -- Chain Hood Pattern
(20569, 1865, 1, 1, 2, 50362.6134), -- Varnish
(20569, 1870, 1, 1, 2, 50362.6134), -- Coal
(20569, 1879, 1, 1, 2, 8393.82225), -- Cokes
(20569, 1875, 1, 1, 2, 3357.5289), -- Stone of Purity
(20569, 4040, 1, 1, 2, 1007.19465), -- Mold Lubricant
(20569, 2508, 1, 1, 2, 41968.9512), -- Cursed Bone
(20569, 2230, 1, 1, 2, 975.9849), -- Recipe: Theca Leather Gaiters
(20569, 2220, 1, 1, 2, 1042.72575), -- Recipe: Rind Leather Armor
(20569, 8723, 1, 1, 2, 2014.54935), -- Life Stone - Level 46
(20569, 8733, 1, 1, 2, 503.67735), -- Mid-Grade Life Stone - Level 46
(20569, 8743, 1, 1, 2, 50.41575), -- High-Grade Life Stone - Level 46
(20569, 8753, 1, 1, 2, 9.9231), -- Top-Grade Life Stone - Level 46
-- Tarlk Bugbear
(20570, 3008, 1, 1, -1, 46633), -- Recipe: Theca Leather Gloves
(20570, 2216, 1, 1, -1, 52993), -- Recipe: Great Helmet
(20570, 1911, 1, 1, -1, 95383), -- Earring of Protection Gemstone
(20570, 57, 506, 1033, 0, 700000), -- Adena
(20570, 355, 1, 1, 1, 57.33637), -- Dwarven Chain Mail Shirt
(20570, 1968, 1, 1, 1, 3422.90028), -- Dwarven Chain Mail Shirt Material
(20570, 382, 1, 1, 1, 91.738192), -- Dwarven Chain Gaiters
(20570, 1969, 1, 1, 1, 5429.025158), -- Dwarven Chain Gaiters Material
(20570, 1866, 1, 1, 2, 34436.948304), -- Suede
(20570, 1871, 1, 1, 2, 51655.471392), -- Charcoal
(20570, 5220, 1, 1, 2, 2066.175792), -- Metal Hardener
(20570, 1885, 1, 1, 2, 4304.606304), -- High-Grade Suede
(20570, 4041, 1, 1, 2, 449.134608), -- Mold Hardener
(20570, 2167, 1, 1, 2, 2635.497216), -- Recipe: Ring of Ages
(20570, 2343, 1, 1, 2, 120.088944), -- Recipe: Mace of Underworld
(20570, 8724, 1, 1, 2, 1721.862096), -- Life Stone - Level 49
(20570, 8734, 1, 1, 2, 430.441056), -- Mid-Grade Life Stone - Level 49
(20570, 8744, 1, 1, 2, 43.06368), -- High-Grade Life Stone - Level 49
(20570, 8754, 1, 1, 2, 8.710608), -- Top-Grade Life Stone - Level 49
-- Tarlk Bugbear Warrior
(20571, 2335, 1, 1, -1, 3525), -- Recipe: War Axe
(20571, 2968, 1, 1, -1, 10228), -- Dwarven War Hammer Head
(20571, 951, 1, 1, -1, 2756), -- Scroll: Enchant Weapon (C-Grade)
(20571, 57, 599, 1219, 0, 700000), -- Adena
(20571, 73, 1, 1, 1, 7.60032), -- Shamshir
(20571, 2077, 1, 1, 1, 557.89968), -- Shamshir Blade
(20571, 74, 1, 1, 1, 7.60032), -- Katana
(20571, 2078, 1, 1, 1, 557.89968), -- Katana Blade
(20571, 131, 1, 1, 1, 7.60032), -- Spirit Sword
(20571, 2080, 1, 1, 1, 557.89968), -- Spirit Sword Blade
(20571, 133, 1, 1, 1, 7.60032), -- Raid Sword
(20571, 2081, 1, 1, 1, 557.89968), -- Raid Sword Blade
(20571, 1866, 1, 1, 2, 34445.326013), -- Suede
(20571, 1871, 1, 1, 2, 51667.910581), -- Charcoal
(20571, 5220, 1, 1, 2, 2066.697598), -- Metal Hardener
(20571, 1885, 1, 1, 2, 4305.646142), -- High-Grade Suede
(20571, 4041, 1, 1, 2, 449.295728), -- Mold Hardener
(20571, 2336, 1, 1, 2, 120.167782), -- Recipe: Nirvana Axe
(20571, 2508, 1, 1, 2, 43056.618297), -- Cursed Bone
(20571, 2351, 1, 1, 2, 108.088253), -- Recipe: Scorpion
(20571, 6668, 1, 1, 2, 18452.814002), -- Deluxe Chest Key - Grade 4
(20571, 8724, 1, 1, 2, 1722.195706), -- Life Stone - Level 49
(20571, 8734, 1, 1, 2, 430.627365), -- Mid-Grade Life Stone - Level 49
(20571, 8744, 1, 1, 2, 42.984298), -- High-Grade Life Stone - Level 49
(20571, 8754, 1, 1, 2, 8.628235), -- Top-Grade Life Stone - Level 49
-- Tarlk Bugbear High Warrior
(20572, 2950, 1, 1, -1, 139779), -- Gloves of Seal Pattern
(20572, 4125, 1, 1, -1, 73865), -- Recipe: Maestro Mold (100%)
(20572, 1894, 1, 1, -1, 58315), -- Crafted Leather
(20572, 57, 656, 1338, 0, 700000), -- Adena
(20572, 94, 1, 1, 1, 33.326689), -- Bec de Corbin
(20572, 2079, 1, 1, 1, 2529.673311), -- Bec De Corbin Blade
(20572, 1867, 1, 1, 2, 75526.054989), -- Animal Skin
(20572, 1872, 1, 1, 2, 75526.054989), -- Animal Bone
(20572, 1882, 1, 1, 2, 12587.842113), -- Leather
(20572, 1894, 1, 1, 2, 1987.396488), -- Crafted Leather
(20572, 4042, 1, 1, 2, 944.146357), -- Enria
(20572, 3009, 1, 1, 2, 2311.977976), -- Recipe: Composite Boots
(20572, 2508, 1, 1, 2, 47203.659657), -- Cursed Bone
(20572, 2224, 1, 1, 2, 769.550782), -- Recipe: Demon's Tunic
(20572, 8724, 1, 1, 2, 1888.292714), -- Life Stone - Level 49
(20572, 8734, 1, 1, 2, 471.906897), -- Mid-Grade Life Stone - Level 49
(20572, 8744, 1, 1, 2, 47.223946), -- High-Grade Life Stone - Level 49
(20572, 8754, 1, 1, 2, 9.311764), -- Top-Grade Life Stone - Level 49
(20572, 1342, 10, 30, 2, 113289.581328), -- Steel Arrow
-- Tarlk Basilisk
(20573, 2119, 1, 1, -1, 5433), -- Crystal Dagger Blade
(20573, 4122, 1, 1, -1, 52996), -- Recipe: Maestro Holder (100%)
(20573, 5549, 1, 1, -1, 119240), -- Metallic Thread
(20573, 57, 472, 959, 0, 700000), -- Adena
(20573, 64, 1, 1, 1, 130.58758), -- Composite Boots
(20573, 2956, 1, 1, 1, 7251.41242), -- Composite Boots Part
(20573, 608, 1, 1, 1, 130.58758), -- Mithril Gauntlets
(20573, 1981, 1, 1, 1, 7251.41242), -- Mithril Gauntlets Design
(20573, 1868, 1, 1, 2, 75862.170244), -- Thread
(20573, 1873, 1, 1, 2, 15172.469662), -- Silver Nugget
(20573, 5549, 1, 1, 2, 3793.161932), -- Metallic Thread
(20573, 1889, 1, 1, 2, 2528.715266), -- Compound Braid
(20573, 4044, 1, 1, 2, 1264.446666), -- Thons
(20573, 2231, 1, 1, 2, 163.464588), -- Recipe: Full Plate Armor
(20573, 3014, 1, 1, 2, 1059.4927), -- Recipe: Full Plate Boots
(20573, 3019, 1, 1, 2, 1011.41488), -- Recipe: Full Plate Shield
(20573, 8725, 1, 1, 2, 1053.616522), -- Life Stone - Level 52
(20573, 8735, 1, 1, 2, 263.359614), -- Mid-Grade Life Stone - Level 52
(20573, 8745, 1, 1, 2, 26.353768), -- High-Grade Life Stone - Level 52
(20573, 8755, 1, 1, 2, 5.34198), -- Top-Grade Life Stone - Level 52
(20573, 1342, 10, 30, 2, 75861.992178), -- Steel Arrow
-- Elder Tarlk Basilisk 
(20574, 1867, 1, 3, -1, 836382), -- Animal Skin
(20574, 1539, 1, 1, -1, 278794), -- Greater Healing Potion
(20574, 4601, 1, 1, -1, 2788), -- Greater Dye of STR (Str+3 Con-3)
(20574, 57, 497, 1009, 0, 700000), -- Adena
(20574, 75, 1, 1, 1, 2.616499), -- Caliburs
(20574, 2089, 1, 1, 1, 235.550644), -- Caliburs Edge
(20574, 76, 1, 1, 1, 2.616499), -- Sword of Delusion
(20574, 2090, 1, 1, 1, 235.550644), -- Delusional Blade
(20574, 77, 1, 1, 1, 2.616499), -- Tsurugi
(20574, 2091, 1, 1, 1, 235.550644), -- Tsurugi Blade
(20574, 84, 1, 1, 1, 2.616499), -- Homunkulus's Sword
(20574, 2092, 1, 1, 1, 235.550644), -- Homunkulus's Sword Blade
(20574, 134, 1, 1, 1, 2.616499), -- Sword of Nightmare
(20574, 2095, 1, 1, 1, 235.550644), -- Sword of Nightmare Blade
(20574, 145, 1, 1, 1, 2.616499), -- Sword of Whispering Death
(20574, 2096, 1, 1, 1, 235.547786), -- Sword of Whispering Death Blade
(20574, 1869, 1, 1, 2, 39908.739234), -- Iron Ore
(20574, 1864, 1, 1, 2, 79817.338965), -- Stem
(20574, 1880, 1, 1, 2, 3990.901824), -- Steel
(20574, 5550, 1, 1, 2, 532.064442), -- Durable Metal Plate
(20574, 4043, 1, 1, 2, 1330.300608), -- Asofe
(20574, 4122, 1, 1, 2, 1773.780645), -- Recipe: Maestro Holder (100%)
(20574, 4609, 1, 1, 2, 88.723908), -- Greater Dye of MEN (Men+3 Int-3)
(20574, 4123, 1, 1, 2, 1773.780645), -- Recipe: Maestro Anvil Lock (100%)
(20574, 8725, 1, 1, 2, 1108.630341), -- Life Stone - Level 52
(20574, 8735, 1, 1, 2, 277.192461), -- Mid-Grade Life Stone - Level 52
(20574, 8745, 1, 1, 2, 27.761097), -- High-Grade Life Stone - Level 52
(20574, 8755, 1, 1, 2, 5.58012), -- Top-Grade Life Stone - Level 52
(20574, 1539, 1, 1, 2, 8868.20571), -- Greater Healing Potion
-- Oel Mahum Warrior
(20575, 4598, 1, 1, -1, 4711), -- Greater Dye of MEN (Men+2 Wit-2)
(20575, 1806, 1, 1, -1, 2826), -- Recipe: Soulshot (B-Grade)
(20575, 1870, 1, 3, -1, 706598), -- Coal
(20575, 57, 558, 1137, 0, 700000), -- Adena
(20575, 135, 1, 1, 1, 5.534095), -- Samurai Longsword
(20575, 2115, 1, 1, 1, 597.588114), -- Samurai Longsword Blade
(20575, 5286, 1, 1, 1, 5.534095), -- Berserker Blade
(20575, 5530, 1, 1, 1, 598.343696), -- Berserker Blade Edge
(20575, 1870, 1, 1, 2, 40137.885173), -- Coal
(20575, 1865, 1, 1, 2, 40137.885173), -- Varnish
(20575, 1874, 1, 1, 2, 2675.846801), -- Oriharukon Ore
(20575, 4043, 1, 1, 2, 1337.96919), -- Asofe
(20575, 4039, 1, 1, 2, 1337.96919), -- Mold Glue
(20575, 4145, 1, 1, 2, 176.014838), -- Recipe: Avadon Leather Armor (100%)
(20575, 4184, 1, 1, 2, 46.247395), -- Recipe: Sprite's Staff (100%)
(20575, 5165, 1, 1, 2, 80.314783), -- Recipe: Blessed Spiritshot (B) Compressed Package (100%)
(20575, 4180, 1, 1, 2, 4459.805721), -- Recipe: Silver Arrow (100%)
(20575, 8726, 1, 1, 2, 929.160534), -- Life Stone - Level 55
(20575, 8736, 1, 1, 2, 232.244344), -- Mid-Grade Life Stone - Level 55
(20575, 8746, 1, 1, 2, 23.261066), -- High-Grade Life Stone - Level 55
(20575, 8756, 1, 1, 2, 4.395792), -- Top-Grade Life Stone - Level 55
-- Oel Mahum Witch Doctor
(20576, 2119, 1, 1, -1, 12928), -- Crystal Dagger Blade
(20576, 4145, 1, 1, -1, 12443), -- Recipe: Avadon Leather Armor (100%)
(20576, 4591, 1, 1, -1, 9457), -- Greater Dye of CON (Con+2 Str-2)
(20576, 57, 1121, 2284, 0, 700000), -- Adena
(20576, 855, 1, 1, 1, 107.178066), -- Nassen's Earring
(20576, 1918, 1, 1, 1, 7561.673208), -- Nassen's Earring Gemstone
(20576, 119, 1, 1, 1, 80.395506), -- Necklace of Seal
(20576, 1920, 1, 1, 1, 5974.304355), -- Necklace of Seal Chain
(20576, 886, 1, 1, 1, 160.767099), -- Ring of Seal
(20576, 2917, 1, 1, 1, 10028.681766), -- Ring of Seal Gemstone
(20576, 1865, 1, 1, 2, 80579.603656), -- Varnish
(20576, 1870, 1, 1, 2, 80579.603656), -- Coal
(20576, 1879, 1, 1, 2, 13429.995894), -- Cokes
(20576, 1875, 1, 1, 2, 5371.924016), -- Stone of Purity
(20576, 4040, 1, 1, 2, 1611.540034), -- Mold Lubricant
(20576, 4187, 1, 1, 2, 92.741146), -- Recipe: Kris (100%)
(20576, 5155, 1, 1, 2, 161.135418), -- Recipe: Soulshot (B) Compressed Package (100%)
(20576, 5275, 1, 1, 2, 161.135418), -- Recipe: Greater Spiritshot (B) Compressed Package(100%)
(20576, 4178, 1, 1, 2, 1478.46857), -- Recipe: Zubei's Shield (100%)
(20576, 8726, 1, 1, 2, 1865.230744), -- Life Stone - Level 55
(20576, 8736, 1, 1, 2, 466.307686), -- Mid-Grade Life Stone - Level 55
(20576, 8746, 1, 1, 2, 46.649354), -- High-Grade Life Stone - Level 55
(20576, 8756, 1, 1, 2, 9.664408), -- Top-Grade Life Stone - Level 55
-- Leto Lizardman
(20577, 351, 1, 1, -1, 904), -- Blast Plate
(20577, 2030, 1, 1, -1, 8256), -- Tome of Blood Page
(20577, 2154, 1, 1, -1, 75575), -- Recipe: Elven Earring
(20577, 57, 298, 595, 0, 700000), -- Adena
(20577, 849, 1, 1, 1, 379.875645), -- Tiger's Eye Earring
(20577, 1901, 1, 1, 1, 12959.713458), -- Tiger's Eye Earring Stone
(20577, 912, 1, 1, 1, 284.754159), -- Near Forest Necklace
(20577, 880, 1, 1, 1, 568.656738), -- Black Pearl Ring
(20577, 1872, 1, 1, 2, 71486.457854), -- Animal Bone
(20577, 1867, 1, 1, 2, 71486.457854), -- Animal Skin
(20577, 1881, 1, 1, 2, 7148.693846), -- Coarse Bone Powder
(20577, 1875, 1, 1, 2, 3574.266822), -- Stone of Purity
(20577, 2154, 1, 1, 2, 5740.358064), -- Recipe: Elven Earring
(20577, 2274, 1, 1, 2, 382.88278), -- Recipe: Skull Breaker
(20577, 2270, 1, 1, 2, 382.88278), -- Recipe: Goat Head Staff
-- Leto Lizardman Archer
(20578, 1882, 1, 1, -1, 170581), -- Leather
(20578, 1939, 1, 1, -1, 67424), -- Mithril Banded Gaiters Material
(20578, 1901, 1, 1, -1, 106024), -- Tiger's Eye Earring Stone
(20578, 57, 324, 649, 0, 700000), -- Adena
(20578, 278, 1, 1, 1, 54.892406), -- Gastraphetes
(20578, 2029, 1, 1, 1, 2434.107594), -- Gastraphetes Shaft
(20578, 1868, 1, 1, 2, 136045.376456), -- Thread
(20578, 1873, 1, 1, 2, 27208.950842), -- Silver Nugget
(20578, 5549, 1, 1, 2, 6802.393272), -- Metallic Thread
(20578, 1889, 1, 1, 2, 4534.928848), -- Compound Braid
(20578, 2273, 1, 1, 2, 485.974126), -- Recipe: Tarbar
(20578, 6037, 1, 1, 2, 136045.376456), -- Waking Scroll
-- Leto Lizardman Soldier
(20579, 1943, 1, 1, -1, 63570), -- Manticore Skin Gaiters Pattern
(20579, 1946, 1, 1, -1, 108154), -- Rip Gauntlets Pattern
(20579, 1889, 1, 1, -1, 53356), -- Compound Braid
(20579, 57, 338, 675, 0, 700000), -- Adena
(20579, 1124, 1, 1, 1, 90.093708), -- Boots of Power
(20579, 1948, 1, 1, 1, 3494.156292), -- Boots of Power Pattern
(20579, 2424, 1, 1, 1, 90.093708), -- Manticore Skin Boots
(20579, 2923, 1, 1, 1, 3494.156292), -- Manticore Skin Boot Lining
(20579, 2425, 1, 1, 1, 90.093708), -- Brigandine Boots
(20579, 2924, 1, 1, 1, 3494.156292), -- Brigandine Boots Design
(20579, 2426, 1, 1, 1, 90.093708), -- Elven Mithril Boots
(20579, 2925, 1, 1, 1, 3494.156292), -- Elven Mithril Boots Design
(20579, 606, 1, 1, 1, 90.093708), -- Rip Gauntlets
(20579, 1946, 1, 1, 1, 3494.156292), -- Rip Gauntlets Pattern
(20579, 2448, 1, 1, 1, 90.093708), -- Manticore Skin Gloves
(20579, 2926, 1, 1, 1, 3494.156292), -- Manticore Skin Gloves Lining
(20579, 2449, 1, 1, 1, 90.093708), -- Brigandine Gauntlets
(20579, 2927, 1, 1, 1, 3494.156292), -- Brigandine Gauntlets Pattern
(20579, 2450, 1, 1, 1, 90.093708), -- Mithril Gloves
(20579, 2928, 1, 1, 1, 3494.156292), -- Mithril Gloves Design
(20579, 1868, 1, 1, 2, 118204.00097), -- Thread
(20579, 1873, 1, 1, 2, 23640.800194), -- Silver Nugget
(20579, 5549, 1, 1, 2, 5910.288725), -- Metallic Thread
(20579, 1889, 1, 1, 2, 3940.074248), -- Compound Braid
(20579, 2146, 1, 1, 2, 4221.533459), -- Recipe: Artisan's frame
(20579, 2286, 1, 1, 2, 328.280403), -- Recipe: Bonebreaker
(20579, 6668, 1, 1, 2, 21108.022001), -- Deluxe Chest Key - Grade 4
-- Leto Lizardman Warrior
(20580, 2031, 1, 1, -1, 15545), -- Morning Star Head
(20580, 1881, 1, 1, -1, 204752), -- Coarse Bone Powder
(20580, 1868, 1, 7, -1, 767821), -- Thread
(20580, 57, 649, 1296, 0, 700000), -- Adena
(20580, 395, 1, 1, 1, 230.755092), -- Manticore Skin Shirt
(20580, 1942, 1, 1, 1, 10122.343704), -- Manticore Skin Shirt Texture
(20580, 417, 1, 1, 1, 368.52486), -- Manticore Skin Gaiters
(20580, 1943, 1, 1, 1, 15762.376344), -- Manticore Skin Gaiters Pattern
(20580, 1868, 1, 1, 2, 264603.200807), -- Thread
(20580, 1873, 1, 1, 2, 52920.569394), -- Silver Nugget
(20580, 5549, 1, 1, 2, 13230.319267), -- Metallic Thread
(20580, 1889, 1, 1, 2, 8820.094899), -- Compound Braid
(20580, 2194, 1, 1, 2, 13527.896184), -- Recipe: Mithril Gloves
(20580, 2288, 1, 1, 2, 734.919449), -- Recipe: Ghost Staff
-- Leto Lizardman Shaman
(20581, 2202, 1, 1, -1, 88930), -- Recipe: Assault Boots
(20581, 2036, 1, 1, -1, 8804), -- Skull Breaker Head
(20581, 1902, 1, 1, -1, 88119), -- Elven Earring Beads
(20581, 57, 368, 733, 0, 700000), -- Adena
(20581, 279, 1, 1, 1, 41.86512), -- Reinforced Long Bow
(20581, 2040, 1, 1, 1, 2601.13488), -- Reinforced Long Bow Shaft
(20581, 1875, 1, 1, 2, 3330.25374), -- Stone of Purity
(20581, 1879, 1, 1, 2, 8325.729148), -- Cokes
(20581, 1885, 1, 1, 2, 4162.769776), -- High-Grade Suede
(20581, 5550, 1, 1, 2, 666.050748), -- Durable Metal Plate
(20581, 5549, 1, 1, 2, 4995.475408), -- Metallic Thread
(20581, 2287, 1, 1, 2, 277.568544), -- Recipe: Atuba Hammer
(20581, 2293, 1, 1, 2, 277.568544), -- Recipe: Glaive
(20581, 2198, 1, 1, 2, 1047.328304), -- Recipe: Sage's Rag
(20581, 1341, 10, 30, 2, 166513.255788), -- Bone Arrow
-- Leto Lizardman Overlord
(20582, 1942, 1, 1, -1, 88686), -- Manticore Skin Shirt Texture
(20582, 1894, 1, 1, -1, 61006), -- Crafted Leather
(20582, 1825, 1, 1, -1, 124192), -- Recipe: Oriharukon
(20582, 57, 726, 1449, 0, 700000), -- Adena
(20582, 629, 1, 1, 1, 496.832448), -- Kite Shield
(20582, 1947, 1, 1, 1, 21567.794024), -- Kite Shield Fragment
(20582, 2493, 1, 1, 1, 496.832448), -- Brigandine Shield
(20582, 2929, 1, 1, 1, 21567.794024), -- Brigandine Shield Fragment
(20582, 2411, 1, 1, 1, 347.95355), -- Brigandine Helmet
(20582, 2922, 1, 1, 1, 5768.793506), -- Brigandine Helmet Design
(20582, 1869, 1, 1, 2, 128395.14093), -- Iron Ore
(20582, 1864, 1, 3, 2, 85596.76062), -- Stem
(20582, 1880, 1, 1, 2, 12839.286236), -- Steel
(20582, 5550, 1, 1, 2, 1712.117498), -- Durable Metal Plate
(20582, 2987, 1, 1, 2, 12465.600756), -- Recipe: Plate Shield
(20582, 3020, 1, 1, 2, 713.19241), -- Recipe: Elven Long Sword
(20582, 1341, 20, 60, 2, 213991.90155), -- Bone Arrow
-- Timak Orc
(20583, 1944, 1, 1, -1, 46746), -- Mithril Tunic Fabric
(20583, 2157, 1, 1, -1, 75739), -- Recipe: Omen Beast's Eye Earring
(20583, 1903, 1, 1, -1, 152869), -- Elven Ring Piece
(20583, 57, 383, 764, 0, 700000), -- Adena
(20583, 261, 1, 1, 1, 44.109846), -- Bich'Hwa
(20583, 2039, 1, 1, 1, 2397.890154), -- Bich'Hwa Edge
(20583, 1870, 1, 1, 2, 78955.31538), -- Coal
(20583, 1865, 1, 1, 2, 78955.31538), -- Varnish
(20583, 1874, 1, 1, 2, 5263.61928), -- Oriharukon Ore
(20583, 2160, 1, 1, 2, 5093.95752), -- Recipe: Moonstone Earring
(20583, 2205, 1, 1, 2, 2498.57727), -- Recipe: Chain Gaiters
(20583, 5154, 1, 1, 2, 263.21517), -- Recipe: Soulshot (C) Compressed Package (100%)
-- Timak Orc Archer
(20584, 2988, 1, 1, -1, 52906), -- Recipe: Reinforced Mithril Gaiters
(20584, 2211, 1, 1, -1, 28114), -- Recipe: Plated Leather Armor
(20584, 1805, 1, 1, -1, 4180), -- Recipe: Soulshot (C-Grade)
(20584, 57, 508, 1017, 0, 700000), -- Adena
(20584, 280, 1, 1, 1, 45.401225), -- Light Crossbow
(20584, 2054, 1, 1, 1, 2679.598775), -- Light Crossbow Shaft
(20584, 1871, 1, 1, 2, 89948.031909), -- Charcoal
(20584, 1866, 1, 1, 2, 59965.290117), -- Suede
(20584, 1877, 1, 1, 2, 3597.905799), -- Adamantite Nugget
(20584, 2297, 1, 1, 2, 392.73801), -- Recipe: Flamberge
(20584, 5154, 1, 1, 2, 299.87385), -- Recipe: Soulshot (C) Compressed Package (100%)
(20584, 2994, 1, 1, 2, 7138.738833), -- Recipe: Boots of Seal
(20584, 6668, 1, 1, 2, 32124.421482), -- Deluxe Chest Key - Grade 4
-- Timak Orc Soldier
(20585, 2204, 1, 1, -1, 24481), -- Recipe: Chain Mail Shirt
(20585, 2308, 1, 1, -1, 5399), -- Recipe: Cursed Dagger
(20585, 1905, 1, 1, -1, 120264), -- Omen Beast's Eye Earring Gemstone
(20585, 57, 498, 1006, 0, 700000), -- Adena
(20585, 159, 1, 1, 1, 8.951877), -- Bonebreaker
(20585, 2048, 1, 1, 1, 513.264114), -- Bonebreaker Head
(20585, 187, 1, 1, 1, 8.951877), -- Atuba Hammer
(20585, 2049, 1, 1, 1, 513.264114), -- Atuba Hammer Head
(20585, 188, 1, 1, 1, 8.951877), -- Ghost Staff
(20585, 2050, 1, 1, 1, 544.225473), -- Ghost Staff Head
(20585, 189, 1, 1, 1, 8.951877), -- Staff of Life
(20585, 2051, 1, 1, 1, 544.225473), -- Staff of Life Shaft
(20585, 190, 1, 1, 1, 8.951877), -- Atuba Mace
(20585, 2058, 1, 1, 1, 513.261441), -- Atuba Mace Head
(20585, 1875, 1, 1, 2, 5912.493115), -- Stone of Purity
(20585, 1879, 1, 1, 2, 14781.25392), -- Cokes
(20585, 1885, 1, 1, 2, 7390.62696), -- High-Grade Suede
(20585, 5550, 1, 1, 2, 1182.49017), -- Durable Metal Plate
(20585, 5549, 1, 1, 2, 8868.760805), -- Metallic Thread
(20585, 2988, 1, 1, 2, 3742.100835), -- Recipe: Reinforced Mithril Gaiters
(20585, 2303, 1, 1, 2, 387.274195), -- Recipe: Skull Graver
-- Timak Orc Warrior
(20586, 3954, 1, 1, -1, 3974), -- Recipe: Blessed Spiritshot C
(20586, 2314, 1, 1, -1, 5206), -- Recipe: Body Slasher
(20586, 1884, 1, 1, -1, 733590), -- Cord
(20586, 57, 471, 957, 0, 700000), -- Adena
(20586, 70, 1, 1, 1, 21.582811), -- Claymore
(20586, 2047, 1, 1, 1, 1315.818139), -- Claymore Blade
(20586, 2499, 1, 1, 1, 21.582811), -- Elven Long Sword
(20586, 2967, 1, 1, 1, 1298.016239), -- Elven Long Sword Blade
(20586, 1895, 1, 1, 2, 21378.974327), -- Metallic Fiber
(20586, 2164, 1, 1, 2, 5755.868048), -- Recipe: Ring of Protection
(20586, 5154, 1, 1, 2, 249.427165), -- Recipe: Soulshot (C) Compressed Package (100%)
(20586, 2219, 1, 1, 2, 4647.593759), -- Recipe: Crimson Boots
(20586, 8723, 1, 1, 2, 2993.054254), -- Life Stone - Level 46
(20586, 8733, 1, 1, 2, 748.281495), -- Mid-Grade Life Stone - Level 46
(20586, 8743, 1, 1, 2, 74.810218), -- High-Grade Life Stone - Level 46
(20586, 8753, 1, 1, 2, 14.990734), -- Top-Grade Life Stone - Level 46
-- Timak Orc Shaman
(20587, 2062, 1, 1, -1, 8809), -- Scythe Edge
(20587, 1953, 1, 1, -1, 35975), -- Sage's Rag Lining
(20587, 1875, 1, 1, -1, 74876), -- Stone of Purity
(20587, 57, 442, 906, 0, 700000), -- Adena
(20587, 89, 1, 1, 1, 3.762928), -- Big Hammer
(20587, 2061, 1, 1, 1, 256.376172), -- Big Hammer Head
(20587, 160, 1, 1, 1, 3.762928), -- Battle Axe
(20587, 2063, 1, 1, 1, 256.376172), -- Battle Axe Head
(20587, 161, 1, 1, 1, 3.762928), -- Silver Axe
(20587, 2064, 1, 1, 1, 256.376172), -- Silver Axe Head
(20587, 173, 1, 1, 1, 3.762928), -- Skull Graver
(20587, 2065, 1, 1, 1, 256.376172), -- Skull Graver Head
(20587, 191, 1, 1, 1, 3.762928), -- Heavy Doom Hammer
(20587, 2066, 1, 1, 1, 260.145262), -- Heavy Doom Hammer Head
(20587, 192, 1, 1, 1, 3.762928), -- Crystal Staff
(20587, 2067, 1, 1, 1, 239.052736), -- Crystal Staff Head
(20587, 193, 1, 1, 1, 3.762928), -- Stick of Faith
(20587, 2068, 1, 1, 1, 239.052736), -- Stick of Faith Shaft
(20587, 194, 1, 1, 1, 3.762928), -- Heavy Doom Axe
(20587, 2069, 1, 1, 1, 260.141154), -- Heavy Doom Axe Blade
(20587, 1864, 1, 1, 2, 81664.211306), -- Stem
(20587, 1865, 1, 1, 2, 40832.23241), -- Varnish
(20587, 1866, 1, 1, 2, 27221.319264), -- Suede
(20587, 1873, 1, 1, 2, 16332.892964), -- Silver Nugget
(20587, 1868, 1, 1, 2, 81664.211306), -- Thread
(20587, 2323, 1, 1, 2, 142.221354), -- Recipe: Elemental Bow
(20587, 2225, 1, 1, 2, 887.552514), -- Recipe: Demon's Stockings
(20587, 2321, 1, 1, 2, 142.221354), -- Recipe: Stiletto
(20587, 3003, 1, 1, 2, 2536.154056), -- Recipe: Gloves of Seal
(20587, 8723, 1, 1, 2, 1633.390702), -- Life Stone - Level 46
(20587, 8733, 1, 1, 2, 408.411054), -- Mid-Grade Life Stone - Level 46
(20587, 8743, 1, 1, 2, 40.815754), -- High-Grade Life Stone - Level 46
(20587, 8753, 1, 1, 2, 8.365962), -- Top-Grade Life Stone - Level 46
-- Timak Orc Overlord
(20588, 1959, 1, 1, -1, 59745), -- Chain Mail Shirt Material
(20588, 2324, 1, 1, -1, 7728), -- Recipe: Noble Elven Bow
(20588, 57, 585, 1188, 0, 700000), -- Adena
(20588, 71, 1, 1, 1, 19.824375), -- Flamberge
(20588, 2059, 1, 1, 1, 1297.92295), -- Flamberge Blade
(20588, 72, 1, 1, 1, 19.824375), -- Stormbringer
(20588, 2060, 1, 1, 1, 1387.4283), -- Stormbringer Blade
(20588, 1868, 1, 1, 2, 127063.620066), -- Thread
(20588, 1873, 1, 1, 2, 25412.65443), -- Silver Nugget
(20588, 5549, 1, 1, 2, 6353.120118), -- Metallic Thread
(20588, 1889, 1, 1, 2, 4235.529384), -- Compound Braid
(20588, 4044, 1, 1, 2, 2117.764692), -- Thons
(20588, 3003, 1, 1, 2, 3946.063272), -- Recipe: Gloves of Seal
(20588, 2214, 1, 1, 2, 1576.407396), -- Recipe: Dwarven Chain Gaiters
(20588, 8723, 1, 1, 2, 2541.352422), -- Life Stone - Level 46
(20588, 8733, 1, 1, 2, 635.294616), -- Mid-Grade Life Stone - Level 46
(20588, 8743, 1, 1, 2, 63.49467), -- High-Grade Life Stone - Level 46
(20588, 8753, 1, 1, 2, 12.698934), -- Top-Grade Life Stone - Level 46
-- Fline
(20589, 1961, 1, 1, -1, 70730), -- Mithril Shirt Fabric
(20589, 1962, 1, 1, -1, 70730), -- Karmian Tunic Pattern
(20589, 1908, 1, 1, -1, 209311), -- Moonstone Earring Wire
(20589, 57, 874, 1776, 0, 700000), -- Adena
(20589, 439, 1, 1, 1, 179.491936), -- Karmian Tunic
(20589, 1962, 1, 1, 1, 8357.661397), -- Karmian Tunic Pattern
(20589, 471, 1, 1, 1, 286.860088), -- Karmian Stockings
(20589, 1954, 1, 1, 1, 13884.986579), -- Karmian Stocking Design
(20589, 1868, 1, 1, 2, 189933.663237), -- Thread
(20589, 1873, 1, 1, 2, 37986.628635), -- Silver Nugget
(20589, 5549, 1, 1, 2, 9496.592151), -- Metallic Thread
(20589, 1889, 1, 1, 2, 6331.234788), -- Compound Braid
(20589, 4044, 1, 1, 2, 3165.617394), -- Thons
(20589, 3003, 1, 1, 2, 5898.543204), -- Recipe: Gloves of Seal
(20589, 2214, 1, 1, 2, 2356.400922), -- Recipe: Dwarven Chain Gaiters
(20589, 8723, 1, 1, 2, 3798.792879), -- Life Stone - Level 46
(20589, 8733, 1, 1, 2, 949.633212), -- Mid-Grade Life Stone - Level 46
(20589, 8743, 1, 1, 2, 94.911315), -- High-Grade Life Stone - Level 46
(20589, 8753, 1, 1, 2, 18.982263), -- Top-Grade Life Stone - Level 46
-- Liele
(20590, 2935, 1, 1, -1, 121583), -- Reinforced Mithril Gaiters Fragment
(20590, 2068, 1, 1, -1, 16483), -- Stick of Faith Shaft
(20590, 2163, 1, 1, -1, 116683), -- Recipe: Earring of Protection
(20590, 57, 901, 1842, 0, 700000), -- Adena
(20590, 354, 1, 1, 1, 139.06922), -- Chain Mail Shirt
(20590, 1959, 1, 1, 1, 7278.06059), -- Chain Mail Shirt Material
(20590, 381, 1, 1, 1, 222.47484), -- Chain Gaiters
(20590, 1960, 1, 1, 1, 14805.39535), -- Chain Gaiters Part
(20590, 1867, 1, 1, 2, 131013.650376), -- Animal Skin
(20590, 1872, 1, 1, 2, 131013.650376), -- Animal Bone
(20590, 1882, 1, 1, 2, 21835.707138), -- Leather
(20590, 1894, 1, 1, 2, 3447.774414), -- Crafted Leather
(20590, 4042, 1, 1, 2, 1637.537328), -- Enria
(20590, 2230, 1, 1, 2, 1904.140728), -- Recipe: Theca Leather Gaiters
(20590, 2320, 1, 1, 2, 342.437256), -- Recipe: Cursed Staff
(20590, 8723, 1, 1, 2, 3930.326568), -- Life Stone - Level 46
(20590, 8733, 1, 1, 2, 982.581642), -- Mid-Grade Life Stone - Level 46
(20590, 8743, 1, 1, 2, 98.347032), -- High-Grade Life Stone - Level 46
(20590, 8753, 1, 1, 2, 19.847142), -- Top-Grade Life Stone - Level 46
-- Valley Treant
(20591, 2947, 1, 1, -1, 191540), -- Dwarven Chain Shield Fragment
(20591, 951, 1, 1, -1, 4876), -- Scroll: Enchant Weapon (C-Grade)
(20591, 1911, 1, 1, -1, 199446), -- Earring of Protection Gemstone
(20591, 57, 1058, 2159, 0, 700000), -- Adena
(20591, 94, 1, 1, 1, 53.767405), -- Bec de Corbin
(20591, 2079, 1, 1, 1, 4081.232595), -- Bec De Corbin Blade
(20591, 1867, 1, 1, 2, 144016.564776), -- Animal Skin
(20591, 1872, 1, 1, 2, 144016.564776), -- Animal Bone
(20591, 1882, 1, 1, 2, 24002.869338), -- Leather
(20591, 1894, 1, 1, 2, 3789.961014), -- Crafted Leather
(20591, 4042, 1, 1, 2, 1800.060528), -- Enria
(20591, 2230, 1, 1, 2, 2093.123928), -- Recipe: Theca Leather Gaiters
(20591, 2320, 1, 1, 2, 376.423656), -- Recipe: Cursed Staff
(20591, 8723, 1, 1, 2, 4320.405768), -- Life Stone - Level 46
(20591, 8733, 1, 1, 2, 1080.101442), -- Mid-Grade Life Stone - Level 46
(20591, 8743, 1, 1, 2, 108.107832), -- High-Grade Life Stone - Level 46
(20591, 8753, 1, 1, 2, 21.816942), -- Top-Grade Life Stone - Level 46
-- Satyr
(20592, 1880, 1, 1, -1, 368745), -- Steel
(20592, 2951, 1, 1, -1, 310131), -- Rind Leather Gloves Design
(20592, 2166, 1, 1, -1, 124998), -- Recipe: Earrings of Binding (100%)
(20592, 57, 1458, 2964, 0, 700000), -- Adena
(20592, 195, 1, 1, 1, 36.971484), -- Cursed Staff
(20592, 2082, 1, 1, 1, 2879.003028), -- Cursed Staff Head
(20592, 2502, 1, 1, 1, 36.971484), -- Dwarven War Hammer
(20592, 2968, 1, 1, 1, 2756.054004), -- Dwarven War Hammer Head
(20592, 1871, 1, 1, 2, 148529.640306), -- Charcoal
(20592, 1866, 1, 1, 2, 99019.85037), -- Suede
(20592, 1877, 1, 1, 2, 5941.218072), -- Adamantite Nugget
(20592, 4041, 1, 1, 2, 1291.62795), -- Mold Hardener
(20592, 4040, 1, 1, 2, 2970.609036), -- Mold Lubricant
(20592, 2340, 1, 1, 2, 345.425946), -- Recipe: Pa'agrian Hammer
(20592, 3006, 1, 1, 2, 6062.401176), -- Recipe: Demon's Gloves
(20592, 8724, 1, 1, 2, 4950.924894), -- Life Stone - Level 49
(20592, 8734, 1, 1, 2, 1237.798848), -- Mid-Grade Life Stone - Level 49
(20592, 8744, 1, 1, 2, 123.888084), -- High-Grade Life Stone - Level 49
(20592, 8754, 1, 1, 2, 24.615318), -- Top-Grade Life Stone - Level 49
-- Unicorn
(20593, 2083, 1, 1, -1, 26308), -- Stiletto Edge
(20593, 2341, 1, 1, -1, 9208), -- Recipe: Sage's Staff
(20593, 1912, 1, 1, -1, 426659), -- Ring of Protection Gemstone
(20593, 57, 1563, 3187, 0, 700000), -- Adena
(20593, 398, 1, 1, 1, 127.866228), -- Plated Leather
(20593, 1966, 1, 1, 1, 8005.832895), -- Plated Leather Fragment
(20593, 399, 1, 1, 1, 117.910106), -- Rind Leather Armor
(20593, 1975, 1, 1, 1, 7202.472588), -- Rind Leather Armor Design
(20593, 418, 1, 1, 1, 204.47077), -- Plated Leather Gaiters
(20593, 1967, 1, 1, 1, 11959.606418), -- Plated Leather Gaiters Material
(20593, 419, 1, 1, 1, 188.796049), -- Rind Leather Gaiters
(20593, 1976, 1, 1, 1, 13334.044946), -- Rind Leather Gaiters Material
(20593, 1871, 1, 1, 2, 159483.576359), -- Charcoal
(20593, 1866, 1, 1, 2, 106322.481055), -- Suede
(20593, 1877, 1, 1, 2, 6379.377908), -- Adamantite Nugget
(20593, 4041, 1, 1, 2, 1386.884425), -- Mold Hardener
(20593, 4040, 1, 1, 2, 3189.688954), -- Mold Lubricant
(20593, 2340, 1, 1, 2, 370.900819), -- Recipe: Pa'agrian Hammer
(20593, 3006, 1, 1, 2, 6509.498164), -- Recipe: Demon's Gloves
(20593, 8724, 1, 1, 2, 5316.051441), -- Life Stone - Level 49
(20593, 8734, 1, 1, 2, 1329.085472), -- Mid-Grade Life Stone - Level 49
(20593, 8744, 1, 1, 2, 133.024726), -- High-Grade Life Stone - Level 49
(20593, 8754, 1, 1, 2, 26.430677), -- Top-Grade Life Stone - Level 49
-- Forest Runner
(20594, 1978, 1, 1, -1, 173613), -- Tower Shield Fragment
(20594, 1871, 1, 5, -1, 902788), -- Charcoal
(20594, 1895, 1, 1, -1, 773819), -- Metallic Fiber
(20594, 57, 1071, 2178, 0, 700000), -- Adena
(20594, 231, 1, 1, 1, 16.948312), -- Grace Dagger
(20594, 2106, 1, 1, 1, 1526.051688), -- Grace Dagger Edge
(20594, 233, 1, 1, 1, 16.948312), -- Dark Screamer
(20594, 2107, 1, 1, 1, 1526.051688), -- Dark Screamer Edge
(20594, 1867, 1, 1, 2, 114873.23559), -- Animal Skin
(20594, 1872, 1, 1, 2, 114873.23559), -- Animal Bone
(20594, 1882, 1, 1, 2, 19145.400232), -- Leather
(20594, 1894, 1, 1, 2, 3022.855486), -- Crafted Leather
(20594, 4042, 1, 1, 2, 1435.932824), -- Enria
(20594, 2234, 1, 1, 2, 1284.108788), -- Recipe: Divine Stockings
(20594, 4609, 1, 1, 2, 191.587474), -- Greater Dye of MEN (Men+3 Int-3)
(20594, 2356, 1, 1, 2, 140.42333), -- Recipe: Demon's Staff
(20594, 6669, 1, 1, 2, 20036.04563), -- Deluxe Chest Key - Grade 5
(20594, 8725, 1, 1, 2, 2393.314062), -- Life Stone - Level 52
(20594, 8735, 1, 1, 2, 598.398032), -- Mid-Grade Life Stone - Level 52
(20594, 8745, 1, 1, 2, 59.78419), -- High-Grade Life Stone - Level 52
(20594, 8755, 1, 1, 2, 11.678772), -- Top-Grade Life Stone - Level 52
-- Fline Elder
(20595, 2096, 1, 1, -1, 15374), -- Sword of Whispering Death Blade
(20595, 2354, 1, 1, -1, 4602), -- Recipe: Deadman's Staff
(20595, 1894, 1, 1, -1, 98988), -- Crafted Leather
(20595, 57, 1117, 2270, 0, 700000), -- Adena
(20595, 231, 1, 1, 1, 17.651288), -- Grace Dagger
(20595, 2106, 1, 1, 1, 1589.348712), -- Grace Dagger Edge
(20595, 233, 1, 1, 1, 17.651288), -- Dark Screamer
(20595, 2107, 1, 1, 1, 1589.348712), -- Dark Screamer Edge
(20595, 1870, 1, 1, 2, 106059.604608), -- Coal
(20595, 1865, 1, 1, 2, 106059.604608), -- Varnish
(20595, 1874, 1, 1, 2, 7070.62446), -- Oriharukon Ore
(20595, 4043, 1, 1, 2, 3535.431084), -- Asofe
(20595, 4039, 1, 1, 2, 3535.431084), -- Mold Glue
(20595, 4125, 1, 1, 2, 4713.74964), -- Recipe: Maestro Mold (100%)
(20595, 3014, 1, 1, 2, 2962.554804), -- Recipe: Full Plate Boots
(20595, 8725, 1, 1, 2, 2946.152952), -- Life Stone - Level 52
(20595, 8735, 1, 1, 2, 736.419384), -- Mid-Grade Life Stone - Level 52
(20595, 8745, 1, 1, 2, 73.68948), -- High-Grade Life Stone - Level 52
(20595, 8755, 1, 1, 2, 14.737896), -- Top-Grade Life Stone - Level 52
-- Liele Elder
(20596, 1875, 1, 1, -1, 199596), -- Stone of Purity
(20596, 1539, 1, 1, -1, 665319), -- Greater Healing Potion
(20596, 4609, 1, 1, -1, 6653), -- Greater Dye of MEN (Men+3 Int-3)
(20596, 57, 1189, 2403, 0, 700000), -- Adena
(20596, 162, 1, 1, 1, 4.683114), -- War Axe
(20596, 2097, 1, 1, 1, 414.443528), -- War Axe Blade
(20596, 174, 1, 1, 1, 4.683114), -- Nirvana Axe
(20596, 2098, 1, 1, 1, 414.443528), -- Nirvana Axe Blade
(20596, 196, 1, 1, 1, 4.683114), -- Stick of Eternity
(20596, 2099, 1, 1, 1, 436.170558), -- Stick of Eternity Shaft
(20596, 197, 1, 1, 1, 4.683114), -- Paradia Staff
(20596, 2100, 1, 1, 1, 436.170558), -- Paradia Staff Head
(20596, 199, 1, 1, 1, 4.683114), -- Pa'agrian Hammer
(20596, 2102, 1, 1, 1, 420.525718), -- Pa'agrian Hammer Head
(20596, 200, 1, 1, 1, 4.683114), -- Sage's Staff
(20596, 2103, 1, 1, 1, 436.170558), -- Sage's Staff Head
(20596, 201, 1, 1, 1, 4.683114), -- Club of Nature
(20596, 2104, 1, 1, 1, 436.170558), -- Club of Nature Head
(20596, 202, 1, 1, 1, 4.683114), -- Mace of Underworld
(20596, 2105, 1, 1, 1, 414.440082), -- Mace of Underworld Head
(20596, 1873, 1, 1, 2, 35374.5169), -- Silver Nugget
(20596, 1868, 1, 1, 2, 176872.0131), -- Thread
(20596, 1876, 1, 1, 2, 17687.1156), -- Mithril Ore
(20596, 1895, 1, 1, 2, 25267.308), -- Metallic Fiber
(20596, 4042, 1, 1, 2, 1473.9263), -- Enria
(20596, 4608, 1, 1, 2, 196.5616), -- Greater Dye of INT (Int+3 Wit-3)
(20596, 3017, 1, 1, 2, 2470.1622), -- Recipe: Divine Gloves
(20596, 5155, 1, 1, 2, 176.8483), -- Recipe: Soulshot (B) Compressed Package (100%)
(20596, 6669, 1, 1, 2, 20566.4002), -- Deluxe Chest Key - Grade 5
(20596, 8725, 1, 1, 2, 2456.4486), -- Life Stone - Level 52
(20596, 8735, 1, 1, 2, 614.255), -- Mid-Grade Life Stone - Level 52
(20596, 8745, 1, 1, 2, 61.4255), -- High-Grade Life Stone - Level 52
(20596, 8755, 1, 1, 2, 12.8565), -- Top-Grade Life Stone - Level 52
-- Valley Treant Elder
(20597, 3034, 1, 1, -1, 9970), -- Recipe: Spiritshot B
(20597, 2113, 1, 1, -1, 24141), -- Scorpion Blade
(20597, 1918, 1, 1, -1, 215903), -- Nassen's Earring Gemstone
(20597, 57, 1973, 4008, 0, 700000), -- Adena
(20597, 442, 1, 1, 1, 111.55485), -- Divine Tunic
(20597, 1988, 1, 1, 1, 8841.906414), -- Divine Tunic Fabric
(20597, 473, 1, 1, 1, 178.441758), -- Divine Stockings
(20597, 1989, 1, 1, 1, 13869.096978), -- Divine Stocking Pattern
(20597, 1870, 1, 1, 2, 153390.651687), -- Coal
(20597, 1865, 1, 1, 2, 153390.651687), -- Varnish
(20597, 1874, 1, 1, 2, 10226.110776), -- Oriharukon Ore
(20597, 4043, 1, 1, 2, 5113.055388), -- Asofe
(20597, 4039, 1, 1, 2, 5113.055388), -- Mold Glue
(20597, 4133, 1, 1, 2, 737.602341), -- Recipe: Zubei's Breastplate (100%)
(20597, 4959, 1, 1, 2, 2955.459129), -- Recipe: Sealed Avadon Boots (60%)
(20597, 4941, 1, 1, 2, 1179.961755), -- Recipe: Zubei's Gaiters (60%)
(20597, 8726, 1, 1, 2, 3550.658097), -- Life Stone - Level 55
(20597, 8736, 1, 1, 2, 887.748687), -- Mid-Grade Life Stone - Level 55
(20597, 8746, 1, 1, 2, 88.875864), -- High-Grade Life Stone - Level 55
(20597, 8756, 1, 1, 2, 17.169201), -- Top-Grade Life Stone - Level 55
-- Satyr Elder
(20598, 4180, 1, 1, -1, 512556), -- Recipe: Silver Arrow (100%)
(20598, 2120, 1, 1, -1, 22159), -- Great Pata Blade
(20598, 1806, 1, 1, -1, 9226), -- Recipe: Soulshot (B-Grade)
(20598, 57, 1822, 3711, 0, 700000), -- Adena
(20598, 442, 1, 1, 1, 103.2274), -- Divine Tunic
(20598, 1988, 1, 1, 1, 8181.867576), -- Divine Tunic Fabric
(20598, 473, 1, 1, 1, 165.121272), -- Divine Stockings
(20598, 1989, 1, 1, 1, 12833.783752), -- Divine Stocking Pattern
(20598, 1864, 1, 3, 2, 141938.691444), -- Stem
(20598, 1869, 1, 1, 2, 141938.691444), -- Iron Ore
(20598, 1878, 1, 1, 2, 56775.740571), -- Braided Hemp
(20598, 1884, 1, 1, 2, 87347.056269), -- Cord
(20598, 4039, 1, 1, 2, 4731.201717), -- Mold Glue
(20598, 4178, 1, 1, 2, 2604.294891), -- Recipe: Zubei's Shield (100%)
(20598, 4184, 1, 1, 2, 163.675908), -- Recipe: Sprite's Staff (100%)
(20598, 5160, 1, 1, 2, 283.792905), -- Recipe: Spiritshot (B) Compressed Package (100%)
(20598, 8726, 1, 1, 2, 3285.837852), -- Life Stone - Level 55
(20598, 8736, 1, 1, 2, 821.459463), -- Mid-Grade Life Stone - Level 55
(20598, 8746, 1, 1, 2, 82.277943), -- High-Grade Life Stone - Level 55
(20598, 8756, 1, 1, 2, 16.279593), -- Top-Grade Life Stone - Level 55
-- Unicorn Elder
(20599, 2120, 1, 1, -1, 23008), -- Great Pata Blade
(20599, 4146, 1, 1, -1, 30703), -- Recipe: Tunic of Zubei (100%)
(20599, 4590, 1, 1, -1, 15966), -- Greater Dye of STR (Str+2 Dex-2)
(20599, 57, 1893, 3856, 0, 700000), -- Adena
(20599, 2436, 1, 1, 1, 119.39733), -- Theca Leather Boots
(20599, 2954, 1, 1, 1, 7996.6068), -- Theca Leather Boots Texture
(20599, 2437, 1, 1, 1, 91.85982), -- Drake Leather Boots
(20599, 2960, 1, 1, 1, 6879.72831), -- Drake Leather Boots Design
(20599, 2438, 1, 1, 1, 91.85982), -- Full Plate Boots
(20599, 2961, 1, 1, 1, 6879.72831), -- Full Plate Boots Part
(20599, 2460, 1, 1, 1, 119.39733), -- Theca Leather Gloves
(20599, 2955, 1, 1, 1, 7996.6068), -- Theca Leather Gloves Texture
(20599, 2461, 1, 1, 1, 91.85982), -- Drake Leather Gloves
(20599, 2962, 1, 1, 1, 6879.72831), -- Drake Leather Gloves Design
(20599, 2462, 1, 1, 1, 91.85982), -- Full Plate Gauntlets
(20599, 2963, 1, 1, 1, 6879.72831), -- Full Plate Gauntlets Part
(20599, 2463, 1, 1, 1, 91.85982), -- Divine Gloves
(20599, 2964, 1, 1, 1, 6879.7794), -- Divine Gloves Pattern
(20599, 1864, 1, 3, 2, 147375.724428), -- Stem
(20599, 1869, 1, 1, 2, 147375.724428), -- Iron Ore
(20599, 1878, 1, 1, 2, 58950.563877), -- Braided Hemp
(20599, 1884, 1, 1, 2, 90692.929203), -- Cord
(20599, 4039, 1, 1, 2, 4912.432779), -- Mold Glue
(20599, 4178, 1, 1, 2, 2704.053717), -- Recipe: Zubei's Shield (100%)
(20599, 4184, 1, 1, 2, 169.945596), -- Recipe: Sprite's Staff (100%)
(20599, 5160, 1, 1, 2, 294.663735), -- Recipe: Spiritshot (B) Compressed Package (100%)
(20599, 8726, 1, 1, 2, 3411.703524), -- Life Stone - Level 55
(20599, 8736, 1, 1, 2, 852.925881), -- Mid-Grade Life Stone - Level 55
(20599, 8746, 1, 1, 2, 85.429641), -- High-Grade Life Stone - Level 55
(20599, 8756, 1, 1, 2, 16.903191), -- Top-Grade Life Stone - Level 55
-- Karul Bugbear
(20600, 1945, 1, 1, -1, 85765), -- Mithril Stocking Design
(20600, 1873, 1, 1, -1, 431910), -- Silver Nugget
(20600, 1825, 1, 1, -1, 77127), -- Recipe: Oriharukon
(20600, 57, 451, 900, 0, 700000), -- Adena
(20600, 629, 1, 1, 1, 308.545152), -- Kite Shield
(20600, 1947, 1, 1, 1, 13394.129776), -- Kite Shield Fragment
(20600, 2493, 1, 1, 1, 308.545152), -- Brigandine Shield
(20600, 2929, 1, 1, 1, 13394.129776), -- Brigandine Shield Fragment
(20600, 2411, 1, 1, 1, 216.0877), -- Brigandine Helmet
(20600, 2922, 1, 1, 1, 3582.562444), -- Brigandine Helmet Design
(20600, 1868, 1, 1, 2, 186053.4229), -- Thread
(20600, 1873, 1, 1, 2, 37210.68458), -- Silver Nugget
(20600, 5549, 1, 1, 2, 9302.54818), -- Metallic Thread
(20600, 1889, 1, 1, 2, 6201.86274), -- Compound Braid
(20600, 5231, 1, 1, 2, 6644.78267), -- Recipe: Metal Hardener (100%)
(20600, 2286, 1, 1, 2, 516.69893), -- Recipe: Bonebreaker
-- Tamlin Orc
(20601, 1880, 1, 1, -1, 97232), -- Steel
(20601, 2304, 1, 1, -1, 4246), -- Recipe: Heavy Doom Hammer
(20601, 1905, 1, 1, -1, 94584), -- Omen Beast's Eye Earring Gemstone
(20601, 57, 394, 788, 0, 700000), -- Adena
(20601, 353, 1, 1, 1, 81.160755), -- Half Plate Armor
(20601, 1950, 1, 1, 1, 3961.994595), -- Half Plate Temper
(20601, 380, 1, 1, 1, 129.859275), -- Plate Gaiters
(20601, 1951, 1, 1, 1, 6161.985375), -- Plate Gaiters Part
(20601, 1869, 1, 1, 2, 81375.90135), -- Iron Ore
(20601, 1864, 1, 1, 2, 162751.8027), -- Stem
(20601, 1880, 1, 1, 2, 8137.590135), -- Steel
(20601, 5550, 1, 1, 2, 1085.029155), -- Durable Metal Plate
(20601, 2199, 1, 1, 2, 3433.483635), -- Recipe: Karmian Stockings
(20601, 5269, 1, 1, 2, 271.193025), -- Recipe: Greater Soulshot (C) Compressed Package(100%)
-- Tamlin Orc Archer
(20602, 1889, 1, 1, -1, 87565), -- Compound Braid
(20602, 2999, 1, 1, -1, 88153), -- Recipe: Plated Leather Gloves
(20602, 1873, 1, 1, -1, 525391), -- Silver Nugget
(20602, 57, 529, 1069, 0, 700000), -- Adena
(20602, 280, 1, 1, 1, 47.550494), -- Light Crossbow
(20602, 2054, 1, 1, 1, 2806.449506), -- Light Crossbow Shaft
(20602, 1873, 1, 1, 2, 32978.3484), -- Silver Nugget
(20602, 1868, 1, 1, 2, 164892.22504), -- Thread
(20602, 1876, 1, 1, 2, 16489.29496), -- Mithril Ore
(20602, 1895, 1, 1, 2, 23555.92864), -- Metallic Fiber
(20602, 2300, 1, 1, 2, 360.10632), -- Recipe: Scythe
(20602, 2205, 1, 1, 2, 2609.14056), -- Recipe: Chain Gaiters
(20602, 5154, 1, 1, 2, 274.84976), -- Recipe: Soulshot (C) Compressed Package (100%)
(20602, 2311, 1, 1, 2, 360.10632), -- Recipe: Chakram
-- Kronbe Spider
(20603, 1952, 1, 1, -1, 34740), -- Salamander Skin Mail Texture
(20603, 2311, 1, 1, -1, 4736), -- Recipe: Chakram
(20603, 1872, 1, 3, -1, 723055), -- Animal Bone
(20603, 57, 429, 871, 0, 700000), -- Adena
(20603, 1125, 1, 1, 1, 120.706722), -- Assault Boots
(20603, 1957, 1, 1, 1, 5065.605866), -- Assault Boots Part
(20603, 2427, 1, 1, 1, 120.706722), -- Salamander Skin Boots
(20603, 2931, 1, 1, 1, 5065.605866), -- Salamander Skin Boot Lining
(20603, 2428, 1, 1, 1, 120.706722), -- Plate Boots
(20603, 2932, 1, 1, 1, 5065.605866), -- Plate Boots Design
(20603, 61, 1, 1, 1, 120.706722), -- Mithril Plate Gloves
(20603, 1949, 1, 1, 1, 5065.605866), -- Mithril Gloves Design
(20603, 607, 1, 1, 1, 120.706722), -- Ogre Power Gauntlets
(20603, 1963, 1, 1, 1, 5065.605866), -- Ogre Power Gauntlets Part
(20603, 2451, 1, 1, 1, 120.706722), -- Sage's Worn Gloves
(20603, 2933, 1, 1, 1, 5065.730338), -- Sage's Worn Gloves Lining
(20603, 1872, 1, 1, 2, 103738.405455), -- Animal Bone
(20603, 1867, 1, 1, 2, 103738.405455), -- Animal Skin
(20603, 1881, 1, 1, 2, 10373.969175), -- Coarse Bone Powder
(20603, 1875, 1, 1, 2, 5186.855958), -- Stone of Purity
(20603, 2991, 1, 1, 2, 6174.987777), -- Recipe: Karmian Boots
(20603, 5279, 1, 1, 2, 259.317072), -- Recipe: Greater Blessed Spiritshot (C) Compressed Package(100%)
(20603, 6668, 1, 1, 2, 27787.059108), -- Deluxe Chest Key - Grade 4
-- Lakin
(20604, 2323, 1, 1, -1, 4611), -- Recipe: Elemental Bow
(20604, 2322, 1, 1, -1, 4611), -- Recipe: Soulfire Dirk
(20604, 4553, 1, 1, -1, 5293), -- Greater Dye of STR (Str+1 Con-1)
(20604, 57, 521, 1068, 0, 700000), -- Adena
(20604, 852, 1, 1, 1, 174.744034), -- Moonstone Earring
(20604, 1908, 1, 1, 1, 9871.30634), -- Moonstone Earring Wire
(20604, 915, 1, 1, 1, 131.114666), -- Aquastone Necklace
(20604, 1910, 1, 1, 1, 7849.467052), -- Aquastone Necklace Chain
(20604, 883, 1, 1, 1, 262.229332), -- Aquastone Ring
(20604, 1909, 1, 1, 1, 14077.138576), -- Aquastone Ring Wire
(20604, 1872, 1, 1, 2, 119127.041145), -- Animal Bone
(20604, 1867, 1, 1, 2, 119127.041145), -- Animal Skin
(20604, 1881, 1, 1, 2, 11912.851825), -- Coarse Bone Powder
(20604, 1875, 1, 1, 2, 5956.278202), -- Stone of Purity
(20604, 2991, 1, 1, 2, 7090.990263), -- Recipe: Karmian Boots
(20604, 5279, 1, 1, 2, 297.784368), -- Recipe: Greater Blessed Spiritshot (C) Compressed Package(100%)
(20604, 6668, 1, 1, 2, 31909.013052), -- Deluxe Chest Key - Grade 4
-- Weird Drake
(20605, 2059, 1, 1, -1, 8915), -- Flamberge Blade
(20605, 1867, 1, 3, -1, 800154), -- Animal Skin
(20605, 1908, 1, 1, -1, 113658), -- Moonstone Earring Wire
(20605, 57, 475, 964, 0, 700000), -- Adena
(20605, 439, 1, 1, 1, 97.464224), -- Karmian Tunic
(20605, 1962, 1, 1, 1, 4538.214923), -- Karmian Tunic Pattern
(20605, 471, 1, 1, 1, 155.765192), -- Karmian Stockings
(20605, 1954, 1, 1, 1, 7539.555661), -- Karmian Stocking Design
(20605, 1868, 1, 1, 2, 103136.2924), -- Thread
(20605, 1873, 1, 1, 2, 20627.202), -- Silver Nugget
(20605, 5549, 1, 1, 2, 5156.7652), -- Metallic Thread
(20605, 1889, 1, 1, 2, 3437.9376), -- Compound Braid
(20605, 4044, 1, 1, 2, 1718.9688), -- Thons
(20605, 3003, 1, 1, 2, 3202.9808), -- Recipe: Gloves of Seal
(20605, 2214, 1, 1, 2, 1279.5544), -- Recipe: Dwarven Chain Gaiters
(20605, 8723, 1, 1, 2, 2062.7908), -- Life Stone - Level 46
(20605, 8733, 1, 1, 2, 515.6624), -- Mid-Grade Life Stone - Level 46
(20605, 8743, 1, 1, 2, 51.538), -- High-Grade Life Stone - Level 46
(20605, 8753, 1, 1, 2, 10.3076), -- Top-Grade Life Stone - Level 46
-- Kuran Kobold
(20606, 2260, 1, 1, -1, 12244), -- Recipe: Mace of Judgment
(20606, 1932, 1, 1, -1, 125162), -- Bone Helmet Design
(20606, 2152, 1, 1, -1, 138824), -- Recipe: Enchanted Necklace
(20606, 57, 340, 656, 0, 700000), -- Adena
(20606, 220, 1, 1, 1, 281), -- Crafted Dagger
(20606, 1869, 1, 1, 2, 88508.21265), -- Iron Ore
(20606, 1864, 1, 1, 2, 177016.4253), -- Stem
(20606, 1880, 1, 1, 2, 8850.95973), -- Steel
(20606, 5550, 1, 1, 2, 1179.99873), -- Durable Metal Plate
(20606, 2262, 1, 1, 2, 1374.40359), -- Recipe: Elven Bow
-- Kuran Kobold Warrior
(20607, 626, 1, 1, -1, 9809), -- Bronze Shield
(20607, 2020, 1, 1, -1, 14509), -- Temptation of Abyss Piece
(20607, 1899, 1, 1, -1, 129508), -- Necklace of Devotion Chain
(20607, 57, 355, 696, 0, 700000), -- Adena
(20607, 101, 1, 1, 1, 59.073875), -- Scroll of Wisdom
(20607, 312, 1, 1, 1, 59.073875), -- Branch of Life
(20607, 313, 1, 1, 1, 59.073875), -- Temptation of Abyss
(20607, 2020, 1, 1, 1, 1628.70823), -- Temptation of Abyss Piece
(20607, 314, 1, 1, 1, 59.070145), -- Proof of Revenge
(20607, 1870, 1, 1, 2, 116293.764398), -- Coal
(20607, 1865, 1, 1, 2, 116293.764398), -- Varnish
(20607, 1874, 1, 1, 2, 7753.030628), -- Oriharukon Ore
(20607, 2262, 1, 1, 2, 1805.440576), -- Recipe: Elven Bow
-- Patin Archer
(20608, 1874, 1, 1, -1, 55672), -- Oriharukon Ore
(20608, 2022, 1, 1, -1, 13008), -- Mace of Judgment Head
(20608, 2153, 1, 1, -1, 129874), -- Recipe: Tiger's Eye Earring
(20608, 57, 354, 701, 0, 700000), -- Adena
(20608, 315, 1, 1, 1, 184), -- Divine Tome
(20608, 1872, 1, 1, 2, 86922.24825), -- Animal Bone
(20608, 1867, 1, 1, 2, 86922.24825), -- Animal Skin
(20608, 1881, 1, 1, 2, 8692.224825), -- Coarse Bone Powder
(20608, 1875, 1, 1, 2, 4346.207879), -- Stone of Purity
(20608, 2265, 1, 1, 2, 674.184423), -- Recipe: Spiked Club
(20608, 2274, 1, 1, 2, 465.685587), -- Recipe: Skull Breaker
(20608, 2189, 1, 1, 2, 2910.200786), -- Recipe: Mithril Tunic
-- Lakin Salamander
(20609, 2265, 1, 1, -1, 8969), -- Recipe: Spiked Club
(20609, 433, 1, 1, -1, 2256), -- Elven Tunic
(20609, 1900, 1, 1, -1, 94887), -- Enchanted Necklace Chain
(20609, 57, 366, 732, 0, 700000), -- Adena
(20609, 259, 1, 1, 1, 191), -- Single-Edged Jamadhr
(20609, 1866, 1, 1, 2, 52658.392072), -- Suede
(20609, 1871, 1, 1, 2, 78987.588108), -- Charcoal
(20609, 5220, 1, 1, 2, 3159.573144), -- Metal Hardener
(20609, 1885, 1, 1, 2, 6582.347356), -- High-Grade Suede
(20609, 956, 1, 1, 2, 2632.97762), -- Scroll: Enchant Armor (D-Grade)
(20609, 6667, 1, 1, 2, 49367.1217), -- Deluxe Chest Key - Grade 3
-- Sentinel Of Water
(20610, 2025, 1, 1, -1, 12109), -- Dwarven Trident Edge
(20610, 2267, 1, 1, -1, 9041), -- Recipe: Gastraphetes
(20610, 1864, 1, 3, -1, 874300), -- Stem
(20610, 57, 370, 737, 0, 700000), -- Adena
(20610, 292, 1, 1, 1, 193), -- Pike
(20610, 1864, 1, 1, 2, 119442.817208), -- Stem
(20610, 1865, 1, 1, 2, 59721.408604), -- Varnish
(20610, 1866, 1, 1, 2, 39814.117002), -- Suede
(20610, 1873, 1, 1, 2, 23888.656682), -- Silver Nugget
(20610, 1868, 1, 1, 2, 119442.817208), -- Thread
(20610, 2183, 1, 1, 2, 3929.150456), -- Recipe: Mithril Banded Mail
(20610, 2270, 1, 1, 2, 426.57483), -- Recipe: Goat Head Staff
(20610, 1341, 20, 60, 2, 99536.45801), -- Bone Arrow
-- Dre Vanul Warrior
(20611, 2153, 1, 1, -1, 143948), -- Recipe: Tiger's Eye Earring
(20611, 467, 1, 1, -1, 3857), -- Dark Stockings
(20611, 1884, 1, 1, -1, 569592), -- Cord
(20611, 57, 390, 782, 0, 700000), -- Adena
(20611, 86, 1, 1, 1, 20.416164), -- Tomahawk
(20611, 179, 1, 1, 1, 20.416164), -- Mace of Prayer
(20611, 180, 1, 1, 1, 20.416164), -- Mace of Judgment
(20611, 2022, 1, 1, 1, 787.87962), -- Mace of Judgment Head
(20611, 181, 1, 1, 1, 20.416164), -- Mace of Miracle
(20611, 182, 1, 1, 1, 20.416164), -- Doom Hammer
(20611, 183, 1, 1, 1, 20.416164), -- Mystic Staff
(20611, 184, 1, 1, 1, 20.416164), -- Conjuror's Staff
(20611, 2023, 1, 1, 1, 626.78949), -- Conjuror's Staff Head
(20611, 185, 1, 1, 1, 20.417742), -- Staff of Mana
(20611, 1864, 1, 1, 2, 144513.606), -- Stem
(20611, 1869, 1, 1, 2, 72256.803), -- Iron Ore
(20611, 1878, 1, 1, 2, 28902.803), -- Braided Hemp
(20611, 1884, 1, 1, 2, 44465.662), -- Cord
(20611, 1829, 1, 1, 2, 28902.803), -- Scroll of Escape: Clan Hall
(20611, 2193, 1, 1, 2, 9672.85), -- Recipe: Boots of Power
(20611, 1834, 1, 1, 2, 80285.473), -- Emergency Dressing
-- Salamander Rowin
(20612, 349, 1, 1, -1, 1496), -- Compound Scale Mail
(20612, 1869, 1, 3, -1, 527615), -- Iron Ore
(20612, 1885, 1, 1, -1, 87936), -- High-Grade Suede
(20612, 57, 446, 892, 0, 700000), -- Adena
(20612, 436, 1, 1, 1, 479.533068), -- Tunic of Knowledge
(20612, 469, 1, 1, 1, 766.466932), -- Stockings of Knowledge
(20612, 1866, 1, 1, 2, 53433.989025), -- Suede
(20612, 1871, 1, 1, 2, 80151.10295), -- Charcoal
(20612, 5220, 1, 1, 2, 3205.9868), -- Metal Hardener
(20612, 1885, 1, 1, 2, 6679.218775), -- High-Grade Suede
(20612, 2188, 1, 1, 2, 5725.1129), -- Recipe: Manticore Skin Gaiters
(20612, 2274, 1, 1, 2, 572.463525), -- Recipe: Skull Breaker
(20612, 1832, 1, 1, 2, 89057.126025), -- Greater Antidote
-- Lafi Lizardman
(20613, 40, 1, 1, -1, 9795), -- Leather Boots
(20613, 1934, 1, 1, -1, 103074), -- Crafted Leather Gloves Lining
(20613, 1899, 1, 1, -1, 123206), -- Necklace of Devotion Chain
(20613, 57, 340, 656, 0, 700000), -- Adena
(20613, 432, 1, 1, 1, 917.992572), -- Cursed Tunic
(20613, 465, 1, 1, 1, 1470.007428), -- Cursed Stockings
(20613, 1864, 1, 1, 2, 126440.201944), -- Stem
(20613, 1865, 1, 1, 2, 63220.100972), -- Varnish
(20613, 1866, 1, 1, 2, 42146.577711), -- Suede
(20613, 1873, 1, 1, 2, 25288.134151), -- Silver Nugget
(20613, 1868, 1, 1, 2, 126440.201944), -- Thread
(20613, 2263, 1, 1, 2, 981.690234), -- Recipe: Dwarven Trident
(20613, 1831, 1, 3, 2, 84294.093044), -- Antidote
-- Lafi Lizardman Scout
(20614, 1869, 1, 1, -1, 774589), -- Iron Ore
(20614, 1899, 1, 1, -1, 121030), -- Necklace of Devotion Chain
(20614, 2152, 1, 1, -1, 136371), -- Recipe: Enchanted Necklace
(20614, 57, 332, 650, 0, 700000), -- Adena
(20614, 220, 1, 1, 1, 276), -- Crafted Dagger
(20614, 1870, 1, 1, 2, 86944.667355), -- Coal
(20614, 1865, 1, 1, 2, 86944.667355), -- Varnish
(20614, 1874, 1, 1, 2, 5796.311157), -- Oriharukon Ore
(20614, 2263, 1, 1, 2, 1350.168183), -- Recipe: Dwarven Trident
(20614, 1834, 1, 1, 2, 96605.18595), -- Emergency Dressing
-- Ritmal Swordsman
(20615, 2185, 1, 1, -1, 175902), -- Recipe: Iron Boots
(20615, 392, 1, 1, -1, 2324), -- Lion Skin Shirt
(20615, 1900, 1, 1, -1, 97766), -- Enchanted Necklace Chain
(20615, 57, 379, 750, 0, 700000), -- Adena
(20615, 627, 1, 1, 1, 1815.325785), -- Aspis
(20615, 46, 1, 1, 1, 1271.674215), -- Bronze Helmet
(20615, 1875, 1, 1, 2, 4650.55716), -- Stone of Purity
(20615, 1879, 1, 1, 2, 11626.501128), -- Cokes
(20615, 1885, 1, 1, 2, 5813.250564), -- High-Grade Suede
(20615, 5550, 1, 1, 2, 930.111432), -- Durable Metal Plate
(20615, 5549, 1, 1, 2, 6975.943968), -- Metallic Thread
(20615, 2266, 1, 1, 2, 721.447848), -- Recipe: Shilen Knife
(20615, 1834, 1, 1, 2, 77510.1879), -- Emergency Dressing
-- Lakin Undine
(20616, 1874, 1, 1, -1, 61682), -- Oriharukon Ore
(20616, 1937, 1, 1, -1, 79487), -- Scale Gaiters Fragment
(20616, 2153, 1, 1, -1, 143893), -- Recipe: Tiger's Eye Earring
(20616, 57, 390, 781, 0, 700000), -- Adena
(20616, 433, 1, 1, 1, 164.372203), -- Elven Tunic
(20616, 434, 1, 1, 1, 164.372203), -- White Tunic
(20616, 1936, 1, 1, 1, 5172.133267), -- White Tunic Pattern
(20616, 435, 1, 1, 1, 164.372203), -- Mystic's Tunic
(20616, 466, 1, 1, 1, 263.345578), -- Elven Stockings
(20616, 467, 1, 1, 1, 263.345578), -- Dark Stockings
(20616, 1933, 1, 1, 1, 7435.699499), -- Dark Stockings Fabric
(20616, 468, 1, 1, 1, 263.359469), -- Mystic's Stockings
(20616, 1872, 1, 1, 2, 84267.395842), -- Animal Bone
(20616, 1867, 1, 1, 2, 84267.395842), -- Animal Skin
(20616, 1881, 1, 1, 2, 8426.833947), -- Coarse Bone Powder
(20616, 1875, 1, 1, 2, 4213.29902), -- Stone of Purity
(20616, 737, 1, 1, 2, 6319.94853), -- Scroll of Resurrection
(20616, 2274, 1, 1, 2, 451.525998), -- Recipe: Skull Breaker
(20616, 2976, 1, 1, 2, 8460.568648), -- Recipe: Manticore Skin Boots
(20616, 6667, 1, 1, 2, 39500.032173), -- Deluxe Chest Key - Grade 3
-- Sentinel Of Water
(20617, 435, 1, 1, -1, 2296), -- Mystic's Tunic
(20617, 1875, 1, 1, -1, 58864), -- Stone of Purity
(20617, 1933, 1, 1, -1, 103877), -- Dark Stockings Fabric
(20617, 57, 373, 744, 0, 700000), -- Adena
(20617, 392, 1, 1, 1, 627.573331), -- Lion Skin Shirt
(20617, 414, 1, 1, 1, 1005.426669), -- Lion Skin Gaiters
(20617, 1872, 1, 1, 2, 128667.265196), -- Animal Bone
(20617, 1867, 1, 1, 2, 128667.265196), -- Animal Skin
(20617, 1881, 1, 1, 2, 12866.841228), -- Coarse Bone Powder
(20617, 1875, 1, 1, 2, 6433.420614), -- Stone of Purity
(20617, 2184, 1, 1, 2, 10136.207766), -- Recipe: Mithril Banded Gaiters
-- Kanil Succubus
(20618, 1885, 1, 1, -1, 81279), -- High-Grade Suede
(20618, 1935, 1, 1, -1, 54489), -- Scale Mail Fragment
(20618, 955, 1, 1, -1, 3901), -- Scroll: Enchant Weapon (D-Grade)
(20618, 57, 411, 824, 0, 700000), -- Adena
(20618, 315, 1, 1, 1, 215), -- Divine Tome
(20618, 1875, 1, 1, 2, 5922.148167), -- Stone of Purity
(20618, 1879, 1, 1, 2, 14805.344411), -- Cokes
(20618, 1885, 1, 1, 2, 7402.646199), -- High-Grade Suede
(20618, 5550, 1, 1, 2, 1184.440036), -- Durable Metal Plate
(20618, 5549, 1, 1, 2, 8883.196244), -- Metallic Thread
(20618, 2153, 1, 1, 2, 13815.224943), -- Recipe: Tiger's Eye Earring
-- Rowin Undine
(20619, 2981, 1, 1, -1, 134055), -- Recipe: Mithril Gloves
(20619, 2270, 1, 1, -1, 7153), -- Recipe: Goat Head Staff
(20619, 1867, 1, 3, -1, 667594), -- Animal Skin
(20619, 57, 423, 846, 0, 700000), -- Adena
(20619, 157, 1, 1, 1, 47.73208), -- Spiked Club
(20619, 2027, 1, 1, 1, 2324.53584), -- Spiked Club Head
(20619, 186, 1, 1, 1, 47.73208), -- Staff of Magic
(20619, 1872, 1, 1, 2, 118318.290624), -- Animal Bone
(20619, 1867, 1, 1, 2, 118318.290624), -- Animal Skin
(20619, 1881, 1, 1, 2, 11831.93487), -- Coarse Bone Powder
(20619, 1875, 1, 1, 2, 5915.967435), -- Stone of Purity
(20619, 2154, 1, 1, 2, 9500.993442), -- Recipe: Elven Earring
(20619, 2278, 1, 1, 2, 633.523005), -- Recipe: Reinforced Long Bow
-- Cave Beast
(20620, 4051, 1, 1, -1, 204462), -- Adamantite Necklace Chain
(20620, 948, 1, 1, -1, 13180), -- Scroll: Enchant Armor (B-Grade)
(20620, 4039, 1, 1, -1, 175735), -- Mold Glue
(20620, 57, 2089, 4237, 0, 700000), -- Adena
(20620, 78, 1, 1, 1, 7.771049), -- Great Sword
(20620, 4104, 1, 1, 1, 1485.236753), -- Great Sword Blade
(20620, 142, 1, 1, 1, 7.771049), -- Keshanberk
(20620, 4107, 1, 1, 1, 1462.22505), -- Keshanberk Blade
(20620, 148, 1, 1, 1, 7.771049), -- Sword of Valhalla
(20620, 4108, 1, 1, 1, 1462.22505), -- Sword of Valhalla Blade
(20620, 1894, 1, 1, 2, 4967.418016), -- Crafted Leather
(20620, 4039, 1, 1, 2, 4719.04816), -- Mold Glue
(20620, 4041, 1, 1, 2, 1231.046048), -- Mold Hardener
(20620, 4044, 1, 1, 2, 4719.04816), -- Thons
(20620, 4614, 1, 1, 2, 195.27312), -- Greater Dye of STR (Str+4 Dex-4)
(20620, 4402, 1, 1, 2, 283.1408), -- Blue Dimensional Stone
(20620, 4999, 1, 1, 2, 1760.843232), -- Recipe: Sealed Doom Boots (60%)
(20620, 8728, 1, 1, 2, 2359.513632), -- Life Stone - Level 61
(20620, 8738, 1, 1, 2, 589.873184), -- Mid-Grade Life Stone - Level 61
(20620, 8748, 1, 1, 2, 58.989408), -- High-Grade Life Stone - Level 61
(20620, 8758, 1, 1, 2, 11.80624), -- Top-Grade Life Stone - Level 61
-- Death Wave
(20621, 4199, 1, 1, -1, 4349), -- Recipe: Bow of Peril (100%)
(20621, 4052, 1, 1, -1, 201691), -- Earring of Black Ore Piece
(20621, 5230, 1, 1, -1, 7596), -- Recipe: Mithril Arrow (100%)
(20621, 57, 2259, 4576, 0, 700000), -- Adena
(20621, 2391, 1, 1, 1, 27.888624), -- Blue Wolf Leather Armor
(20621, 4082, 1, 1, 1, 4754.111376), -- Blue Wolf Leather Armor Texture
(20621, 2392, 1, 1, 1, 27.888624), -- Leather Armor of Doom
(20621, 4083, 1, 1, 1, 4754.111376), -- Leather Armor of Doom Design
(20621, 1873, 1, 1, 2, 61190.3327), -- Silver Nugget
(20621, 1868, 1, 1, 2, 305951.6635), -- Thread
(20621, 1876, 1, 1, 2, 30595.38986), -- Mithril Ore
(20621, 1895, 1, 1, 2, 43707.3805), -- Metallic Fiber
(20621, 4042, 1, 1, 2, 2549.80208), -- Enria
(20621, 4623, 1, 1, 2, 210.99344), -- Greater Dye of WIT (Wit+4 Int-4)
(20621, 5276, 1, 1, 2, 203.84112), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20621, 8729, 1, 1, 2, 2039.75226), -- Life Stone - Level 64
(20621, 8739, 1, 1, 2, 510.04982), -- Mid-Grade Life Stone - Level 64
(20621, 8749, 1, 1, 2, 50.96028), -- High-Grade Life Stone - Level 64
(20621, 8759, 1, 1, 2, 9.83444), -- Top-Grade Life Stone - Level 64
-- Maluk Soldier
(20622, 4044, 1, 1, -1, 203292), -- Thons
(20622, 4042, 1, 1, -1, 101646), -- Enria
(20622, 4053, 1, 1, -1, 261413), -- Ring of Black Ore Gemstone
(20622, 57, 2419, 4898, 0, 700000), -- Adena
(20622, 864, 1, 1, 1, 84.45667), -- Earring of Black Ore
(20622, 4052, 1, 1, 1, 10629.36916), -- Earring of Black Ore Piece
(20622, 926, 1, 1, 1, 63.349924), -- Necklace of Black Ore
(20622, 4054, 1, 1, 1, 5913.4512), -- Necklace of Black Ore Beads
(20622, 895, 1, 1, 1, 126.670162), -- Ring of Black Ore
(20622, 4053, 1, 1, 1, 12868.702884), -- Ring of Black Ore Gemstone
(20622, 1867, 1, 1, 2, 200165.035026), -- Animal Skin
(20622, 1872, 1, 1, 2, 200165.035026), -- Animal Bone
(20622, 1882, 1, 1, 2, 33361.07434), -- Leather
(20622, 1894, 1, 1, 2, 5267.315262), -- Crafted Leather
(20622, 4042, 1, 1, 2, 2502.19816), -- Enria
(20622, 4988, 1, 1, 2, 994.294532), -- Recipe: Blue Wolf Stockings (60%)
(20622, 4401, 1, 1, 2, 300.075644), -- Green Dimensional Stone
(20622, 6670, 1, 1, 2, 25020.570586), -- Deluxe Chest Key - Grade 6
(20622, 8729, 1, 1, 2, 2001.758528), -- Life Stone - Level 64
(20622, 8739, 1, 1, 2, 500.439632), -- Mid-Grade Life Stone - Level 64
(20622, 8749, 1, 1, 2, 49.855828), -- High-Grade Life Stone - Level 64
(20622, 8759, 1, 1, 2, 10.347436), -- Top-Grade Life Stone - Level 64
-- Plando
(20623, 4039, 1, 1, -1, 271715), -- Mold Glue
(20623, 4040, 1, 1, -1, 163029), -- Mold Lubricant
(20623, 5230, 1, 1, -1, 10869), -- Recipe: Mithril Arrow (100%)
(20623, 57, 3236, 6545, 0, 700000), -- Adena
(20623, 110, 1, 1, 1, 123.516382), -- Doom Shield
(20623, 4077, 1, 1, 1, 18053.98595), -- Doom Shield Fragment
(20623, 2416, 1, 1, 1, 86.466336), -- Blue Wolf Helmet
(20623, 4088, 1, 1, 1, 15167.782498), -- Blue Wolf Helmet Design
(20623, 2417, 1, 1, 1, 86.466336), -- Doom Helmet
(20623, 4089, 1, 1, 1, 15167.782498), -- Doom Helmet Pattern
(20623, 1868, 1, 3, 2, 218891.932928), -- Thread
(20623, 1873, 1, 1, 2, 87556.701409), -- Silver Nugget
(20623, 5549, 1, 1, 2, 21889.265055), -- Metallic Thread
(20623, 1889, 1, 1, 2, 14592.84337), -- Compound Braid
(20623, 4044, 1, 1, 2, 7296.421685), -- Thons
(20623, 4177, 1, 1, 2, 4217.464494), -- Recipe: Sealed Zubei's Gauntlets (100%)
(20623, 5332, 1, 1, 2, 630.789738), -- Recipe: Sealed Dark Crystal Leather Armor(60%)
(20623, 8729, 1, 1, 2, 2918.568674), -- Life Stone - Level 64
(20623, 8739, 1, 1, 2, 729.462763), -- Mid-Grade Life Stone - Level 64
(20623, 8749, 1, 1, 2, 72.838633), -- High-Grade Life Stone - Level 64
(20623, 8759, 1, 1, 2, 14.711251), -- Top-Grade Life Stone - Level 64
-- Cave Howler
(20624, 1877, 1, 1, -1, 332612), -- Adamantite Nugget
(20624, 4054, 1, 1, -1, 163784), -- Necklace of Black Ore Beads
(20624, 4052, 1, 1, -1, 294399), -- Earring of Black Ore Piece
(20624, 57, 3295, 6681, 0, 700000), -- Adena
(20624, 79, 1, 1, 1, 8.113194), -- Sword of Damascus
(20624, 4114, 1, 1, 1, 1792.222368), -- Sword of Damascus Blade
(20624, 7883, 1, 1, 1, 8.113194), -- Guardian Sword
(20624, 8330, 1, 1, 1, 1789.210284), -- Guardian Sword Blade
(20624, 7889, 1, 1, 1, 8.113194), -- Wizard's Tear
(20624, 8336, 1, 1, 1, 1792.227766), -- Blade of the Wizard's Tear
(20624, 1873, 1, 1, 2, 75575.770128), -- Silver Nugget
(20624, 1868, 1, 3, 2, 188939.42532), -- Thread
(20624, 1876, 1, 1, 2, 37787.885064), -- Mithril Ore
(20624, 1895, 1, 1, 2, 53982.588264), -- Metallic Fiber
(20624, 4042, 1, 1, 2, 3149.17362), -- Enria
(20624, 4154, 1, 1, 2, 2236.114788), -- Recipe: Doom Shield (100%)
(20624, 4403, 1, 1, 2, 377.754276), -- Red Dimensional Stone
(20624, 5281, 1, 1, 2, 252.080448), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(20624, 5340, 1, 1, 2, 870.556896), -- Recipe: Sealed Dark Crystal Leggings(60%)
(20624, 8729, 1, 1, 2, 2519.338896), -- Life Stone - Level 64
(20624, 8739, 1, 1, 2, 629.834724), -- Mid-Grade Life Stone - Level 64
(20624, 8749, 1, 1, 2, 63.020112), -- High-Grade Life Stone - Level 64
(20624, 8759, 1, 1, 2, 12.457464), -- Top-Grade Life Stone - Level 64
-- Maluk Knight
(20625, 4043, 1, 1, -1, 277527), -- Asofe
(20625, 4044, 1, 1, -1, 277527), -- Thons
(20625, 5230, 1, 1, -1, 11101), -- Recipe: Mithril Arrow (100%)
(20625, 57, 3298, 6689, 0, 700000), -- Adena
(20625, 268, 1, 1, 1, 24.37197), -- Bellion Cestus
(20625, 4120, 1, 1, 1, 5373.62803), -- Bellion Cestus Edge
(20625, 1894, 1, 1, 2, 8629.183836), -- Crafted Leather
(20625, 4039, 1, 1, 2, 8197.7103), -- Mold Glue
(20625, 4041, 1, 1, 2, 2138.528964), -- Mold Hardener
(20625, 4044, 1, 1, 2, 8197.7103), -- Thons
(20625, 4192, 1, 1, 2, 187.74964), -- Recipe: Sword of Damascus (100%)
(20625, 5276, 1, 1, 2, 327.908412), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20625, 8729, 1, 1, 2, 3279.08412), -- Life Stone - Level 64
(20625, 8739, 1, 1, 2, 819.786968), -- Mid-Grade Life Stone - Level 64
(20625, 8749, 1, 1, 2, 81.985072), -- High-Grade Life Stone - Level 64
(20625, 8759, 1, 1, 2, 16.352388), -- Top-Grade Life Stone - Level 64
-- Maluk Berserker
(20626, 1875, 1, 1, -1, 685963), -- Stone of Purity
(20626, 4053, 1, 1, -1, 441039), -- Ring of Black Ore Gemstone
(20626, 5230, 1, 1, -1, 13719), -- Recipe: Mithril Arrow (100%)
(20626, 57, 4056, 8290, 0, 700000), -- Adena
(20626, 358, 1, 1, 1, 40.93388), -- Blue Wolf Breastplate
(20626, 4078, 1, 1, 1, 7399.831335), -- Blue Wolf Breastplate Part
(20626, 2381, 1, 1, 1, 25.19361), -- Doom Plate Armor
(20626, 4081, 1, 1, 1, 4993.038505), -- Doom Plate Armor Temper
(20626, 2380, 1, 1, 1, 65.48503), -- Blue Wolf Gaiters
(20626, 4080, 1, 1, 1, 10420.51764), -- Blue Wolf Gaiters Material
(20626, 1872, 1, 3, 2, 168852.683584), -- Animal Bone
(20626, 1867, 1, 3, 2, 112568.342644), -- Animal Skin
(20626, 1881, 1, 1, 2, 33770.604564), -- Coarse Bone Powder
(20626, 1875, 1, 1, 2, 16885.132664), -- Stone of Purity
(20626, 4041, 1, 1, 2, 2202.320112), -- Mold Hardener
(20626, 4615, 1, 1, 2, 349.41308), -- Greater Dye of CON (Con+4 Str-4)
(20626, 4402, 1, 1, 2, 506.479348), -- Blue Dimensional Stone
(20626, 5334, 1, 1, 2, 498.67692), -- Recipe: Sealed Tallum Leather Armor(60%)
(20626, 8730, 1, 1, 2, 2814.301856), -- Life Stone - Level 67
(20626, 8740, 1, 1, 2, 703.575464), -- Mid-Grade Life Stone - Level 67
(20626, 8750, 1, 1, 2, 70.221852), -- High-Grade Life Stone - Level 67
(20626, 8760, 1, 1, 2, 14.247912), -- Top-Grade Life Stone - Level 67
-- Maluk Lord
(20627, 1877, 1, 1, -1, 413122), -- Adamantite Nugget
(20627, 5478, 1, 1, -1, 86849), -- Sealed Dark Crystal Leather Armor Pattern
(20627, 57, 4085, 8305, 0, 700000), -- Adena
(20627, 5291, 1, 1, 1, 85.696149), -- Sealed Dark Crystal Boots
(20627, 5496, 1, 1, 1, 8942.553851), -- Sealed Dark Crystal Boots Lining
(20627, 5296, 1, 1, 1, 85.696149), -- Sealed Tallum Boots
(20627, 5497, 1, 1, 1, 8942.553851), -- Sealed Tallum Boots Lining
(20627, 5290, 1, 1, 1, 85.696149), -- Sealed Dark Crystal Gloves
(20627, 5508, 1, 1, 1, 8942.553851), -- Sealed Dark Crystal Gloves Design
(20627, 5295, 1, 1, 1, 85.696149), -- Sealed Tallum Gloves
(20627, 5509, 1, 1, 1, 8942.553851), -- Sealed Tallum Gloves Design
(20627, 1871, 1, 1, 2, 254229.140691), -- Charcoal
(20627, 1866, 1, 1, 2, 169485.766956), -- Suede
(20627, 1877, 1, 1, 2, 10169.400951), -- Adamantite Nugget
(20627, 4041, 1, 1, 2, 2210.568813), -- Mold Hardener
(20627, 4040, 1, 1, 2, 5084.455347), -- Mold Lubricant
(20627, 4973, 1, 1, 2, 2751.322284), -- Recipe: Earring of Black Ore (70%)
(20627, 3956, 1, 1, 2, 338.767587), -- Recipe: Blessed Spiritshot A
(20627, 6670, 1, 1, 2, 42371.441739), -- Deluxe Chest Key - Grade 6
(20627, 8730, 1, 1, 2, 2824.860834), -- Life Stone - Level 67
(20627, 8740, 1, 1, 2, 705.97008), -- Mid-Grade Life Stone - Level 67
(20627, 8750, 1, 1, 2, 70.597008), -- High-Grade Life Stone - Level 67
(20627, 8760, 1, 1, 2, 14.70771), -- Top-Grade Life Stone - Level 67
-- Limal Karinness
(20628, 1807, 1, 1, -1, 14876), -- Recipe: Soulshot (A-Grade)
(20628, 5479, 1, 1, -1, 66016), -- Sealed Tallum Leather Armor Pattern
(20628, 1895, 1, 7, -1, 796908), -- Metallic Fiber
(20628, 57, 4416, 8967, 0, 700000), -- Adena
(20628, 5304, 1, 1, 1, 41.126553), -- Sealed Tallum Tunic
(20628, 5485, 1, 1, 1, 4618.266393), -- Sealed Tallum Tunic Texture
(20628, 5308, 1, 1, 1, 25.298091), -- Sealed Dark Crystal Robe
(20628, 5486, 1, 1, 1, 3249.729639), -- Sealed Dark Crystal Robe Fabric
(20628, 5305, 1, 1, 1, 65.768937), -- Sealed Tallum Stockings
(20628, 5489, 1, 1, 1, 7248.810387), -- Sealed Tallum Stockings Fabric
(20628, 1895, 1, 1, 2, 94157.83821), -- Metallic Fiber
(20628, 4040, 1, 1, 2, 6591.05616), -- Mold Lubricant
(20628, 4042, 1, 1, 2, 5492.588385), -- Enria
(20628, 4043, 1, 1, 2, 10985.052015), -- Asofe
(20628, 4988, 1, 1, 2, 2182.46397), -- Recipe: Blue Wolf Stockings (60%)
(20628, 4401, 1, 1, 2, 659.080665), -- Green Dimensional Stone
(20628, 8730, 1, 1, 2, 3661.684005), -- Life Stone - Level 67
(20628, 8740, 1, 1, 2, 915.45219), -- Mid-Grade Life Stone - Level 67
(20628, 8750, 1, 1, 2, 91.57017), -- High-Grade Life Stone - Level 67
(20628, 8760, 1, 1, 2, 18.21423), -- Top-Grade Life Stone - Level 67
-- Karik
(20629, 4077, 1, 1, -1, 589396), -- Doom Shield Fragment
(20629, 4078, 1, 1, -1, 191386), -- Blue Wolf Breastplate Part
(20629, 3035, 1, 1, -1, 17470), -- Recipe: Spiritshot A
(20629, 57, 5182, 10542, 0, 700000), -- Adena
(20629, 5292, 1, 1, 1, 137.97336), -- Sealed Dark Crystal Shield
(20629, 5494, 1, 1, 1, 13545.568435), -- Sealed Dark Crystal Shield Fragment
(20629, 5289, 1, 1, 1, 96.547535), -- Sealed Dark Crystal Helmet
(20629, 5525, 1, 1, 1, 9970.198476), -- Sealed Dark Crystal Helmet Design
(20629, 5294, 1, 1, 1, 96.547535), -- Sealed Tallum Helmet
(20629, 5526, 1, 1, 1, 9970.164659), -- Sealed Tallum Helm Design
(20629, 1873, 1, 1, 2, 154808.395587), -- Silver Nugget
(20629, 1868, 3, 9, 2, 129006.754299), -- Thread
(20629, 1876, 1, 1, 2, 77403.95577), -- Mithril Ore
(20629, 1895, 1, 1, 2, 110577.632868), -- Metallic Fiber
(20629, 4042, 1, 1, 2, 6450.410322), -- Enria
(20629, 5006, 1, 1, 2, 295.26867), -- Recipe: Bellion Cestus (60%)
(20629, 8730, 1, 1, 2, 4300.273548), -- Life Stone - Level 67
(20629, 8740, 1, 1, 2, 1075.068387), -- Mid-Grade Life Stone - Level 67
(20629, 8750, 1, 1, 2, 107.458434), -- High-Grade Life Stone - Level 67
(20629, 8760, 1, 1, 2, 21.782115), -- Top-Grade Life Stone - Level 67
-- Taik Orc
(20630, 2291, 1, 1, -1, 5091), -- Recipe: Scallop Jamadhr
(20630, 1943, 1, 1, -1, 72792), -- Manticore Skin Gaiters Pattern
(20630, 1902, 1, 1, -1, 92852), -- Elven Earring Beads
(20630, 57, 383, 764, 0, 700000), -- Adena
(20630, 629, 1, 1, 1, 261.873792), -- Kite Shield
(20630, 1947, 1, 1, 1, 11368.098096), -- Kite Shield Fragment
(20630, 2493, 1, 1, 1, 261.873792), -- Brigandine Shield
(20630, 2929, 1, 1, 1, 11368.098096), -- Brigandine Shield Fragment
(20630, 2411, 1, 1, 1, 183.4017), -- Brigandine Helmet
(20630, 2922, 1, 1, 1, 3040.654524), -- Brigandine Helmet Design
(20630, 1866, 1, 1, 2, 45117.507951), -- Suede
(20630, 1871, 1, 1, 2, 67676.195466), -- Charcoal
(20630, 5220, 1, 1, 2, 2707.069086), -- Metal Hardener
(20630, 1885, 1, 1, 2, 5639.705109), -- High-Grade Suede
(20630, 5472, 1, 1, 2, 4834.070928), -- Recipe: Metallic Thread(100%)
(20630, 2286, 1, 1, 2, 376.033509), -- Recipe: Bonebreaker
(20630, 2987, 1, 1, 2, 6570.417951), -- Recipe: Plate Shield
-- Taik Orc Archer
(20631, 2998, 1, 1, -1, 94276), -- Recipe: Chain Shield
(20631, 2996, 1, 1, -1, 99513), -- Recipe: Chain Gloves
(20631, 1873, 1, 1, -1, 501547), -- Silver Nugget
(20631, 57, 508, 1017, 0, 700000), -- Adena
(20631, 1125, 1, 1, 1, 139.547025), -- Assault Boots
(20631, 1957, 1, 1, 1, 5856.262325), -- Assault Boots Part
(20631, 2427, 1, 1, 1, 139.547025), -- Salamander Skin Boots
(20631, 2931, 1, 1, 1, 5856.262325), -- Salamander Skin Boot Lining
(20631, 2428, 1, 1, 1, 139.547025), -- Plate Boots
(20631, 2932, 1, 1, 1, 5856.262325), -- Plate Boots Design
(20631, 61, 1, 1, 1, 139.547025), -- Mithril Plate Gloves
(20631, 1949, 1, 1, 1, 5856.262325), -- Mithril Gloves Design
(20631, 607, 1, 1, 1, 139.547025), -- Ogre Power Gauntlets
(20631, 1963, 1, 1, 1, 5856.262325), -- Ogre Power Gauntlets Part
(20631, 2451, 1, 1, 1, 139.547025), -- Sage's Worn Gloves
(20631, 2933, 1, 1, 1, 5856.406225), -- Sage's Worn Gloves Lining
(20631, 1868, 1, 1, 2, 157408.598016), -- Thread
(20631, 1873, 1, 1, 2, 31481.568768), -- Silver Nugget
(20631, 5549, 1, 1, 2, 7870.580736), -- Metallic Thread
(20631, 1889, 1, 1, 2, 5246.802432), -- Compound Braid
(20631, 2203, 1, 1, 2, 17146.945536), -- Recipe: Reinforced Mithril Boots
(20631, 5274, 1, 1, 2, 262.453248), -- Recipe: Greater Spiritshot (C) Compressed Package(100%)
(20631, 5164, 1, 1, 2, 262.453248), -- Recipe: Blessed Spiritshot (C) Compressed Package (100%)
(20631, 1342, 10, 30, 2, 157408.598016), -- Steel Arrow
-- Taik Orc Warrior
(20632, 1951, 1, 1, -1, 63026), -- Plate Gaiters Part
(20632, 1873, 1, 1, -1, 499421), -- Silver Nugget
(20632, 1880, 1, 1, -1, 124855), -- Steel
(20632, 57, 503, 1016, 0, 700000), -- Adena
(20632, 353, 1, 1, 1, 104.217163), -- Half Plate Armor
(20632, 1950, 1, 1, 1, 5087.530747), -- Half Plate Temper
(20632, 380, 1, 1, 1, 166.750115), -- Plate Gaiters
(20632, 1951, 1, 1, 1, 7912.501975), -- Plate Gaiters Part
(20632, 1869, 1, 1, 2, 78370.714305), -- Iron Ore
(20632, 1864, 1, 1, 2, 156741.153543), -- Stem
(20632, 1880, 1, 1, 2, 7836.933897), -- Steel
(20632, 5550, 1, 1, 2, 1044.979533), -- Durable Metal Plate
(20632, 2301, 1, 1, 2, 342.183348), -- Recipe: Battle Axe
(20632, 2205, 1, 1, 2, 2480.004072), -- Recipe: Chain Gaiters
(20632, 5274, 1, 1, 2, 261.31365), -- Recipe: Greater Spiritshot (C) Compressed Package(100%)
(20632, 6668, 1, 1, 2, 27989.717652), -- Deluxe Chest Key - Grade 4
-- Taik Orc Shaman
(20633, 2313, 1, 1, -1, 5351), -- Recipe: Orcish Glaive
(20633, 2212, 1, 1, -1, 43920), -- Recipe: Plated Leather Gaiters
(20633, 4469, 1, 1, -1, 7002), -- Dye of STR (Str+1 Con-1)
(20633, 57, 485, 984, 0, 700000), -- Adena
(20633, 851, 1, 1, 1, 219.839927), -- Omen Beast's Eye Earring
(20633, 1905, 1, 1, 1, 9975.918999), -- Omen Beast's Eye Earring Gemstone
(20633, 914, 1, 1, 1, 164.871965), -- Necklace of Darkness
(20633, 1907, 1, 1, 1, 7134.088132), -- Necklace of Darkness Gem
(20633, 882, 1, 1, 1, 329.74393), -- Mithril Ring
(20633, 1906, 1, 1, 1, 14096.537047), -- Mithril Ring Wire
(20633, 1873, 1, 1, 2, 35161.574252), -- Silver Nugget
(20633, 1868, 1, 1, 2, 175807.87126), -- Thread
(20633, 1876, 1, 1, 2, 17580.787126), -- Mithril Ore
(20633, 1895, 1, 1, 2, 25115.41018), -- Metallic Fiber
(20633, 2992, 1, 1, 2, 6976.473616), -- Recipe: Plated Leather Boots
(20633, 5159, 1, 1, 2, 293.14019), -- Recipe: Spiritshot (C) Compressed Package (100%)
(20633, 2211, 1, 1, 2, 1970.743376), -- Recipe: Plated Leather Armor
-- Taik Orc Captain
(20634, 2213, 1, 1, -1, 36467), -- Recipe: Dwarven Chain Mail Shirt
(20634, 1880, 1, 1, -1, 234850), -- Steel
(20634, 1908, 1, 1, -1, 222396), -- Moonstone Earring Wire
(20634, 57, 925, 1895, 0, 700000), -- Adena
(20634, 354, 1, 1, 1, 142.811604), -- Chain Mail Shirt
(20634, 1959, 1, 1, 1, 7473.914838), -- Chain Mail Shirt Material
(20634, 381, 1, 1, 1, 228.461688), -- Chain Gaiters
(20634, 1960, 1, 1, 1, 15203.81187), -- Chain Gaiters Part
(20634, 1872, 1, 1, 2, 123326.177326), -- Animal Bone
(20634, 1867, 1, 1, 2, 123326.177326), -- Animal Skin
(20634, 1881, 1, 1, 2, 12332.646614), -- Coarse Bone Powder
(20634, 1875, 1, 1, 2, 6166.1789), -- Stone of Purity
(20634, 2215, 1, 1, 2, 1178.36112), -- Recipe: Robe of Seal
(20634, 2225, 1, 1, 2, 2010.723068), -- Recipe: Demon's Stockings
(20634, 2321, 1, 1, 2, 322.316424), -- Recipe: Stiletto
(20634, 2251, 1, 1, 2, 15415.736064), -- Recipe: Steel Arrow
(20634, 8723, 1, 1, 2, 3699.70734), -- Life Stone - Level 46
(20634, 8733, 1, 1, 2, 925.071242), -- Mid-Grade Life Stone - Level 46
(20634, 8743, 1, 1, 2, 92.42048), -- High-Grade Life Stone - Level 46
(20634, 8753, 1, 1, 2, 18.484096), -- Top-Grade Life Stone - Level 46
-- Carinkain
(20635, 2215, 1, 1, -1, 15138), -- Recipe: Robe of Seal
(20635, 1959, 1, 1, -1, 32009), -- Chain Mail Shirt Material
(20635, 2163, 1, 1, -1, 60630), -- Recipe: Earring of Protection
(20635, 57, 470, 955, 0, 700000), -- Adena
(20635, 263, 1, 1, 1, 31.85193), -- Chakram
(20635, 2073, 1, 1, 1, 2170.14807), -- Chakram Edge
(20635, 1866, 1, 1, 2, 34038.436182), -- Suede
(20635, 1871, 1, 1, 2, 51057.70467), -- Charcoal
(20635, 5220, 1, 1, 2, 2042.288028), -- Metal Hardener
(20635, 1885, 1, 1, 2, 4254.817122), -- High-Grade Suede
(20635, 4041, 1, 1, 2, 443.99757), -- Mold Hardener
(20635, 3004, 1, 1, 2, 3171.281622), -- Recipe: Rind Leather Gloves
(20635, 3002, 1, 1, 2, 3171.281622), -- Recipe: Dwarven Chain Gloves
(20635, 8723, 1, 1, 2, 2042.288028), -- Life Stone - Level 46
(20635, 8733, 1, 1, 2, 510.622404), -- Mid-Grade Life Stone - Level 46
(20635, 8743, 1, 1, 2, 51.102558), -- High-Grade Life Stone - Level 46
(20635, 8753, 1, 1, 2, 10.180194), -- Top-Grade Life Stone - Level 46
-- Forest of Mirrors Ghost
(20636, 2163, 1, 1, -1, 67491), -- Recipe: Earring of Protection
(20636, 2214, 1, 1, -1, 32824), -- Recipe: Dwarven Chain Gaiters
(20636, 1909, 1, 1, -1, 178638), -- Aquastone Ring Wire
(20636, 57, 521, 1066, 0, 700000), -- Adena
(20636, 89, 1, 1, 1, 4.43344), -- Big Hammer
(20636, 2061, 1, 1, 1, 302.05956), -- Big Hammer Head
(20636, 160, 1, 1, 1, 4.43344), -- Battle Axe
(20636, 2063, 1, 1, 1, 302.05956), -- Battle Axe Head
(20636, 161, 1, 1, 1, 4.43344), -- Silver Axe
(20636, 2064, 1, 1, 1, 302.05956), -- Silver Axe Head
(20636, 173, 1, 1, 1, 4.43344), -- Skull Graver
(20636, 2065, 1, 1, 1, 302.05956), -- Skull Graver Head
(20636, 191, 1, 1, 1, 4.43344), -- Heavy Doom Hammer
(20636, 2066, 1, 1, 1, 306.50026), -- Heavy Doom Hammer Head
(20636, 192, 1, 1, 1, 4.43344), -- Crystal Staff
(20636, 2067, 1, 1, 1, 281.64928), -- Crystal Staff Head
(20636, 193, 1, 1, 1, 4.43344), -- Stick of Faith
(20636, 2068, 1, 1, 1, 281.64928), -- Stick of Faith Shaft
(20636, 194, 1, 1, 1, 4.43344), -- Heavy Doom Axe
(20636, 2069, 1, 1, 1, 306.49542), -- Heavy Doom Axe Blade
(20636, 1867, 1, 1, 2, 75780.012116), -- Animal Skin
(20636, 1872, 1, 1, 2, 75780.012116), -- Animal Bone
(20636, 1882, 1, 1, 2, 12630.059133), -- Leather
(20636, 1894, 1, 1, 2, 1994.237899), -- Crafted Leather
(20636, 4042, 1, 1, 2, 947.173048), -- Enria
(20636, 2230, 1, 1, 2, 1101.379948), -- Recipe: Theca Leather Gaiters
(20636, 2320, 1, 1, 2, 198.070196), -- Recipe: Cursed Staff
(20636, 8723, 1, 1, 2, 2273.352388), -- Life Stone - Level 46
(20636, 8733, 1, 1, 2, 568.338097), -- Mid-Grade Life Stone - Level 46
(20636, 8743, 1, 1, 2, 56.885212), -- High-Grade Life Stone - Level 46
(20636, 8753, 1, 1, 2, 11.479847), -- Top-Grade Life Stone - Level 46
-- Forest of Mirrors Ghost
(20637, 2337, 1, 1, -1, 3209), -- Recipe: Stick of Eternity
(20637, 2338, 1, 1, -1, 3209), -- Recipe: Paradia Staff
(20637, 440, 1, 1, -1, 457), -- Robe of Seal
(20637, 57, 545, 1111, 0, 700000), -- Adena
(20637, 1126, 1, 1, 1, 82.22976), -- Crimson Boots
(20637, 1974, 1, 1, 1, 4284.096192), -- Crimson Boot Fabric
(20637, 2434, 1, 1, 1, 82.22976), -- Rind Leather Boots
(20637, 2948, 1, 1, 1, 4284.096192), -- Rind Leather Boots Lining
(20637, 2455, 1, 1, 1, 89.04096), -- Plated Leather Gloves
(20637, 2946, 1, 1, 1, 2847.279744), -- Plate Leather Gloves Design
(20637, 2456, 1, 1, 1, 82.22976), -- Dwarven Chain Gloves
(20637, 2949, 1, 1, 1, 4284.096192), -- Dwarven Chain Gloves Design
(20637, 2457, 1, 1, 1, 82.22976), -- Gloves of Seal
(20637, 2950, 1, 1, 1, 4284.096192), -- Gloves of Seal Pattern
(20637, 2458, 1, 1, 1, 82.22976), -- Rind Leather Gloves
(20637, 2951, 1, 1, 1, 4284.145728), -- Rind Leather Gloves Design
(20637, 1869, 1, 1, 2, 50942.36372), -- Iron Ore
(20637, 1864, 1, 1, 2, 101884.919745), -- Stem
(20637, 1880, 1, 1, 2, 5094.15945), -- Steel
(20637, 5550, 1, 1, 2, 679.22126), -- Durable Metal Plate
(20637, 4043, 1, 1, 2, 1698.05315), -- Asofe
(20637, 2222, 1, 1, 2, 318.45708), -- Recipe: Composite Armor
(20637, 6668, 1, 1, 2, 18193.783745), -- Deluxe Chest Key - Grade 4
(20637, 8724, 1, 1, 2, 1698.05315), -- Life Stone - Level 49
(20637, 8734, 1, 1, 2, 424.60944), -- Mid-Grade Life Stone - Level 49
(20637, 8744, 1, 1, 2, 42.499405), -- High-Grade Life Stone - Level 49
(20637, 8754, 1, 1, 2, 8.46142), -- Top-Grade Life Stone - Level 49
(20637, 1539, 1, 1, 2, 11320.418435), -- Greater Healing Potion
-- Forest of Mirrors Ghost
(20638, 1873, 1, 1, -1, 576200), -- Silver Nugget
(20638, 2946, 1, 1, -1, 80520), -- Plate Leather Gloves Design
(20638, 1911, 1, 1, -1, 107140), -- Earring of Protection Gemstone
(20638, 57, 570, 1158, 0, 700000), -- Adena
(20638, 282, 1, 1, 1, 14.444309), -- Elemental Bow
(20638, 2085, 1, 1, 1, 1104.055691), -- Crossbow Shaft
(20638, 285, 1, 1, 1, 14.444309), -- Noble Elven Bow
(20638, 2086, 1, 1, 1, 1104.055691), -- Noble Elven Bow Shaft
(20638, 1867, 1, 1, 2, 65461.79647), -- Animal Skin
(20638, 1872, 1, 1, 2, 65461.79647), -- Animal Bone
(20638, 1882, 1, 1, 2, 10910.24963), -- Leather
(20638, 1894, 1, 1, 2, 1722.694575), -- Crafted Leather
(20638, 4042, 1, 1, 2, 818.261255), -- Enria
(20638, 2338, 1, 1, 2, 114.248925), -- Recipe: Paradia Staff
(20638, 2351, 1, 1, 2, 102.74936), -- Recipe: Scorpion
(20638, 3005, 1, 1, 2, 2003.91121), -- Recipe: Demon's Boots
(20638, 952, 1, 1, 2, 654.579135), -- Scroll: Enchant Armor (C-Grade)
(20638, 8724, 1, 1, 2, 1636.52251), -- Life Stone - Level 49
(20638, 8734, 1, 1, 2, 409.2053), -- Mid-Grade Life Stone - Level 49
(20638, 8744, 1, 1, 2, 40.92053), -- High-Grade Life Stone - Level 49
(20638, 8754, 1, 1, 2, 8.06463), -- Top-Grade Life Stone - Level 49
-- Mirror
(20639, 2342, 1, 1, -1, 7048), -- Recipe: Club of Nature
(20639, 2334, 1, 1, -1, 7048), -- Recipe: Sword of Whispering Death
(20639, 951, 1, 1, -1, 5510), -- Scroll: Enchant Weapon (C-Grade)
(20639, 57, 1196, 2440, 0, 700000), -- Adena
(20639, 227, 1, 1, 1, 30.383318), -- Stiletto
(20639, 2083, 1, 1, 1, 2230.616682), -- Stiletto Edge
(20639, 242, 1, 1, 1, 30.383318), -- Soulfire Dirk
(20639, 2084, 1, 1, 1, 2230.616682), -- Soulfire Dirk Blade
(20639, 1868, 1, 1, 2, 223801.838579), -- Thread
(20639, 1873, 1, 1, 2, 44760.29966), -- Silver Nugget
(20639, 5549, 1, 1, 2, 11190.074915), -- Metallic Thread
(20639, 1889, 1, 1, 2, 7459.936517), -- Compound Braid
(20639, 4044, 1, 1, 2, 3730.138398), -- Thons
(20639, 4132, 1, 1, 2, 4337.196134), -- Recipe: Composite Shield (100%)
(20639, 2328, 1, 1, 2, 260.313435), -- Recipe: Sword of Delusion
(20639, 6668, 1, 1, 2, 39964.747713), -- Deluxe Chest Key - Grade 4
(20639, 8724, 1, 1, 2, 3730.138398), -- Life Stone - Level 49
(20639, 8734, 1, 1, 2, 932.36446), -- Mid-Grade Life Stone - Level 49
(20639, 8744, 1, 1, 2, 93.236446), -- High-Grade Life Stone - Level 49
(20639, 8754, 1, 1, 2, 18.715345), -- Top-Grade Life Stone - Level 49
-- Harit Lizardman
(20640, 1868, 1, 7, -1, 728055), -- Thread
(20640, 1539, 1, 1, -1, 323580), -- Greater Healing Potion
(20640, 1870, 1, 3, -1, 728055), -- Coal
(20640, 57, 576, 1171, 0, 700000), -- Adena
(20640, 283, 1, 1, 1, 18.22008), -- Akat Long Bow
(20640, 2109, 1, 1, 1, 1687.77992), -- Akat Longbow Shaft
(20640, 1865, 1, 1, 2, 46319.687274), -- Varnish
(20640, 1870, 1, 1, 2, 46319.687274), -- Coal
(20640, 1879, 1, 1, 2, 7719.927852), -- Cokes
(20640, 1875, 1, 1, 2, 3087.923076), -- Stone of Purity
(20640, 4040, 1, 1, 2, 926.44902), -- Mold Lubricant
(20640, 2233, 1, 1, 2, 432.943686), -- Recipe: Divine Tunic
(20640, 3014, 1, 1, 2, 1293.904416), -- Recipe: Full Plate Boots
(20640, 2970, 1, 1, 2, 1642.494378), -- Recipe: Ring of Seal
(20640, 6669, 1, 1, 2, 10772.042652), -- Deluxe Chest Key - Grade 5
(20640, 8725, 1, 1, 2, 1286.694696), -- Life Stone - Level 52
(20640, 8735, 1, 1, 2, 321.673674), -- Mid-Grade Life Stone - Level 52
(20640, 8745, 1, 1, 2, 32.203416), -- High-Grade Life Stone - Level 52
(20640, 8755, 1, 1, 2, 6.368586), -- Top-Grade Life Stone - Level 52
-- Harit Lizardman Grunt
(20641, 2097, 1, 1, -1, 9668), -- War Axe Blade
(20641, 2355, 1, 1, -1, 2944), -- Recipe: Ghoul's Staff
(20641, 4042, 1, 1, -1, 30082), -- Enria
(20641, 57, 715, 1452, 0, 700000), -- Adena
(20641, 854, 1, 1, 1, 109.796841), -- Earring of Seal
(20641, 1914, 1, 1, 1, 6988.01558), -- Earring of Seal Gemstone
(20641, 917, 1, 1, 1, 82.35353), -- Necklace of Mermaid
(20641, 1916, 1, 1, 1, 5293.04307), -- Necklace of Mermaid Teardrop
(20641, 885, 1, 1, 1, 164.636269), -- Ring of Ages
(20641, 1915, 1, 1, 1, 10959.15471), -- Ring of Ages Gemstone
(20641, 1867, 1, 1, 2, 82934.40647), -- Animal Skin
(20641, 1872, 1, 1, 2, 82934.40647), -- Animal Bone
(20641, 1882, 1, 1, 2, 13822.369724), -- Leather
(20641, 1894, 1, 1, 2, 2182.449726), -- Crafted Leather
(20641, 4042, 1, 1, 2, 1036.762386), -- Enria
(20641, 4124, 1, 1, 2, 2764.51157), -- Recipe: Craftsman Mold (100%)
(20641, 4609, 1, 1, 2, 138.27261), -- Greater Dye of MEN (Men+3 Int-3)
(20641, 2353, 1, 1, 2, 101.399914), -- Recipe: Samurai Longsword
(20641, 8725, 1, 1, 2, 1727.749184), -- Life Stone - Level 52
(20641, 8735, 1, 1, 2, 431.937296), -- Mid-Grade Life Stone - Level 52
(20641, 8745, 1, 1, 2, 43.26898), -- High-Grade Life Stone - Level 52
(20641, 8755, 1, 1, 2, 8.46567), -- Top-Grade Life Stone - Level 52
-- Harit Lizardman Archer
(20642, 2103, 1, 1, -1, 9533), -- Sage's Staff Head
(20642, 2358, 1, 1, -1, 2759), -- Recipe: Great Pata
(20642, 4602, 1, 1, -1, 3758), -- Greater Dye of STR (Str+3 Dex-3)
(20642, 57, 672, 1357, 0, 700000), -- Adena
(20642, 283, 1, 1, 1, 21.16776), -- Akat Long Bow
(20642, 2109, 1, 1, 1, 1960.83224), -- Akat Longbow Shaft
(20642, 1873, 1, 1, 2, 18648.809658), -- Silver Nugget
(20642, 1868, 1, 1, 2, 93244.04829), -- Thread
(20642, 1876, 1, 1, 2, 9324.241698), -- Mithril Ore
(20642, 1895, 1, 1, 2, 13320.624936), -- Metallic Fiber
(20642, 4042, 1, 1, 2, 777.156084), -- Enria
(20642, 4606, 1, 1, 2, 103.751316), -- Greater Dye of DEX (Dex+3 Con-3)
(20642, 3017, 1, 1, 2, 1302.437904), -- Recipe: Divine Gloves
(20642, 5155, 1, 1, 2, 93.310932), -- Recipe: Soulshot (B) Compressed Package (100%)
(20642, 3015, 1, 1, 2, 1302.437904), -- Recipe: Drake Leather Gloves
(20642, 8725, 1, 1, 2, 1294.933878), -- Life Stone - Level 52
(20642, 8735, 1, 1, 2, 323.651904), -- Mid-Grade Life Stone - Level 52
(20642, 8745, 1, 1, 2, 32.299938), -- High-Grade Life Stone - Level 52
(20642, 8755, 1, 1, 2, 6.52524), -- Top-Grade Life Stone - Level 52
(20642, 1342, 10, 30, 2, 93244.04829), -- Steel Arrow
-- Harit Lizardman Warrior
(20643, 3955, 1, 1, -1, 3483), -- Recipe: Blessed Spiritshot B
(20643, 2114, 1, 1, -1, 8434), -- Widowmaker Head
(20643, 1918, 1, 1, -1, 75426), -- Nassen's Earring Gemstone
(20643, 57, 689, 1400, 0, 700000), -- Adena
(20643, 2497, 1, 1, 1, 111.328191), -- Full Plate Shield
(20643, 2966, 1, 1, 1, 8796.905481), -- Full Plate Shield Fragment
(20643, 2414, 1, 1, 1, 77.928279), -- Full Plate Helmet
(20643, 2959, 1, 1, 1, 5560.838049), -- Full Plate Helmet Design
(20643, 1894, 1, 1, 2, 1880.22975), -- Crafted Leather
(20643, 4039, 1, 1, 2, 1786.228796), -- Mold Glue
(20643, 4041, 1, 1, 2, 465.959906), -- Mold Hardener
(20643, 4044, 1, 1, 2, 1786.228796), -- Thons
(20643, 4126, 1, 1, 2, 884.266258), -- Recipe: Adamantite Earrings (100%)
(20643, 5270, 1, 1, 2, 107.167829), -- Recipe: Greater Soulshot (B) Compressed Package(100%)
(20643, 5275, 1, 1, 2, 107.167829), -- Recipe: Greater Spiritshot (B) Compressed Package(100%)
(20643, 6669, 1, 1, 2, 12461.994247), -- Deluxe Chest Key - Grade 5
(20643, 8726, 1, 1, 2, 1240.42496), -- Life Stone - Level 55
(20643, 8736, 1, 1, 2, 310.10624), -- Mid-Grade Life Stone - Level 55
(20643, 8746, 1, 1, 2, 31.010624), -- High-Grade Life Stone - Level 55
(20643, 8756, 1, 1, 2, 6.214765), -- Top-Grade Life Stone - Level 55
-- Harit Lizardman Shaman
(20644, 1865, 1, 3, -1, 854261), -- Varnish
(20644, 1987, 1, 1, -1, 26066), -- Drake Leather Armor Texture
(20644, 1806, 1, 1, -1, 3417), -- Recipe: Soulshot (B-Grade)
(20644, 57, 675, 1374, 0, 700000), -- Adena
(20644, 442, 1, 1, 1, 38.23255), -- Divine Tunic
(20644, 1988, 1, 1, 1, 3030.335562), -- Divine Tunic Fabric
(20644, 473, 1, 1, 1, 61.156314), -- Divine Stockings
(20644, 1989, 1, 1, 1, 4753.275574), -- Divine Stocking Pattern
(20644, 1864, 1, 1, 2, 97052.069108), -- Stem
(20644, 1869, 1, 1, 2, 48526.034554), -- Iron Ore
(20644, 1878, 1, 1, 2, 19410.493394), -- Braided Hemp
(20644, 1884, 1, 1, 2, 29862.129203), -- Cord
(20644, 4039, 1, 1, 2, 1617.507961), -- Mold Glue
(20644, 4147, 1, 1, 2, 498.720017), -- Recipe: Stockings of Zubei (100%)
(20644, 4184, 1, 1, 2, 55.899611), -- Recipe: Sprite's Staff (100%)
(20644, 5160, 1, 1, 2, 97.078328), -- Recipe: Spiritshot (B) Compressed Package (100%)
(20644, 4142, 1, 1, 2, 373.194556), -- Recipe: Avadon Gaiters (100%)
(20644, 8726, 1, 1, 2, 1123.363357), -- Life Stone - Level 55
(20644, 8736, 1, 1, 2, 280.890572), -- Mid-Grade Life Stone - Level 55
(20644, 8746, 1, 1, 2, 28.049271), -- High-Grade Life Stone - Level 55
(20644, 8756, 1, 1, 2, 5.570068), -- Top-Grade Life Stone - Level 55
-- Harit Lizardman Matriarch
(20645, 2121, 1, 1, -1, 17683), -- Eminence Bow Shaft
(20645, 1885, 1, 1, -1, 320445), -- High-Grade Suede
(20645, 1920, 1, 1, -1, 131577), -- Necklace of Seal Chain
(20645, 57, 1520, 3096, 0, 700000), -- Adena
(20645, 286, 1, 1, 1, 30.126185), -- Eminence Bow
(20645, 2121, 1, 1, 1, 3264.873815), -- Eminence Bow Shaft
(20645, 1870, 1, 1, 2, 118317.975663), -- Coal
(20645, 1865, 1, 1, 2, 118317.975663), -- Varnish
(20645, 1874, 1, 1, 2, 7887.985356), -- Oriharukon Ore
(20645, 4043, 1, 1, 2, 3943.992678), -- Asofe
(20645, 4039, 1, 1, 2, 3943.992678), -- Mold Glue
(20645, 4189, 1, 1, 2, 136.382019), -- Recipe: Arthro Nail (100%)
(20645, 5275, 1, 1, 2, 236.670498), -- Recipe: Greater Spiritshot (B) Compressed Package(100%)
(20645, 4179, 1, 1, 2, 1520.827089), -- Recipe: Zubei's Helmet (100%)
(20645, 8726, 1, 1, 2, 2738.726253), -- Life Stone - Level 55
(20645, 8736, 1, 1, 2, 684.746016), -- Mid-Grade Life Stone - Level 55
(20645, 8746, 1, 1, 2, 68.577726), -- High-Grade Life Stone - Level 55
(20645, 8756, 1, 1, 2, 13.148361), -- Top-Grade Life Stone - Level 55
-- Halingka
(20646, 4044, 1, 1, -1, 96583), -- Thons
(20646, 2122, 1, 1, -1, 13225), -- Orcish Poleaxe Blade
(20646, 3034, 1, 1, -1, 5795), -- Recipe: Spiritshot B
(20646, 57, 1145, 2333, 0, 700000), -- Adena
(20646, 301, 1, 1, 1, 9.696768), -- Scorpion
(20646, 2113, 1, 1, 1, 863.5542), -- Scorpion Blade
(20646, 303, 1, 1, 1, 9.696768), -- Widow Maker
(20646, 2114, 1, 1, 1, 863.5542), -- Widowmaker Head
(20646, 299, 1, 1, 1, 7.565328), -- Orcish Poleaxe
(20646, 2122, 1, 1, 1, 813.932736), -- Orcish Poleaxe Blade
(20646, 1864, 1, 1, 2, 178306.774196), -- Stem
(20646, 1869, 1, 1, 2, 89153.387098), -- Iron Ore
(20646, 1878, 1, 1, 2, 35661.500432), -- Braided Hemp
(20646, 1884, 1, 1, 2, 54863.734824), -- Cord
(20646, 4039, 1, 1, 2, 2971.91303), -- Mold Glue
(20646, 4190, 1, 1, 2, 102.642924), -- Recipe: Dark Elven Long Bow (100%)
(20646, 4186, 1, 1, 2, 102.642924), -- Recipe: Sword of Valhalla (100%)
(20646, 5165, 1, 1, 2, 178.35118), -- Recipe: Blessed Spiritshot (B) Compressed Package (100%)
(20646, 8726, 1, 1, 2, 2063.77794), -- Life Stone - Level 55
(20646, 8736, 1, 1, 2, 515.762494), -- Mid-Grade Life Stone - Level 55
(20646, 8746, 1, 1, 2, 51.685444), -- High-Grade Life Stone - Level 55
(20646, 8756, 1, 1, 2, 9.827514), -- Top-Grade Life Stone - Level 55
-- Yintzu
(20647, 2960, 1, 1, -1, 158666), -- Drake Leather Boots Design
(20647, 4049, 1, 1, -1, 152841), -- Adamantite Earring Gemstone
(20647, 947, 1, 1, -1, 1166), -- Scroll: Enchant Weapon (B-Grade)
(20647, 57, 1150, 2348, 0, 700000), -- Adena
(20647, 554, 1, 1, 1, 53.916544), -- Sealed Zubei's Boots
(20647, 4097, 1, 1, 1, 5600.083456), -- Sealed Zubei's Boots Design
(20647, 600, 1, 1, 1, 53.916544), -- Sealed Avadon Boots
(20647, 4098, 1, 1, 1, 5600.083456), -- Sealed Avadon Boots Design
(20647, 612, 1, 1, 1, 53.916544), -- Sealed Zubei's Gauntlets
(20647, 4100, 1, 1, 1, 5600.083456), -- Sealed Zubei's Gauntlets Part
(20647, 2464, 1, 1, 1, 53.916544), -- Sealed Avadon Gloves
(20647, 4073, 1, 1, 1, 5600.083456), -- Sealed Avadon Gloves Part
(20647, 1865, 1, 1, 2, 71726.827744), -- Varnish
(20647, 1870, 1, 1, 2, 71726.827744), -- Coal
(20647, 1879, 1, 1, 2, 11954.526276), -- Cokes
(20647, 1875, 1, 1, 2, 4781.744528), -- Stone of Purity
(20647, 4040, 1, 1, 2, 1434.457376), -- Mold Lubricant
(20647, 4946, 1, 1, 2, 459.732372), -- Recipe: Zubei's Leather Shirt (60%)
(20647, 5280, 1, 1, 2, 143.51172), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(20647, 4176, 1, 1, 2, 892.082048), -- Recipe: Sealed Doom Boots (100%)
(20647, 8727, 1, 1, 2, 1434.457376), -- Life Stone - Level 58
(20647, 8737, 1, 1, 2, 358.614344), -- Mid-Grade Life Stone - Level 58
(20647, 8747, 1, 1, 2, 35.795452), -- High-Grade Life Stone - Level 58
(20647, 8757, 1, 1, 2, 7.42302), -- Top-Grade Life Stone - Level 58
-- Paliote
(20648, 4191, 1, 1, -1, 3620), -- Recipe: Great Axe (100%)
(20648, 2963, 1, 1, -1, 171074), -- Full Plate Gauntlets Part
(20648, 1868, 1, 13, -1, 897647), -- Thread
(20648, 57, 1239, 2531, 0, 700000), -- Adena
(20648, 554, 1, 1, 1, 58.131456), -- Sealed Zubei's Boots
(20648, 4097, 1, 1, 1, 6037.868544), -- Sealed Zubei's Boots Design
(20648, 600, 1, 1, 1, 58.131456), -- Sealed Avadon Boots
(20648, 4098, 1, 1, 1, 6037.868544), -- Sealed Avadon Boots Design
(20648, 612, 1, 1, 1, 58.131456), -- Sealed Zubei's Gauntlets
(20648, 4100, 1, 1, 1, 6037.868544), -- Sealed Zubei's Gauntlets Part
(20648, 2464, 1, 1, 1, 58.131456), -- Sealed Avadon Gloves
(20648, 4073, 1, 1, 1, 6037.868544), -- Sealed Avadon Gloves Part
(20648, 1873, 1, 1, 2, 30934.28802), -- Silver Nugget
(20648, 1868, 1, 1, 2, 154671.193297), -- Thread
(20648, 1876, 1, 1, 2, 15467.14401), -- Mithril Ore
(20648, 1895, 1, 1, 2, 22095.778984), -- Metallic Fiber
(20648, 4042, 1, 1, 2, 1288.805266), -- Enria
(20648, 4961, 1, 1, 2, 1419.11725), -- Recipe: Zubei's Shield (60%)
(20648, 4999, 1, 1, 2, 961.791291), -- Recipe: Sealed Doom Boots (60%)
(20648, 6669, 1, 1, 2, 17985.028216), -- Deluxe Chest Key - Grade 5
(20648, 8727, 1, 1, 2, 1546.714401), -- Life Stone - Level 58
(20648, 8737, 1, 1, 2, 386.740301), -- Mid-Grade Life Stone - Level 58
(20648, 8747, 1, 1, 2, 38.748071), -- High-Grade Life Stone - Level 58
(20648, 8757, 1, 1, 2, 7.650893), -- Top-Grade Life Stone - Level 58
-- Hamrut
(20649, 2112, 1, 1, -1, 16014), -- Pa'agrian Axe Blade
(20649, 4133, 1, 1, -1, 15899), -- Recipe: Zubei's Breastplate (100%)
(20649, 5549, 1, 1, -1, 330694), -- Metallic Thread
(20649, 57, 1306, 2660, 0, 700000), -- Adena
(20649, 78, 1, 1, 1, 4.87334), -- Great Sword
(20649, 4104, 1, 1, 1, 931.41398), -- Great Sword Blade
(20649, 142, 1, 1, 1, 4.87334), -- Keshanberk
(20649, 4107, 1, 1, 1, 916.983), -- Keshanberk Blade
(20649, 148, 1, 1, 1, 4.87334), -- Sword of Valhalla
(20649, 4108, 1, 1, 1, 916.983), -- Sword of Valhalla Blade
(20649, 1868, 1, 1, 2, 150280.240366), -- Thread
(20649, 1873, 1, 1, 2, 30055.935682), -- Silver Nugget
(20649, 5549, 1, 1, 2, 7513.913676), -- Metallic Thread
(20649, 1889, 1, 1, 2, 5009.275784), -- Compound Braid
(20649, 4044, 1, 1, 2, 2504.637892), -- Thons
(20649, 4970, 1, 1, 2, 86.541224), -- Recipe: Arthro Nail (60%)
(20649, 4194, 1, 1, 2, 57.319512), -- Recipe: Deadman's Glory (100%)
(20649, 8311, 1, 1, 2, 57.319512), -- Recipe: Kaim Vanul's Bones (100%)
(20649, 8727, 1, 1, 2, 1502.670344), -- Life Stone - Level 58
(20649, 8737, 1, 1, 2, 375.667586), -- Mid-Grade Life Stone - Level 58
(20649, 8747, 1, 1, 2, 37.651052), -- High-Grade Life Stone - Level 58
(20649, 8757, 1, 1, 2, 7.586406), -- Top-Grade Life Stone - Level 58
(20649, 1832, 1, 1, 2, 83489.240964), -- Greater Antidote
-- Kranrot
(20650, 4049, 1, 1, -1, 188177), -- Adamantite Earring Gemstone
(20650, 4195, 1, 1, -1, 2739), -- Recipe: Art of Battle Axe (100%)
(20650, 4613, 1, 1, -1, 4948), -- Greater Dye of STR (Str+4 Con-4)
(20650, 57, 1417, 2887, 0, 700000), -- Adena
(20650, 856, 1, 1, 1, 75.817654), -- Adamantite Earring
(20650, 4049, 1, 1, 1, 9263.677808), -- Adamantite Earring Gemstone
(20650, 918, 1, 1, 1, 56.870066), -- Adamantite Necklace
(20650, 4051, 1, 1, 1, 6849.416552), -- Adamantite Necklace Chain
(20650, 887, 1, 1, 1, 113.71283), -- Adamantite Ring
(20650, 4050, 1, 1, 1, 10942.50509), -- Adamantite Ring Wire
(20650, 1867, 1, 1, 2, 117746.485692), -- Animal Skin
(20650, 1872, 1, 1, 2, 117746.485692), -- Animal Bone
(20650, 1882, 1, 1, 2, 19624.414282), -- Leather
(20650, 1894, 1, 1, 2, 3098.702882), -- Crafted Leather
(20650, 4042, 1, 1, 2, 1471.738675), -- Enria
(20650, 948, 1, 1, 2, 220.694804), -- Scroll: Enchant Armor (B-Grade)
(20650, 4167, 1, 1, 2, 1098.458229), -- Recipe: Sealed Blue Wolf Boots (100%)
(20650, 4168, 1, 1, 2, 1098.458229), -- Recipe: Sealed Doom Gloves (100%)
(20650, 8728, 1, 1, 2, 1471.738675), -- Life Stone - Level 61
(20650, 8738, 1, 1, 2, 368.000666), -- Mid-Grade Life Stone - Level 61
(20650, 8748, 1, 1, 2, 36.694471), -- High-Grade Life Stone - Level 61
(20650, 8758, 1, 1, 2, 7.127703), -- Top-Grade Life Stone - Level 61
-- Gamlin
(20651, 4050, 1, 1, -1, 206850), -- Adamantite Ring Wire
(20651, 4196, 1, 1, -1, 2549), -- Recipe: Staff of Evil Spirits (100%)
(20651, 57, 1320, 2684, 0, 700000), -- Adena
(20651, 78, 1, 1, 1, 4.920671), -- Great Sword
(20651, 4104, 1, 1, 1, 940.460087), -- Great Sword Blade
(20651, 142, 1, 1, 1, 4.920671), -- Keshanberk
(20651, 4107, 1, 1, 1, 925.88895), -- Keshanberk Blade
(20651, 148, 1, 1, 1, 4.920671), -- Sword of Valhalla
(20651, 4108, 1, 1, 1, 925.88895), -- Sword of Valhalla Blade
(20651, 1867, 1, 1, 2, 109573.022592), -- Animal Skin
(20651, 1872, 1, 1, 2, 109573.022592), -- Animal Bone
(20651, 1882, 1, 1, 2, 18262.170432), -- Leather
(20651, 1894, 1, 1, 2, 2883.604032), -- Crafted Leather
(20651, 4042, 1, 1, 2, 1369.5768), -- Enria
(20651, 948, 1, 1, 2, 205.375104), -- Scroll: Enchant Armor (B-Grade)
(20651, 4167, 1, 1, 2, 1022.207904), -- Recipe: Sealed Blue Wolf Boots (100%)
(20651, 4168, 1, 1, 2, 1022.207904), -- Recipe: Sealed Doom Gloves (100%)
(20651, 8728, 1, 1, 2, 1369.5768), -- Life Stone - Level 61
(20651, 8738, 1, 1, 2, 342.455616), -- Mid-Grade Life Stone - Level 61
(20651, 8748, 1, 1, 2, 34.147296), -- High-Grade Life Stone - Level 61
(20651, 8758, 1, 1, 2, 6.632928), -- Top-Grade Life Stone - Level 61
-- Leogul
(20652, 4042, 1, 1, -1, 58802), -- Enria
(20652, 4043, 1, 1, -1, 117603), -- Asofe
(20652, 4129, 1, 1, -1, 38183), -- Recipe: Earrings of Black Ore (100%)
(20652, 57, 1398, 2835, 0, 700000), -- Adena
(20652, 2384, 1, 1, 1, 29.021255), -- Zubei's Leather Shirt
(20652, 4066, 1, 1, 1, 4095.94146), -- Zubei's Leather Shirt Fabric
(20652, 2390, 1, 1, 1, 17.851935), -- Avadon Leather Armor
(20652, 4068, 1, 1, 1, 3146.698365), -- Avadon Leather Armor Lining
(20652, 2388, 1, 1, 1, 46.43943), -- Zubei's Leather Gaiters
(20652, 4067, 1, 1, 1, 6219.047555), -- Zubei's Leather Gaiter Texture
(20652, 1869, 1, 1, 2, 86845.277172), -- Iron Ore
(20652, 1864, 1, 1, 2, 173690.554344), -- Stem
(20652, 1880, 1, 1, 2, 8684.472236), -- Steel
(20652, 5550, 1, 1, 2, 1157.892644), -- Durable Metal Plate
(20652, 4043, 1, 1, 2, 2894.73161), -- Asofe
(20652, 4615, 1, 1, 2, 119.839392), -- Greater Dye of CON (Con+4 Str-4)
(20652, 4998, 1, 1, 2, 1080.218964), -- Recipe: Sealed Blue Wolf Gloves (60%)
(20652, 4173, 1, 1, 2, 1080.218964), -- Recipe: Sealed Blue Wolf Gloves (100%)
(20652, 8728, 1, 1, 2, 1447.504508), -- Life Stone - Level 61
(20652, 8738, 1, 1, 2, 361.737424), -- Mid-Grade Life Stone - Level 61
(20652, 8748, 1, 1, 2, 36.06278), -- High-Grade Life Stone - Level 61
(20652, 8758, 1, 1, 2, 7.489962), -- Top-Grade Life Stone - Level 61
-- Lesser Giant Soldier
(20654, 4064, 1, 1, -1, 119042), -- Avadon Breastplate Part
(20654, 4052, 1, 1, -1, 232857), -- Earring of Black Ore Piece
(20654, 5230, 1, 1, -1, 8769), -- Recipe: Mithril Arrow (100%)
(20654, 57, 2608, 5284, 0, 700000), -- Adena
(20654, 2398, 1, 1, 1, 26.155129), -- Blue Wolf Tunic
(20654, 4084, 1, 1, 1, 4221.905376), -- Blue Wolf Tunic Fabric
(20654, 2399, 1, 1, 1, 26.155129), -- Tunic of Doom
(20654, 4085, 1, 1, 1, 4221.905376), -- Tunic of Doom Pattern
(20654, 2403, 1, 1, 1, 41.880176), -- Blue Wolf Stockings
(20654, 4086, 1, 1, 1, 5700.539338), -- Blue Wolf Stockings Pattern
(20654, 2404, 1, 1, 1, 41.880176), -- Stockings of Doom
(20654, 4087, 1, 1, 1, 5700.5793), -- Stockings of Doom Pattern
(20654, 1894, 1, 1, 2, 6197.111536), -- Crafted Leather
(20654, 4039, 1, 1, 2, 5887.22996), -- Mold Glue
(20654, 4041, 1, 1, 2, 1535.801632), -- Mold Hardener
(20654, 4044, 1, 1, 2, 5887.22996), -- Thons
(20654, 4624, 1, 1, 2, 243.612504), -- Greater Dye of WIT (Wit+4 Men-4)
(20654, 5276, 1, 1, 2, 235.494976), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20654, 8729, 1, 1, 2, 2354.891984), -- Life Stone - Level 64
(20654, 8739, 1, 1, 2, 588.73744), -- Mid-Grade Life Stone - Level 64
(20654, 8749, 1, 1, 2, 58.873744), -- High-Grade Life Stone - Level 64
(20654, 8759, 1, 1, 2, 11.786304), -- Top-Grade Life Stone - Level 64
(20654, 6036, 1, 1, 2, 5887.22996), -- Greater Magic Haste Potion
-- Lesser Giant Shooter
(20655, 4067, 1, 1, -1, 212287), -- Zubei's Leather Gaiter Texture
(20655, 4160, 1, 1, -1, 16800), -- Recipe: Leather Armor of Doom (100%)
(20655, 4053, 1, 1, -1, 254190), -- Ring of Black Ore Gemstone
(20655, 57, 2352, 4762, 0, 700000), -- Adena
(20655, 110, 1, 1, 1, 89.858003), -- Doom Shield
(20655, 4077, 1, 1, 1, 13134.250675), -- Doom Shield Fragment
(20655, 2416, 1, 1, 1, 62.904144), -- Blue Wolf Helmet
(20655, 4088, 1, 1, 1, 11034.541517), -- Blue Wolf Helmet Design
(20655, 2417, 1, 1, 1, 62.904144), -- Doom Helmet
(20655, 4089, 1, 1, 1, 11034.541517), -- Doom Helmet Pattern
(20655, 1870, 1, 1, 2, 134746.353792), -- Coal
(20655, 1865, 1, 1, 2, 134746.353792), -- Varnish
(20655, 1874, 1, 1, 2, 8983.17216), -- Oriharukon Ore
(20655, 4043, 1, 1, 2, 4491.381312), -- Asofe
(20655, 4039, 1, 1, 2, 4491.381312); -- Mold Glue

INSERT INTO `droplist` VALUES
(20655, 4989, 1, 1, 2, 892.378944), -- Recipe: Stockings of Doom (60%)
(20655, 5276, 1, 1, 2, 179.786304), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20655, 6670, 1, 1, 2, 22457.725632), -- Deluxe Chest Key - Grade 6
(20655, 8729, 1, 1, 2, 1796.634432), -- Life Stone - Level 64
(20655, 8739, 1, 1, 2, 449.260992), -- Mid-Grade Life Stone - Level 64
(20655, 8749, 1, 1, 2, 45.04896), -- High-Grade Life Stone - Level 64
(20655, 8759, 1, 1, 2, 9.009792), -- Top-Grade Life Stone - Level 64
(20655, 1343, 20, 60, 2, 96247.512576), -- Silver Arrow
-- Lesser Giant Scout
(20656, 4069, 1, 1, -1, 134666), -- Tunic of Zubei Fabric
(20656, 4040, 1, 1, -1, 114237), -- Mold Lubricant
(20656, 57, 2265, 4587, 0, 700000), -- Adena
(20656, 2398, 1, 1, 1, 22.713768), -- Blue Wolf Tunic
(20656, 4084, 1, 1, 1, 3666.408192), -- Blue Wolf Tunic Fabric
(20656, 2399, 1, 1, 1, 22.713768), -- Tunic of Doom
(20656, 4085, 1, 1, 1, 3666.408192), -- Tunic of Doom Pattern
(20656, 2403, 1, 1, 1, 36.369792), -- Blue Wolf Stockings
(20656, 4086, 1, 1, 1, 4950.490896), -- Blue Wolf Stockings Pattern
(20656, 2404, 1, 1, 1, 36.369792), -- Stockings of Doom
(20656, 4087, 1, 1, 1, 4950.5256), -- Stockings of Doom Pattern
(20656, 1895, 1, 1, 2, 48205.247259), -- Metallic Fiber
(20656, 4040, 1, 1, 2, 3374.407044), -- Mold Lubricant
(20656, 4042, 1, 1, 2, 2812.00587), -- Enria
(20656, 4043, 1, 1, 2, 5623.919331), -- Asofe
(20656, 4990, 1, 1, 2, 1394.359401), -- Recipe: Blue Wolf Helmet (60%)
(20656, 6670, 1, 1, 2, 28119.689064), -- Deluxe Chest Key - Grade 6
(20656, 8729, 1, 1, 2, 2249.604696), -- Life Stone - Level 64
(20656, 8739, 1, 1, 2, 562.401174), -- Mid-Grade Life Stone - Level 64
(20656, 8749, 1, 1, 2, 56.277081), -- High-Grade Life Stone - Level 64
(20656, 8759, 1, 1, 2, 11.08908), -- Top-Grade Life Stone - Level 64
-- Lesser Giant Mage
(20657, 1920, 1, 1, -1, 144429), -- Necklace of Seal Chain
(20657, 1914, 1, 1, -1, 237131), -- Earring of Seal Gemstone
(20657, 1877, 1, 1, -1, 168837), -- Adamantite Nugget
(20657, 57, 1676, 3389, 0, 700000), -- Adena
(20657, 2398, 1, 1, 1, 16.785307), -- Blue Wolf Tunic
(20657, 4084, 1, 1, 1, 2709.448608), -- Blue Wolf Tunic Fabric
(20657, 2399, 1, 1, 1, 16.785307), -- Tunic of Doom
(20657, 4085, 1, 1, 1, 2709.448608), -- Tunic of Doom Pattern
(20657, 2403, 1, 1, 1, 26.877008), -- Blue Wolf Stockings
(20657, 4086, 1, 1, 1, 3658.376254), -- Blue Wolf Stockings Pattern
(20657, 2404, 1, 1, 1, 26.877008), -- Stockings of Doom
(20657, 4087, 1, 1, 1, 3658.4019), -- Stockings of Doom Pattern
(20657, 1871, 1, 1, 2, 103899.577968), -- Charcoal
(20657, 1866, 1, 1, 2, 69266.385312), -- Suede
(20657, 1877, 1, 1, 2, 4155.931522), -- Adamantite Nugget
(20657, 4041, 1, 1, 2, 903.495422), -- Mold Hardener
(20657, 4040, 1, 1, 2, 2078.057898), -- Mold Lubricant
(20657, 4960, 1, 1, 2, 2001.952736), -- Recipe: Sealed Zubei's Gauntlets (60%)
(20657, 5276, 1, 1, 2, 138.574048), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20657, 8300, 1, 1, 2, 56.756392), -- Recipe: Infernal Master (60%)
(20657, 8729, 1, 1, 2, 1385.371932), -- Life Stone - Level 64
(20657, 8739, 1, 1, 2, 346.250846), -- Mid-Grade Life Stone - Level 64
(20657, 8749, 1, 1, 2, 34.643512), -- High-Grade Life Stone - Level 64
(20657, 8759, 1, 1, 2, 7.002412), -- Top-Grade Life Stone - Level 64
-- Lesser Giant Elder
(20658, 2220, 1, 1, -1, 84264), -- Recipe: Rind Leather Armor
(20658, 1960, 1, 1, -1, 223012), -- Chain Gaiters Part
(20658, 4054, 1, 1, -1, 80165), -- Necklace of Black Ore Beads
(20658, 57, 1613, 3270, 0, 700000), -- Adena
(20658, 864, 1, 1, 1, 56.362295), -- Earring of Black Ore
(20658, 4052, 1, 1, 1, 7093.52666), -- Earring of Black Ore Piece
(20658, 926, 1, 1, 1, 42.276674), -- Necklace of Black Ore
(20658, 4054, 1, 1, 1, 3946.3512), -- Necklace of Black Ore Beads
(20658, 895, 1, 1, 1, 84.533537), -- Ring of Black Ore
(20658, 4053, 1, 1, 1, 8587.949634), -- Ring of Black Ore Gemstone
(20658, 1866, 1, 1, 2, 66789.15416), -- Suede
(20658, 1871, 1, 1, 2, 100183.73124), -- Charcoal
(20658, 5220, 1, 1, 2, 4007.32576), -- Metal Hardener
(20658, 1885, 1, 1, 2, 8348.79108), -- High-Grade Suede
(20658, 4041, 1, 1, 2, 871.17054), -- Mold Hardener
(20658, 4155, 1, 1, 2, 311.2372), -- Recipe: Blue Wolf Breastplate (100%)
(20658, 730, 1, 1, 2, 83.38808), -- Scroll: Enchant Armor (A-Grade)
(20658, 8729, 1, 1, 2, 1335.67738), -- Life Stone - Level 64
(20658, 8739, 1, 1, 2, 333.84594), -- Mid-Grade Life Stone - Level 64
(20658, 8749, 1, 1, 2, 33.47268), -- High-Grade Life Stone - Level 64
(20658, 8759, 1, 1, 2, 6.75326), -- Top-Grade Life Stone - Level 64
(20658, 1832, 1, 1, 2, 111315.45268), -- Greater Antidote
-- Grave Wanderer
(20659, 2062, 1, 1, -1, 10273), -- Scythe Edge
(20659, 1885, 1, 1, -1, 109145), -- High-Grade Suede
(20659, 2163, 1, 1, -1, 66824), -- Recipe: Earring of Protection
(20659, 57, 518, 1052, 0, 700000), -- Adena
(20659, 631, 1, 1, 1, 202.2864), -- Eldarake
(20659, 1964, 1, 1, 1, 8336.20767), -- Eldarake Temper
(20659, 2495, 1, 1, 1, 202.2864), -- Chain Shield
(20659, 2945, 1, 1, 1, 8336.20767), -- Chain Shield Fragment
(20659, 2413, 1, 1, 1, 141.60048), -- Chain Hood
(20659, 2936, 1, 1, 1, 7571.41138), -- Chain Hood Pattern
(20659, 1868, 1, 1, 2, 95232.000732), -- Thread
(20659, 1873, 1, 1, 2, 19046.425789), -- Silver Nugget
(20659, 5549, 1, 1, 2, 4761.574394), -- Metallic Thread
(20659, 1889, 1, 1, 2, 3174.425667), -- Compound Braid
(20659, 4044, 1, 1, 2, 1587.148727), -- Thons
(20659, 3021, 1, 1, 2, 165.907622), -- Recipe: Dwarven War Hammer
(20659, 2225, 1, 1, 2, 1035.191762), -- Recipe: Demon's Stockings
(20659, 2321, 1, 1, 2, 165.907622), -- Recipe: Stiletto
(20659, 2215, 1, 1, 2, 606.575703), -- Recipe: Robe of Seal
(20659, 8723, 1, 1, 2, 1904.604115), -- Life Stone - Level 46
(20659, 8733, 1, 1, 2, 476.183082), -- Mid-Grade Life Stone - Level 46
(20659, 8743, 1, 1, 2, 47.567023), -- High-Grade Life Stone - Level 46
(20659, 8753, 1, 1, 2, 9.487762), -- Top-Grade Life Stone - Level 46
-- Archer of Greed
(20660, 2330, 1, 1, -1, 3761), -- Recipe: Homunkulus's Sword
(20660, 2084, 1, 1, -1, 10746), -- Soulfire Dirk Blade
(20660, 1908, 1, 1, -1, 153154), -- Moonstone Earring Wire
(20660, 57, 637, 1303, 0, 700000), -- Adena
(20660, 439, 1, 1, 1, 131.332864), -- Karmian Tunic
(20660, 1962, 1, 1, 1, 6115.236328), -- Karmian Tunic Pattern
(20660, 471, 1, 1, 1, 209.893312), -- Karmian Stockings
(20660, 1954, 1, 1, 1, 10159.537496), -- Karmian Stocking Design
(20660, 1869, 1, 1, 2, 76436.092936), -- Iron Ore
(20660, 1864, 1, 1, 2, 152871.93754), -- Stem
(20660, 1880, 1, 1, 2, 7643.65896), -- Steel
(20660, 5550, 1, 1, 2, 1019.154528), -- Durable Metal Plate
(20660, 4043, 1, 1, 2, 2547.88632), -- Asofe
(20660, 2163, 1, 1, 2, 3899.805728), -- Recipe: Earring of Protection
(20660, 8723, 1, 1, 2, 3057.463584), -- Life Stone - Level 46
(20660, 8733, 1, 1, 2, 764.365896), -- Mid-Grade Life Stone - Level 46
(20660, 8743, 1, 1, 2, 76.486256), -- High-Grade Life Stone - Level 46
(20660, 8753, 1, 1, 2, 15.148252), -- Top-Grade Life Stone - Level 46
-- Hatar Ratman Thief
(20661, 2223, 1, 1, -1, 59150), -- Recipe: Tower Shield
(20661, 2347, 1, 1, -1, 3549), -- Recipe: Akat Long Bow
(20661, 2166, 1, 1, -1, 51732), -- Recipe: Earrings of Binding (100%)
(20661, 57, 602, 1229, 0, 700000), -- Adena
(20661, 2496, 1, 1, 1, 187.671942), -- Dwarven Chain Shield
(20661, 2947, 1, 1, 1, 8049.505542), -- Dwarven Chain Shield Fragment
(20661, 632, 1, 1, 1, 173.248802), -- Knight's Shield
(20661, 1972, 1, 1, 1, 9015.44034), -- Knight's Shield Fragment
(20661, 500, 1, 1, 1, 121.301052), -- Great Helmet
(20661, 1971, 1, 1, 1, 6898.832322), -- Great Helmet Material
(20661, 1873, 1, 1, 2, 19319.157744), -- Silver Nugget
(20661, 1868, 1, 1, 2, 96595.322192), -- Thread
(20661, 1876, 1, 1, 2, 9659.46224), -- Mithril Ore
(20661, 1895, 1, 1, 2, 13799.431712), -- Metallic Fiber
(20661, 4042, 1, 1, 2, 804.994064), -- Enria
(20661, 2223, 1, 1, 2, 1871.9436), -- Recipe: Tower Shield
(20661, 2230, 1, 1, 2, 936.088432), -- Recipe: Theca Leather Gaiters
(20661, 3005, 1, 1, 2, 1971.314064), -- Recipe: Demon's Boots
(20661, 6668, 1, 1, 2, 17249.173008), -- Deluxe Chest Key - Grade 4
(20661, 8724, 1, 1, 2, 1609.988128), -- Life Stone - Level 49
(20661, 8734, 1, 1, 2, 402.3804), -- Mid-Grade Life Stone - Level 49
(20661, 8744, 1, 1, 2, 40.354672), -- High-Grade Life Stone - Level 49
(20661, 8754, 1, 1, 2, 8.16424), -- Top-Grade Life Stone - Level 49
(20661, 1343, 10, 30, 2, 68996.225504), -- Silver Arrow
-- Hatar Ratman Boss
(20662, 951, 1, 1, -1, 2897), -- Scroll: Enchant Weapon (C-Grade)
(20662, 1873, 1, 1, -1, 637338), -- Silver Nugget
(20662, 1911, 1, 1, -1, 118508), -- Earring of Protection Gemstone
(20662, 57, 630, 1281, 0, 700000), -- Adena
(20662, 73, 1, 1, 1, 7.98672), -- Shamshir
(20662, 2077, 1, 1, 1, 586.26328), -- Shamshir Blade
(20662, 74, 1, 1, 1, 7.98672), -- Katana
(20662, 2078, 1, 1, 1, 586.26328), -- Katana Blade
(20662, 131, 1, 1, 1, 7.98672), -- Spirit Sword
(20662, 2080, 1, 1, 1, 586.26328), -- Spirit Sword Blade
(20662, 133, 1, 1, 1, 7.98672), -- Raid Sword
(20662, 2081, 1, 1, 1, 586.26328), -- Raid Sword Blade
(20662, 1871, 1, 1, 2, 58831.182362), -- Charcoal
(20662, 1866, 1, 1, 2, 39220.660784), -- Suede
(20662, 1877, 1, 1, 2, 2353.308474), -- Adamantite Nugget
(20662, 4041, 1, 1, 2, 511.613736), -- Mold Hardener
(20662, 4040, 1, 1, 2, 1176.558644), -- Mold Lubricant
(20662, 2340, 1, 1, 2, 136.889176), -- Recipe: Pa'agrian Hammer
(20662, 3006, 1, 1, 2, 2401.29616), -- Recipe: Demon's Gloves
(20662, 8724, 1, 1, 2, 1960.994802), -- Life Stone - Level 49
(20662, 8734, 1, 1, 2, 490.200904), -- Mid-Grade Life Stone - Level 49
(20662, 8744, 1, 1, 2, 48.943616), -- High-Grade Life Stone - Level 49
(20662, 8754, 1, 1, 2, 9.750486), -- Top-Grade Life Stone - Level 49
(20662, 1343, 10, 30, 2, 84044.600856), -- Silver Arrow
-- Hatar Hanishee
(20663, 1981, 1, 1, -1, 82154), -- Mithril Gauntlets Design
(20663, 4123, 1, 1, -1, 62072), -- Recipe: Maestro Anvil Lock (100%)
(20663, 951, 1, 1, -1, 2539), -- Scroll: Enchant Weapon (C-Grade)
(20663, 57, 551, 1124, 0, 700000), -- Adena
(20663, 853, 1, 1, 1, 137.053122), -- Earring of Protection
(20663, 1911, 1, 1, 1, 7671.3024), -- Earring of Protection Gemstone
(20663, 916, 1, 1, 1, 102.828096), -- Necklace of Protection
(20663, 1913, 1, 1, 1, 6271.850778), -- Necklace of Protection Gemstone
(20663, 884, 1, 1, 1, 205.656192), -- Ring of Protection
(20663, 1912, 1, 1, 1, 11114.309412), -- Ring of Protection Gemstone
(20663, 1871, 1, 1, 2, 56254.98765), -- Charcoal
(20663, 1866, 1, 1, 2, 37503.35925), -- Suede
(20663, 1877, 1, 1, 2, 2250.2118), -- Adamantite Nugget
(20663, 4041, 1, 1, 2, 489.19875), -- Mold Hardener
(20663, 4040, 1, 1, 2, 1125.1059), -- Mold Lubricant
(20663, 2340, 1, 1, 2, 130.82865), -- Recipe: Pa'agrian Hammer
(20663, 3006, 1, 1, 2, 2296.1094), -- Recipe: Demon's Gloves
(20663, 8724, 1, 1, 2, 1875.14235), -- Life Stone - Level 49
(20663, 8734, 1, 1, 2, 468.8112), -- Mid-Grade Life Stone - Level 49
(20663, 8744, 1, 1, 2, 46.9221), -- High-Grade Life Stone - Level 49
(20663, 8754, 1, 1, 2, 9.32295), -- Top-Grade Life Stone - Level 49
-- Deprive
(20664, 2098, 1, 1, -1, 7876), -- Nirvana Axe Blade
(20664, 1865, 1, 3, -1, 735264), -- Varnish
(20664, 1867, 1, 5, -1, 653568), -- Animal Skin
(20664, 57, 582, 1182, 0, 700000), -- Adena
(20664, 64, 1, 1, 1, 161.04976), -- Composite Boots
(20664, 2956, 1, 1, 1, 8942.95024), -- Composite Boots Part
(20664, 608, 1, 1, 1, 161.04976), -- Mithril Gauntlets
(20664, 1981, 1, 1, 1, 8942.95024), -- Mithril Gauntlets Design
(20664, 1867, 1, 1, 2, 57916.315041), -- Animal Skin
(20664, 1872, 1, 1, 2, 57916.315041), -- Animal Bone
(20664, 1882, 1, 1, 2, 9652.694199), -- Leather
(20664, 1894, 1, 1, 2, 1524.093837), -- Crafted Leather
(20664, 4042, 1, 1, 2, 723.910857), -- Enria
(20664, 2234, 1, 1, 2, 647.33904), -- Recipe: Divine Stockings
(20664, 4609, 1, 1, 2, 96.501468), -- Greater Dye of MEN (Men+3 Int-3)
(20664, 2356, 1, 1, 2, 70.877631), -- Recipe: Demon's Staff
(20664, 6669, 1, 1, 2, 10101.635811), -- Deluxe Chest Key - Grade 5
(20664, 8725, 1, 1, 2, 1206.568044), -- Life Stone - Level 52
(20664, 8735, 1, 1, 2, 301.642011), -- Mid-Grade Life Stone - Level 52
(20664, 8745, 1, 1, 2, 30.119247), -- High-Grade Life Stone - Level 52
(20664, 8755, 1, 1, 2, 5.99388), -- Top-Grade Life Stone - Level 52
(20664, 1539, 1, 1, 2, 9652.993893), -- Greater Healing Potion
-- Taik Orc Supply
(20665, 2104, 1, 1, -1, 10174), -- Club of Nature Head
(20665, 2359, 1, 1, -1, 2944), -- Recipe: Eminence Bow
(20665, 4043, 1, 1, -1, 60164), -- Asofe
(20665, 57, 715, 1452, 0, 700000), -- Adena
(20665, 162, 1, 1, 1, 2.824002), -- War Axe
(20665, 2097, 1, 1, 1, 249.916904), -- War Axe Blade
(20665, 174, 1, 1, 1, 2.824002), -- Nirvana Axe
(20665, 2098, 1, 1, 1, 249.916904), -- Nirvana Axe Blade
(20665, 196, 1, 1, 1, 2.824002), -- Stick of Eternity
(20665, 2099, 1, 1, 1, 263.018694), -- Stick of Eternity Shaft
(20665, 197, 1, 1, 1, 2.824002), -- Paradia Staff
(20665, 2100, 1, 1, 1, 263.018694), -- Paradia Staff Head
(20665, 199, 1, 1, 1, 2.824002), -- Pa'agrian Hammer
(20665, 2102, 1, 1, 1, 253.584574), -- Pa'agrian Hammer Head
(20665, 200, 1, 1, 1, 2.824002), -- Sage's Staff
(20665, 2103, 1, 1, 1, 263.018694), -- Sage's Staff Head
(20665, 201, 1, 1, 1, 2.824002), -- Club of Nature
(20665, 2104, 1, 1, 1, 263.018694), -- Club of Nature Head
(20665, 202, 1, 1, 1, 2.824002), -- Mace of Underworld
(20665, 2105, 1, 1, 1, 249.914826), -- Mace of Underworld Head
(20665, 1870, 1, 1, 2, 67855.338432), -- Coal
(20665, 1865, 1, 1, 2, 67855.338432), -- Varnish
(20665, 1874, 1, 1, 2, 4523.67909), -- Oriharukon Ore
(20665, 4043, 1, 1, 2, 2261.915586), -- Asofe
(20665, 4039, 1, 1, 2, 2261.915586), -- Mold Glue
(20665, 4125, 1, 1, 2, 3015.78606), -- Recipe: Maestro Mold (100%)
(20665, 3014, 1, 1, 2, 1895.397966), -- Recipe: Full Plate Boots
(20665, 8725, 1, 1, 2, 1884.904308), -- Life Stone - Level 52
(20665, 8735, 1, 1, 2, 471.150036), -- Mid-Grade Life Stone - Level 52
(20665, 8745, 1, 1, 2, 47.14542), -- High-Grade Life Stone - Level 52
(20665, 8755, 1, 1, 2, 9.429084), -- Top-Grade Life Stone - Level 52
-- Taik Orc Seeker
(20666, 1977, 1, 1, -1, 27780), -- Composite Armor Temper
(20666, 1884, 1, 3, -1, 577821), -- Cord
(20666, 4606, 1, 1, -1, 4173), -- Greater Dye of DEX (Dex+3 Con-3)
(20666, 57, 746, 1507, 0, 700000), -- Adena
(20666, 64, 1, 1, 1, 205.66394), -- Composite Boots
(20666, 2956, 1, 1, 1, 11420.33606), -- Composite Boots Part
(20666, 608, 1, 1, 1, 205.66394), -- Mithril Gauntlets
(20666, 1981, 1, 1, 1, 11420.33606), -- Mithril Gauntlets Design
(20666, 1870, 1, 1, 2, 59737.700113), -- Coal
(20666, 1865, 1, 1, 2, 59737.700113), -- Varnish
(20666, 1874, 1, 1, 2, 3982.452642), -- Oriharukon Ore
(20666, 4043, 1, 1, 2, 1991.226321), -- Asofe
(20666, 4039, 1, 1, 2, 1991.226321), -- Mold Glue
(20666, 4607, 1, 1, 2, 132.800449), -- Greater Dye of INT (Int+3 Men-3)
(20666, 4609, 1, 1, 2, 132.800449), -- Greater Dye of MEN (Men+3 Int-3)
(20666, 3955, 1, 1, 2, 119.533411), -- Recipe: Blessed Spiritshot B
(20666, 5280, 1, 1, 2, 119.533411), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(20666, 8725, 1, 1, 2, 1659.420302), -- Life Stone - Level 52
(20666, 8735, 1, 1, 2, 414.790041), -- Mid-Grade Life Stone - Level 52
(20666, 8745, 1, 1, 2, 41.492011), -- High-Grade Life Stone - Level 52
(20666, 8755, 1, 1, 2, 8.324416), -- Top-Grade Life Stone - Level 52
-- Farcran
(20667, 1988, 1, 1, -1, 37181), -- Divine Tunic Fabric
(20667, 4141, 1, 1, -1, 9303), -- Recipe: Avadon Breastplate (100%)
(20667, 4604, 1, 1, -1, 4300), -- Greater Dye of CON (Con+3 Dex-3)
(20667, 57, 766, 1556, 0, 700000), -- Adena
(20667, 301, 1, 1, 1, 6.47584), -- Scorpion
(20667, 2113, 1, 1, 1, 576.711625), -- Scorpion Blade
(20667, 303, 1, 1, 1, 6.47584), -- Widow Maker
(20667, 2114, 1, 1, 1, 576.711625), -- Widowmaker Head
(20667, 299, 1, 1, 1, 5.05239), -- Orcish Poleaxe
(20667, 2122, 1, 1, 1, 543.57268), -- Orcish Poleaxe Blade
(20667, 1875, 1, 1, 2, 3664.03052), -- Stone of Purity
(20667, 1879, 1, 1, 2, 9160.0763), -- Cokes
(20667, 1885, 1, 1, 2, 4580.03815), -- High-Grade Suede
(20667, 5550, 1, 1, 2, 732.811485), -- Durable Metal Plate
(20667, 5549, 1, 1, 2, 5496.04578), -- Metallic Thread
(20667, 4127, 1, 1, 2, 1360.397515), -- Recipe: Adamantite Ring (100%)
(20667, 4184, 1, 1, 2, 63.307465), -- Recipe: Sprite's Staff (100%)
(20667, 5155, 1, 1, 2, 109.93383), -- Recipe: Soulshot (B) Compressed Package (100%)
(20667, 5165, 1, 1, 2, 109.93383), -- Recipe: Blessed Spiritshot (B) Compressed Package (100%)
(20667, 8726, 1, 1, 2, 1272.22983), -- Life Stone - Level 55
(20667, 8736, 1, 1, 2, 318.07091), -- Mid-Grade Life Stone - Level 55
(20667, 8746, 1, 1, 2, 31.80171), -- High-Grade Life Stone - Level 55
(20667, 8756, 1, 1, 2, 6.322675), -- Top-Grade Life Stone - Level 55
-- Grave Guard
(20668, 4147, 1, 1, -1, 17733), -- Recipe: Stockings of Zubei (100%)
(20668, 2917, 1, 1, -1, 99106), -- Ring of Seal Gemstone
(20668, 1806, 1, 1, -1, 3451), -- Recipe: Soulshot (B-Grade)
(20668, 57, 682, 1388, 0, 700000), -- Adena
(20668, 203, 1, 1, 1, 3.463976), -- Pa'agrian Axe
(20668, 2112, 1, 1, 1, 308.507784), -- Pa'agrian Axe Blade
(20668, 204, 1, 1, 1, 2.703032), -- Deadman's Staff
(20668, 2116, 1, 1, 1, 299.73248), -- Deadman's Staff Head
(20668, 205, 1, 1, 1, 2.703032), -- Ghoul's Staff
(20668, 2117, 1, 1, 1, 299.73248), -- Ghoul's Staff Head
(20668, 206, 1, 1, 1, 2.703032), -- Demon's Staff
(20668, 2118, 1, 1, 1, 299.73248), -- Demon's Staff Head
(20668, 2503, 1, 1, 1, 2.703032), -- Yaksa Mace
(20668, 2969, 1, 1, 1, 306.018672), -- Yaksa Mace Head
(20668, 1866, 1, 1, 2, 35393.71655), -- Suede
(20668, 1871, 1, 1, 2, 53090.574825), -- Charcoal
(20668, 5220, 1, 1, 2, 2123.64266), -- Metal Hardener
(20668, 1885, 1, 1, 2, 4424.189985), -- High-Grade Suede
(20668, 4041, 1, 1, 2, 461.682825), -- Mold Hardener
(20668, 4148, 1, 1, 2, 232.85728), -- Recipe: Avadon Robe (100%)
(20668, 4936, 1, 1, 2, 974.10651), -- Recipe: Avadon Shield (60%)
(20668, 8309, 1, 1, 2, 61.16437), -- Recipe: Spell Breaker (100%)
(20668, 8726, 1, 1, 2, 1228.99083), -- Life Stone - Level 55
(20668, 8736, 1, 1, 2, 307.19854), -- Mid-Grade Life Stone - Level 55
(20668, 8746, 1, 1, 2, 30.68052), -- High-Grade Life Stone - Level 55
(20668, 8756, 1, 1, 2, 6.195105), -- Top-Grade Life Stone - Level 55
-- Taik Orc Supply Leader
(20669, 4057, 1, 1, -1, 60231), -- Zubei's Gaiter Material
(20669, 4198, 1, 1, -1, 1644), -- Recipe: Bellion Cestus (100%)
(20669, 4589, 1, 1, -1, 7177), -- Greater Dye of STR (Str+2 Con-2)
(20669, 57, 851, 1734, 0, 700000), -- Adena
(20669, 286, 1, 1, 1, 16.868835), -- Eminence Bow
(20669, 2121, 1, 1, 1, 1828.131165), -- Eminence Bow Shaft
(20669, 1871, 1, 1, 2, 56789.027286), -- Charcoal
(20669, 1866, 1, 1, 2, 37859.351524), -- Suede
(20669, 1877, 1, 1, 2, 2271.615714), -- Adamantite Nugget
(20669, 4041, 1, 1, 2, 493.765183), -- Mold Hardener
(20669, 4040, 1, 1, 2, 1135.807857), -- Mold Lubricant
(20669, 4191, 1, 1, 2, 65.433275), -- Recipe: Great Axe (100%)
(20669, 4186, 1, 1, 2, 65.433275), -- Recipe: Sword of Valhalla (100%)
(20669, 5160, 1, 1, 2, 113.569406), -- Recipe: Spiritshot (B) Compressed Package (100%)
(20669, 5275, 1, 1, 2, 113.569406), -- Recipe: Greater Spiritshot (B) Compressed Package(100%)
(20669, 6669, 1, 1, 2, 13206.710835), -- Deluxe Chest Key - Grade 5
(20669, 8726, 1, 1, 2, 1314.582944), -- Life Stone - Level 55
(20669, 8736, 1, 1, 2, 328.645736), -- Mid-Grade Life Stone - Level 55
(20669, 8746, 1, 1, 2, 32.887333), -- High-Grade Life Stone - Level 55
(20669, 8756, 1, 1, 2, 6.600226), -- Top-Grade Life Stone - Level 55
-- Crimson Drake
(20670, 4065, 1, 1, -1, 62421), -- Avadon Gaiters Material
(20670, 948, 1, 1, -1, 5579), -- Scroll: Enchant Armor (B-Grade)
(20670, 4129, 1, 1, -1, 24151), -- Recipe: Earrings of Black Ore (100%)
(20670, 57, 884, 1793, 0, 700000), -- Adena
(20670, 12159, 1, 1, 1, 752.464554), -- Common Item - Zubei's Shield
(20670, 4101, 1, 1, 1, 4776.48483), -- Zubei's Shield Fragment
(20670, 12171, 1, 1, 1, 752.464554), -- Common Item - Avadon Shield
(20670, 4439, 1, 1, 1, 5682.370236), -- Avadon Shield Fragment
(20670, 12160, 1, 1, 1, 526.47813), -- Common Item - Zubei's Helmet
(20670, 4102, 1, 1, 1, 3700.619574), -- Zubei's Helmet Design
(20670, 12170, 1, 1, 1, 526.47813), -- Common Item - Avadon Circlet
(20670, 4072, 1, 1, 1, 3700.639992), -- Avadon Circlet Pattern
(20670, 1869, 1, 1, 2, 54930.624519), -- Iron Ore
(20670, 1864, 1, 1, 2, 109861.249038), -- Stem
(20670, 1880, 1, 1, 2, 5493.009909), -- Steel
(20670, 5550, 1, 1, 2, 732.448026), -- Durable Metal Plate
(20670, 4043, 1, 1, 2, 1830.944922), -- Asofe
(20670, 4616, 1, 1, 2, 75.836919), -- Greater Dye of CON (Con+4 Dex-4)
(20670, 4168, 1, 1, 2, 683.232843), -- Recipe: Sealed Doom Gloves (100%)
(20670, 4164, 1, 1, 2, 363.772011), -- Recipe: Stockings of Doom (100%)
(20670, 8728, 1, 1, 2, 915.472461), -- Life Stone - Level 61
(20670, 8738, 1, 1, 2, 228.911901), -- Mid-Grade Life Stone - Level 61
(20670, 8748, 1, 1, 2, 22.943733), -- High-Grade Life Stone - Level 61
(20670, 8758, 1, 1, 2, 4.553718), -- Top-Grade Life Stone - Level 61
-- Kadios
(20671, 2098, 1, 1, -1, 12502), -- Nirvana Axe Blade
(20671, 947, 1, 1, -1, 934), -- Scroll: Enchant Weapon (B-Grade)
(20671, 4052, 1, 1, -1, 82640), -- Earring of Black Ore Piece
(20671, 57, 926, 1875, 0, 700000), -- Adena
(20671, 358, 1, 1, 1, 9.28572), -- Blue Wolf Breastplate
(20671, 4078, 1, 1, 1, 1678.628115), -- Blue Wolf Breastplate Part
(20671, 2381, 1, 1, 1, 5.71509), -- Doom Plate Armor
(20671, 4081, 1, 1, 1, 1132.654845), -- Doom Plate Armor Temper
(20671, 2380, 1, 1, 1, 14.85507), -- Blue Wolf Gaiters
(20671, 4080, 1, 1, 1, 2363.86116), -- Blue Wolf Gaiters Material
(20671, 1869, 1, 1, 2, 57456.624701), -- Iron Ore
(20671, 1864, 1, 1, 2, 114913.249402), -- Stem
(20671, 1880, 1, 1, 2, 5745.607511), -- Steel
(20671, 5550, 1, 1, 2, 766.129854), -- Durable Metal Plate
(20671, 4043, 1, 1, 2, 1915.141438), -- Asofe
(20671, 4616, 1, 1, 2, 79.324301), -- Greater Dye of CON (Con+4 Dex-4)
(20671, 4168, 1, 1, 2, 714.651497), -- Recipe: Sealed Doom Gloves (100%)
(20671, 4164, 1, 1, 2, 380.500169), -- Recipe: Stockings of Doom (100%)
(20671, 8728, 1, 1, 2, 957.570719), -- Life Stone - Level 61
(20671, 8738, 1, 1, 2, 239.438479), -- Mid-Grade Life Stone - Level 61
(20671, 8748, 1, 1, 2, 23.998807), -- High-Grade Life Stone - Level 61
(20671, 8758, 1, 1, 2, 4.763122), -- Top-Grade Life Stone - Level 61
-- Trives
(20672, 4070, 1, 1, -1, 84802), -- Stockings of Zubei Fabric
(20672, 4154, 1, 1, -1, 28035), -- Recipe: Doom Shield (100%)
(20672, 4052, 1, 1, -1, 83872), -- Earring of Black Ore Piece
(20672, 57, 940, 1902, 0, 700000), -- Adena
(20672, 601, 1, 1, 1, 28.27034), -- Sealed Doom Boots
(20672, 4099, 1, 1, 1, 3926.72966), -- Sealed Doom Boots Part
(20672, 2439, 1, 1, 1, 28.27034), -- Sealed Blue Wolf Boots
(20672, 4090, 1, 1, 1, 3926.72966), -- Sealed Blue Wolf Boots Design
(20672, 2475, 1, 1, 1, 28.27034), -- Sealed Doom Gloves
(20672, 4091, 1, 1, 1, 3926.72966), -- Sealed Doom Gloves Part
(20672, 2487, 1, 1, 1, 28.27034), -- Sealed Blue Wolf Gloves
(20672, 4096, 1, 1, 1, 3926.72966), -- Sealed Blue Wolf Gloves Fabric
(20672, 1868, 1, 1, 2, 127227.524824), -- Thread
(20672, 1873, 1, 1, 2, 25445.438128), -- Silver Nugget
(20672, 5549, 1, 1, 2, 6361.359532), -- Metallic Thread
(20672, 1889, 1, 1, 2, 4240.962052), -- Compound Braid
(20672, 4044, 1, 1, 2, 2120.39748), -- Thons
(20672, 4991, 1, 1, 2, 525.671432), -- Recipe: Doom Helmet (60%)
(20672, 5276, 1, 1, 2, 84.882736), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20672, 8729, 1, 1, 2, 848.158992), -- Life Stone - Level 64
(20672, 8739, 1, 1, 2, 212.039748), -- Mid-Grade Life Stone - Level 64
(20672, 8749, 1, 1, 2, 21.220684), -- High-Grade Life Stone - Level 64
(20672, 8759, 1, 1, 2, 4.344392), -- Top-Grade Life Stone - Level 64
-- Falibati
(20673, 4052, 1, 1, -1, 87623), -- Earring of Black Ore Piece
(20673, 4041, 1, 1, -1, 21521), -- Mold Hardener
(20673, 5230, 1, 1, -1, 3300), -- Recipe: Mithril Arrow (100%)
(20673, 57, 983, 1987, 0, 700000), -- Adena
(20673, 79, 1, 1, 1, 2.415321), -- Sword of Damascus
(20673, 4114, 1, 1, 1, 533.549712), -- Sword of Damascus Blade
(20673, 7883, 1, 1, 1, 2.415321), -- Guardian Sword
(20673, 8330, 1, 1, 1, 532.653006), -- Guardian Sword Blade
(20673, 7889, 1, 1, 1, 2.415321), -- Wizard's Tear
(20673, 8336, 1, 1, 1, 533.551319), -- Blade of the Wizard's Tear
(20673, 1872, 1, 1, 2, 88612.199847), -- Animal Bone
(20673, 1867, 1, 1, 2, 88612.199847), -- Animal Skin
(20673, 1881, 1, 1, 2, 8861.187342), -- Coarse Bone Powder
(20673, 1875, 1, 1, 2, 4430.593671), -- Stone of Purity
(20673, 4041, 1, 1, 2, 577.77579), -- Mold Hardener
(20673, 4150, 1, 1, 2, 1280.573121), -- Recipe: Sealed Avadon Gloves (100%)
(20673, 6037, 1, 1, 2, 132918.136557), -- Waking Scroll
(20673, 8729, 1, 1, 2, 886.249305), -- Life Stone - Level 64
(20673, 8739, 1, 1, 2, 221.643933), -- Mid-Grade Life Stone - Level 64
(20673, 8749, 1, 1, 2, 22.197036), -- High-Grade Life Stone - Level 64
(20673, 8759, 1, 1, 2, 4.243551), -- Top-Grade Life Stone - Level 64
-- Doom Knight
(20674, 2089, 1, 1, -1, 19453), -- Caliburs Edge
(20674, 4124, 1, 1, -1, 158653), -- Recipe: Craftsman Mold (100%)
(20674, 4053, 1, 1, -1, 153008), -- Ring of Black Ore Gemstone
(20674, 57, 1415, 2868, 0, 700000), -- Adena
(20674, 601, 1, 1, 1, 42.600293), -- Sealed Doom Boots
(20674, 4099, 1, 1, 1, 5917.149707), -- Sealed Doom Boots Part
(20674, 2439, 1, 1, 1, 42.600293), -- Sealed Blue Wolf Boots
(20674, 4090, 1, 1, 1, 5917.149707), -- Sealed Blue Wolf Boots Design
(20674, 2475, 1, 1, 1, 42.600293), -- Sealed Doom Gloves
(20674, 4091, 1, 1, 1, 5917.149707), -- Sealed Doom Gloves Part
(20674, 2487, 1, 1, 1, 42.600293), -- Sealed Blue Wolf Gloves
(20674, 4096, 1, 1, 1, 5917.149707), -- Sealed Blue Wolf Gloves Fabric
(20674, 1872, 1, 1, 2, 117158.902704), -- Animal Bone
(20674, 1867, 1, 1, 2, 117158.902704), -- Animal Skin
(20674, 1881, 1, 1, 2, 11715.839322), -- Coarse Bone Powder
(20674, 1875, 1, 1, 2, 5858.047032), -- Stone of Purity
(20674, 4041, 1, 1, 2, 763.971258), -- Mold Hardener
(20674, 4157, 1, 1, 2, 437.137272), -- Recipe: Blue Wolf Gaiters (100%)
(20674, 5276, 1, 1, 2, 117.18132), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20674, 8316, 1, 1, 2, 32.606976), -- Recipe: Flaming Dragon Skull (60%)
(20674, 8729, 1, 1, 2, 1171.558458), -- Life Stone - Level 64
(20674, 8739, 1, 1, 2, 292.9533), -- Mid-Grade Life Stone - Level 64
(20674, 8749, 1, 1, 2, 29.29533), -- High-Grade Life Stone - Level 64
(20674, 8759, 1, 1, 2, 5.604324), -- Top-Grade Life Stone - Level 64
-- Tairim
(20675, 4042, 1, 1, -1, 25482), -- Enria
(20675, 1539, 1, 1, -1, 339759), -- Greater Healing Potion
(20675, 4602, 1, 1, -1, 3398), -- Greater Dye of STR (Str+3 Dex-3)
(20675, 57, 605, 1229, 0, 700000), -- Adena
(20675, 60, 1, 1, 1, 51.530472), -- Composite Armor
(20675, 1977, 1, 1, 1, 4676.469528), -- Composite Armor Temper
(20675, 1872, 1, 1, 2, 70251.79075), -- Animal Bone
(20675, 1867, 1, 1, 2, 70251.79075), -- Animal Skin
(20675, 1881, 1, 1, 2, 7025.117625), -- Coarse Bone Powder
(20675, 1875, 1, 1, 2, 3512.635625), -- Stone of Purity
(20675, 4041, 1, 1, 2, 458.10975), -- Mold Hardener
(20675, 2353, 1, 1, 2, 85.876375), -- Recipe: Samurai Longsword
(20675, 4184, 1, 1, 2, 60.681875), -- Recipe: Sprite's Staff (100%)
(20675, 5155, 1, 1, 2, 105.38675), -- Recipe: Soulshot (B) Compressed Package (100%)
(20675, 8725, 1, 1, 2, 1463.585375), -- Life Stone - Level 52
(20675, 8735, 1, 1, 2, 365.93475), -- Mid-Grade Life Stone - Level 52
(20675, 8745, 1, 1, 2, 36.56275), -- High-Grade Life Stone - Level 52
(20675, 8755, 1, 1, 2, 7.527625), -- Top-Grade Life Stone - Level 52
-- Judge of Marsh
(20676, 5478, 1, 1, -1, 21536), -- Sealed Dark Crystal Leather Armor Pattern
(20676, 1807, 1, 1, -1, 3415), -- Recipe: Soulshot (A-Grade)
(20676, 5479, 1, 1, -1, 15155), -- Sealed Tallum Leather Armor Pattern
(20676, 57, 1015, 2058, 0, 700000), -- Adena
(20676, 12341, 1, 1, 1, 585.074805), -- Common Item - Earring of Black Ore
(20676, 4052, 1, 1, 1, 4463.954738), -- Earring of Black Ore Piece
(20676, 12342, 1, 1, 1, 438.560274), -- Common Item - Necklace of Black Ore
(20676, 4054, 1, 1, 1, 2483.436264), -- Necklace of Black Ore Beads
(20676, 12343, 1, 1, 1, 875.58144), -- Common Item - Ring of Black Ore
(20676, 4053, 1, 1, 1, 5404.392479), -- Ring of Black Ore Gemstone
(20676, 1867, 1, 1, 2, 100868.629675), -- Animal Skin
(20676, 1872, 1, 1, 2, 100868.629675), -- Animal Bone
(20676, 1882, 1, 1, 2, 16811.475992), -- Leather
(20676, 1894, 1, 1, 2, 2654.455487), -- Crafted Leather
(20676, 4042, 1, 1, 2, 1260.815444), -- Enria
(20676, 8729, 1, 1, 2, 1008.742866), -- Life Stone - Level 64
(20676, 8739, 1, 1, 2, 252.072578), -- Mid-Grade Life Stone - Level 64
(20676, 8749, 1, 1, 2, 25.116747), -- High-Grade Life Stone - Level 64
(20676, 8759, 1, 1, 2, 4.978094), -- Top-Grade Life Stone - Level 64
(20676, 6036, 1, 1, 2, 2522.083442), -- Greater Magic Haste Potion
-- Tulben
(20677, 3035, 1, 1, -1, 3845), -- Recipe: Spiritshot A
(20677, 5482, 1, 1, -1, 38058), -- Sealed Dark Crystal Leggings Design
(20677, 5230, 1, 1, -1, 3845), -- Recipe: Mithril Arrow (100%)
(20677, 57, 1142, 2317, 0, 700000), -- Adena
(20677, 11944, 1, 1, 1, 139.117392), -- Common Item - Bow of Peril
(20677, 4121, 1, 1, 1, 1854.882608), -- Bow of Peril Shaft
(20677, 1869, 1, 1, 2, 85174.1275), -- Iron Ore
(20677, 1864, 1, 1, 2, 170348.5245), -- Stem
(20677, 1880, 1, 1, 2, 8517.5475), -- Steel
(20677, 5550, 1, 1, 2, 1135.673), -- Durable Metal Plate
(20677, 4043, 1, 1, 2, 2839.1825), -- Asofe
(20677, 8316, 1, 1, 2, 31.5315), -- Recipe: Flaming Dragon Skull (60%)
(20677, 8729, 1, 1, 2, 1135.673), -- Life Stone - Level 64
(20677, 8739, 1, 1, 2, 283.7835), -- Mid-Grade Life Stone - Level 64
(20677, 8749, 1, 1, 2, 28.2975), -- High-Grade Life Stone - Level 64
(20677, 8759, 1, 1, 2, 5.6595), -- Top-Grade Life Stone - Level 64
-- Tortured Undead
(20678, 1989, 1, 1, -1, 49499), -- Divine Stocking Pattern
(20678, 4142, 1, 1, -1, 12634), -- Recipe: Avadon Gaiters (100%)
(20678, 1918, 1, 1, -1, 71130), -- Nassen's Earring Gemstone
(20678, 57, 650, 1321, 0, 700000), -- Adena
(20678, 266, 1, 1, 1, 12.862564), -- Great Pata
(20678, 2120, 1, 1, 1, 1456.137436), -- Great Pata Blade
(20678, 1895, 1, 1, 2, 15750.9734), -- Metallic Fiber
(20678, 4040, 1, 1, 2, 1102.5614), -- Mold Lubricant
(20678, 4042, 1, 1, 2, 918.81614), -- Enria
(20678, 4043, 1, 1, 2, 1837.60982), -- Asofe
(20678, 4128, 1, 1, 2, 682.28988), -- Recipe: Adamantite Necklace (100%)
(20678, 5280, 1, 1, 2, 110.25614), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(20678, 4134, 1, 1, 2, 424.06726), -- Recipe: Zubei's Gaiters (100%)
(20678, 8726, 1, 1, 2, 1276.10982), -- Life Stone - Level 55
(20678, 8736, 1, 1, 2, 319.02184), -- Mid-Grade Life Stone - Level 55
(20678, 8746, 1, 1, 2, 31.8932), -- High-Grade Life Stone - Level 55
(20678, 8756, 1, 1, 2, 6.4011), -- Top-Grade Life Stone - Level 55
-- Marsh Stalker
(20679, 4148, 1, 1, -1, 7419), -- Recipe: Avadon Robe (100%)
(20679, 1806, 1, 1, -1, 3383), -- Recipe: Soulshot (B-Grade)
(20679, 1920, 1, 1, -1, 57882), -- Necklace of Seal Chain
(20679, 57, 668, 1361, 0, 700000), -- Adena
(20679, 203, 1, 1, 1, 3.395966), -- Pa'agrian Axe
(20679, 2112, 1, 1, 1, 302.450694), -- Pa'agrian Axe Blade
(20679, 204, 1, 1, 1, 2.649962), -- Deadman's Staff
(20679, 2116, 1, 1, 1, 293.84768), -- Deadman's Staff Head
(20679, 205, 1, 1, 1, 2.649962), -- Ghoul's Staff
(20679, 2117, 1, 1, 1, 293.84768), -- Ghoul's Staff Head
(20679, 206, 1, 1, 1, 2.649962), -- Demon's Staff
(20679, 2118, 1, 1, 1, 293.84768), -- Demon's Staff Head
(20679, 2503, 1, 1, 1, 2.649962), -- Yaksa Mace
(20679, 2969, 1, 1, 1, 300.010452), -- Yaksa Mace Head
(20679, 1869, 1, 1, 2, 48045.55767), -- Iron Ore
(20679, 1870, 1, 1, 2, 48045.55767), -- Coal
(20679, 1871, 1, 1, 2, 48045.55767), -- Charcoal
(20679, 1872, 1, 1, 2, 64060.651974), -- Animal Bone
(20679, 1867, 1, 1, 2, 64060.651974), -- Animal Skin
(20679, 4149, 1, 1, 2, 617.655984), -- Recipe: Avadon Circlet (100%)
(20679, 4186, 1, 1, 2, 55.226358), -- Recipe: Sword of Valhalla (100%)
(20679, 5160, 1, 1, 2, 96.1653), -- Recipe: Spiritshot (B) Compressed Package (100%)
(20679, 4143, 1, 1, 2, 308.003718), -- Recipe: Zubei's Leather Shirt (100%)
(20679, 8726, 1, 1, 2, 1112.220384), -- Life Stone - Level 55
(20679, 8736, 1, 1, 2, 278.055096), -- Mid-Grade Life Stone - Level 55
(20679, 8746, 1, 1, 2, 27.750558), -- High-Grade Life Stone - Level 55
(20679, 8756, 1, 1, 2, 4.945644), -- Top-Grade Life Stone - Level 55
-- Marsh Drake
(20680, 1873, 1, 1, -1, 716613), -- Silver Nugget
(20680, 1876, 1, 1, -1, 358306), -- Mithril Ore
(20680, 3034, 1, 1, -1, 3583), -- Recipe: Spiritshot B
(20680, 57, 708, 1442, 0, 700000), -- Adena
(20680, 301, 1, 1, 1, 5.996288), -- Scorpion
(20680, 2113, 1, 1, 1, 534.0047), -- Scorpion Blade
(20680, 303, 1, 1, 1, 5.996288), -- Widow Maker
(20680, 2114, 1, 1, 1, 534.0047), -- Widowmaker Head
(20680, 299, 1, 1, 1, 4.678248), -- Orcish Poleaxe
(20680, 2122, 1, 1, 1, 503.319776), -- Orcish Poleaxe Blade
(20680, 1874, 1, 1, 2, 3674.942988), -- Oriharukon Ore
(20680, 1878, 1, 1, 2, 22049.589604), -- Braided Hemp
(20680, 1884, 1, 1, 2, 33922.456056), -- Cord
(20680, 1889, 1, 1, 2, 3674.942988), -- Compound Braid
(20680, 5220, 1, 1, 2, 2204.952128), -- Metal Hardener
(20680, 4441, 1, 1, 2, 1011.468496), -- Recipe: Avadon Shield
(20680, 5280, 1, 1, 2, 110.274936), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(20680, 8311, 1, 1, 2, 42.087584), -- Recipe: Kaim Vanul's Bones (100%)
(20680, 8726, 1, 1, 2, 1276.019024), -- Life Stone - Level 55
(20680, 8736, 1, 1, 2, 319.004756), -- Mid-Grade Life Stone - Level 55
(20680, 8746, 1, 1, 2, 31.907308), -- High-Grade Life Stone - Level 55
(20680, 8756, 1, 1, 2, 6.354132), -- Top-Grade Life Stone - Level 55
-- Vanor Silenos
(20681, 1873, 1, 1, -1, 494213), -- Silver Nugget
(20681, 2063, 1, 1, -1, 9550), -- Battle Axe Head
(20681, 1908, 1, 1, -1, 117001), -- Moonstone Earring Wire
(20681, 57, 489, 993, 0, 700000), -- Adena
(20681, 71, 1, 1, 1, 16.565175), -- Flamberge
(20681, 2059, 1, 1, 1, 1084.539654), -- Flamberge Blade
(20681, 72, 1, 1, 1, 16.565175), -- Stormbringer
(20681, 2060, 1, 1, 1, 1159.329996), -- Stormbringer Blade
(20681, 1866, 1, 1, 2, 32440.80671), -- Suede
(20681, 1871, 1, 1, 2, 48661.11865), -- Charcoal
(20681, 5220, 1, 1, 2, 1946.40818), -- Metal Hardener
(20681, 1885, 1, 1, 2, 4055.077985), -- High-Grade Suede
(20681, 4041, 1, 1, 2, 423.160035), -- Mold Hardener
(20681, 4440, 1, 1, 2, 169.574825), -- Recipe: Knuckle Duster
(20681, 2225, 1, 1, 2, 1057.85438), -- Recipe: Demon's Stockings
(20681, 2321, 1, 1, 2, 169.574825), -- Recipe: Stiletto
(20681, 8723, 1, 1, 2, 1946.40818), -- Life Stone - Level 46
(20681, 8733, 1, 1, 2, 486.602045), -- Mid-Grade Life Stone - Level 46
(20681, 8743, 1, 1, 2, 48.63278), -- High-Grade Life Stone - Level 46
(20681, 8753, 1, 1, 2, 9.781405), -- Top-Grade Life Stone - Level 46
-- Vanor Silenos Grunt
(20682, 951, 1, 1, -1, 2236), -- Scroll: Enchant Weapon (C-Grade)
(20682, 1876, 1, 1, -1, 245912), -- Mithril Ore
(20682, 4039, 1, 1, -1, 40985), -- Mold Glue
(20682, 57, 484, 990, 0, 700000), -- Adena
(20682, 397, 1, 1, 1, 99.843328), -- Mithril Shirt
(20682, 1961, 1, 1, 1, 4648.992856), -- Mithril Shirt Fabric
(20682, 2387, 1, 1, 1, 159.567424), -- Reinforced Mithril Gaiters
(20682, 2935, 1, 1, 1, 7723.596392), -- Reinforced Mithril Gaiters Fragment
(20682, 1870, 1, 1, 2, 58110.629145), -- Coal
(20682, 1865, 1, 1, 2, 58110.629145), -- Varnish
(20682, 1874, 1, 1, 2, 3874.041943), -- Oriharukon Ore
(20682, 4043, 1, 1, 2, 1936.957398), -- Asofe
(20682, 4039, 1, 1, 2, 1936.957398), -- Mold Glue
(20682, 2323, 1, 1, 2, 202.418024), -- Recipe: Elemental Bow
(20682, 8723, 1, 1, 2, 2324.374307), -- Life Stone - Level 46
(20682, 8733, 1, 1, 2, 581.06179), -- Mid-Grade Life Stone - Level 46
(20682, 8743, 1, 1, 2, 58.106179), -- High-Grade Life Stone - Level 46
(20682, 8753, 1, 1, 2, 11.824671), -- Top-Grade Life Stone - Level 46
-- Vanor Silenos Scout
(20683, 2336, 1, 1, -1, 3717), -- Recipe: Nirvana Axe
(20683, 1974, 1, 1, -1, 134435), -- Crimson Boot Fabric
(20683, 1889, 1, 1, -1, 106562), -- Compound Braid
(20683, 57, 631, 1287, 0, 700000), -- Adena
(20683, 227, 1, 1, 1, 16.024815), -- Stiletto
(20683, 2083, 1, 1, 1, 1176.475185), -- Stiletto Edge
(20683, 242, 1, 1, 1, 16.024815), -- Soulfire Dirk
(20683, 2084, 1, 1, 1, 1176.475185), -- Soulfire Dirk Blade
(20683, 1868, 1, 1, 2, 118037.87411), -- Thread
(20683, 1873, 1, 1, 2, 23607.574822), -- Silver Nugget
(20683, 5549, 1, 1, 2, 5901.933786), -- Metallic Thread
(20683, 1889, 1, 1, 2, 3934.622524), -- Compound Braid
(20683, 4044, 1, 1, 2, 1967.311262), -- Thons
(20683, 2224, 1, 1, 2, 801.930644), -- Recipe: Demon's Tunic
(20683, 2230, 1, 1, 2, 1143.737148), -- Recipe: Theca Leather Gaiters
(20683, 3005, 1, 1, 2, 2408.998372), -- Recipe: Demon's Boots
(20683, 8724, 1, 1, 2, 1967.311262), -- Life Stone - Level 49
(20683, 8734, 1, 1, 2, 491.867896), -- Mid-Grade Life Stone - Level 49
(20683, 8744, 1, 1, 2, 49.218854), -- High-Grade Life Stone - Level 49
(20683, 8754, 1, 1, 2, 9.61932), -- Top-Grade Life Stone - Level 49
-- Vanor Silenos Warrior
(20684, 1876, 1, 1, -1, 334736), -- Mithril Ore
(20684, 2078, 1, 1, -1, 11121), -- Katana Blade
(20684, 1966, 1, 1, -1, 61106), -- Plated Leather Fragment
(20684, 57, 662, 1345, 0, 700000), -- Adena
(20684, 398, 1, 1, 1, 54.051228), -- Plated Leather
(20684, 1966, 1, 1, 1, 3384.201645), -- Plated Leather Fragment
(20684, 399, 1, 1, 1, 49.842606), -- Rind Leather Armor
(20684, 1975, 1, 1, 1, 3044.607588), -- Rind Leather Armor Design
(20684, 418, 1, 1, 1, 86.43327), -- Plated Leather Gaiters
(20684, 1967, 1, 1, 1, 5055.528918), -- Plated Leather Gaiters Material
(20684, 419, 1, 1, 1, 79.807299), -- Rind Leather Gaiters
(20684, 1976, 1, 1, 1, 5636.527446), -- Rind Leather Gaiters Material
(20684, 1871, 1, 1, 2, 61797.572675), -- Charcoal
(20684, 1866, 1, 1, 2, 41198.333175), -- Suede
(20684, 1877, 1, 1, 2, 2471.879575), -- Adamantite Nugget
(20684, 4041, 1, 1, 2, 537.365125), -- Mold Hardener
(20684, 4040, 1, 1, 2, 1236.0127), -- Mold Lubricant
(20684, 2341, 1, 1, 2, 143.78345), -- Recipe: Sage's Staff
(20684, 6668, 1, 1, 2, 22070.61375), -- Deluxe Chest Key - Grade 4
(20684, 8724, 1, 1, 2, 2059.92395), -- Life Stone - Level 49
(20684, 8734, 1, 1, 2, 514.908075), -- Mid-Grade Life Stone - Level 49
(20684, 8744, 1, 1, 2, 51.476225), -- High-Grade Life Stone - Level 49
(20684, 8754, 1, 1, 2, 10.353575), -- Top-Grade Life Stone - Level 49
(20684, 1539, 1, 1, 2, 13732.777725), -- Greater Healing Potion
-- Vanor Silenos Shaman
(20685, 2090, 1, 1, -1, 7611), -- Delusional Blade
(20685, 1970, 1, 1, -1, 31188), -- Robe of Seal Fabric
(20685, 2166, 1, 1, -1, 47343), -- Recipe: Earrings of Binding (100%)
(20685, 57, 551, 1124, 0, 700000), -- Adena
(20685, 195, 1, 1, 1, 14.001112), -- Cursed Staff
(20685, 2082, 1, 1, 1, 1090.279304), -- Cursed Staff Head
(20685, 2502, 1, 1, 1, 14.001112), -- Dwarven War Hammer
(20685, 2968, 1, 1, 1, 1043.718472), -- Dwarven War Hammer Head
(20685, 1872, 1, 1, 2, 75007.060317), -- Animal Bone
(20685, 1867, 1, 1, 2, 75007.060317), -- Animal Skin
(20685, 1881, 1, 1, 2, 7500.722472), -- Coarse Bone Powder
(20685, 1875, 1, 1, 2, 3750.361236), -- Stone of Purity
(20685, 4041, 1, 1, 2, 489.098925), -- Mold Hardener
(20685, 2351, 1, 1, 2, 117.712548), -- Recipe: Scorpion
(20685, 2330, 1, 1, 2, 130.864788), -- Recipe: Homunkulus's Sword
(20685, 8724, 1, 1, 2, 1875.180618), -- Life Stone - Level 49
(20685, 8734, 1, 1, 2, 468.712953), -- Mid-Grade Life Stone - Level 49
(20685, 8744, 1, 1, 2, 46.854855), -- High-Grade Life Stone - Level 49
(20685, 8754, 1, 1, 2, 9.370971), -- Top-Grade Life Stone - Level 49
-- Vanor Silenos Chieftain
(20686, 2231, 1, 1, -1, 12559), -- Recipe: Full Plate Armor
(20686, 1880, 1, 1, -1, 291368), -- Steel
(20686, 2169, 1, 1, -1, 51570), -- Recipe: Necklace of Seal
(20686, 57, 1152, 2343, 0, 700000), -- Adena
(20686, 326, 1, 1, 1, 36.468759), -- Heathen's Book
(20686, 2110, 1, 1, 1, 3396.531241), -- Heathen's Book Page
(20686, 1871, 1, 1, 2, 100409.59008), -- Charcoal
(20686, 1866, 1, 1, 2, 66939.72672), -- Suede
(20686, 1877, 1, 1, 2, 4016.312256), -- Adamantite Nugget
(20686, 4041, 1, 1, 2, 873.11136), -- Mold Hardener
(20686, 4040, 1, 1, 2, 2008.245312), -- Mold Lubricant
(20686, 2354, 1, 1, 2, 163.741824), -- Recipe: Deadman's Staff
(20686, 4609, 1, 1, 2, 223.138368), -- Greater Dye of MEN (Men+3 Int-3)
(20686, 2358, 1, 1, 2, 163.741824), -- Recipe: Great Pata
(20686, 8725, 1, 1, 2, 2789.140416), -- Life Stone - Level 52
(20686, 8735, 1, 1, 2, 697.240512), -- Mid-Grade Life Stone - Level 52
(20686, 8745, 1, 1, 2, 69.741888), -- High-Grade Life Stone - Level 52
(20686, 8755, 1, 1, 2, 14.26944), -- Top-Grade Life Stone - Level 52
-- Gigantiops
(20745, 848, 1, 1, -1, 6478), -- Enchanted Earring
(20745, 1832, 1, 3, -1, 590229), -- Greater Antidote
(20745, 1901, 1, 1, -1, 146742), -- Tiger's Eye Earring Stone
(20745, 57, 449, 895, 0, 700000), -- Adena
(20745, 393, 1, 1, 1, 160.930318), -- Mithril Banded Mail
(20745, 1938, 1, 1, 1, 6328.819738), -- Mithril Banded Mail Material
(20745, 394, 1, 1, 1, 160.930318), -- Reinforced Leather Shirt
(20745, 415, 1, 1, 1, 257.223044), -- Mithril Banded Gaiters
(20745, 1939, 1, 1, 1, 8268.888972), -- Mithril Banded Gaiters Material
(20745, 416, 1, 1, 1, 257.20761), -- Reinforced Leather Gaiters
(20745, 1867, 1, 1, 2, 150633.733232), -- Animal Skin
(20745, 1872, 1, 1, 2, 150633.733232), -- Animal Bone
(20745, 1882, 1, 1, 2, 25105.734278), -- Leather
(20745, 2156, 1, 1, 2, 9037.876058), -- Recipe: Elven Necklace
(20745, 2272, 1, 1, 2, 806.9232), -- Recipe: Sword of Revolution
-- Young Gigantiops
(20746, 2153, 1, 1, -1, 129445), -- Recipe: Tiger's Eye Earring
(20746, 1900, 1, 1, -1, 91065), -- Enchanted Necklace Chain
(20746, 1061, 1, 1, -1, 504445), -- Greater Healing Potion
(20746, 57, 352, 702, 0, 700000), -- Adena
(20746, 259, 1, 1, 1, 184), -- Single-Edged Jamadhr
(20746, 1865, 1, 1, 2, 75806.272725), -- Varnish
(20746, 1870, 1, 1, 2, 75806.272725), -- Coal
(20746, 1879, 1, 1, 2, 12634.46769), -- Cokes
(20746, 1875, 1, 1, 2, 5053.751515), -- Stone of Purity
(20746, 2184, 1, 1, 2, 7962.81912), -- Recipe: Mithril Banded Gaiters
(20746, 2272, 1, 1, 2, 541.416225), -- Recipe: Sword of Revolution
-- Roxide
(20747, 2024, 1, 1, -1, 16676), -- Elven Bow Shaft
(20747, 2203, 1, 1, -1, 255050), -- Recipe: Reinforced Mithril Boots
(20747, 1900, 1, 1, -1, 128083), -- Enchanted Necklace Chain
(20747, 57, 493, 989, 0, 700000), -- Adena
(20747, 627, 1, 1, 1, 2378.09442), -- Aspis
(20747, 46, 1, 1, 1, 1665.90558), -- Bronze Helmet
(20747, 1872, 1, 1, 2, 121853.866008), -- Animal Bone
(20747, 1867, 1, 1, 2, 121853.866008), -- Animal Skin
(20747, 1881, 1, 1, 2, 12185.467392), -- Coarse Bone Powder
(20747, 1875, 1, 1, 2, 6092.733696), -- Stone of Purity
(20747, 2183, 1, 1, 2, 6012.481104), -- Recipe: Mithril Banded Mail
(20747, 2274, 1, 1, 2, 652.792896), -- Recipe: Skull Breaker
(20747, 2282, 1, 1, 2, 652.792896), -- Recipe: Cursed Maingauche
-- Roxide Cohort
(20748, 1866, 1, 1, -1, 734952), -- Suede
(20748, 1871, 1, 3, -1, 551214), -- Charcoal
(20748, 1061, 1, 1, -1, 668138), -- Greater Healing Potion
(20748, 57, 467, 925, 0, 700000), -- Adena
(20748, 275, 1, 1, 1, 81.061745), -- Long Bow
(20748, 276, 1, 1, 1, 81.061745), -- Elven Bow
(20748, 2024, 1, 1, 1, 2860.87651), -- Elven Bow Shaft
(20748, 1866, 1, 1, 2, 57374.698598), -- Suede
(20748, 1871, 1, 1, 2, 86062.24418), -- Charcoal
(20748, 5220, 1, 1, 2, 3442.411254), -- Metal Hardener
(20748, 1885, 1, 1, 2, 7171.788254), -- High-Grade Suede
(20748, 956, 1, 1, 2, 2868.872328), -- Scroll: Enchant Armor (D-Grade)
(20748, 2190, 1, 1, 2, 6147.190994), -- Recipe: Mithril Stockings
(20748, 1831, 1, 1, 2, 229498.794392), -- Antidote
-- Death Fire
(20749, 2025, 1, 1, -1, 16214), -- Dwarven Trident Edge
(20749, 1871, 1, 3, -1, 585341), -- Charcoal
(20749, 2153, 1, 1, -1, 182066), -- Recipe: Tiger's Eye Earring
(20749, 57, 493, 989, 0, 700000), -- Adena
(20749, 627, 1, 1, 1, 2378.09442), -- Aspis
(20749, 46, 1, 1, 1, 1665.90558), -- Bronze Helmet
(20749, 1871, 1, 1, 2, 159932.96268), -- Charcoal
(20749, 1866, 1, 1, 2, 106622.071704), -- Suede
(20749, 1877, 1, 1, 2, 6397.434408), -- Adamantite Nugget
(20749, 2184, 1, 1, 2, 16799.531208), -- Recipe: Mithril Banded Gaiters
-- Fire Archer
(20750, 1933, 1, 1, -1, 134288), -- Dark Stockings Fabric
(20750, 2183, 1, 1, -1, 75095), -- Recipe: Mithril Banded Mail
(20750, 1935, 1, 1, -1, 63768), -- Scale Mail Fragment
(20750, 57, 484, 958, 0, 700000), -- Adena
(20750, 222, 1, 1, 1, 252), -- Poniard Dagger
(20750, 1867, 1, 3, 2, 55445.058376), -- Animal Skin
(20750, 1872, 1, 1, 2, 166334.709391), -- Animal Bone
(20750, 1882, 1, 1, 2, 27722.529188), -- Leather
(20750, 1829, 1, 1, 2, 49900.459391), -- Scroll of Escape: Clan Hall
(20750, 1831, 1, 3, 2, 166334.243654), -- Antidote
-- Snipe
(20751, 2161, 1, 1, -1, 423261), -- Recipe: Aquastone Ring
(20751, 1949, 1, 1, -1, 486561), -- Mithril Gloves Design
(20751, 1894, 1, 1, -1, 152968), -- Crafted Leather
(20751, 57, 1716, 3517, 0, 700000), -- Adena
(20751, 62, 1, 1, 1, 235.770525), -- Reinforced Mithril Boots
(20751, 1958, 1, 1, 1, 10289.21895), -- Reinforced Mithril Boots Design
(20751, 2429, 1, 1, 1, 235.770525), -- Chain Boots
(20751, 2937, 1, 1, 1, 10289.21895), -- Chain Boots Part
(20751, 2430, 1, 1, 1, 235.770525), -- Karmian Boots
(20751, 2938, 1, 1, 1, 10289.21895), -- Karmian Boots Fabric
(20751, 2431, 1, 1, 1, 235.770525), -- Plated Leather Boots
(20751, 2939, 1, 1, 1, 10289.21895), -- Plate Leather Boots Lining
(20751, 2432, 1, 1, 1, 235.770525), -- Dwarven Chain Boots
(20751, 2940, 1, 1, 1, 10289.21895), -- Dwarven Chain Boots Part
(20751, 2433, 1, 1, 1, 235.770525), -- Boots of Seal
(20751, 2941, 1, 1, 1, 10289.21895), -- Boots of Seal Pattern
(20751, 2452, 1, 1, 1, 235.770525), -- Reinforced Mithril Gloves
(20751, 2942, 1, 1, 1, 10289.21895), -- Reinforced Mithril Gloves Design
(20751, 2453, 1, 1, 1, 235.770525), -- Chain Gloves
(20751, 2943, 1, 1, 1, 10289.21895), -- Chain Gloves Design
(20751, 2454, 1, 1, 1, 235.770525), -- Karmian Gloves
(20751, 2944, 1, 1, 1, 10289.313675), -- Karmian Gloves Fabric
(20751, 1894, 1, 1, 2, 9036.767322), -- Crafted Leather
(20751, 2216, 1, 1, 2, 10642.50075), -- Recipe: Great Helmet
(20751, 2225, 1, 1, 2, 5598.890242), -- Recipe: Demon's Stockings
(20751, 2321, 1, 1, 2, 897.374876), -- Recipe: Stiletto
(20751, 8723, 1, 1, 2, 10301.940726), -- Life Stone - Level 46
(20751, 8733, 1, 1, 2, 2575.495022), -- Mid-Grade Life Stone - Level 46
(20751, 8743, 1, 1, 2, 257.545566), -- High-Grade Life Stone - Level 46
(20751, 8753, 1, 1, 2, 51.485496), -- Top-Grade Life Stone - Level 46
-- Snipe Cohort
(20752, 1805, 1, 1, -1, 7711), -- Recipe: Soulshot (C-Grade)
(20752, 1905, 1, 1, -1, 225036), -- Omen Beast's Eye Earring Gemstone
(20752, 5549, 1, 1, -1, 231337), -- Metallic Thread
(20752, 57, 932, 1883, 0, 700000), -- Adena
(20752, 353, 1, 1, 1, 193.097417), -- Half Plate Armor
(20752, 1950, 1, 1, 1, 9426.365273), -- Half Plate Temper
(20752, 380, 1, 1, 1, 308.960785), -- Plate Gaiters
(20752, 1951, 1, 1, 1, 14660.576525), -- Plate Gaiters Part
(20752, 1868, 1, 1, 2, 331904.637384), -- Thread
(20752, 1873, 1, 1, 2, 66380.839891), -- Silver Nugget
(20752, 5549, 1, 1, 2, 16595.319455), -- Metallic Thread
(20752, 1889, 1, 1, 2, 11063.400327), -- Compound Braid
(20752, 2160, 1, 1, 2, 10706.488192), -- Recipe: Moonstone Earring
(20752, 5159, 1, 1, 2, 553.104327), -- Recipe: Spiritshot (C) Compressed Package (100%)
(20752, 2312, 1, 1, 2, 725.210424), -- Recipe: Crystallized Ice Bow
-- Dark Lord
(20753, 1874, 1, 1, -1, 250765), -- Oriharukon Ore
(20753, 1875, 1, 1, -1, 250765), -- Stone of Purity
(20753, 4601, 1, 1, -1, 8359), -- Greater Dye of STR (Str+3 Con-3)
(20753, 57, 1488, 3024, 0, 700000), -- Adena
(20753, 75, 1, 1, 1, 7.845835), -- Caliburs
(20753, 2089, 1, 1, 1, 706.32226), -- Caliburs Edge
(20753, 76, 1, 1, 1, 7.845835), -- Sword of Delusion
(20753, 2090, 1, 1, 1, 706.32226), -- Delusional Blade
(20753, 77, 1, 1, 1, 7.845835), -- Tsurugi
(20753, 2091, 1, 1, 1, 706.32226), -- Tsurugi Blade
(20753, 84, 1, 1, 1, 7.845835), -- Homunkulus's Sword
(20753, 2092, 1, 1, 1, 706.32226), -- Homunkulus's Sword Blade
(20753, 134, 1, 1, 1, 7.845835), -- Sword of Nightmare
(20753, 2095, 1, 1, 1, 706.32226), -- Sword of Nightmare Blade
(20753, 145, 1, 1, 1, 7.845835), -- Sword of Whispering Death
(20753, 2096, 1, 1, 1, 706.31369), -- Sword of Whispering Death Blade
(20753, 1868, 1, 3, 2, 119654.817944), -- Thread
(20753, 1873, 1, 1, 2, 47861.751712), -- Silver Nugget
(20753, 5549, 1, 1, 2, 11965.437928), -- Metallic Thread
(20753, 1889, 1, 1, 2, 7977.10484), -- Compound Braid
(20753, 4044, 1, 1, 2, 3988.333088), -- Thons
(20753, 2355, 1, 1, 2, 195.20548), -- Recipe: Ghoul's Staff
(20753, 4609, 1, 1, 2, 265.830384), -- Greater Dye of MEN (Men+3 Int-3)
(20753, 3019, 1, 1, 2, 3190.841936), -- Recipe: Full Plate Shield
(20753, 8725, 1, 1, 2, 3323.757128), -- Life Stone - Level 52
(20753, 8735, 1, 1, 2, 830.829616), -- Mid-Grade Life Stone - Level 52
(20753, 8745, 1, 1, 2, 82.907496), -- High-Grade Life Stone - Level 52
(20753, 8755, 1, 1, 2, 16.669232), -- Top-Grade Life Stone - Level 52
(20753, 1342, 10, 30, 2, 239310.513216), -- Steel Arrow
-- Dark Knight
(20754, 1869, 1, 9, -1, 826759), -- Iron Ore
(20754, 1911, 1, 1, -1, 307460), -- Earring of Protection Gemstone
(20754, 1967, 1, 1, -1, 225459), -- Plated Leather Gaiters Material
(20754, 57, 1634, 3323, 0, 700000), -- Adena
(20754, 94, 1, 1, 1, 82.894125), -- Bec de Corbin
(20754, 2079, 1, 1, 1, 6292.105875), -- Bec De Corbin Blade
(20754, 1869, 1, 1, 2, 166508.151876), -- Iron Ore
(20754, 1864, 1, 3, 2, 166508.151876), -- Stem
(20754, 1880, 1, 1, 2, 16650.739221), -- Steel
(20754, 5550, 1, 1, 2, 2220.123885), -- Durable Metal Plate
(20754, 4043, 1, 1, 2, 5550.119796), -- Asofe
(20754, 2167, 1, 1, 2, 8495.344878), -- Recipe: Ring of Ages
(20754, 3009, 1, 1, 2, 6796.351869), -- Recipe: Composite Boots
(20754, 8724, 1, 1, 2, 5550.119796), -- Life Stone - Level 49
(20754, 8734, 1, 1, 2, 1387.529949), -- Mid-Grade Life Stone - Level 49
(20754, 8744, 1, 1, 2, 138.639045), -- High-Grade Life Stone - Level 49
(20754, 8754, 1, 1, 2, 27.727809), -- Top-Grade Life Stone - Level 49
-- Talakin
(20755, 2184, 1, 1, -1, 83948), -- Recipe: Mithril Banded Gaiters
(20755, 1900, 1, 1, -1, 87438), -- Enchanted Necklace Chain
(20755, 1061, 1, 1, -1, 484352), -- Greater Healing Potion
(20755, 57, 337, 674, 0, 700000), -- Adena
(20755, 222, 1, 1, 1, 176), -- Poniard Dagger
(20755, 1876, 1, 1, 2, 10918.05411), -- Mithril Ore
(20755, 1880, 1, 1, 2, 5459.148138), -- Steel
(20755, 1877, 1, 1, 2, 2183.610822), -- Adamantite Nugget
(20755, 1881, 1, 1, 2, 7278.783462), -- Coarse Bone Powder
(20755, 1882, 1, 1, 2, 12131.30577), -- Leather
(20755, 1829, 1, 1, 2, 21836.350386), -- Scroll of Escape: Clan Hall
(20755, 2274, 1, 1, 2, 389.88726), -- Recipe: Skull Breaker
(20755, 1341, 10, 30, 2, 181968.860052), -- Bone Arrow
-- Talakin Archer
(20756, 1932, 1, 1, -1, 123147), -- Bone Helmet Design
(20756, 2262, 1, 1, -1, 12047), -- Recipe: Elven Bow
(20756, 1899, 1, 1, -1, 121223), -- Necklace of Devotion Chain
(20756, 57, 333, 651, 0, 700000), -- Adena
(20756, 274, 1, 1, 1, 276), -- Reinforced Bow
(20756, 1873, 1, 1, 2, 34833.58923), -- Silver Nugget
(20756, 1868, 1, 1, 2, 174167.94615), -- Thread
(20756, 1876, 1, 1, 2, 17416.794615), -- Mithril Ore
(20756, 2152, 1, 1, 2, 15331.609997), -- Recipe: Enchanted Necklace
(20756, 6035, 1, 1, 2, 7257.060008), -- Magic Haste Potion
-- Talakin Raider
(20757, 1868, 1, 3, -1, 572349), -- Thread
(20757, 847, 1, 1, -1, 5530), -- Red Crescent Earring
(20757, 2180, 1, 1, -1, 43034), -- Recipe: Scale Mail
(20757, 57, 247, 476, 0, 700000), -- Adena
(20757, 291, 1, 1, 1, 101.975412), -- Trident
(20757, 2019, 1, 1, 1, 3454.024588), -- Trident Edge
(20757, 1875, 1, 1, 2, 3569.092446), -- Stone of Purity
(20757, 1879, 1, 1, 2, 8922.714892), -- Cokes
(20757, 1885, 1, 1, 2, 4461.357446), -- High-Grade Suede
(20757, 5550, 1, 1, 2, 713.812), -- Durable Metal Plate
(20757, 5549, 1, 1, 2, 5353.622446), -- Metallic Thread
(20757, 2152, 1, 1, 2, 9425.40077), -- Recipe: Enchanted Necklace
-- Dragon Bearer Chief
(20758, 2946, 1, 1, -1, 117499), -- Plate Leather Gloves Design
(20758, 2167, 1, 1, -1, 107248), -- Recipe: Ring of Ages
(20758, 57, 830, 1692, 0, 700000), -- Adena
(20758, 853, 1, 1, 1, 206.286364), -- Earring of Protection
(20758, 1911, 1, 1, 1, 11546.5088), -- Earring of Protection Gemstone
(20758, 916, 1, 1, 1, 154.772352), -- Necklace of Protection
(20758, 1913, 1, 1, 1, 9440.115436), -- Necklace of Protection Gemstone
(20758, 884, 1, 1, 1, 309.544704), -- Ring of Protection
(20758, 1912, 1, 1, 1, 16728.772344), -- Ring of Protection Gemstone
(20758, 1872, 1, 1, 2, 124182.965169), -- Animal Bone
(20758, 1867, 1, 1, 2, 124182.965169), -- Animal Skin
(20758, 1881, 1, 1, 2, 12418.269215), -- Coarse Bone Powder
(20758, 1875, 1, 1, 2, 6209.271117), -- Stone of Purity
(20758, 4041, 1, 1, 2, 809.774354), -- Mold Hardener
(20758, 952, 1, 1, 2, 1241.963431), -- Scroll: Enchant Armor (C-Grade)
(20758, 8724, 1, 1, 2, 3104.499049), -- Life Stone - Level 49
(20758, 8734, 1, 1, 2, 776.193017), -- Mid-Grade Life Stone - Level 49
(20758, 8744, 1, 1, 2, 77.537396), -- High-Grade Life Stone - Level 49
(20758, 8754, 1, 1, 2, 15.562083), -- Top-Grade Life Stone - Level 49
-- Dragon Bearer Warrior
(20759, 2166, 1, 1, -1, 66974), -- Recipe: Earrings of Binding (100%)
(20759, 1912, 1, 1, -1, 212904), -- Ring of Protection Gemstone
(20759, 2167, 1, 1, -1, 100803), -- Recipe: Ring of Ages
(20759, 57, 781, 1588, 0, 700000), -- Adena
(20759, 398, 1, 1, 1, 63.804132), -- Plated Leather
(20759, 1966, 1, 1, 1, 3994.840755), -- Plated Leather Fragment
(20759, 399, 1, 1, 1, 58.836114), -- Rind Leather Armor
(20759, 1975, 1, 1, 1, 3593.970972), -- Rind Leather Armor Design
(20759, 418, 1, 1, 1, 102.02913), -- Plated Leather Gaiters
(20759, 1967, 1, 1, 1, 5967.739242), -- Plated Leather Gaiters Material
(20759, 419, 1, 1, 1, 94.207581), -- Rind Leather Gaiters
(20759, 1976, 1, 1, 1, 6653.572074), -- Rind Leather Gaiters Material
(20759, 1870, 1, 1, 2, 79582.602096), -- Coal
(20759, 1865, 1, 1, 2, 79582.602096), -- Varnish
(20759, 1874, 1, 1, 2, 5305.542058), -- Oriharukon Ore
(20759, 4043, 1, 1, 2, 2652.6829), -- Asofe
(20759, 4039, 1, 1, 2, 2652.6829), -- Mold Glue
(20759, 2168, 1, 1, 2, 2025.028162), -- Recipe: Necklace of Mermaid
(20759, 952, 1, 1, 2, 1061.07316), -- Scroll: Enchant Armor (C-Grade)
(20759, 8724, 1, 1, 2, 2652.6829), -- Life Stone - Level 49
(20759, 8734, 1, 1, 2, 663.258854), -- Mid-Grade Life Stone - Level 49
(20759, 8744, 1, 1, 2, 66.273008), -- High-Grade Life Stone - Level 49
(20759, 8754, 1, 1, 2, 13.571866), -- Top-Grade Life Stone - Level 49
-- Dragon Bearer Archer
(20760, 1911, 1, 1, -1, 152522), -- Earring of Protection Gemstone
(20760, 951, 1, 1, -1, 3728), -- Scroll: Enchant Weapon (C-Grade)
(20760, 1871, 1, 5, -1, 683553), -- Charcoal
(20760, 57, 809, 1651, 0, 700000), -- Adena
(20760, 398, 1, 1, 1, 66.225264), -- Plated Leather
(20760, 1966, 1, 1, 1, 4146.43026), -- Plated Leather Fragment
(20760, 399, 1, 1, 1, 61.068728), -- Rind Leather Armor
(20760, 1975, 1, 1, 1, 3730.348944), -- Rind Leather Armor Design
(20760, 418, 1, 1, 1, 105.90076), -- Plated Leather Gaiters
(20760, 1967, 1, 1, 1, 6194.192984), -- Plated Leather Gaiters Material
(20760, 419, 1, 1, 1, 97.782412), -- Rind Leather Gaiters
(20760, 1976, 1, 1, 1, 6906.050648), -- Rind Leather Gaiters Material
(20760, 1871, 1, 1, 2, 75716.574312), -- Charcoal
(20760, 1866, 1, 1, 2, 50477.716208), -- Suede
(20760, 1877, 1, 1, 2, 3028.62514), -- Adamantite Nugget
(20760, 4041, 1, 1, 2, 658.420268), -- Mold Hardener
(20760, 4040, 1, 1, 2, 1514.380128), -- Mold Lubricant
(20760, 951, 1, 1, 2, 137.683204), -- Scroll: Enchant Weapon (C-Grade)
(20760, 2343, 1, 1, 2, 176.056148), -- Recipe: Mace of Underworld
(20760, 2327, 1, 1, 2, 176.056148), -- Recipe: Caliburs
(20760, 8724, 1, 1, 2, 2523.831764), -- Life Stone - Level 49
(20760, 8734, 1, 1, 2, 630.99172), -- Mid-Grade Life Stone - Level 49
(20760, 8744, 1, 1, 2, 63.099172), -- High-Grade Life Stone - Level 49
(20760, 8754, 1, 1, 2, 12.565788), -- Top-Grade Life Stone - Level 49
-- Pytan
(20761, 1875, 1, 1, -1, 553373), -- Stone of Purity
(20761, 1874, 1, 1, -1, 553373), -- Oriharukon Ore
(20761, 1807, 1, 1, -1, 11067), -- Recipe: Soulshot (A-Grade)
(20761, 57, 3285, 6671, 0, 700000), -- Adena
(20761, 5287, 1, 1, 1, 22.945393), -- Sealed Dark Crystal breastplate
(20761, 5520, 1, 1, 1, 2635.436141), -- Sealed Dark Crystal Breastplate Pattern
(20761, 5293, 1, 1, 1, 14.124871), -- Sealed Tallum Plate Armor
(20761, 5521, 1, 1, 1, 1859.668652), -- Sealed Tallum Plate Armor Pattern
(20761, 5288, 1, 1, 1, 36.717787), -- Sealed Dark Crystal Gaiters
(20761, 5524, 1, 1, 1, 4028.107156), -- Sealed Dark Crystal Gaiters Pattern
(20761, 1868, 1, 3, 2, 204322.463928), -- Thread
(20761, 1873, 1, 1, 2, 81728.852832), -- Silver Nugget
(20761, 5549, 1, 1, 2, 20432.213208), -- Metallic Thread
(20761, 1889, 1, 1, 2, 13621.364856), -- Compound Braid
(20761, 4044, 1, 1, 2, 6810.848352), -- Thons
(20761, 4989, 1, 1, 2, 1353.276144), -- Recipe: Stockings of Doom (60%)
(20761, 4403, 1, 1, 2, 408.504888), -- Red Dimensional Stone
(20761, 5338, 1, 1, 2, 264.482856), -- Recipe: Sealed Majestic Leather Armor(60%)
(20761, 8730, 1, 1, 2, 2270.172168), -- Life Stone - Level 67
(20761, 8740, 1, 1, 2, 567.46008), -- Mid-Grade Life Stone - Level 67
(20761, 8750, 1, 1, 2, 56.746008), -- High-Grade Life Stone - Level 67
(20761, 8760, 1, 1, 2, 11.61468), -- Top-Grade Life Stone - Level 67
-- Pytan Knight
(20762, 5478, 1, 1, -1, 49132), -- Sealed Dark Crystal Leather Armor Pattern
(20762, 1807, 1, 1, -1, 7790), -- Recipe: Soulshot (A-Grade)
(20762, 57, 2311, 4698, 0, 700000), -- Adena
(20762, 5297, 1, 1, 1, 21.538242), -- Sealed Dark Crystal Leather Armor
(20762, 5478, 1, 1, 1, 2418.616002), -- Sealed Dark Crystal Leather Armor Pattern
(20762, 5301, 1, 1, 1, 13.248774), -- Sealed Tallum Leather Armor
(20762, 5479, 1, 1, 1, 1701.904446), -- Sealed Tallum Leather Armor Pattern
(20762, 5298, 1, 1, 1, 34.443618), -- Sealed Dark Crystal Leggings
(20762, 5482, 1, 1, 1, 3796.248918), -- Sealed Dark Crystal Leggings Design
(20762, 1872, 1, 1, 2, 209195.749232), -- Animal Bone
(20762, 1867, 1, 1, 2, 209195.749232), -- Animal Skin
(20762, 1881, 1, 1, 2, 20919.665679), -- Coarse Bone Powder
(20762, 1875, 1, 1, 2, 10459.60595), -- Stone of Purity
(20762, 4041, 1, 1, 2, 1364.513453), -- Mold Hardener
(20762, 1807, 1, 1, 2, 209.192119), -- Recipe: Soulshot (A-Grade)
(20762, 5336, 1, 1, 2, 202.839213), -- Recipe: Sealed Leather Armor of Nightmare(60%)
(20762, 8730, 1, 1, 2, 1743.418918), -- Life Stone - Level 67
(20762, 8740, 1, 1, 2, 435.62784), -- Mid-Grade Life Stone - Level 67
(20762, 8750, 1, 1, 2, 43.562784), -- High-Grade Life Stone - Level 67
(20762, 8760, 1, 1, 2, 9.07558), -- Top-Grade Life Stone - Level 67
-- Lord of the Plains
(20763, 1941, 1, 1, -1, 60607), -- Brigandine Temper
(20763, 1873, 1, 1, -1, 609587), -- Silver Nugget
(20763, 1902, 1, 1, -1, 154404), -- Elven Earring Beads
(20763, 57, 636, 1270, 0, 700000), -- Adena
(20763, 129, 1, 1, 1, 73.3502), -- Sword of Revolution
(20763, 2034, 1, 1, 1, 4161.6498), -- Sword of Revolution Blade
(20763, 1872, 1, 1, 2, 175060.96524), -- Animal Bone
(20763, 1867, 1, 1, 2, 175060.96524), -- Animal Skin
(20763, 1881, 1, 1, 2, 17506.25298), -- Coarse Bone Powder
(20763, 1875, 1, 1, 2, 8752.93092), -- Stone of Purity
(20763, 2146, 1, 1, 2, 9378.36378), -- Recipe: Artisan's frame
(20763, 2196, 1, 1, 2, 5380.52184), -- Recipe: Plate Gaiters
-- Shaman of the Plains
(20764, 1902, 1, 1, -1, 137744), -- Elven Earring Beads
(20764, 1825, 1, 1, -1, 97110), -- Recipe: Oriharukon
(20764, 1903, 1, 1, -1, 226779), -- Elven Ring Piece
(20764, 57, 575, 1146, 0, 700000), -- Adena
(20764, 437, 1, 1, 1, 204.293711), -- Mithril Tunic
(20764, 1944, 1, 1, 1, 8961.584082), -- Mithril Tunic Fabric
(20764, 470, 1, 1, 1, 326.265005), -- Mithril Stockings
(20764, 1945, 1, 1, 1, 13954.857202), -- Mithril Stocking Design
(20764, 1872, 1, 1, 2, 156172.667152), -- Animal Bone
(20764, 1867, 1, 1, 2, 156172.667152), -- Animal Skin
(20764, 1881, 1, 1, 2, 15617.337216), -- Coarse Bone Powder
(20764, 1875, 1, 1, 2, 7808.668608), -- Stone of Purity
(20764, 2149, 1, 1, 2, 8366.329936), -- Recipe: Metallic Fiber
(20764, 5473, 1, 1, 2, 8366.329936), -- Recipe: Durable Metal Plate(100%)
-- Warrior of the Plains
(20765, 2145, 1, 1, -1, 84024), -- Recipe: Mithril Alloy
(20765, 1904, 1, 1, -1, 109784), -- Elven Necklace Beads
(20765, 1873, 1, 1, -1, 470534), -- Silver Nugget
(20765, 57, 497, 993, 0, 700000), -- Adena
(20765, 850, 1, 1, 1, 281.910384), -- Elven Earring
(20765, 1902, 1, 1, 1, 10268.06382), -- Elven Earring Beads
(20765, 913, 1, 1, 1, 211.58298), -- Elven Necklace
(20765, 1904, 1, 1, 1, 9458.303652), -- Elven Necklace Beads
(20765, 881, 1, 1, 1, 423.16596), -- Elven Ring
(20765, 1903, 1, 1, 1, 16904.973204), -- Elven Ring Piece
(20765, 1873, 1, 1, 2, 40538.354184), -- Silver Nugget
(20765, 1868, 1, 1, 2, 202691.77092), -- Thread
(20765, 1876, 1, 1, 2, 20269.177092), -- Mithril Ore
(20765, 1895, 1, 1, 2, 28955.922669), -- Metallic Fiber
(20765, 2145, 1, 1, 2, 7238.902608), -- Recipe: Mithril Alloy
(20765, 2158, 1, 1, 2, 12542.872527), -- Recipe: Mithril Ring
-- Scout of the Plains
(20766, 1869, 1, 3, -1, 525817), -- Iron Ore
(20766, 1901, 1, 1, -1, 145253), -- Tiger's Eye Earring Stone
(20766, 2154, 1, 1, -1, 112595), -- Recipe: Elven Earring
(20766, 57, 443, 889, 0, 700000), -- Adena
(20766, 553, 1, 1, 1, 408.595324), -- Iron Boots
(20766, 1940, 1, 1, 1, 11922.428056), -- Iron Boots Design
(20766, 2422, 1, 1, 1, 408.595324), -- Reinforced Leather Boots
(20766, 2423, 1, 1, 1, 408.595324), -- Boots of Knowledge
(20766, 63, 1, 1, 1, 408.595324), -- Gauntlets
(20766, 2446, 1, 1, 1, 408.595324), -- Reinforced Leather Gloves
(20766, 2447, 1, 1, 1, 408.595324), -- Gloves of Knowledge
(20766, 1864, 1, 1, 2, 159755.92243), -- Stem
(20766, 1869, 1, 1, 2, 79878.132346), -- Iron Ore
(20766, 1878, 1, 1, 2, 31951.184486), -- Braided Hemp
(20766, 1884, 1, 1, 2, 49155.66844), -- Cord
(20766, 2155, 1, 1, 2, 12821.476782), -- Recipe: Elven Ring
(20766, 2195, 1, 1, 2, 2042.961878), -- Recipe: Half Plate Armor
(20766, 6035, 1, 1, 2, 6656.653638), -- Magic Haste Potion
-- Timak Orc Troop Leader
(20767, 2076, 1, 1, -1, 15046), -- Body Slasher Blade
(20767, 2220, 1, 1, -1, 39718), -- Recipe: Rind Leather Armor
(20767, 1879, 1, 1, -1, 319728), -- Cokes
(20767, 57, 759, 1541, 0, 700000), -- Adena
(20767, 281, 1, 1, 1, 51.42543), -- Crystallized Ice Bow
(20767, 2074, 1, 1, 1, 3210.57457), -- Crystallized Ice Bow Shaft
(20767, 1865, 1, 1, 2, 75554.064168), -- Varnish
(20767, 1870, 1, 1, 2, 75554.064168), -- Coal
(20767, 1879, 1, 1, 2, 12592.285266), -- Cokes
(20767, 1875, 1, 1, 2, 5037.019878), -- Stone of Purity
(20767, 4040, 1, 1, 2, 1511.123592), -- Mold Lubricant
(20767, 2225, 1, 1, 2, 1642.456662), -- Recipe: Demon's Stockings
(20767, 2321, 1, 1, 2, 263.194998), -- Recipe: Stiletto
(20767, 2322, 1, 1, 2, 263.194998), -- Recipe: Soulfire Dirk
(20767, 8723, 1, 1, 2, 3022.247184), -- Life Stone - Level 46
(20767, 8733, 1, 1, 2, 755.561796), -- Mid-Grade Life Stone - Level 46
(20767, 8743, 1, 1, 2, 75.626694), -- High-Grade Life Stone - Level 46
(20767, 8753, 1, 1, 2, 15.160596), -- Top-Grade Life Stone - Level 46
-- Timak Orc Troop Shaman
(20768, 1908, 1, 1, -1, 174999), -- Moonstone Earring Wire
(20768, 2163, 1, 1, -1, 94285), -- Recipe: Earring of Protection
(20768, 1909, 1, 1, -1, 249560), -- Aquastone Ring Wire
(20768, 57, 727, 1491, 0, 700000), -- Adena
(20768, 631, 1, 1, 1, 285.42048), -- Eldarake
(20768, 1964, 1, 1, 1, 11762.156994), -- Eldarake Temper
(20768, 2495, 1, 1, 1, 285.42048), -- Chain Shield
(20768, 2945, 1, 1, 1, 11762.156994), -- Chain Shield Fragment
(20768, 2413, 1, 1, 1, 199.794336), -- Chain Hood
(20768, 2936, 1, 1, 1, 10683.050716), -- Chain Hood Pattern
(20768, 1865, 1, 1, 2, 72782.4462), -- Varnish
(20768, 1870, 1, 1, 2, 72782.4462), -- Coal
(20768, 1879, 1, 1, 2, 12130.323912), -- Cokes
(20768, 1875, 1, 1, 2, 4852.079292), -- Stone of Purity
(20768, 2163, 1, 1, 2, 3713.400372), -- Recipe: Earring of Protection
(20768, 2315, 1, 1, 2, 253.626276), -- Recipe: Shamshir
(20768, 2319, 1, 1, 2, 253.626276), -- Recipe: Raid Sword
(20768, 8723, 1, 1, 2, 2911.297848), -- Life Stone - Level 46
(20768, 8733, 1, 1, 2, 727.950144), -- Mid-Grade Life Stone - Level 46
(20768, 8743, 1, 1, 2, 72.89556), -- High-Grade Life Stone - Level 46
(20768, 8753, 1, 1, 2, 14.579112), -- Top-Grade Life Stone - Level 46
(20768, 1832, 1, 1, 2, 80869.328808), -- Greater Antidote
-- Timak Orc Troop Warrior
(20769, 5220, 1, 1, -1, 58852), -- Metal Hardener
(20769, 1885, 1, 1, -1, 122609), -- High-Grade Suede
(20769, 4469, 1, 1, -1, 8407), -- Dye of STR (Str+1 Con-1)
(20769, 57, 582, 1182, 0, 700000), -- Adena
(20769, 70, 1, 1, 1, 26.635317), -- Claymore
(20769, 2047, 1, 1, 1, 1623.849333), -- Claymore Blade
(20769, 2499, 1, 1, 1, 26.635317), -- Elven Long Sword
(20769, 2967, 1, 1, 1, 1601.880033), -- Elven Long Sword Blade
(20769, 1866, 1, 1, 2, 70364.177896), -- Suede
(20769, 1871, 1, 1, 2, 105546.466832), -- Charcoal
(20769, 5220, 1, 1, 2, 4221.946668), -- Metal Hardener
(20769, 1885, 1, 1, 2, 8795.47224), -- High-Grade Suede
(20769, 2161, 1, 1, 2, 10247.185132), -- Recipe: Aquastone Ring
(20769, 5269, 1, 1, 2, 351.778892), -- Recipe: Greater Soulshot (C) Compressed Package(100%)
(20769, 2297, 1, 1, 2, 460.97234), -- Recipe: Flamberge
-- Timak Orc Troop Archer
(20770, 1905, 1, 1, -1, 167101), -- Omen Beast's Eye Earring Gemstone
(20770, 1805, 1, 1, -1, 5726), -- Recipe: Soulshot (C-Grade)
(20770, 1906, 1, 1, -1, 236124), -- Mithril Ring Wire
(20770, 57, 696, 1393, 0, 700000), -- Adena
(20770, 159, 1, 1, 1, 12.438186), -- Bonebreaker
(20770, 2048, 1, 1, 1, 713.154852), -- Bonebreaker Head
(20770, 187, 1, 1, 1, 12.438186), -- Atuba Hammer
(20770, 2049, 1, 1, 1, 713.154852), -- Atuba Hammer Head
(20770, 188, 1, 1, 1, 12.438186), -- Ghost Staff
(20770, 2050, 1, 1, 1, 756.174114), -- Ghost Staff Head
(20770, 189, 1, 1, 1, 12.438186), -- Staff of Life
(20770, 2051, 1, 1, 1, 756.174114), -- Staff of Life Shaft
(20770, 190, 1, 1, 1, 12.438186), -- Atuba Mace
(20770, 2058, 1, 1, 1, 713.151138), -- Atuba Mace Head
(20770, 1867, 1, 1, 2, 164304.797622), -- Animal Skin
(20770, 1872, 1, 1, 2, 164304.797622), -- Animal Bone
(20770, 1882, 1, 1, 2, 27384.012378), -- Leather
(20770, 1894, 1, 1, 2, 4323.848535), -- Crafted Leather
(20770, 1805, 1, 1, 2, 410.865072), -- Recipe: Soulshot (C-Grade)
(20770, 2298, 1, 1, 2, 538.175376), -- Recipe: Stormbringer
(20770, 5269, 1, 1, 2, 410.503395), -- Recipe: Greater Soulshot (C) Compressed Package(100%)
-- Barif
(20771, 1875, 1, 1, -1, 357372), -- Stone of Purity
(20771, 948, 1, 1, -1, 13401), -- Scroll: Enchant Armor (B-Grade)
(20771, 4042, 1, 1, -1, 89343), -- Enria
(20771, 57, 2128, 4304, 0, 700000), -- Adena
(20771, 171, 1, 1, 1, 5.230248), -- Deadman's Glory
(20771, 4116, 1, 1, 1, 1152.969252), -- Deadman's Glory Stone
(20771, 175, 1, 1, 1, 5.230248), -- Art of Battle Axe
(20771, 4117, 1, 1, 1, 1152.969252), -- Art of Battle Axe Blade
(20771, 210, 1, 1, 1, 5.230248), -- Staff of Evil Spirits
(20771, 4118, 1, 1, 1, 1092.370752), -- Evil Spirit Head
(20771, 1895, 1, 1, 2, 45241.35158), -- Metallic Fiber
(20771, 4040, 1, 1, 2, 3166.88589), -- Mold Lubricant
(20771, 4042, 1, 1, 2, 2639.10272), -- Enria
(20771, 4043, 1, 1, 2, 5278.14315), -- Asofe
(20771, 4953, 1, 1, 2, 3050.9642), -- Recipe: Sealed Avadon Gloves (60%)
(20771, 5276, 1, 1, 2, 211.10081), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20771, 8729, 1, 1, 2, 2111.25726), -- Life Stone - Level 64
(20771, 8739, 1, 1, 2, 527.84546), -- Mid-Grade Life Stone - Level 64
(20771, 8749, 1, 1, 2, 52.75963), -- High-Grade Life Stone - Level 64
(20771, 8759, 1, 1, 2, 10.5893), -- Top-Grade Life Stone - Level 64
-- Barif's Pet
(20772, 1875, 1, 1, -1, 344772), -- Stone of Purity
(20772, 1986, 1, 1, -1, 54648), -- Full Plate Armor Temper
(20772, 4613, 1, 1, -1, 7133), -- Greater Dye of STR (Str+4 Con-4)
(20772, 57, 2049, 4156, 0, 700000), -- Adena
(20772, 300, 1, 1, 1, 22.864152), -- Great Axe
(20772, 4113, 1, 1, 1, 3930.135848), -- Great Axe Head
(20772, 1872, 1, 1, 2, 169733.487288), -- Animal Bone
(20772, 1867, 1, 1, 2, 169733.487288), -- Animal Skin
(20772, 1881, 1, 1, 2, 16973.385864), -- Coarse Bone Powder
(20772, 1875, 1, 1, 2, 8486.507256), -- Stone of Purity
(20772, 4041, 1, 1, 2, 1107.000312), -- Mold Hardener
(20772, 4618, 1, 1, 2, 175.649496), -- Greater Dye of DEX (Dex+4 Con-4)
(20772, 4999, 1, 1, 2, 1583.444928), -- Recipe: Sealed Doom Boots (60%)
(20772, 4163, 1, 1, 2, 842.96904), -- Recipe: Blue Wolf Stockings (100%)
(20772, 8728, 1, 1, 2, 2121.533976), -- Life Stone - Level 61
(20772, 8738, 1, 1, 2, 530.290656), -- Mid-Grade Life Stone - Level 61
(20772, 8748, 1, 1, 2, 53.103336), -- High-Grade Life Stone - Level 61
(20772, 8758, 1, 1, 2, 11.14056), -- Top-Grade Life Stone - Level 61
-- Conjurer Bat Lord
(20773, 5478, 1, 1, -1, 29805), -- Sealed Dark Crystal Leather Armor Pattern
(20773, 1807, 1, 1, -1, 4726), -- Recipe: Soulshot (A-Grade)
(20773, 5479, 1, 1, -1, 20973), -- Sealed Tallum Leather Armor Pattern
(20773, 57, 1748, 3569, 0, 700000), -- Adena
(20773, 6324, 1, 1, 1, 43.406603), -- Sealed Phoenix Earring
(20773, 6341, 1, 1, 1, 6032.61631), -- Sealed Phoenix Earring Gemstone
(20773, 6323, 1, 1, 1, 32.550157), -- Sealed Phoenix Necklace
(20773, 6343, 1, 1, 1, 4663.438168), -- Sealed Phoenix Necklace Beads
(20773, 6325, 1, 1, 1, 65.100314), -- Sealed Phoenix Ring
(20773, 6345, 1, 1, 1, 8343.888448), -- Sealed Phoenix Ring Gemstone
(20773, 1868, 1, 1, 2, 237949.17195), -- Thread
(20773, 1873, 1, 1, 2, 47589.83439), -- Silver Nugget
(20773, 5549, 1, 1, 2, 11897.302739), -- Metallic Thread
(20773, 1889, 1, 1, 2, 7931.639065), -- Compound Braid
(20773, 4044, 1, 1, 2, 3965.663674), -- Thons
(20773, 4157, 1, 1, 2, 591.950583), -- Recipe: Blue Wolf Gaiters (100%)
(20773, 730, 1, 1, 2, 99.126006), -- Scroll: Enchant Armor (A-Grade)
(20773, 8730, 1, 1, 2, 1321.991797), -- Life Stone - Level 67
(20773, 8740, 1, 1, 2, 330.42002), -- Mid-Grade Life Stone - Level 67
(20773, 8750, 1, 1, 2, 33.042002), -- High-Grade Life Stone - Level 67
(20773, 8760, 1, 1, 2, 6.857774), -- Top-Grade Life Stone - Level 67
-- Conjurer Bat 
(20774, 1807, 1, 1, -1, 6216), -- Recipe: Soulshot (A-Grade)
(20774, 5478, 1, 1, -1, 39204), -- Sealed Dark Crystal Leather Armor Pattern
(20774, 1889, 1, 1, -1, 310807), -- Compound Braid
(20774, 57, 1844, 3751, 0, 700000), -- Adena
(20774, 5291, 1, 1, 1, 38.682273), -- Sealed Dark Crystal Boots
(20774, 5496, 1, 1, 1, 4036.567727), -- Sealed Dark Crystal Boots Lining
(20774, 5296, 1, 1, 1, 38.682273), -- Sealed Tallum Boots
(20774, 5497, 1, 1, 1, 4036.567727), -- Sealed Tallum Boots Lining
(20774, 5290, 1, 1, 1, 38.682273), -- Sealed Dark Crystal Gloves
(20774, 5508, 1, 1, 1, 4036.567727), -- Sealed Dark Crystal Gloves Design
(20774, 5295, 1, 1, 1, 38.682273), -- Sealed Tallum Gloves
(20774, 5509, 1, 1, 1, 4036.567727), -- Sealed Tallum Gloves Design
(20774, 1873, 1, 1, 2, 55084.610222), -- Silver Nugget
(20774, 1868, 1, 1, 2, 275423.452944), -- Thread
(20774, 1876, 1, 1, 2, 27542.506028), -- Mithril Ore
(20774, 1895, 1, 1, 2, 39346.379778), -- Metallic Fiber
(20774, 4042, 1, 1, 2, 2295.275808), -- Enria
(20774, 5271, 1, 1, 2, 183.638138), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(20774, 8730, 1, 1, 2, 1530.183872), -- Life Stone - Level 67
(20774, 8740, 1, 1, 2, 382.545968), -- Mid-Grade Life Stone - Level 67
(20774, 8750, 1, 1, 2, 38.17423), -- High-Grade Life Stone - Level 67
(20774, 8760, 1, 1, 2, 7.233012), -- Top-Grade Life Stone - Level 67
-- Bugbear Raider
(20775, 2253, 1, 1, -1, 9985), -- Recipe: Sword Breaker
(20775, 1897, 1, 1, -1, 58010), -- Necklace of Wisdom Chain
(20775, 1800, 1, 1, -1, 76617), -- Recipe: Piece Bone Breastplate
(20775, 57, 119, 191, 0, 700000), -- Adena
(20775, 15, 1, 1, 1, 137.091519), -- Short Spear
(20775, 2011, 1, 1, 1, 1641.908481), -- Short Spear Edge
(20775, 1873, 1, 1, 2, 19191.51927), -- Silver Nugget
(20775, 1868, 1, 1, 2, 95957.721095), -- Thread
(20775, 2144, 1, 1, 2, 9595.759635), -- Recipe: Compound Braid
-- Dark Succubus
(20776, 1865, 1, 1, -1, 297237), -- Varnish
(20776, 1866, 1, 1, -1, 198158), -- Suede
(20776, 1897, 1, 1, -1, 70771), -- Necklace of Wisdom Chain
(20776, 57, 137, 239, 0, 700000), -- Adena
(20776, 1101, 1, 1, 1, 1125.650223), -- Tunic of Devotion
(20776, 1104, 1, 1, 1, 1797.349777), -- Stockings of Devotion
(20776, 1869, 1, 1, 2, 19510.9902), -- Iron Ore
(20776, 1870, 1, 1, 2, 19510.9902), -- Coal
(20776, 1871, 1, 1, 2, 19510.9902), -- Charcoal
(20776, 1872, 1, 1, 2, 26014.6536), -- Animal Bone
(20776, 1867, 1, 1, 2, 26014.6536), -- Animal Skin
(20776, 2140, 1, 1, 2, 3902.2656), -- Recipe: High-Grade Suede
(20776, 5158, 1, 1, 2, 780.4869), -- Recipe: Spiritshot (D) Compressed Package (100%)
(20776, 735, 1, 1, 2, 1625.8314), -- Alacrity Potion
(20776, 1831, 1, 1, 2, 52029.1383), -- Antidote
-- Hunter Bear
(20777, 1831, 1, 1, -1, 594351), -- Antidote
(20777, 1896, 1, 1, -1, 94441), -- Necklace of Anguish Chain
(20777, 1792, 1, 1, -1, 16388), -- Recipe: Short Spear
(20777, 57, 114, 168, 0, 700000), -- Adena
(20777, 37, 1, 1, 1, 4303.043343), -- Leather Shoes
(20777, 1921, 1, 1, 1, 28316.876391), -- Leather Shoes Texture
(20777, 49, 1, 1, 1, 4303.080266), -- Gloves
(20777, 1868, 1, 1, 2, 87781.424965), -- Thread
(20777, 1873, 1, 1, 2, 17556.26328), -- Silver Nugget
(20777, 1794, 1, 1, 2, 3227.311755), -- Recipe: Forest Bow
-- Ragna Orc Overlord
(20778, 2290, 1, 1, -1, 5412), -- Recipe: Mithril Dagger
(20778, 1903, 1, 1, -1, 162485), -- Elven Ring Piece
(20778, 1902, 1, 1, -1, 98693), -- Elven Earring Beads
(20778, 57, 412, 821, 0, 700000), -- Adena
(20778, 352, 1, 1, 1, 73.069944), -- Brigandine Tunic
(20778, 1941, 1, 1, 1, 3337.400322), -- Brigandine Temper
(20778, 2377, 1, 1, 1, 116.881986), -- Mithril Scale Gaiters
(20778, 2918, 1, 1, 1, 4978.889682), -- Mithril Scale Gaiters Material
(20778, 2378, 1, 1, 1, 116.881986), -- Brigandine Gaiters
(20778, 2919, 1, 1, 1, 4978.87608), -- Brigandine Gaiters Material
(20778, 1871, 1, 1, 2, 83922.320522), -- Charcoal
(20778, 1866, 1, 1, 2, 55948.264595), -- Suede
(20778, 1877, 1, 1, 2, 3356.941698), -- Adamantite Nugget
(20778, 2289, 1, 1, 2, 466.165532), -- Recipe: Staff of Life
(20778, 2288, 1, 1, 2, 466.165532), -- Recipe: Ghost Staff
(20778, 2202, 1, 1, 2, 8581.142121), -- Recipe: Assault Boots
-- Ragna Orc Priest
(20779, 2158, 1, 1, -1, 107640), -- Recipe: Mithril Ring
(20779, 1904, 1, 1, -1, 81170), -- Elven Necklace Beads
(20779, 1866, 1, 1, -1, 579821), -- Suede
(20779, 57, 368, 733, 0, 700000), -- Adena
(20779, 318, 1, 1, 1, 41.858726), -- Crucifix of Blood
(20779, 2042, 1, 1, 1, 2077.141274), -- Crucifix of Blood Piece
(20779, 1871, 1, 1, 2, 89916.679179), -- Charcoal
(20779, 1866, 1, 1, 2, 59944.452786), -- Suede
(20779, 1877, 1, 1, 2, 3596.685702), -- Adamantite Nugget
(20779, 2290, 1, 1, 2, 499.513938), -- Recipe: Mithril Dagger
(20779, 2286, 1, 1, 2, 499.668395), -- Recipe: Bonebreaker
-- Bloody Axe Elite
(20780, 2980, 1, 1, -1, 95429), -- Recipe: Brigandine Gauntlets
(20780, 1901, 1, 1, -1, 98461), -- Tiger's Eye Earring Stone
(20780, 1877, 1, 1, -1, 28514), -- Adamantite Nugget
(20780, 57, 301, 601, 0, 700000), -- Adena
(20780, 157, 1, 1, 1, 33.984452), -- Spiked Club
(20780, 2027, 1, 1, 1, 1655.031096), -- Spiked Club Head
(20780, 186, 1, 1, 1, 33.984452), -- Staff of Magic
(20780, 1871, 1, 1, 2, 94755.45226), -- Charcoal
(20780, 1866, 1, 1, 2, 63170.246545), -- Suede
(20780, 1877, 1, 1, 2, 3790.211495), -- Adamantite Nugget
(20780, 2186, 1, 1, 2, 3169.0897), -- Recipe: Brigandine Tunic
-- Delu Lizardman Shaman
(20781, 2192, 1, 1, -1, 90034), -- Recipe: Kite Shield
(20781, 1938, 1, 1, -1, 47453), -- Mithril Banded Mail Material
(20781, 1901, 1, 1, -1, 97496), -- Tiger's Eye Earring Stone
(20781, 57, 298, 595, 0, 700000), -- Adena
(20781, 436, 1, 1, 1, 320.586714), -- Tunic of Knowledge
(20781, 469, 1, 1, 1, 512.413286), -- Stockings of Knowledge
(20781, 1875, 1, 1, 2, 3127.529982), -- Stone of Purity
(20781, 1879, 1, 1, 2, 7818.876878), -- Cokes
(20781, 1885, 1, 1, 2, 3909.438439), -- High-Grade Suede
(20781, 5550, 1, 1, 2, 625.516381), -- Durable Metal Plate
(20781, 5549, 1, 1, 2, 4691.346896), -- Metallic Thread
(20781, 2187, 1, 1, 2, 2094.366128), -- Recipe: Manticore Skin Shirt
(20781, 2273, 1, 1, 2, 335.111042), -- Recipe: Tarbar
(20781, 6667, 1, 1, 2, 29320.814254), -- Deluxe Chest Key - Grade 3
-- Ol Mahum Novice
(20782, 1801, 1, 1, -1, 126448), -- Recipe: Piece Bone Gaiters
(20782, 1924, 1, 1, -1, 80968), -- Leather Helmet Design
(20782, 1800, 1, 1, -1, 78931), -- Recipe: Piece Bone Breastplate
(20782, 57, 122, 197, 0, 700000), -- Adena
(20782, 256, 1, 1, 1, 282), -- Cestus
(20782, 1872, 1, 1, 2, 49427.50289), -- Animal Bone
(20782, 1867, 1, 1, 2, 49427.50289), -- Animal Skin
(20782, 2150, 1, 1, 2, 17404.03373), -- Recipe: Blue Diamond Necklace
(20782, 5268, 1, 1, 2, 1482.96049), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Dread Wolf
(20783, 2203, 1, 1, -1, 70587), -- Recipe: Reinforced Mithril Boots
(20783, 1935, 1, 1, -1, 18100), -- Scale Mail Fragment
(20783, 1900, 1, 1, -1, 35448), -- Enchanted Necklace Chain
(20783, 57, 137, 273, 0, 700000), -- Adena
(20783, 316, 1, 1, 1, 15.435576), -- Sage's Blood
(20783, 317, 1, 1, 1, 15.435576), -- Tome of Blood
(20783, 2030, 1, 1, 1, 671.128848), -- Tome of Blood Page
(20783, 1874, 1, 1, 2, 1435.544052), -- Oriharukon Ore
(20783, 1878, 1, 1, 2, 8613.23233), -- Braided Hemp
(20783, 1884, 1, 1, 2, 13251.10206), -- Cord
(20783, 1889, 1, 1, 2, 1435.544052), -- Compound Braid
(20783, 5220, 1, 1, 2, 861.307242), -- Metal Hardener
(20783, 2153, 1, 1, 2, 3348.83522), -- Recipe: Tiger's Eye Earring
(20783, 2977, 1, 1, 2, 2882.601624), -- Recipe: Brigandine Boots
(20783, 8307, 1, 1, 2, 153.83342), -- Recipe: Priest Mace (100%)
-- Tasaba Lizardman
(20784, 2021, 1, 1, -1, 4623), -- Spinebone Sword Blade
(20784, 2184, 1, 1, -1, 38461), -- Recipe: Mithril Banded Gaiters
(20784, 2153, 1, 1, -1, 56945), -- Recipe: Tiger's Eye Earring
(20784, 57, 154, 309, 0, 700000), -- Adena
(20784, 83, 1, 1, 1, 11.7744), -- Sword of Magic
(20784, 144, 1, 1, 1, 11.7744), -- Sword of Occult
(20784, 124, 1, 1, 1, 8.72256), -- Two-Handed Sword
(20784, 2026, 1, 1, 1, 390.28308), -- Two-Handed Sword Edge
(20784, 127, 1, 1, 1, 8.72256), -- Crimson Sword
(20784, 130, 1, 1, 1, 8.723), -- Elven Sword
(20784, 1875, 1, 1, 2, 2163.132496), -- Stone of Purity
(20784, 1879, 1, 1, 2, 5407.842272), -- Cokes
(20784, 1885, 1, 1, 2, 2703.921136), -- High-Grade Suede
(20784, 5550, 1, 1, 2, 432.630912), -- Durable Metal Plate
(20784, 5549, 1, 1, 2, 3244.709776), -- Metallic Thread
(20784, 2250, 1, 1, 2, 8111.763408), -- Recipe: Bone Arrow
-- Tasaba Lizardman Shaman
(20785, 2022, 1, 1, -1, 5500), -- Mace of Judgment Head
(20785, 1933, 1, 1, -1, 41540), -- Dark Stockings Fabric
(20785, 1875, 1, 1, -1, 23539), -- Stone of Purity
(20785, 57, 149, 298, 0, 700000), -- Adena
(20785, 1124, 1, 1, 1, 39.7463), -- Boots of Power
(20785, 1948, 1, 1, 1, 1541.5037), -- Boots of Power Pattern
(20785, 2424, 1, 1, 1, 39.7463), -- Manticore Skin Boots
(20785, 2923, 1, 1, 1, 1541.5037), -- Manticore Skin Boot Lining
(20785, 2425, 1, 1, 1, 39.7463), -- Brigandine Boots
(20785, 2924, 1, 1, 1, 1541.5037), -- Brigandine Boots Design
(20785, 2426, 1, 1, 1, 39.7463), -- Elven Mithril Boots
(20785, 2925, 1, 1, 1, 1541.5037), -- Elven Mithril Boots Design
(20785, 606, 1, 1, 1, 39.7463), -- Rip Gauntlets
(20785, 1946, 1, 1, 1, 1541.5037), -- Rip Gauntlets Pattern
(20785, 2448, 1, 1, 1, 39.7463), -- Manticore Skin Gloves
(20785, 2926, 1, 1, 1, 1541.5037), -- Manticore Skin Gloves Lining
(20785, 2449, 1, 1, 1, 39.7463), -- Brigandine Gauntlets
(20785, 2927, 1, 1, 1, 1541.5037), -- Brigandine Gauntlets Pattern
(20785, 2450, 1, 1, 1, 39.7463), -- Mithril Gloves
(20785, 2928, 1, 1, 1, 1541.5037), -- Mithril Gloves Design
(20785, 1875, 1, 1, 2, 1352.00395), -- Stone of Purity
(20785, 1879, 1, 1, 2, 3380.009875), -- Cokes
(20785, 1885, 1, 1, 2, 1690.052725), -- High-Grade Suede
(20785, 5550, 1, 1, 2, 270.381675), -- Durable Metal Plate
(20785, 5549, 1, 1, 2, 2028.005925), -- Metallic Thread
(20785, 2185, 1, 1, 2, 3992.16775), -- Recipe: Iron Boots
(20785, 2982, 1, 1, 2, 2586.737375), -- Recipe: Brigandine Shield
(20785, 6667, 1, 1, 2, 12675.060925), -- Deluxe Chest Key - Grade 3
(20785, 1341, 10, 30, 2, 67600.5798), -- Bone Arrow
-- Lienrik
(20786, 2026, 1, 1, -1, 4711), -- Two-Handed Sword Edge
(20786, 2155, 1, 1, -1, 62822), -- Recipe: Elven Ring
(20786, 5550, 1, 1, -1, 5218), -- Durable Metal Plate
(20786, 57, 166, 330, 0, 700000), -- Adena
(20786, 395, 1, 1, 1, 58.81275), -- Manticore Skin Shirt
(20786, 1942, 1, 1, 1, 2579.8905), -- Manticore Skin Shirt Texture
(20786, 417, 1, 1, 1, 93.92625), -- Manticore Skin Gaiters
(20786, 1943, 1, 1, 1, 4017.3705), -- Manticore Skin Gaiters Pattern
(20786, 1875, 1, 1, 2, 1685.957287), -- Stone of Purity
(20786, 1879, 1, 1, 2, 4214.885927), -- Cokes
(20786, 1885, 1, 1, 2, 2107.450254), -- High-Grade Suede
(20786, 5550, 1, 1, 2, 337.185625), -- Durable Metal Plate
(20786, 5549, 1, 1, 2, 2528.92864), -- Metallic Thread
(20786, 2278, 1, 1, 2, 180.644009), -- Recipe: Reinforced Long Bow
(20786, 2286, 1, 1, 2, 140.502516), -- Recipe: Bonebreaker
(20786, 2977, 1, 1, 2, 3385.445742), -- Recipe: Brigandine Boots
-- Lienrik Lad
(20787, 1870, 1, 1, -1, 476736), -- Coal
(20787, 2029, 1, 1, -1, 5687), -- Gastraphetes Shaft
(20787, 5549, 1, 1, -1, 47674), -- Metallic Thread
(20787, 57, 199, 397, 0, 700000), -- Adena
(20787, 850, 1, 1, 1, 114.249236), -- Elven Earring
(20787, 1902, 1, 1, 1, 4161.316905), -- Elven Earring Beads
(20787, 913, 1, 1, 1, 85.747795), -- Elven Necklace
(20787, 1904, 1, 1, 1, 3833.147083), -- Elven Necklace Beads
(20787, 881, 1, 1, 1, 171.49559), -- Elven Ring
(20787, 1903, 1, 1, 1, 6851.043391), -- Elven Ring Piece
(20787, 1875, 1, 1, 2, 1825.447782), -- Stone of Purity
(20787, 1879, 1, 1, 2, 4563.688148), -- Cokes
(20787, 1885, 1, 1, 2, 2281.844074), -- High-Grade Suede
(20787, 5550, 1, 1, 2, 365.034602), -- Durable Metal Plate
(20787, 5549, 1, 1, 2, 2738.240366), -- Metallic Thread
(20787, 2188, 1, 1, 2, 1955.827096), -- Recipe: Manticore Skin Gaiters
(20787, 5473, 1, 1, 2, 1955.827096), -- Recipe: Durable Metal Plate(100%)
(20787, 1832, 1, 1, 2, 30424.954016), -- Greater Antidote
(20787, 1341, 10, 30, 2, 91275.13682), -- Bone Arrow
-- Rakul
(20788, 2186, 1, 1, -1, 28093), -- Recipe: Brigandine Tunic
(20788, 1901, 1, 1, -1, 116020), -- Tiger's Eye Earring Stone
(20788, 57, 355, 708, 0, 700000), -- Adena
(20788, 260, 1, 1, 1, 120), -- Triple-Edged Jamadhr
(20788, 1874, 1, 1, 2, 3721.759626), -- Oriharukon Ore
(20788, 1878, 1, 1, 2, 22330.557756), -- Braided Hemp
(20788, 1884, 1, 1, 2, 34354.730995), -- Cord
(20788, 1889, 1, 1, 2, 3721.759626), -- Compound Braid
(20788, 5220, 1, 1, 2, 2233.041863), -- Metal Hardener
(20788, 2189, 1, 1, 2, 2492.233601), -- Recipe: Mithril Tunic
(20788, 2293, 1, 1, 2, 310.181417), -- Recipe: Glaive
(20788, 2275, 1, 1, 2, 398.735116), -- Recipe: Heavy Bone Club
-- Crokian
(20789, 2030, 1, 1, -1, 9246), -- Tome of Blood Page
(20789, 2188, 1, 1, -1, 56469), -- Recipe: Manticore Skin Gaiters
(20789, 2154, 1, 1, -1, 84644), -- Recipe: Elven Earring
(20789, 57, 333, 668, 0, 700000), -- Adena
(20789, 393, 1, 1, 1, 119.754095), -- Mithril Banded Mail
(20789, 1938, 1, 1, 1, 4709.504645), -- Mithril Banded Mail Material
(20789, 394, 1, 1, 1, 119.754095), -- Reinforced Leather Shirt
(20789, 415, 1, 1, 1, 191.40901), -- Mithril Banded Gaiters
(20789, 1939, 1, 1, 1, 6153.18063), -- Mithril Banded Gaiters Material
(20789, 416, 1, 1, 1, 191.397525), -- Reinforced Leather Gaiters
(20789, 1874, 1, 1, 2, 3502.836657), -- Oriharukon Ore
(20789, 1878, 1, 1, 2, 21016.771461), -- Braided Hemp
(20789, 1884, 1, 1, 2, 32333.590125), -- Cord
(20789, 1889, 1, 1, 2, 3502.836657), -- Compound Braid
(20789, 5220, 1, 1, 2, 2101.652298), -- Metal Hardener
(20789, 2275, 1, 1, 2, 375.20631), -- Recipe: Heavy Bone Club
(20789, 1661, 1, 1, 2, 10508.509971), -- Thief Key
(20789, 1341, 10, 30, 2, 175139.596521), -- Bone Arrow
-- Dailaon
(20790, 2039, 1, 1, -1, 10243), -- Bich'Hwa Edge
(20790, 1868, 1, 5, -1, 674568), -- Thread
(20790, 1902, 1, 1, -1, 102518), -- Elven Earring Beads
(20790, 57, 428, 853, 0, 700000), -- Adena
(20790, 224, 1, 1, 1, 24.35192), -- Maingauche
(20790, 2038, 1, 1, 1, 1381.64808), -- Maingauche Edge
(20790, 1660, 1, 1, 1, 24.35192), -- Cursed Maingauche
(20790, 2044, 1, 1, 1, 1381.64808), -- Cursed Maingauche Edge
(20790, 1874, 1, 1, 2, 3486.998377), -- Oriharukon Ore
(20790, 1878, 1, 1, 2, 20921.154519), -- Braided Hemp
(20790, 1884, 1, 1, 2, 32186.412997), -- Cord
(20790, 1889, 1, 1, 2, 3486.998377), -- Compound Braid
(20790, 5220, 1, 1, 2, 2092.14331), -- Metal Hardener
(20790, 2147, 1, 1, 2, 3736.049791), -- Recipe: Blacksmith's frame
(20790, 2984, 1, 1, 2, 5347.919457), -- Recipe: Salamander Skin Boots
(20790, 2289, 1, 1, 2, 290.559983), -- Recipe: Staff of Life
(20790, 6667, 1, 1, 2, 32689.530283), -- Deluxe Chest Key - Grade 3
(20790, 1341, 10, 30, 2, 174343.232906), -- Bone Arrow
-- Crokian Warrior
(20791, 2196, 1, 1, -1, 71256), -- Recipe: Plate Gaiters
(20791, 2041, 1, 1, -1, 19395), -- War Pick Head
(20791, 1825, 1, 1, -1, 124190), -- Recipe: Oriharukon
(20791, 57, 735, 1467, 0, 700000), -- Adena
(20791, 352, 1, 1, 1, 130.421416), -- Brigandine Tunic
(20791, 1941, 1, 1, 1, 5956.874358), -- Brigandine Temper
(20791, 2377, 1, 1, 1, 208.620854), -- Mithril Scale Gaiters
(20791, 2918, 1, 1, 1, 8886.743398), -- Mithril Scale Gaiters Material
(20791, 2378, 1, 1, 1, 208.620854), -- Brigandine Gaiters
(20791, 2919, 1, 1, 1, 8886.71912), -- Brigandine Gaiters Material
(20791, 1876, 1, 1, 2, 25678.72309), -- Mithril Ore
(20791, 1880, 1, 1, 2, 12839.4079), -- Steel
(20791, 1877, 1, 1, 2, 5135.76316), -- Adamantite Nugget
(20791, 1881, 1, 1, 2, 17119.17963), -- Coarse Bone Powder
(20791, 1882, 1, 1, 2, 28531.96605), -- Leather
(20791, 2198, 1, 1, 2, 2691.64943), -- Recipe: Sage's Rag
(20791, 3020, 1, 1, 2, 713.31074), -- Recipe: Elven Long Sword
-- Farhite
(20792, 2035, 1, 1, -1, 16376), -- Tarbar Head
(20792, 2202, 1, 1, -1, 165409), -- Recipe: Assault Boots
(20792, 1903, 1, 1, -1, 269842), -- Elven Ring Piece
(20792, 57, 684, 1363, 0, 700000), -- Adena
(20792, 88, 1, 1, 1, 15.571536), -- Morning Star
(20792, 2031, 1, 1, 1, 846.382452), -- Morning Star Head
(20792, 90, 1, 1, 1, 15.571536), -- Goat Head Staff
(20792, 2032, 1, 1, 1, 772.62522), -- Goat Head Staff Head
(20792, 158, 1, 1, 1, 15.571536), -- Tarbar
(20792, 2035, 1, 1, 1, 846.382452), -- Tarbar Head
(20792, 169, 1, 1, 1, 15.571536), -- Skull Breaker
(20792, 2036, 1, 1, 1, 846.382452), -- Skull Breaker Head
(20792, 172, 1, 1, 1, 15.571536), -- Heavy Bone Club
(20792, 2037, 1, 1, 1, 846.369744), -- Heavy Bone Club Head
(20792, 1876, 1, 1, 2, 23892.20854), -- Mithril Ore
(20792, 1880, 1, 1, 2, 11946.1474), -- Steel
(20792, 1877, 1, 1, 2, 4778.45896), -- Adamantite Nugget
(20792, 1881, 1, 1, 2, 15928.16778), -- Coarse Bone Powder
(20792, 1882, 1, 1, 2, 26546.9463), -- Leather
(20792, 2198, 1, 1, 2, 2504.38658), -- Recipe: Sage's Rag
(20792, 3020, 1, 1, 2, 663.68444), -- Recipe: Elven Long Sword
-- Nos
(20793, 2037, 1, 1, -1, 17953), -- Heavy Bone Club Head
(20793, 1877, 1, 1, -1, 70938), -- Adamantite Nugget
(20793, 1881, 1, 1, -1, 236461), -- Coarse Bone Powder
(20793, 57, 740, 1478, 0, 700000), -- Adena
(20793, 93, 1, 1, 1, 42.67558), -- Winged Spear
(20793, 2033, 1, 1, 1, 2556.32442), -- Winged Spear Blade
(20793, 294, 1, 1, 1, 42.67558), -- War Pick
(20793, 2041, 1, 1, 1, 2556.32442), -- War Pick Head
(20793, 1876, 1, 1, 2, 22918.530082), -- Mithril Ore
(20793, 1880, 1, 1, 2, 11459.501788), -- Steel
(20793, 1877, 1, 1, 2, 4583.895414), -- Adamantite Nugget
(20793, 1881, 1, 1, 2, 15279.177886), -- Coarse Bone Powder
(20793, 1882, 1, 1, 2, 25464.980814), -- Leather
(20793, 2147, 1, 1, 2, 8185.290778), -- Recipe: Blacksmith's frame
(20793, 2205, 1, 1, 2, 3626.490546), -- Recipe: Chain Gaiters
(20793, 1341, 10, 30, 2, 381976.132692), -- Bone Arrow
-- Blade Stakato
(20794, 2991, 1, 1, -1, 132768), -- Recipe: Karmian Boots
(20794, 1952, 1, 1, -1, 53584), -- Salamander Skin Mail Texture
(20794, 1866, 1, 3, -1, 557627), -- Suede
(20794, 57, 678, 1356, 0, 700000), -- Adena
(20794, 225, 1, 1, 1, 60.562565), -- Mithril Dagger
(20794, 2052, 1, 1, 1, 3642.437435), -- Mithril Dagger Blade
(20794, 1866, 1, 1, 2, 80004.198474), -- Suede
(20794, 1871, 1, 1, 2, 120006.40714), -- Charcoal
(20794, 5220, 1, 1, 2, 4800.212514), -- Metal Hardener
(20794, 1885, 1, 1, 2, 10000.497452), -- High-Grade Suede
(20794, 2206, 1, 1, 2, 3166.437544), -- Recipe: Mithril Shirt
(20794, 4556, 1, 1, 2, 479.955594), -- Greater Dye of CON (Con+1 Dex-1)
(20794, 5274, 1, 1, 2, 400.291282), -- Recipe: Greater Spiritshot (C) Compressed Package(100%)
-- Blade Stakato Worker
(20795, 2161, 1, 1, -1, 153276), -- Recipe: Aquastone Ring
(20795, 2047, 1, 1, -1, 13879), -- Claymore Blade
(20795, 4469, 1, 1, -1, 9021), -- Dye of STR (Str+1 Con-1)
(20795, 57, 636, 1285, 0, 700000), -- Adena
(20795, 851, 1, 1, 1, 283.234762), -- Omen Beast's Eye Earring
(20795, 1905, 1, 1, 1, 12852.656394), -- Omen Beast's Eye Earring Gemstone
(20795, 914, 1, 1, 1, 212.41579), -- Necklace of Darkness
(20795, 1907, 1, 1, 1, 9191.331992), -- Necklace of Darkness Gem
(20795, 882, 1, 1, 1, 424.83158), -- Mithril Ring
(20795, 1906, 1, 1, 1, 18161.529482), -- Mithril Ring Wire
(20795, 1867, 1, 1, 2, 151004.48972), -- Animal Skin
(20795, 1872, 1, 1, 2, 151004.48972), -- Animal Bone
(20795, 1882, 1, 1, 2, 25167.544542), -- Leather
(20795, 1894, 1, 1, 2, 3973.966052), -- Crafted Leather
(20795, 2304, 1, 1, 2, 494.510352), -- Recipe: Heavy Doom Hammer
(20795, 736, 1, 1, 2, 56626.878028), -- Scroll of Escape
(20795, 2303, 1, 1, 2, 494.121586), -- Recipe: Skull Graver
-- Blade Stakato Warrior
(20796, 2199, 1, 1, -1, 71642), -- Recipe: Karmian Stockings
(20796, 2930, 1, 1, -1, 136873), -- Plate Helmet Design
(20796, 1905, 1, 1, -1, 165167), -- Omen Beast's Eye Earring Gemstone
(20796, 57, 671, 1364, 0, 700000), -- Adena
(20796, 396, 1, 1, 1, 232.565589), -- Salamander Skin Mail
(20796, 1952, 1, 1, 1, 13654.434411), -- Salamander Skin Mail Texture
(20796, 1868, 1, 1, 2, 170522.522904), -- Thread
(20796, 1873, 1, 1, 2, 34104.451554), -- Silver Nugget
(20796, 5549, 1, 1, 2, 8526.179172), -- Metallic Thread
(20796, 1889, 1, 1, 2, 5684.207826), -- Compound Braid
(20796, 2998, 1, 1, 2, 6410.674986), -- Recipe: Chain Shield
(20796, 737, 1, 1, 2, 8526.179172), -- Scroll of Resurrection
(20796, 4557, 1, 1, 2, 340.962324), -- Greater Dye of DEX (Dex+1 Str-1)
(20796, 3033, 1, 1, 2, 284.223648), -- Recipe: Spiritshot C
(20796, 3954, 1, 1, 2, 284.223648), -- Recipe: Blessed Spiritshot C
(20796, 6668, 1, 1, 2, 30450.374766), -- Deluxe Chest Key - Grade 4
-- Blade Stakato Drone
(20797, 4440, 1, 1, -1, 8981), -- Recipe: Knuckle Duster
(20797, 1908, 1, 1, -1, 244093), -- Moonstone Earring Wire
(20797, 2163, 1, 1, -1, 131511), -- Recipe: Earring of Protection
(20797, 57, 1015, 2079, 0, 700000), -- Adena
(20797, 397, 1, 1, 1, 209.313728), -- Mithril Shirt
(20797, 1961, 1, 1, 1, 9746.249906), -- Mithril Shirt Fabric
(20797, 2387, 1, 1, 1, 334.520624), -- Reinforced Mithril Gaiters
(20797, 2935, 1, 1, 1, 16191.915742), -- Reinforced Mithril Gaiters Fragment
(20797, 1869, 1, 1, 2, 110747.736582), -- Iron Ore
(20797, 1864, 1, 1, 2, 221495.473164), -- Stem
(20797, 1880, 1, 1, 2, 11074.702548), -- Steel
(20797, 5550, 1, 1, 2, 1476.603303), -- Durable Metal Plate
(20797, 2220, 1, 1, 2, 2292.948399), -- Recipe: Rind Leather Armor
(20797, 2225, 1, 1, 2, 2407.435821), -- Recipe: Demon's Stockings
(20797, 2321, 1, 1, 2, 385.772835), -- Recipe: Stiletto
(20797, 8723, 1, 1, 2, 4429.809909), -- Life Stone - Level 46
(20797, 8733, 1, 1, 2, 1107.541365), -- Mid-Grade Life Stone - Level 46
(20797, 8743, 1, 1, 2, 110.576361), -- High-Grade Life Stone - Level 46
(20797, 8753, 1, 1, 2, 22.399713), -- Top-Grade Life Stone - Level 46
-- Water Giant
(20798, 4042, 1, 1, -1, 34793), -- Enria
(20798, 4043, 1, 1, -1, 69587), -- Asofe
(20798, 1908, 1, 1, -1, 197690), -- Moonstone Earring Wire
(20798, 57, 826, 1677, 0, 700000), -- Adena
(20798, 71, 1, 1, 1, 27.97965), -- Flamberge
(20798, 2059, 1, 1, 1, 1831.857492), -- Flamberge Blade
(20798, 72, 1, 1, 1, 27.97965), -- Stormbringer
(20798, 2060, 1, 1, 1, 1958.183208), -- Stormbringer Blade
(20798, 1869, 1, 1, 2, 89694.045238), -- Iron Ore
(20798, 1864, 1, 1, 2, 179388.090476), -- Stem
(20798, 1880, 1, 1, 2, 8969.346932), -- Steel
(20798, 5550, 1, 1, 2, 1195.893727), -- Durable Metal Plate
(20798, 2220, 1, 1, 2, 1857.047591), -- Recipe: Rind Leather Armor
(20798, 2225, 1, 1, 2, 1949.770389), -- Recipe: Demon's Stockings
(20798, 2321, 1, 1, 2, 312.435515), -- Recipe: Stiletto
(20798, 8723, 1, 1, 2, 3587.681181), -- Life Stone - Level 46
(20798, 8733, 1, 1, 2, 896.992285), -- Mid-Grade Life Stone - Level 46
(20798, 8743, 1, 1, 2, 89.555249), -- High-Grade Life Stone - Level 46
(20798, 8753, 1, 1, 2, 18.141417), -- Top-Grade Life Stone - Level 46
-- Queen Undine Lad
(20799, 2317, 1, 1, -1, 7323), -- Recipe: Bec de Corbin
(20799, 2065, 1, 1, -1, 16244), -- Skull Graver Head
(20799, 2164, 1, 1, -1, 161662), -- Recipe: Ring of Protection
(20799, 57, 828, 1693, 0, 700000), -- Adena
(20799, 354, 1, 1, 1, 127.798696), -- Chain Mail Shirt
(20799, 1959, 1, 1, 1, 6688.228012), -- Chain Mail Shirt Material
(20799, 381, 1, 1, 1, 204.444912), -- Chain Gaiters
(20799, 1960, 1, 1, 1, 13605.52838), -- Chain Gaiters Part
(20799, 1871, 1, 1, 2, 90295.964824), -- Charcoal
(20799, 1866, 1, 1, 2, 60197.364344), -- Suede
(20799, 1877, 1, 1, 2, 3611.766704), -- Adamantite Nugget
(20799, 4041, 1, 1, 2, 785.223504), -- Mold Hardener
(20799, 4040, 1, 1, 2, 1805.883352), -- Mold Lubricant
(20799, 2230, 1, 1, 2, 1749.84264), -- Recipe: Theca Leather Gaiters
(20799, 2326, 1, 1, 2, 314.677584), -- Recipe: Horn of Glory
(20799, 8723, 1, 1, 2, 3611.766704), -- Life Stone - Level 46
(20799, 8733, 1, 1, 2, 903.023368), -- Mid-Grade Life Stone - Level 46
(20799, 8743, 1, 1, 2, 90.351352), -- High-Grade Life Stone - Level 46
(20799, 8753, 1, 1, 2, 18.135624), -- Top-Grade Life Stone - Level 46
-- Eva's Seeker
(20800, 2223, 1, 1, -1, 76282), -- Recipe: Tower Shield
(20800, 1966, 1, 1, -1, 71854), -- Plated Leather Fragment
(20800, 1911, 1, 1, -1, 146379), -- Earring of Protection Gemstone
(20800, 57, 777, 1585, 0, 700000), -- Adena
(20800, 355, 1, 1, 1, 87.99518), -- Dwarven Chain Mail Shirt
(20800, 1968, 1, 1, 1, 5253.18792), -- Dwarven Chain Mail Shirt Material
(20800, 382, 1, 1, 1, 140.792288), -- Dwarven Chain Gaiters
(20800, 1969, 1, 1, 1, 8332.024612), -- Dwarven Chain Gaiters Material
(20800, 1872, 1, 1, 2, 105697.749824), -- Animal Bone
(20800, 1867, 1, 1, 2, 105697.749824), -- Animal Skin
(20800, 1881, 1, 1, 2, 10569.728034), -- Coarse Bone Powder
(20800, 1875, 1, 1, 2, 5284.981388), -- Stone of Purity
(20800, 4041, 1, 1, 2, 689.437254), -- Mold Hardener
(20800, 2226, 1, 1, 2, 3235.683728), -- Recipe: Mithril Gauntlets
(20800, 2333, 1, 1, 2, 184.27247), -- Recipe: Sword of Nightmare
(20800, 8724, 1, 1, 2, 2642.490694), -- Life Stone - Level 49
(20800, 8734, 1, 1, 2, 660.563988), -- Mid-Grade Life Stone - Level 49
(20800, 8744, 1, 1, 2, 65.962502), -- High-Grade Life Stone - Level 49
(20800, 8754, 1, 1, 2, 13.380294), -- Top-Grade Life Stone - Level 49
-- Theeder Piker
(20801, 2946, 1, 1, -1, 132781), -- Plate Leather Gloves Design
(20801, 2330, 1, 1, -1, 5524), -- Recipe: Homunkulus's Sword
(20801, 951, 1, 1, -1, 4319), -- Scroll: Enchant Weapon (C-Grade)
(20801, 57, 939, 1909, 0, 700000), -- Adena
(20801, 4233, 1, 1, 1, 47.634132), -- Knuckle Duster
(20801, 4438, 1, 1, 1, 3753.365868), -- Knuckle Duster Edge
(20801, 1873, 1, 1, 2, 30071.557296), -- Silver Nugget
(20801, 1868, 1, 1, 2, 150357.519144), -- Thread
(20801, 1876, 1, 1, 2, 15035.778648), -- Mithril Ore
(20801, 1895, 1, 1, 2, 21479.645592), -- Metallic Fiber
(20801, 4042, 1, 1, 2, 1253.003832), -- Enria
(20801, 2347, 1, 1, 2, 174.837744), -- Recipe: Akat Long Bow
(20801, 2351, 1, 1, 2, 157.193568), -- Recipe: Scorpion
(20801, 3010, 1, 1, 2, 2042.981712), -- Recipe: Composite Helmet
(20801, 6668, 1, 1, 2, 26849.623824), -- Deluxe Chest Key - Grade 4
(20801, 8724, 1, 1, 2, 2506.007664), -- Life Stone - Level 49
(20801, 8734, 1, 1, 2, 626.368248), -- Mid-Grade Life Stone - Level 49
(20801, 8744, 1, 1, 2, 62.556624), -- High-Grade Life Stone - Level 49
(20801, 8754, 1, 1, 2, 12.564792), -- Top-Grade Life Stone - Level 49
(20801, 1539, 1, 1, 2, 16706.361312), -- Greater Healing Potion
-- Theeder Mage
(20802, 2333, 1, 1, -1, 5213), -- Recipe: Sword of Nightmare
(20802, 1975, 1, 1, -1, 73621), -- Rind Leather Armor Design
(20802, 4039, 1, 1, -1, 74713), -- Mold Glue
(20802, 57, 885, 1804, 0, 700000), -- Adena
(20802, 325, 1, 1, 1, 44.93792), -- Horn of Glory
(20802, 2088, 1, 1, 1, 3499.06208), -- Horn of Glory Fragment
(20802, 1894, 1, 1, 2, 3167.794125), -- Crafted Leather
(20802, 4039, 1, 1, 2, 3009.373875), -- Mold Glue
(20802, 4041, 1, 1, 2, 784.974375), -- Mold Hardener
(20802, 4044, 1, 1, 2, 3009.373875), -- Thons
(20802, 737, 1, 1, 2, 9028.121625), -- Scroll of Resurrection
(20802, 2334, 1, 1, 2, 209.937375), -- Recipe: Sword of Whispering Death
(20802, 8724, 1, 1, 2, 3009.373875), -- Life Stone - Level 49
(20802, 8734, 1, 1, 2, 752.394375), -- Mid-Grade Life Stone - Level 49
(20802, 8744, 1, 1, 2, 75.137625), -- High-Grade Life Stone - Level 49
(20802, 8754, 1, 1, 2, 15.06825), -- Top-Grade Life Stone - Level 49
(20802, 1342, 10, 30, 2, 180563.450625), -- Steel Arrow
-- Doll Master
(20803, 4044, 1, 1, -1, 140295), -- Thons
(20803, 4042, 1, 1, -1, 70147), -- Enria
(20803, 4043, 1, 1, -1, 140295), -- Asofe
(20803, 57, 1665, 3384, 0, 700000), -- Adena
(20803, 231, 1, 1, 1, 26.339632), -- Grace Dagger
(20803, 2106, 1, 1, 1, 2371.660368), -- Grace Dagger Edge
(20803, 233, 1, 1, 1, 26.339632), -- Dark Screamer
(20803, 2107, 1, 1, 1, 2371.660368), -- Dark Screamer Edge
(20803, 1895, 1, 1, 2, 45208.083492), -- Metallic Fiber
(20803, 4040, 1, 1, 2, 3164.556486), -- Mold Lubricant
(20803, 4042, 1, 1, 2, 2637.141546), -- Enria
(20803, 4043, 1, 1, 2, 5274.283092), -- Asofe
(20803, 2356, 1, 1, 2, 258.092406), -- Recipe: Demon's Staff
(20803, 3014, 1, 1, 2, 4419.790674), -- Recipe: Full Plate Boots
(20803, 2360, 1, 1, 2, 258.092406), -- Recipe: Orcish Poleaxe
(20803, 8725, 1, 1, 2, 4395.258192), -- Life Stone - Level 52
(20803, 8735, 1, 1, 2, 1098.814548), -- Mid-Grade Life Stone - Level 52
(20803, 8745, 1, 1, 2, 109.894824), -- High-Grade Life Stone - Level 52
(20803, 8755, 1, 1, 2, 21.992334), -- Top-Grade Life Stone - Level 52
-- Crokian Lad
(20804, 2160, 1, 1, -1, 132104), -- Recipe: Moonstone Earring
(20804, 1953, 1, 1, -1, 65586), -- Sage's Rag Lining
(20804, 4470, 1, 1, -1, 11701), -- Dye of STR (Str+1 Dex-1)
(20804, 57, 830, 1660, 0, 700000), -- Adena
(20804, 630, 1, 1, 1, 433.844237), -- Square Shield
(20804, 1956, 1, 1, 1, 19450.782085), -- Square Shield Fragment
(20804, 2494, 1, 1, 1, 433.844237), -- Plate Shield
(20804, 2934, 1, 1, 1, 19450.782085), -- Plate Shield Fragment
(20804, 2412, 1, 1, 1, 303.814906), -- Plate Helmet
(20804, 2930, 1, 1, 1, 13813.93245), -- Plate Helmet Design
(20804, 1864, 1, 3, 2, 128526.768747), -- Stem
(20804, 1869, 1, 1, 2, 128526.768747), -- Iron Ore
(20804, 1878, 1, 1, 2, 51410.626969), -- Braided Hemp
(20804, 1884, 1, 1, 2, 79093.551017), -- Cord
(20804, 2207, 1, 1, 2, 3391.109878), -- Recipe: Karmian Tunic
(20804, 2298, 1, 1, 2, 561.292706), -- Recipe: Stormbringer
(20804, 5274, 1, 1, 2, 428.418536), -- Recipe: Greater Spiritshot (C) Compressed Package(100%)
(20804, 735, 1, 1, 2, 10710.4634), -- Alacrity Potion
-- Dailaon Lad
(20805, 2162, 1, 1, -1, 107039), -- Recipe: Aquastone Necklace
(20805, 2053, 1, 1, -1, 18321), -- Scallop Jamadhr Edge
(20805, 1905, 1, 1, -1, 215536), -- Omen Beast's Eye Earring Gemstone
(20805, 57, 892, 1803, 0, 700000), -- Adena
(20805, 159, 1, 1, 1, 16.045059), -- Bonebreaker
(20805, 2048, 1, 1, 1, 919.958238), -- Bonebreaker Head
(20805, 187, 1, 1, 1, 16.045059), -- Atuba Hammer
(20805, 2049, 1, 1, 1, 919.958238), -- Atuba Hammer Head
(20805, 188, 1, 1, 1, 16.045059), -- Ghost Staff
(20805, 2050, 1, 1, 1, 975.452391), -- Ghost Staff Head
(20805, 189, 1, 1, 1, 16.045059), -- Staff of Life
(20805, 2051, 1, 1, 1, 975.452391), -- Staff of Life Shaft
(20805, 190, 1, 1, 1, 16.045059), -- Atuba Mace
(20805, 2058, 1, 1, 1, 919.953447), -- Atuba Mace Head
(20805, 1895, 1, 1, 2, 63578.441477), -- Metallic Fiber
(20805, 2305, 1, 1, 2, 971.716607), -- Recipe: Crystal Staff
(20805, 2205, 1, 1, 2, 7041.871309), -- Recipe: Chain Gaiters
(20805, 5164, 1, 1, 2, 741.729002), -- Recipe: Blessed Spiritshot (C) Compressed Package (100%)
(20805, 6668, 1, 1, 2, 79473.241605), -- Deluxe Chest Key - Grade 4
-- Crokian Lad Warrior
(20806, 2204, 1, 1, -1, 42364), -- Recipe: Chain Mail Shirt
(20806, 2934, 1, 1, -1, 242834), -- Plate Shield Fragment
(20806, 1805, 1, 1, -1, 7131), -- Recipe: Soulshot (C-Grade)
(20806, 57, 846, 1718, 0, 700000), -- Adena
(20806, 70, 1, 1, 1, 38.730464), -- Claymore
(20806, 2047, 1, 1, 1, 2361.242336), -- Claymore Blade
(20806, 2499, 1, 1, 1, 38.730464), -- Elven Long Sword
(20806, 2967, 1, 1, 1, 2329.296736), -- Elven Long Sword Blade
(20806, 1865, 1, 1, 2, 153470.305536), -- Varnish
(20806, 1870, 1, 1, 2, 153470.305536), -- Coal
(20806, 1879, 1, 1, 2, 25578.384256), -- Cokes
(20806, 1875, 1, 1, 2, 10231.282856), -- Stone of Purity
(20806, 2999, 1, 1, 2, 10300.003864), -- Recipe: Plated Leather Gloves
(20806, 5159, 1, 1, 2, 511.511008), -- Recipe: Spiritshot (C) Compressed Package (100%)
(20806, 2300, 1, 1, 2, 670.206944), -- Recipe: Scythe
-- Farhite Lad
(20807, 2164, 1, 1, -1, 172878), -- Recipe: Ring of Protection
(20807, 1910, 1, 1, -1, 169233), -- Aquastone Necklace Chain
(20807, 1908, 1, 1, -1, 212824), -- Moonstone Earring Wire
(20807, 57, 885, 1813, 0, 700000), -- Adena
(20807, 439, 1, 1, 1, 182.50336), -- Karmian Tunic
(20807, 1962, 1, 1, 1, 8497.88197), -- Karmian Tunic Pattern
(20807, 471, 1, 1, 1, 291.67288), -- Karmian Stockings
(20807, 1954, 1, 1, 1, 14117.94179), -- Karmian Stocking Design
(20807, 1866, 1, 1, 2, 54469.790136), -- Suede
(20807, 1871, 1, 1, 2, 81704.603376), -- Charcoal
(20807, 5220, 1, 1, 2, 3268.21032), -- Metal Hardener
(20807, 1885, 1, 1, 2, 6808.744224), -- High-Grade Suede
(20807, 2221, 1, 1, 2, 2705.397336), -- Recipe: Rind Leather Gaiters
(20807, 737, 1, 1, 2, 8170.5258), -- Scroll of Resurrection
(20807, 2225, 1, 1, 2, 1776.158568), -- Recipe: Demon's Stockings
(20807, 2321, 1, 1, 2, 284.76144), -- Recipe: Stiletto
(20807, 2316, 1, 1, 2, 284.76144), -- Recipe: Katana
(20807, 8723, 1, 1, 2, 3268.21032), -- Life Stone - Level 46
(20807, 8733, 1, 1, 2, 816.970752), -- Mid-Grade Life Stone - Level 46
(20807, 8743, 1, 1, 2, 81.664344), -- High-Grade Life Stone - Level 46
(20807, 8753, 1, 1, 2, 16.201944), -- Top-Grade Life Stone - Level 46
-- Nos Lad
(20808, 1954, 1, 1, -1, 148174), -- Karmian Stocking Design
(20808, 2163, 1, 1, -1, 142201), -- Recipe: Earring of Protection
(20808, 1908, 1, 1, -1, 263934), -- Moonstone Earring Wire
(20808, 57, 1102, 2239, 0, 700000), -- Adena
(20808, 439, 1, 1, 1, 226.33104), -- Karmian Tunic
(20808, 1962, 1, 1, 1, 10538.624955), -- Karmian Tunic Pattern
(20808, 471, 1, 1, 1, 361.71732), -- Karmian Stockings
(20808, 1954, 1, 1, 1, 17508.326685), -- Karmian Stocking Design
(20808, 1894, 1, 1, 2, 4621.920054), -- Crafted Leather
(20808, 4039, 1, 1, 2, 4390.830931), -- Mold Glue
(20808, 4041, 1, 1, 2, 1145.401253), -- Mold Hardener
(20808, 4044, 1, 1, 2, 4390.830931), -- Thons
(20808, 2324, 1, 1, 2, 458.944787), -- Recipe: Noble Elven Bow
(20808, 6668, 1, 1, 2, 47044.695743), -- Deluxe Chest Key - Grade 4
(20808, 8723, 1, 1, 2, 5269.024636), -- Life Stone - Level 46
(20808, 8733, 1, 1, 2, 1317.256159), -- Mid-Grade Life Stone - Level 46
(20808, 8743, 1, 1, 2, 131.746255), -- High-Grade Life Stone - Level 46
(20808, 8753, 1, 1, 2, 26.349251), -- Top-Grade Life Stone - Level 46
-- Ghost of the Tower
(20809, 4439, 1, 1, -1, 340912), -- Avadon Shield Fragment
(20809, 4973, 1, 1, -1, 53498), -- Recipe: Earring of Black Ore (70%)
(20809, 4049, 1, 1, -1, 259282), -- Adamantite Earring Gemstone
(20809, 57, 1955, 3974, 0, 700000), -- Adena
(20809, 357, 1, 1, 1, 22.8717), -- Zubei's Breastplate
(20809, 4056, 1, 1, 1, 3304.520158), -- Zubei's Breastplate Part
(20809, 2376, 1, 1, 1, 22.8717), -- Avadon Breastplate
(20809, 4064, 1, 1, 1, 3304.520158), -- Avadon Breastplate Part
(20809, 383, 1, 1, 1, 36.59472), -- Zubei's Gaiters
(20809, 4057, 1, 1, 1, 5106.99648), -- Zubei's Gaiter Material
(20809, 2379, 1, 1, 1, 36.59472), -- Avadon Gaiters
(20809, 4065, 1, 1, 1, 5107.030364), -- Avadon Gaiters Material
(20809, 1868, 1, 1, 2, 243358.145793), -- Thread
(20809, 1873, 1, 1, 2, 48671.757603), -- Silver Nugget
(20809, 5549, 1, 1, 2, 12167.859123), -- Metallic Thread
(20809, 1889, 1, 1, 2, 8111.906082), -- Compound Braid
(20809, 4044, 1, 1, 2, 4055.953041), -- Thons
(20809, 4158, 1, 1, 2, 258.494355), -- Recipe: Doom Plate Armor (100%)
(20809, 4999, 1, 1, 2, 1513.396143), -- Recipe: Sealed Doom Boots (60%)
(20809, 4981, 1, 1, 2, 377.947647), -- Recipe: Blue Wolf Breastplate (60%)
(20809, 8728, 1, 1, 2, 2028.137076), -- Life Stone - Level 61
(20809, 8738, 1, 1, 2, 507.034269), -- Mid-Grade Life Stone - Level 61
(20809, 8748, 1, 1, 2, 50.735538), -- High-Grade Life Stone - Level 61
(20809, 8758, 1, 1, 2, 9.63333), -- Top-Grade Life Stone - Level 61
-- Hallate's Seer
(20810, 4109, 1, 1, -1, 27849), -- Kris Edge
(20810, 4974, 1, 1, -1, 80247), -- Recipe: Ring of Black Ore (70%)
(20810, 947, 1, 1, -1, 1977), -- Scroll: Enchant Weapon (B-Grade)
(20810, 57, 1955, 3974, 0, 700000), -- Adena
(20810, 91, 1, 1, 1, 10.92896), -- Heavy War Axe
(20810, 4105, 1, 1, 1, 2088.70585), -- Heavy War Axe Head
(20810, 92, 1, 1, 1, 10.92896), -- Sprite's Staff
(20810, 4106, 1, 1, 1, 2054.43623), -- Sprite's Staff Head
(20810, 1874, 1, 1, 2, 8849.375712), -- Oriharukon Ore
(20810, 1878, 1, 1, 2, 53096.577024), -- Braided Hemp
(20810, 1884, 1, 1, 2, 81687.078816), -- Cord
(20810, 1889, 1, 1, 2, 8849.375712), -- Compound Braid
(20810, 5220, 1, 1, 2, 5309.593152), -- Metal Hardener
(20810, 4159, 1, 1, 2, 376.00608), -- Recipe: Blue Wolf Leather Armor (100%)
(20810, 8728, 1, 1, 2, 2212.303584), -- Life Stone - Level 61
(20810, 8738, 1, 1, 2, 553.035552), -- Mid-Grade Life Stone - Level 61
(20810, 8748, 1, 1, 2, 55.351968), -- High-Grade Life Stone - Level 61
(20810, 8758, 1, 1, 2, 11.29632), -- Top-Grade Life Stone - Level 61
-- Ghastly Warrior
(20811, 947, 1, 1, -1, 2337), -- Scroll: Enchant Weapon (B-Grade)
(20811, 1875, 1, 1, -1, 389481), -- Stone of Purity
(20811, 4040, 1, 1, -1, 116844), -- Mold Lubricant
(20811, 57, 2315, 4695, 0, 700000), -- Adena
(20811, 78, 1, 1, 1, 8.610736), -- Great Sword
(20811, 4104, 1, 1, 1, 1645.721392), -- Great Sword Blade
(20811, 142, 1, 1, 1, 8.610736), -- Keshanberk
(20811, 4107, 1, 1, 1, 1620.2232), -- Keshanberk Blade
(20811, 148, 1, 1, 1, 8.610736), -- Sword of Valhalla
(20811, 4108, 1, 1, 1, 1620.2232), -- Sword of Valhalla Blade
(20811, 1865, 1, 1, 2, 132746.29155), -- Varnish
(20811, 1870, 1, 1, 2, 132746.29155), -- Coal
(20811, 1879, 1, 1, 2, 22124.327562), -- Cokes
(20811, 1875, 1, 1, 2, 8849.861496), -- Stone of Purity
(20811, 4040, 1, 1, 2, 2655.08892), -- Mold Lubricant
(20811, 4619, 1, 1, 2, 182.985858), -- Greater Dye of INT (Int+4 Men-4)
(20811, 4401, 1, 1, 2, 265.508892), -- Green Dimensional Stone
(20811, 4167, 1, 1, 2, 1651.113036), -- Recipe: Sealed Blue Wolf Boots (100%)
(20811, 6670, 1, 1, 2, 22124.327562), -- Deluxe Chest Key - Grade 6
(20811, 8728, 1, 1, 2, 2212.465374), -- Life Stone - Level 61
(20811, 8738, 1, 1, 2, 553.197888), -- Mid-Grade Life Stone - Level 61
(20811, 8748, 1, 1, 2, 55.45026), -- High-Grade Life Stone - Level 61
(20811, 8758, 1, 1, 2, 11.090052), -- Top-Grade Life Stone - Level 61
-- Archer of Despair
(20812, 1875, 1, 1, -1, 384494), -- Stone of Purity
(20812, 4617, 1, 1, -1, 7955), -- Greater Dye of DEX (Dex+4 Str-4)
(20812, 4613, 1, 1, -1, 7955), -- Greater Dye of STR (Str+4 Con-4)
(20812, 57, 2285, 4635, 0, 700000), -- Adena
(20812, 284, 1, 1, 1, 25.50048), -- Dark Elven Long Bow
(20812, 4112, 1, 1, 1, 4822.49952), -- Dark Elven Longbow Shaft
(20812, 1872, 1, 1, 2, 227147.342492), -- Animal Bone
(20812, 1867, 1, 1, 2, 227147.342492), -- Animal Skin
(20812, 1881, 1, 1, 2, 22714.931736), -- Coarse Bone Powder
(20812, 1875, 1, 1, 2, 11357.465868), -- Stone of Purity
(20812, 4041, 1, 1, 2, 1481.151), -- Mold Hardener
(20812, 4620, 1, 1, 2, 235.009292), -- Greater Dye of INT (Int+4 Wit-4)
(20812, 8728, 1, 1, 2, 2839.366467), -- Life Stone - Level 61
(20812, 8738, 1, 1, 2, 709.965046), -- Mid-Grade Life Stone - Level 61
(20812, 8748, 1, 1, 2, 71.095248), -- High-Grade Life Stone - Level 61
(20812, 8758, 1, 1, 2, 13.330359), -- Top-Grade Life Stone - Level 61
-- Crendion
(20813, 4982, 1, 1, -1, 26129), -- Recipe: Blue Wolf Gaiters (60%)
(20813, 4052, 1, 1, -1, 185940), -- Earring of Black Ore Piece
(20813, 5230, 1, 1, -1, 7003), -- Recipe: Mithril Arrow (100%)
(20813, 57, 2083, 4219, 0, 700000), -- Adena
(20813, 2398, 1, 1, 1, 20.885095), -- Blue Wolf Tunic
(20813, 4084, 1, 1, 1, 3371.22768), -- Blue Wolf Tunic Fabric
(20813, 2399, 1, 1, 1, 20.885095), -- Tunic of Doom
(20813, 4085, 1, 1, 1, 3371.22768), -- Tunic of Doom Pattern
(20813, 2403, 1, 1, 1, 33.44168), -- Blue Wolf Stockings
(20813, 4086, 1, 1, 1, 4551.92959), -- Blue Wolf Stockings Pattern
(20813, 2404, 1, 1, 1, 33.44168), -- Stockings of Doom
(20813, 4087, 1, 1, 1, 4551.9615), -- Stockings of Doom Pattern
(20813, 1872, 1, 1, 2, 206843.26846), -- Animal Bone
(20813, 1867, 1, 1, 2, 206843.26846), -- Animal Skin
(20813, 1881, 1, 1, 2, 20684.50668), -- Coarse Bone Powder
(20813, 1875, 1, 1, 2, 10342.25334), -- Stone of Purity
(20813, 4041, 1, 1, 2, 1348.755), -- Mold Hardener
(20813, 4620, 1, 1, 2, 214.00246), -- Greater Dye of INT (Int+4 Wit-4)
(20813, 8728, 1, 1, 2, 2585.563335), -- Life Stone - Level 61
(20813, 8738, 1, 1, 2, 646.50323), -- Mid-Grade Life Stone - Level 61
(20813, 8748, 1, 1, 2, 64.74024), -- High-Grade Life Stone - Level 61
(20813, 8758, 1, 1, 2, 12.138795), -- Top-Grade Life Stone - Level 61
-- Blader of Despair
(20814, 948, 1, 1, -1, 15160), -- Scroll: Enchant Armor (B-Grade)
(20814, 4053, 1, 1, -1, 259927), -- Ring of Black Ore Gemstone
(20814, 5230, 1, 1, -1, 8085), -- Recipe: Mithril Arrow (100%)
(20814, 57, 2405, 4872, 0, 700000), -- Adena
(20814, 601, 1, 1, 1, 72.368139), -- Sealed Doom Boots
(20814, 4099, 1, 1, 1, 10051.881861), -- Sealed Doom Boots Part
(20814, 2439, 1, 1, 1, 72.368139), -- Sealed Blue Wolf Boots
(20814, 4090, 1, 1, 1, 10051.881861), -- Sealed Blue Wolf Boots Design
(20814, 2475, 1, 1, 1, 72.368139), -- Sealed Doom Gloves
(20814, 4091, 1, 1, 1, 10051.881861), -- Sealed Doom Gloves Part
(20814, 2487, 1, 1, 1, 72.368139), -- Sealed Blue Wolf Gloves
(20814, 4096, 1, 1, 1, 10051.881861), -- Sealed Blue Wolf Gloves Fabric
(20814, 1871, 1, 1, 2, 162840.379804), -- Charcoal
(20814, 1866, 1, 1, 2, 108560.157567), -- Suede
(20814, 1877, 1, 1, 2, 6513.649621), -- Adamantite Nugget
(20814, 4041, 1, 1, 2, 1415.886045), -- Mold Hardener
(20814, 4040, 1, 1, 2, 3256.681357), -- Mold Lubricant
(20814, 4975, 1, 1, 2, 1323.788898), -- Recipe: Necklace of Black Ore (70%)
(20814, 5276, 1, 1, 2, 217.188599), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20814, 8729, 1, 1, 2, 2171.312176), -- Life Stone - Level 64
(20814, 8739, 1, 1, 2, 542.828044), -- Mid-Grade Life Stone - Level 64
(20814, 8749, 1, 1, 2, 54.225423), -- High-Grade Life Stone - Level 64
(20814, 8759, 1, 1, 2, 10.902466), -- Top-Grade Life Stone - Level 64
-- Hound Dog of Hallate
(20815, 4984, 1, 1, -1, 21315), -- Recipe: Blue Wolf Leather Armor (60%)
(20815, 4054, 1, 1, -1, 148200), -- Necklace of Black Ore Beads
(20815, 4052, 1, 1, -1, 266388), -- Earring of Black Ore Piece
(20815, 57, 2984, 6042, 0, 700000), -- Adena
(20815, 2391, 1, 1, 1, 36.831996), -- Blue Wolf Leather Armor
(20815, 4082, 1, 1, 1, 6278.668004), -- Blue Wolf Leather Armor Texture
(20815, 2392, 1, 1, 1, 36.831996), -- Leather Armor of Doom
(20815, 4083, 1, 1, 1, 6278.668004), -- Leather Armor of Doom Design
(20815, 1870, 1, 1, 2, 202046.298342), -- Coal
(20815, 1865, 1, 1, 2, 202046.298342), -- Varnish
(20815, 1874, 1, 1, 2, 13469.971767), -- Oriharukon Ore
(20815, 4043, 1, 1, 2, 6734.751729), -- Asofe
(20815, 4039, 1, 1, 2, 6734.751729), -- Mold Glue
(20815, 5000, 1, 1, 2, 154.073661), -- Recipe: Sword of Damascus (60%)
(20815, 6670, 1, 1, 2, 33674.226954), -- Deluxe Chest Key - Grade 6
(20815, 8729, 1, 1, 2, 2694.181677), -- Life Stone - Level 64
(20815, 8739, 1, 1, 2, 673.428342), -- Mid-Grade Life Stone - Level 64
(20815, 8749, 1, 1, 2, 67.436496), -- High-Grade Life Stone - Level 64
(20815, 8759, 1, 1, 2, 13.580961), -- Top-Grade Life Stone - Level 64
-- Hallate's Royal Guard
(20816, 947, 1, 1, -1, 2511), -- Scroll: Enchant Weapon (B-Grade)
(20816, 4039, 1, 1, -1, 209252), -- Mold Glue
(20816, 5230, 1, 1, -1, 8370), -- Recipe: Mithril Arrow (100%)
(20816, 57, 2490, 5041, 0, 700000), -- Adena
(20816, 2391, 1, 1, 1, 30.731724), -- Blue Wolf Leather Armor
(20816, 4082, 1, 1, 1, 5238.768276), -- Blue Wolf Leather Armor Texture
(20816, 2392, 1, 1, 1, 30.731724), -- Leather Armor of Doom
(20816, 4083, 1, 1, 1, 5238.768276), -- Leather Armor of Doom Design
(20816, 1864, 1, 3, 2, 154524.632885), -- Stem
(20816, 1869, 1, 1, 2, 154524.632885), -- Iron Ore
(20816, 1878, 1, 1, 2, 61809.853154), -- Braided Hemp
(20816, 1884, 1, 1, 2, 95092.337207), -- Cord
(20816, 4039, 1, 1, 2, 5150.742034), -- Mold Glue
(20816, 5001, 1, 1, 2, 118.118877), -- Recipe: Lance (60%)
(20816, 4402, 1, 1, 2, 308.816823), -- Blue Dimensional Stone
(20816, 5276, 1, 1, 2, 205.877882), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20816, 8729, 1, 1, 2, 2060.201939), -- Life Stone - Level 64
(20816, 8739, 1, 1, 2, 515.169078), -- Mid-Grade Life Stone - Level 64
(20816, 8749, 1, 1, 2, 51.706657), -- High-Grade Life Stone - Level 64
(20816, 8759, 1, 1, 2, 10.910579), -- Top-Grade Life Stone - Level 64
-- Corrupt Sage
(20817, 4040, 1, 1, -1, 121827), -- Mold Lubricant
(20817, 4053, 1, 1, -1, 261096), -- Ring of Black Ore Gemstone
(20817, 5230, 1, 1, -1, 8122), -- Recipe: Mithril Arrow (100%)
(20817, 57, 2418, 4891, 0, 700000), -- Adena
(20817, 268, 1, 1, 1, 17.829735), -- Bellion Cestus
(20817, 4120, 1, 1, 1, 3931.170265), -- Bellion Cestus Edge
(20817, 1865, 1, 1, 2, 163572.416002), -- Varnish
(20817, 1870, 1, 1, 2, 163572.416002), -- Coal
(20817, 1879, 1, 1, 2, 27262.006858), -- Cokes
(20817, 1875, 1, 1, 2, 10904.877714), -- Stone of Purity
(20817, 4040, 1, 1, 2, 3271.350858), -- Mold Lubricant
(20817, 4174, 1, 1, 2, 3151.772432), -- Recipe: Sealed Zubei's Boots (100%)
(20817, 4402, 1, 1, 2, 327.247542), -- Blue Dimensional Stone
(20817, 8729, 1, 1, 2, 2180.900572), -- Life Stone - Level 64
(20817, 8739, 1, 1, 2, 545.41257), -- Mid-Grade Life Stone - Level 64
(20817, 8749, 1, 1, 2, 54.35383), -- High-Grade Life Stone - Level 64
(20817, 8759, 1, 1, 2, 11.24562), -- Top-Grade Life Stone - Level 64
-- Hallate's Warrior
(20818, 4620, 1, 1, -1, 8386), -- Greater Dye of INT (Int+4 Wit-4)
(20818, 4105, 1, 1, -1, 34790), -- Heavy War Axe Head
(20818, 4077, 1, 1, -1, 273487), -- Doom Shield Fragment
(20818, 57, 2414, 4882, 0, 700000), -- Adena
(20818, 287, 1, 1, 1, 17.79384), -- Bow of Peril
(20818, 4121, 1, 1, 1, 3910.20616), -- Bow of Peril Shaft
(20818, 1866, 1, 1, 2, 92093.780216), -- Suede
(20818, 1871, 1, 1, 2, 138140.670324), -- Charcoal
(20818, 5220, 1, 1, 2, 5525.636983), -- Metal Hardener
(20818, 1885, 1, 1, 2, 11511.722527), -- High-Grade Suede
(20818, 4041, 1, 1, 2, 1201.335975), -- Mold Hardener
(20818, 4958, 1, 1, 2, 2661.753719), -- Recipe: Sealed Zubei's Boots (60%)
(20818, 4401, 1, 1, 2, 276.370837), -- Green Dimensional Stone
(20818, 5276, 1, 1, 2, 184.077724), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20818, 5416, 1, 1, 2, 298.236423), -- Recipe: Sealed Dark Crystal Breastplate(60%)
(20818, 8729, 1, 1, 2, 1841.794244), -- Life Stone - Level 64
(20818, 8739, 1, 1, 2, 460.448561), -- Mid-Grade Life Stone - Level 64
(20818, 8749, 1, 1, 2, 46.019431), -- High-Grade Life Stone - Level 64
(20818, 8759, 1, 1, 2, 9.153036), -- Top-Grade Life Stone - Level 64
-- Archer of Abyss
(20819, 4053, 1, 1, -1, 259498), -- Ring of Black Ore Gemstone
(20819, 5230, 1, 1, -1, 8072), -- Recipe: Mithril Arrow (100%)
(20819, 4078, 1, 1, -1, 88433), -- Blue Wolf Breastplate Part
(20819, 57, 2399, 4864, 0, 700000), -- Adena
(20819, 171, 1, 1, 1, 5.907392), -- Deadman's Glory
(20819, 4116, 1, 1, 1, 1302.240608), -- Deadman's Glory Stone
(20819, 175, 1, 1, 1, 5.907392), -- Art of Battle Axe
(20819, 4117, 1, 1, 1, 1302.240608), -- Art of Battle Axe Blade
(20819, 210, 1, 1, 1, 5.907392), -- Staff of Evil Spirits
(20819, 4118, 1, 1, 1, 1233.796608), -- Evil Spirit Head
(20819, 1874, 1, 1, 2, 9934.89608), -- Oriharukon Ore
(20819, 1878, 1, 1, 2, 59609.918088), -- Braided Hemp
(20819, 1884, 1, 1, 2, 91707.413528), -- Cord
(20819, 1889, 1, 1, 2, 9934.89608), -- Compound Braid
(20819, 5220, 1, 1, 2, 5960.937648), -- Metal Hardener
(20819, 4159, 1, 1, 2, 422.093168), -- Recipe: Blue Wolf Leather Armor (100%)
(20819, 4402, 1, 1, 2, 298.064936), -- Blue Dimensional Stone
(20819, 730, 1, 1, 2, 124.208768), -- Scroll: Enchant Armor (A-Grade)
(20819, 8729, 1, 1, 2, 1986.979216), -- Life Stone - Level 64
(20819, 8739, 1, 1, 2, 496.835072), -- Mid-Grade Life Stone - Level 64
(20819, 8749, 1, 1, 2, 49.6474), -- High-Grade Life Stone - Level 64
(20819, 8759, 1, 1, 2, 10.110016), -- Top-Grade Life Stone - Level 64
-- Hallate's Knight
(20820, 4080, 1, 1, -1, 214391), -- Blue Wolf Gaiters Material
(20820, 5230, 1, 1, -1, 13897), -- Recipe: Mithril Arrow (100%)
(20820, 4054, 1, 1, -1, 205291), -- Necklace of Black Ore Beads
(20820, 57, 4130, 8374, 0, 700000), -- Adena
(20820, 864, 1, 1, 1, 144.335385), -- Earring of Black Ore
(20820, 4052, 1, 1, 1, 18165.45798), -- Earring of Black Ore Piece
(20820, 926, 1, 1, 1, 108.264222), -- Necklace of Black Ore
(20820, 4054, 1, 1, 1, 10106.0136), -- Necklace of Black Ore Beads
(20820, 895, 1, 1, 1, 216.477711), -- Ring of Black Ore
(20820, 4053, 1, 1, 1, 21992.451102), -- Ring of Black Ore Gemstone
(20820, 1867, 1, 3, 2, 171038.026143), -- Animal Skin
(20820, 1872, 1, 3, 2, 114025.350762), -- Animal Bone
(20820, 1882, 1, 1, 2, 57012.675381); -- Leather

INSERT INTO `droplist` VALUES
(20820, 1894, 1, 1, 2, 9002.077521), -- Crafted Leather
(20820, 4042, 1, 1, 2, 4275.887358), -- Enria
(20820, 4160, 1, 1, 2, 726.633201), -- Recipe: Leather Armor of Doom (100%)
(20820, 5276, 1, 1, 2, 342.157794), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20820, 5424, 1, 1, 2, 887.584806), -- Recipe: Sealed Dark Crystal Gaiters(60%)
(20820, 8729, 1, 1, 2, 3420.854562), -- Life Stone - Level 64
(20820, 8739, 1, 1, 2, 855.032796), -- Mid-Grade Life Stone - Level 64
(20820, 8749, 1, 1, 2, 85.358604), -- High-Grade Life Stone - Level 64
(20820, 8759, 1, 1, 2, 17.361072), -- Top-Grade Life Stone - Level 64
-- Erin Ediunce
(20821, 4084, 1, 1, -1, 142125), -- Blue Wolf Tunic Fabric
(20821, 4080, 1, 1, -1, 168217), -- Blue Wolf Gaiters Material
(20821, 1894, 1, 1, -1, 286943), -- Crafted Leather
(20821, 57, 3240, 6570, 0, 700000), -- Adena
(20821, 97, 1, 1, 1, 23.935716), -- Lance
(20821, 4115, 1, 1, 1, 5268.064284), -- Lance Blade
(20821, 1867, 1, 3, 2, 146401.197624), -- Animal Skin
(20821, 1872, 1, 3, 2, 97600.695624), -- Animal Bone
(20821, 1882, 1, 1, 2, 48800.502), -- Leather
(20821, 1894, 1, 1, 2, 7705.391112), -- Crafted Leather
(20821, 4042, 1, 1, 2, 3660.114744), -- Enria
(20821, 4195, 1, 1, 2, 167.756544), -- Recipe: Art of Battle Axe (100%)
(20821, 5276, 1, 1, 2, 292.648824), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20821, 8729, 1, 1, 2, 2928.03012), -- Life Stone - Level 64
(20821, 8739, 1, 1, 2, 732.084624), -- Mid-Grade Life Stone - Level 64
(20821, 8749, 1, 1, 2, 73.085112), -- High-Grade Life Stone - Level 64
(20821, 8759, 1, 1, 2, 14.493672), -- Top-Grade Life Stone - Level 64
-- Hallate's Maid
(20822, 1894, 1, 1, -1, 288329), -- Crafted Leather
(20822, 1889, 1, 1, -1, 547825), -- Compound Braid
(20822, 4077, 1, 1, -1, 369652), -- Doom Shield Fragment
(20822, 57, 3255, 6602, 0, 700000), -- Adena
(20822, 97, 1, 1, 1, 24.053314), -- Lance
(20822, 4115, 1, 1, 1, 5293.946686), -- Lance Blade
(20822, 1868, 1, 3, 2, 202273.626555), -- Thread
(20822, 1873, 1, 1, 2, 80909.450622), -- Silver Nugget
(20822, 5549, 1, 1, 2, 20227.181975), -- Metallic Thread
(20822, 1889, 1, 1, 2, 13484.908437), -- Compound Braid
(20822, 4044, 1, 1, 2, 6742.273538), -- Thons
(20822, 4196, 1, 1, 2, 154.301147), -- Recipe: Staff of Evil Spirits (100%)
(20822, 4402, 1, 1, 2, 404.72432), -- Blue Dimensional Stone
(20822, 6670, 1, 1, 2, 33712.090412), -- Deluxe Chest Key - Grade 6
(20822, 8729, 1, 1, 2, 2696.837143), -- Life Stone - Level 64
(20822, 8739, 1, 1, 2, 674.299626), -- Mid-Grade Life Stone - Level 64
(20822, 8749, 1, 1, 2, 67.574507), -- High-Grade Life Stone - Level 64
(20822, 8759, 1, 1, 2, 13.731718), -- Top-Grade Life Stone - Level 64
-- Platinum Tribe Soldier
(20823, 4088, 1, 1, -1, 343233), -- Blue Wolf Helmet Design
(20823, 4089, 1, 1, -1, 343233), -- Doom Helmet Pattern
(20823, 5416, 1, 1, -1, 19615), -- Recipe: Sealed Dark Crystal Breastplate(60%)
(20823, 57, 3580, 7317, 0, 700000), -- Adena
(20823, 2398, 1, 1, 1, 36.11531), -- Blue Wolf Tunic
(20823, 4084, 1, 1, 1, 5829.65664), -- Blue Wolf Tunic Fabric
(20823, 2399, 1, 1, 1, 36.11531), -- Tunic of Doom
(20823, 4085, 1, 1, 1, 5829.65664), -- Tunic of Doom Pattern
(20823, 2403, 1, 1, 1, 57.82864), -- Blue Wolf Stockings
(20823, 4086, 1, 1, 1, 7871.37182), -- Blue Wolf Stockings Pattern
(20823, 2404, 1, 1, 1, 57.82864), -- Stockings of Doom
(20823, 4087, 1, 1, 1, 7871.427), -- Stockings of Doom Pattern
(20823, 1869, 1, 1, 2, 223555.158436), -- Iron Ore
(20823, 1864, 1, 3, 2, 223555.158436), -- Stem
(20823, 1880, 1, 1, 2, 22355.467452), -- Steel
(20823, 5550, 1, 1, 2, 2980.92256), -- Durable Metal Plate
(20823, 4043, 1, 1, 2, 7451.822484), -- Asofe
(20823, 4616, 1, 1, 2, 308.254492), -- Greater Dye of CON (Con+4 Dex-4)
(20823, 4402, 1, 1, 2, 447.138384), -- Blue Dimensional Stone
(20823, 8316, 1, 1, 2, 82.749636), -- Recipe: Flaming Dragon Skull (60%)
(20823, 8730, 1, 1, 2, 2483.940828), -- Life Stone - Level 67
(20823, 8740, 1, 1, 2, 620.864228), -- Mid-Grade Life Stone - Level 67
(20823, 8750, 1, 1, 2, 61.941248), -- High-Grade Life Stone - Level 67
(20823, 8760, 1, 1, 2, 12.581816), -- Top-Grade Life Stone - Level 67
-- Hallate's Commander
(20824, 4081, 1, 1, -1, 84768), -- Doom Plate Armor Temper
(20824, 5424, 1, 1, -1, 29760), -- Recipe: Sealed Dark Crystal Gaiters(60%)
(20824, 4078, 1, 1, -1, 125629), -- Blue Wolf Breastplate Part
(20824, 57, 3391, 6929, 0, 700000), -- Adena
(20824, 864, 1, 1, 1, 119.10308), -- Earring of Black Ore
(20824, 4052, 1, 1, 1, 14989.82384), -- Earring of Black Ore Piece
(20824, 926, 1, 1, 1, 89.337776), -- Necklace of Black Ore
(20824, 4054, 1, 1, 1, 8339.3088), -- Necklace of Black Ore Beads
(20824, 895, 1, 1, 1, 178.633688), -- Ring of Black Ore
(20824, 4053, 1, 1, 1, 18147.792816), -- Ring of Black Ore Gemstone
(20824, 1870, 1, 1, 2, 211706.202438), -- Coal
(20824, 1865, 1, 1, 2, 211706.202438), -- Varnish
(20824, 1874, 1, 1, 2, 14113.931742), -- Oriharukon Ore
(20824, 4043, 1, 1, 2, 7056.73473), -- Asofe
(20824, 4039, 1, 1, 2, 7056.73473), -- Mold Glue
(20824, 4617, 1, 1, 2, 292.162224), -- Greater Dye of DEX (Dex+4 Str-4)
(20824, 5276, 1, 1, 2, 282.454302), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20824, 8730, 1, 1, 2, 2352.090816), -- Life Stone - Level 67
(20824, 8740, 1, 1, 2, 588.022704), -- Mid-Grade Life Stone - Level 67
(20824, 8750, 1, 1, 2, 58.709814), -- High-Grade Life Stone - Level 67
(20824, 8760, 1, 1, 2, 11.55705), -- Top-Grade Life Stone - Level 67
(20824, 6036, 1, 1, 2, 7057.197012), -- Greater Magic Haste Potion
-- Hallate's Inspector
(20825, 1876, 1, 3, -1, 901136), -- Mithril Ore
(20825, 1807, 1, 1, -1, 12015), -- Recipe: Soulshot (A-Grade)
(20825, 57, 3565, 7246, 0, 700000), -- Adena
(20825, 5292, 1, 1, 1, 94.89672), -- Sealed Dark Crystal Shield
(20825, 5494, 1, 1, 1, 9316.508745), -- Sealed Dark Crystal Shield Fragment
(20825, 5289, 1, 1, 1, 66.404445), -- Sealed Dark Crystal Helmet
(20825, 5525, 1, 1, 1, 6857.404452), -- Sealed Dark Crystal Helmet Design
(20825, 5294, 1, 1, 1, 66.404445), -- Sealed Tallum Helmet
(20825, 5526, 1, 1, 1, 6857.381193), -- Sealed Tallum Helm Design
(20825, 1871, 1, 1, 2, 241983.002954), -- Charcoal
(20825, 1866, 1, 1, 2, 161321.860029), -- Suede
(20825, 1877, 1, 1, 2, 9679.337151), -- Adamantite Nugget
(20825, 4041, 1, 1, 2, 2104.407382), -- Mold Hardener
(20825, 4040, 1, 1, 2, 4839.455665), -- Mold Lubricant
(20825, 4975, 1, 1, 2, 1967.29302), -- Recipe: Necklace of Black Ore (70%)
(20825, 4402, 1, 1, 2, 484.158477), -- Blue Dimensional Stone
(20825, 8730, 1, 1, 2, 2688.633794), -- Life Stone - Level 67
(20825, 8740, 1, 1, 2, 672.371359), -- Mid-Grade Life Stone - Level 67
(20825, 8750, 1, 1, 2, 67.279718), -- High-Grade Life Stone - Level 67
(20825, 8760, 1, 1, 2, 13.200451), -- Top-Grade Life Stone - Level 67
-- Platinum Tribe Archer
(20826, 5478, 1, 1, -1, 68984), -- Sealed Dark Crystal Leather Armor Pattern
(20826, 4041, 1, 1, -1, 71335), -- Mold Hardener
(20826, 57, 3245, 6597, 0, 700000), -- Adena
(20826, 5287, 1, 1, 1, 22.675824), -- Sealed Dark Crystal breastplate
(20826, 5520, 1, 1, 1, 2604.474288), -- Sealed Dark Crystal Breastplate Pattern
(20826, 5293, 1, 1, 1, 13.958928), -- Sealed Tallum Plate Armor
(20826, 5521, 1, 1, 1, 1837.820736), -- Sealed Tallum Plate Armor Pattern
(20826, 5288, 1, 1, 1, 36.286416), -- Sealed Dark Crystal Gaiters
(20826, 5524, 1, 1, 1, 3980.783808), -- Sealed Dark Crystal Gaiters Pattern
(20826, 1872, 1, 3, 2, 134622.2047), -- Animal Bone
(20826, 1867, 1, 1, 2, 269243.924205), -- Animal Skin
(20826, 1881, 1, 1, 2, 26924.44094), -- Coarse Bone Powder
(20826, 1875, 1, 1, 2, 13462.22047), -- Stone of Purity
(20826, 4041, 1, 1, 2, 1755.920705), -- Mold Hardener
(20826, 4980, 1, 1, 2, 2389.585375), -- Recipe: Doom Shield (60%)
(20826, 3956, 1, 1, 2, 269.283225), -- Recipe: Blessed Spiritshot A
(20826, 6670, 1, 1, 2, 33655.551175), -- Deluxe Chest Key - Grade 6
(20826, 8730, 1, 1, 2, 2243.54168), -- Life Stone - Level 67
(20826, 8740, 1, 1, 2, 560.88542), -- Mid-Grade Life Stone - Level 67
(20826, 8750, 1, 1, 2, 56.28262), -- High-Grade Life Stone - Level 67
(20826, 8760, 1, 1, 2, 11.159485), -- Top-Grade Life Stone - Level 67
-- Platinum Tribe Warrior
(20827, 4117, 1, 1, -1, 43680), -- Art of Battle Axe Blade
(20827, 4118, 1, 1, -1, 41384), -- Evil Spirit Head
(20827, 3035, 1, 1, -1, 13328), -- Recipe: Spiritshot A
(20827, 57, 3956, 8034, 0, 700000), -- Adena
(20827, 5297, 1, 1, 1, 36.849111), -- Sealed Dark Crystal Leather Armor
(20827, 5478, 1, 1, 1, 4137.935191), -- Sealed Dark Crystal Leather Armor Pattern
(20827, 5301, 1, 1, 1, 22.666917), -- Sealed Tallum Leather Armor
(20827, 5479, 1, 1, 1, 2911.735593), -- Sealed Tallum Leather Armor Pattern
(20827, 5298, 1, 1, 1, 58.928519), -- Sealed Dark Crystal Leggings
(20827, 5482, 1, 1, 1, 6494.884669), -- Sealed Dark Crystal Leggings Design
(20827, 1873, 1, 1, 2, 98421.399072), -- Silver Nugget
(20827, 1868, 1, 3, 2, 246053.972032), -- Thread
(20827, 1876, 1, 1, 2, 49210.699536), -- Mithril Ore
(20827, 1895, 1, 1, 2, 70300.863808), -- Metallic Fiber
(20827, 4042, 1, 1, 2, 4100.77304), -- Enria
(20827, 4990, 1, 1, 2, 2033.547024), -- Recipe: Blue Wolf Helmet (60%)
(20827, 4402, 1, 1, 2, 491.903024), -- Blue Dimensional Stone
(20827, 5420, 1, 1, 2, 239.073408), -- Recipe: Sealed Armor of Nightmare(60%)
(20827, 8730, 1, 1, 2, 2734.164928), -- Life Stone - Level 67
(20827, 8740, 1, 1, 2, 683.541232), -- Mid-Grade Life Stone - Level 67
(20827, 8750, 1, 1, 2, 68.306688), -- High-Grade Life Stone - Level 67
(20827, 8760, 1, 1, 2, 13.756208), -- Top-Grade Life Stone - Level 67
-- Platinum Tribe Shaman
(20828, 4120, 1, 1, -1, 49809), -- Bellion Cestus Edge
(20828, 4121, 1, 1, -1, 49642), -- Bow of Peril Shaft
(20828, 5479, 1, 1, -1, 67447), -- Sealed Tallum Leather Armor Pattern
(20828, 57, 4508, 9172, 0, 700000), -- Adena
(20828, 5304, 1, 1, 1, 42.01926), -- Sealed Tallum Tunic
(20828, 5485, 1, 1, 1, 4718.51206), -- Sealed Tallum Tunic Texture
(20828, 5308, 1, 1, 1, 25.84722), -- Sealed Dark Crystal Robe
(20828, 5486, 1, 1, 1, 3320.26938), -- Sealed Dark Crystal Robe Fabric
(20828, 5305, 1, 1, 1, 67.19654), -- Sealed Tallum Stockings
(20828, 5489, 1, 1, 1, 7406.15554), -- Sealed Tallum Stockings Fabric
(20828, 1864, 3, 9, 2, 112232.24376), -- Stem
(20828, 1869, 2, 6, 2, 84174.084064), -- Iron Ore
(20828, 1878, 1, 1, 2, 134678.692512), -- Braided Hemp
(20828, 1884, 2, 6, 2, 41439.597696), -- Cord
(20828, 4039, 1, 1, 2, 11223.421888), -- Mold Glue
(20828, 4177, 1, 1, 2, 6487.479152), -- Recipe: Sealed Zubei's Gauntlets (100%)
(20828, 8730, 1, 1, 2, 3741.272304), -- Life Stone - Level 67
(20828, 8740, 1, 1, 2, 935.416832), -- Mid-Grade Life Stone - Level 67
(20828, 8750, 1, 1, 2, 93.620688), -- High-Grade Life Stone - Level 67
(20828, 8760, 1, 1, 2, 18.171104), -- Top-Grade Life Stone - Level 67
-- Platinum Tribe Overlord
(20829, 1894, 1, 1, -1, 428952), -- Crafted Leather
(20829, 5550, 1, 1, -1, 163002), -- Durable Metal Plate
(20829, 5479, 1, 1, -1, 72338), -- Sealed Tallum Leather Armor Pattern
(20829, 57, 6033, 12296, 0, 700000), -- Adena
(20829, 5287, 1, 1, 1, 42.242263), -- Sealed Dark Crystal breastplate
(20829, 5520, 1, 1, 1, 4851.814331), -- Sealed Dark Crystal Breastplate Pattern
(20829, 5293, 1, 1, 1, 26.003761), -- Sealed Tallum Plate Armor
(20829, 5521, 1, 1, 1, 3423.633332), -- Sealed Tallum Plate Armor Pattern
(20829, 5288, 1, 1, 1, 67.597117), -- Sealed Dark Crystal Gaiters
(20829, 5524, 1, 1, 1, 7415.709196), -- Sealed Dark Crystal Gaiters Pattern
(20829, 1871, 1, 3, 2, 205177.152999), -- Charcoal
(20829, 1866, 1, 3, 2, 91189.972587), -- Suede
(20829, 1877, 1, 1, 2, 16414.370063), -- Adamantite Nugget
(20829, 4041, 1, 1, 2, 3568.42402), -- Mold Hardener
(20829, 4040, 1, 1, 2, 8206.994817), -- Mold Lubricant
(20829, 4129, 1, 1, 2, 4441.128146), -- Recipe: Earrings of Black Ore (100%)
(20829, 6671, 1, 1, 2, 45594.796079), -- Deluxe Chest Key - Grade 7
(20829, 8730, 1, 1, 2, 4559.441565), -- Life Stone - Level 67
(20829, 8740, 1, 1, 2, 1139.765284), -- Mid-Grade Life Stone - Level 67
(20829, 8750, 1, 1, 2, 114.1287), -- High-Grade Life Stone - Level 67
(20829, 8760, 1, 1, 2, 22.82574), -- Top-Grade Life Stone - Level 67
-- Zaken's Pikeman
(20832, 5231, 1, 1, -1, 77593), -- Recipe: Metal Hardener (100%)
(20832, 1902, 1, 1, -1, 110061), -- Elven Earring Beads
(20832, 1825, 1, 1, -1, 77593), -- Recipe: Oriharukon
(20832, 57, 430, 872, 0, 700000), -- Adena
(20832, 1125, 1, 1, 1, 120.896793), -- Assault Boots
(20832, 1957, 1, 1, 1, 5073.582429), -- Assault Boots Part
(20832, 2427, 1, 1, 1, 120.896793), -- Salamander Skin Boots
(20832, 2931, 1, 1, 1, 5073.582429), -- Salamander Skin Boot Lining
(20832, 2428, 1, 1, 1, 120.896793), -- Plate Boots
(20832, 2932, 1, 1, 1, 5073.582429), -- Plate Boots Design
(20832, 61, 1, 1, 1, 120.896793), -- Mithril Plate Gloves
(20832, 1949, 1, 1, 1, 5073.582429), -- Mithril Gloves Design
(20832, 607, 1, 1, 1, 120.896793), -- Ogre Power Gauntlets
(20832, 1963, 1, 1, 1, 5073.582429), -- Ogre Power Gauntlets Part
(20832, 2451, 1, 1, 1, 120.896793), -- Sage's Worn Gloves
(20832, 2933, 1, 1, 1, 5073.707097), -- Sage's Worn Gloves Lining
(20832, 1865, 1, 1, 2, 77927.242414), -- Varnish
(20832, 1870, 1, 1, 2, 77927.242414), -- Coal
(20832, 1879, 1, 1, 2, 12987.844002), -- Cokes
(20832, 1875, 1, 1, 2, 5195.06624), -- Stone of Purity
(20832, 2162, 1, 1, 2, 3764.639004), -- Recipe: Aquastone Necklace
(20832, 5159, 1, 1, 2, 259.753312), -- Recipe: Spiritshot (C) Compressed Package (100%)
(20832, 2312, 1, 1, 2, 340.212614), -- Recipe: Crystallized Ice Bow
-- Zaken's Archer
(20833, 1874, 1, 1, -1, 80465), -- Oriharukon Ore
(20833, 1875, 1, 1, -1, 80465), -- Stone of Purity
(20833, 1905, 1, 1, -1, 117410), -- Omen Beast's Eye Earring Gemstone
(20833, 57, 475, 974, 0, 700000), -- Adena
(20833, 281, 1, 1, 1, 32.34978), -- Crystallized Ice Bow
(20833, 2074, 1, 1, 1, 2019.65022), -- Crystallized Ice Bow Shaft
(20833, 1872, 1, 1, 2, 69143.4744), -- Animal Bone
(20833, 1867, 1, 1, 2, 69143.4744), -- Animal Skin
(20833, 1881, 1, 1, 2, 6914.34744), -- Coarse Bone Powder
(20833, 1875, 1, 1, 2, 3457.17372), -- Stone of Purity
(20833, 2209, 1, 1, 2, 3899.03976), -- Recipe: Eldarake
(20833, 2205, 1, 1, 2, 1641.01476), -- Recipe: Chain Gaiters
(20833, 2299, 1, 1, 2, 226.50936), -- Recipe: Big Hammer
(20833, 8723, 1, 1, 2, 2074.2414), -- Life Stone - Level 46
(20833, 8733, 1, 1, 2, 518.52108), -- Mid-Grade Life Stone - Level 46
(20833, 8743, 1, 1, 2, 51.8364), -- High-Grade Life Stone - Level 46
(20833, 8753, 1, 1, 2, 10.36728), -- Top-Grade Life Stone - Level 46
-- Mardian
(20834, 1878, 1, 1, -1, 714983), -- Braided Hemp
(20834, 1885, 1, 1, -1, 148955), -- High-Grade Suede
(20834, 1805, 1, 1, -1, 5958), -- Recipe: Soulshot (C-Grade)
(20834, 57, 720, 1455, 0, 700000), -- Adena
(20834, 353, 1, 1, 1, 149.199147), -- Half Plate Armor
(20834, 1950, 1, 1, 1, 7283.399643), -- Half Plate Temper
(20834, 380, 1, 1, 1, 238.722435), -- Plate Gaiters
(20834, 1951, 1, 1, 1, 11327.678775), -- Plate Gaiters Part
(20834, 1864, 1, 3, 2, 112197.458058), -- Stem
(20834, 1869, 1, 1, 2, 112197.458058), -- Iron Ore
(20834, 1878, 1, 1, 2, 44879.216118), -- Braided Hemp
(20834, 1884, 1, 1, 2, 69044.768724), -- Cord
(20834, 2306, 1, 1, 2, 489.855396), -- Recipe: Stick of Faith
(20834, 5274, 1, 1, 2, 374.184312), -- Recipe: Greater Spiritshot (C) Compressed Package(100%)
(20834, 2996, 1, 1, 2, 8904.732678), -- Recipe: Chain Gloves
(20834, 6668, 1, 1, 2, 40070.326656), -- Deluxe Chest Key - Grade 4
-- Zaken's Seer
(20835, 1871, 1, 3, -1, 495145), -- Charcoal
(20835, 1879, 1, 1, -1, 165048), -- Cokes
(20835, 1906, 1, 1, -1, 136122), -- Mithril Ring Wire
(20835, 57, 392, 796, 0, 700000), -- Adena
(20835, 439, 1, 1, 1, 80.415296), -- Karmian Tunic
(20835, 1962, 1, 1, 1, 3744.367742), -- Karmian Tunic Pattern
(20835, 471, 1, 1, 1, 128.517968), -- Karmian Stockings
(20835, 1954, 1, 1, 1, 6220.698994), -- Karmian Stocking Design
(20835, 1865, 1, 1, 2, 33430.627448), -- Varnish
(20835, 1870, 1, 1, 2, 33430.627448), -- Coal
(20835, 1879, 1, 1, 2, 5571.743839), -- Cokes
(20835, 1875, 1, 1, 2, 2228.713977), -- Stone of Purity
(20835, 4040, 1, 1, 2, 668.589531), -- Mold Lubricant
(20835, 3000, 1, 1, 2, 2142.972076), -- Recipe: Dwarven Chain Shield
(20835, 2303, 1, 1, 2, 145.999632), -- Recipe: Skull Graver
(20835, 2990, 1, 1, 2, 2653.230925), -- Recipe: Chain Boots
(20835, 3033, 1, 1, 2, 111.472692), -- Recipe: Spiritshot C
(20835, 3954, 1, 1, 2, 111.472692), -- Recipe: Blessed Spiritshot C
(20835, 8723, 1, 1, 2, 1337.261269), -- Life Stone - Level 46
(20835, 8733, 1, 1, 2, 334.335869), -- Mid-Grade Life Stone - Level 46
(20835, 8743, 1, 1, 2, 33.458249), -- High-Grade Life Stone - Level 46
(20835, 8753, 1, 1, 2, 6.494353), -- Top-Grade Life Stone - Level 46
-- Pirate Zombie
(20836, 1874, 1, 1, -1, 139288), -- Oriharukon Ore
(20836, 1875, 1, 1, -1, 139288), -- Stone of Purity
(20836, 57, 822, 1686, 0, 700000), -- Adena
(20836, 96, 1, 1, 1, 18.669784), -- Scythe
(20836, 2062, 1, 1, 1, 1290.66224), -- Scythe Edge
(20836, 298, 1, 1, 1, 18.669784), -- Orcish Glaive
(20836, 2075, 1, 1, 1, 1290.66224), -- Orcish Glaive Blade
(20836, 302, 1, 1, 1, 18.669784), -- Body Slasher
(20836, 2076, 1, 1, 1, 1290.666168), -- Body Slasher Blade
(20836, 1872, 1, 1, 2, 131658.865024), -- Animal Bone
(20836, 1867, 1, 1, 2, 131658.865024), -- Animal Skin
(20836, 1881, 1, 1, 2, 13166.008472), -- Coarse Bone Powder
(20836, 1875, 1, 1, 2, 6583.004236), -- Stone of Purity
(20836, 2251, 1, 1, 2, 16457.358128), -- Recipe: Steel Arrow
(20836, 2319, 1, 1, 2, 343.954272), -- Recipe: Raid Sword
(20836, 8723, 1, 1, 2, 3949.680572), -- Life Stone - Level 46
(20836, 8733, 1, 1, 2, 987.343912), -- Mid-Grade Life Stone - Level 46
(20836, 8743, 1, 1, 2, 98.795376), -- High-Grade Life Stone - Level 46
(20836, 8753, 1, 1, 2, 20.124984), -- Top-Grade Life Stone - Level 46
-- Tainted Ogre
(20837, 2214, 1, 1, -1, 50878), -- Recipe: Dwarven Chain Gaiters
(20837, 1960, 1, 1, -1, 112350), -- Chain Gaiters Part
(20837, 1895, 1, 1, -1, 585827), -- Metallic Fiber
(20837, 57, 811, 1647, 0, 700000), -- Adena
(20837, 62, 1, 1, 1, 110.887439), -- Reinforced Mithril Boots
(20837, 1958, 1, 1, 1, 4839.218722), -- Reinforced Mithril Boots Design
(20837, 2429, 1, 1, 1, 110.887439), -- Chain Boots
(20837, 2937, 1, 1, 1, 4839.218722), -- Chain Boots Part
(20837, 2430, 1, 1, 1, 110.887439), -- Karmian Boots
(20837, 2938, 1, 1, 1, 4839.218722), -- Karmian Boots Fabric
(20837, 2431, 1, 1, 1, 110.887439), -- Plated Leather Boots
(20837, 2939, 1, 1, 1, 4839.218722), -- Plate Leather Boots Lining
(20837, 2432, 1, 1, 1, 110.887439), -- Dwarven Chain Boots
(20837, 2940, 1, 1, 1, 4839.218722), -- Dwarven Chain Boots Part
(20837, 2433, 1, 1, 1, 110.887439), -- Boots of Seal
(20837, 2941, 1, 1, 1, 4839.218722), -- Boots of Seal Pattern
(20837, 2452, 1, 1, 1, 110.887439), -- Reinforced Mithril Gloves
(20837, 2942, 1, 1, 1, 4839.218722), -- Reinforced Mithril Gloves Design
(20837, 2453, 1, 1, 1, 110.887439), -- Chain Gloves
(20837, 2943, 1, 1, 1, 4839.218722), -- Chain Gloves Design
(20837, 2454, 1, 1, 1, 110.887439), -- Karmian Gloves
(20837, 2944, 1, 1, 1, 4839.263273), -- Karmian Gloves Fabric
(20837, 1873, 1, 1, 2, 35238.148158), -- Silver Nugget
(20837, 1868, 1, 1, 2, 176190.74079), -- Thread
(20837, 1876, 1, 1, 2, 17619.074079), -- Mithril Ore
(20837, 1895, 1, 1, 2, 25170.180804), -- Metallic Fiber
(20837, 4042, 1, 1, 2, 1468.234305), -- Enria
(20837, 2225, 1, 1, 2, 1915.133862), -- Recipe: Demon's Stockings
(20837, 2321, 1, 1, 2, 307.03023), -- Recipe: Stiletto
(20837, 8723, 1, 1, 2, 3523.762332), -- Life Stone - Level 46
(20837, 8733, 1, 1, 2, 880.940583), -- Mid-Grade Life Stone - Level 46
(20837, 8743, 1, 1, 2, 88.172784), -- High-Grade Life Stone - Level 46
(20837, 8753, 1, 1, 2, 17.582073), -- Top-Grade Life Stone - Level 46
-- Bloody Bat
(20838, 2216, 1, 1, -1, 79419), -- Recipe: Great Helmet
(20838, 1964, 1, 1, -1, 155308), -- Eldarake Temper
(20838, 1866, 1, 3, -1, 640646), -- Suede
(20838, 57, 760, 1544, 0, 700000), -- Adena
(20838, 852, 1, 1, 1, 253.796192), -- Moonstone Earring
(20838, 1908, 1, 1, 1, 14336.96992), -- Moonstone Earring Wire
(20838, 915, 1, 1, 1, 190.429408), -- Aquastone Necklace
(20838, 1910, 1, 1, 1, 11400.474176), -- Aquastone Necklace Chain
(20838, 883, 1, 1, 1, 380.858816), -- Aquastone Ring
(20838, 1909, 1, 1, 1, 20445.471488), -- Aquastone Ring Wire
(20838, 1866, 1, 1, 2, 60555.95695), -- Suede
(20838, 1871, 1, 1, 2, 90833.935425), -- Charcoal
(20838, 5220, 1, 1, 2, 3633.281), -- Metal Hardener
(20838, 1885, 1, 1, 2, 7569.4512), -- High-Grade Suede
(20838, 4041, 1, 1, 2, 789.8739), -- Mold Hardener
(20838, 3004, 1, 1, 2, 5641.832375), -- Recipe: Rind Leather Gloves
(20838, 8723, 1, 1, 2, 3633.281), -- Life Stone - Level 46
(20838, 8733, 1, 1, 2, 908.32025), -- Mid-Grade Life Stone - Level 46
(20838, 8743, 1, 1, 2, 90.832025), -- High-Grade Life Stone - Level 46
(20838, 8753, 1, 1, 2, 18.235875), -- Top-Grade Life Stone - Level 46
-- Unpleasant Humming
(20839, 2320, 1, 1, -1, 4006), -- Recipe: Cursed Staff
(20839, 2066, 1, 1, -1, 9017), -- Heavy Doom Hammer Head
(20839, 1908, 1, 1, -1, 108867), -- Moonstone Earring Wire
(20839, 57, 453, 926, 0, 700000), -- Adena
(20839, 631, 1, 1, 1, 177.5616), -- Eldarake
(20839, 1964, 1, 1, 1, 7317.30048), -- Eldarake Temper
(20839, 2495, 1, 1, 1, 177.5616), -- Chain Shield
(20839, 2945, 1, 1, 1, 7317.30048), -- Chain Shield Fragment
(20839, 2413, 1, 1, 1, 124.29312), -- Chain Hood
(20839, 2936, 1, 1, 1, 6645.98272), -- Chain Hood Pattern
(20839, 1867, 1, 1, 2, 60370.846201), -- Animal Skin
(20839, 1872, 1, 1, 2, 60370.846201), -- Animal Bone
(20839, 1882, 1, 1, 2, 10061.782255), -- Leather
(20839, 1894, 1, 1, 2, 1588.694426), -- Crafted Leather
(20839, 4042, 1, 1, 2, 754.652753), -- Enria
(20839, 2230, 1, 1, 2, 877.552908), -- Recipe: Theca Leather Gaiters
(20839, 2326, 1, 1, 2, 157.709143), -- Recipe: Horn of Glory
(20839, 6668, 1, 1, 2, 16170.759649), -- Deluxe Chest Key - Grade 4
(20839, 8723, 1, 1, 2, 1811.136073), -- Life Stone - Level 46
(20839, 8733, 1, 1, 2, 452.822186), -- Mid-Grade Life Stone - Level 46
(20839, 8743, 1, 1, 2, 45.343287), -- High-Grade Life Stone - Level 46
(20839, 8753, 1, 1, 2, 8.854918), -- Top-Grade Life Stone - Level 46
-- Death Flyer
(20840, 2328, 1, 1, -1, 2759), -- Recipe: Sword of Delusion
(20840, 1967, 1, 1, -1, 64698), -- Plated Leather Gaiters Material
(20840, 2166, 1, 1, -1, 40211), -- Recipe: Earrings of Binding (100%)
(20840, 57, 468, 955, 0, 700000), -- Adena
(20840, 227, 1, 1, 1, 11.89263), -- Stiletto
(20840, 2083, 1, 1, 1, 873.10737), -- Stiletto Edge
(20840, 242, 1, 1, 1, 11.89263), -- Soulfire Dirk
(20840, 2084, 1, 1, 1, 873.10737), -- Soulfire Dirk Blade
(20840, 1868, 1, 1, 2, 95562.358226), -- Thread
(20840, 1873, 1, 1, 2, 19112.446148), -- Silver Nugget
(20840, 5549, 1, 1, 2, 4778.17528), -- Metallic Thread
(20840, 1889, 1, 1, 2, 3185.365196), -- Compound Braid
(20840, 4044, 1, 1, 2, 1592.682598), -- Thons
(20840, 2229, 1, 1, 2, 579.168898), -- Recipe: Theca Leather Armor
(20840, 952, 1, 1, 2, 637.047542), -- Scroll: Enchant Armor (C-Grade)
(20840, 8724, 1, 1, 2, 1592.682598), -- Life Stone - Level 49
(20840, 8734, 1, 1, 2, 398.138778), -- Mid-Grade Life Stone - Level 49
(20840, 8744, 1, 1, 2, 39.775632), -- High-Grade Life Stone - Level 49
(20840, 8754, 1, 1, 2, 8.159104), -- Top-Grade Life Stone - Level 49
-- Fiend Archer
(20841, 4438, 1, 1, -1, 8698), -- Knuckle Duster Edge
(20841, 951, 1, 1, -1, 2217), -- Scroll: Enchant Weapon (C-Grade)
(20841, 1911, 1, 1, -1, 90711), -- Earring of Protection Gemstone
(20841, 57, 482, 980, 0, 700000), -- Adena
(20841, 282, 1, 1, 1, 12.229558), -- Elemental Bow
(20841, 2085, 1, 1, 1, 934.770442), -- Crossbow Shaft
(20841, 285, 1, 1, 1, 12.229558), -- Noble Elven Bow
(20841, 2086, 1, 1, 1, 934.770442), -- Noble Elven Bow Shaft
(20841, 1869, 1, 1, 2, 45031.6002), -- Iron Ore
(20841, 1864, 1, 1, 2, 90063.05598), -- Stem
(20841, 1880, 1, 1, 2, 4503.16002), -- Steel
(20841, 5550, 1, 1, 2, 600.35394), -- Durable Metal Plate
(20841, 4043, 1, 1, 2, 1501.10148), -- Asofe
(20841, 2348, 1, 1, 2, 104.7045), -- Recipe: Heathen's Book
(20841, 2351, 1, 1, 2, 94.16184), -- Recipe: Scorpion
(20841, 952, 1, 1, 2, 600.35394), -- Scroll: Enchant Armor (C-Grade)
(20841, 8724, 1, 1, 2, 1501.10148), -- Life Stone - Level 49
(20841, 8734, 1, 1, 2, 375.20316), -- Mid-Grade Life Stone - Level 49
(20841, 8744, 1, 1, 2, 37.5492), -- High-Grade Life Stone - Level 49
(20841, 8754, 1, 1, 2, 7.65426), -- Top-Grade Life Stone - Level 49
-- Musveren
(20842, 2335, 1, 1, -1, 2707), -- Recipe: War Axe
(20842, 1976, 1, 1, -1, 70772), -- Rind Leather Gaiters Material
(20842, 2167, 1, 1, -1, 59380), -- Recipe: Ring of Ages
(20842, 57, 459, 937, 0, 700000), -- Adena
(20842, 853, 1, 1, 1, 114.213622), -- Earring of Protection
(20842, 1911, 1, 1, 1, 6392.9024), -- Earring of Protection Gemstone
(20842, 916, 1, 1, 1, 85.692096), -- Necklace of Protection
(20842, 1913, 1, 1, 1, 5226.665278), -- Necklace of Protection Gemstone
(20842, 884, 1, 1, 1, 171.384192), -- Ring of Protection
(20842, 1912, 1, 1, 1, 9262.142412), -- Ring of Protection Gemstone
(20842, 1870, 1, 1, 2, 51567.29048), -- Coal
(20842, 1865, 1, 1, 2, 51567.29048), -- Varnish
(20842, 1874, 1, 1, 2, 3437.856998), -- Oriharukon Ore
(20842, 4043, 1, 1, 2, 1718.87205), -- Asofe
(20842, 4039, 1, 1, 2, 1718.87205), -- Mold Glue
(20842, 952, 1, 1, 2, 687.54882), -- Scroll: Enchant Armor (C-Grade)
(20842, 8724, 1, 1, 2, 1718.87205), -- Life Stone - Level 49
(20842, 8734, 1, 1, 2, 429.689788), -- Mid-Grade Life Stone - Level 49
(20842, 8744, 1, 1, 2, 43.014138), -- High-Grade Life Stone - Level 49
(20842, 8754, 1, 1, 2, 8.693146), -- Top-Grade Life Stone - Level 49
-- Zaken's Royal Guard
(20843, 4601, 1, 1, -1, 3273), -- Greater Dye of STR (Str+3 Con-3)
(20843, 1539, 1, 1, -1, 327301), -- Greater Healing Potion
(20843, 1914, 1, 1, -1, 82745), -- Earring of Seal Gemstone
(20843, 57, 583, 1184, 0, 700000), -- Adena
(20843, 283, 1, 1, 1, 18.43368), -- Akat Long Bow
(20843, 2109, 1, 1, 1, 1707.56632), -- Akat Longbow Shaft
(20843, 1871, 1, 1, 2, 50756.73014), -- Charcoal
(20843, 1866, 1, 1, 2, 33837.75913), -- Suede
(20843, 1877, 1, 1, 2, 2030.26189), -- Adamantite Nugget
(20843, 4041, 1, 1, 2, 441.405015), -- Mold Hardener
(20843, 4040, 1, 1, 2, 1015.130945), -- Mold Lubricant
(20843, 2357, 1, 1, 2, 82.757725), -- Recipe: Crystal Dagger
(20843, 3014, 1, 1, 2, 1417.76328), -- Recipe: Full Plate Boots
(20843, 4188, 1, 1, 2, 58.433355), -- Recipe: Hell Knife (100%)
(20843, 8725, 1, 1, 2, 1409.89901), -- Life Stone - Level 52
(20843, 8735, 1, 1, 2, 352.520475), -- Mid-Grade Life Stone - Level 52
(20843, 8745, 1, 1, 2, 35.206325), -- High-Grade Life Stone - Level 52
(20843, 8755, 1, 1, 2, 7.13271), -- Top-Grade Life Stone - Level 52
-- Kaim Vanul
(20844, 4603, 1, 1, -1, 2922), -- Greater Dye of CON (Con+3 Str-3)
(20844, 1539, 1, 1, -1, 292227), -- Greater Healing Potion
(20844, 4041, 1, 1, -1, 11435), -- Mold Hardener
(20844, 57, 521, 1058, 0, 700000), -- Adena
(20844, 854, 1, 1, 1, 79.994376), -- Earring of Seal
(20844, 1914, 1, 1, 1, 5091.23888), -- Earring of Seal Gemstone
(20844, 917, 1, 1, 1, 60.00008), -- Necklace of Mermaid
(20844, 1916, 1, 1, 1, 3856.33752), -- Necklace of Mermaid Teardrop
(20844, 885, 1, 1, 1, 119.948584), -- Ring of Ages
(20844, 1915, 1, 1, 1, 7984.48056), -- Ring of Ages Gemstone
(20844, 1872, 1, 1, 2, 60423.448572), -- Animal Bone
(20844, 1867, 1, 1, 2, 60423.448572), -- Animal Skin
(20844, 1881, 1, 1, 2, 6042.318419), -- Coarse Bone Powder
(20844, 1875, 1, 1, 2, 3021.225305), -- Stone of Purity
(20844, 4041, 1, 1, 2, 394.061371), -- Mold Hardener
(20844, 4601, 1, 1, 2, 100.729542), -- Greater Dye of STR (Str+3 Con-3)
(20844, 4609, 1, 1, 2, 100.729542), -- Greater Dye of MEN (Men+3 Int-3)
(20844, 2355, 1, 1, 2, 73.894769), -- Recipe: Ghoul's Staff
(20844, 8725, 1, 1, 2, 1258.854893), -- Life Stone - Level 52
(20844, 8735, 1, 1, 2, 314.746771), -- Mid-Grade Life Stone - Level 52
(20844, 8745, 1, 1, 2, 31.461458), -- High-Grade Life Stone - Level 52
(20844, 8755, 1, 1, 2, 6.080786), -- Top-Grade Life Stone - Level 52
-- Pirate Zombie Captain
(20845, 2100, 1, 1, -1, 10102), -- Paradia Staff Head
(20845, 2354, 1, 1, -1, 2923), -- Recipe: Deadman's Staff
(20845, 4042, 1, 1, -1, 29868), -- Enria
(20845, 57, 712, 1439, 0, 700000), -- Adena
(20845, 75, 1, 1, 1, 3.738902), -- Caliburs
(20845, 2089, 1, 1, 1, 336.595112), -- Caliburs Edge
(20845, 76, 1, 1, 1, 3.738902), -- Sword of Delusion
(20845, 2090, 1, 1, 1, 336.595112), -- Delusional Blade
(20845, 77, 1, 1, 1, 3.738902), -- Tsurugi
(20845, 2091, 1, 1, 1, 336.595112), -- Tsurugi Blade
(20845, 84, 1, 1, 1, 3.738902), -- Homunkulus's Sword
(20845, 2092, 1, 1, 1, 336.595112), -- Homunkulus's Sword Blade
(20845, 134, 1, 1, 1, 3.738902), -- Sword of Nightmare
(20845, 2095, 1, 1, 1, 336.595112), -- Sword of Nightmare Blade
(20845, 145, 1, 1, 1, 3.738902), -- Sword of Whispering Death
(20845, 2096, 1, 1, 1, 336.591028), -- Sword of Whispering Death Blade
(20845, 1873, 1, 1, 2, 21173.94517), -- Silver Nugget
(20845, 1868, 1, 1, 2, 105869.38383), -- Thread
(20845, 1876, 1, 1, 2, 10586.88708), -- Mithril Ore
(20845, 1895, 1, 1, 2, 15124.1244), -- Metallic Fiber
(20845, 4042, 1, 1, 2, 882.24059), -- Enria
(20845, 4608, 1, 1, 2, 117.65488), -- Greater Dye of INT (Int+3 Wit-3)
(20845, 3017, 1, 1, 2, 1478.55246), -- Recipe: Divine Gloves
(20845, 5155, 1, 1, 2, 105.85519), -- Recipe: Soulshot (B) Compressed Package (100%)
(20845, 6669, 1, 1, 2, 12310.32586), -- Deluxe Chest Key - Grade 5
(20845, 8725, 1, 1, 2, 1470.34398), -- Life Stone - Level 52
(20845, 8735, 1, 1, 2, 367.6715), -- Mid-Grade Life Stone - Level 52
(20845, 8745, 1, 1, 2, 36.76715), -- High-Grade Life Stone - Level 52
(20845, 8755, 1, 1, 2, 7.69545), -- Top-Grade Life Stone - Level 52
-- Doll Blader
(20846, 2955, 1, 1, -1, 100037), -- Theca Leather Gloves Texture
(20846, 4042, 1, 1, -1, 26343), -- Enria
(20846, 1918, 1, 1, -1, 68453), -- Nassen's Earring Gemstone
(20846, 57, 626, 1271, 0, 700000), -- Adena
(20846, 400, 1, 1, 1, 30.636222), -- Theca Leather Armor
(20846, 1984, 1, 1, 1, 2084.968227), -- Theca Leather Armor Pattern
(20846, 401, 1, 1, 1, 14.504139), -- Drake Leather Armor
(20846, 1987, 1, 1, 1, 1483.927092), -- Drake Leather Armor Texture
(20846, 420, 1, 1, 1, 49.034796), -- Theca Leather Gaiters
(20846, 1985, 1, 1, 1, 3353.929524), -- Theca Leather Gaiters Pattern
(20846, 1870, 1, 1, 2, 48633.326469), -- Coal
(20846, 1865, 1, 1, 2, 48633.326469), -- Varnish
(20846, 1874, 1, 1, 2, 3242.243112), -- Oriharukon Ore
(20846, 4043, 1, 1, 2, 1621.121556), -- Asofe
(20846, 4039, 1, 1, 2, 1621.121556), -- Mold Glue
(20846, 4133, 1, 1, 2, 233.860767), -- Recipe: Zubei's Breastplate (100%)
(20846, 4959, 1, 1, 2, 937.044123), -- Recipe: Sealed Avadon Boots (60%)
(20846, 4941, 1, 1, 2, 374.113185), -- Recipe: Zubei's Gaiters (60%)
(20846, 8726, 1, 1, 2, 1125.755139), -- Life Stone - Level 55
(20846, 8736, 1, 1, 2, 281.465469), -- Mid-Grade Life Stone - Level 55
(20846, 8746, 1, 1, 2, 28.178568), -- High-Grade Life Stone - Level 55
(20846, 8756, 1, 1, 2, 5.443587), -- Top-Grade Life Stone - Level 55
-- Veil Master
(20847, 1985, 1, 1, -1, 52100), -- Theca Leather Gaiters Pattern
(20847, 4937, 1, 1, -1, 24933), -- Recipe: Adamantite Earrings (70%)
(20847, 1806, 1, 1, -1, 3022), -- Recipe: Soulshot (B-Grade)
(20847, 57, 597, 1215, 0, 700000), -- Adena
(20847, 2436, 1, 1, 1, 37.663092), -- Theca Leather Boots
(20847, 2954, 1, 1, 1, 2522.47632), -- Theca Leather Boots Texture
(20847, 2437, 1, 1, 1, 28.976568), -- Drake Leather Boots
(20847, 2960, 1, 1, 1, 2170.164444), -- Drake Leather Boots Design
(20847, 2438, 1, 1, 1, 28.976568), -- Full Plate Boots
(20847, 2961, 1, 1, 1, 2170.164444), -- Full Plate Boots Part
(20847, 2460, 1, 1, 1, 37.663092), -- Theca Leather Gloves
(20847, 2955, 1, 1, 1, 2522.47632), -- Theca Leather Gloves Texture
(20847, 2461, 1, 1, 1, 28.976568), -- Drake Leather Gloves
(20847, 2962, 1, 1, 1, 2170.164444), -- Drake Leather Gloves Design
(20847, 2462, 1, 1, 1, 28.976568), -- Full Plate Gauntlets
(20847, 2963, 1, 1, 1, 2170.164444), -- Full Plate Gauntlets Part
(20847, 2463, 1, 1, 1, 28.976568), -- Divine Gloves
(20847, 2964, 1, 1, 1, 2170.18056), -- Divine Gloves Pattern
(20847, 1864, 1, 1, 2, 92979.551623), -- Stem
(20847, 1869, 1, 1, 2, 46489.680511), -- Iron Ore
(20847, 1878, 1, 1, 2, 18595.986565), -- Braided Hemp
(20847, 1884, 1, 1, 2, 28609.019499), -- Cord
(20847, 4039, 1, 1, 2, 1549.58613), -- Mold Glue
(20847, 4178, 1, 1, 2, 852.939475), -- Recipe: Zubei's Shield (100%)
(20847, 4184, 1, 1, 2, 53.558881), -- Recipe: Sprite's Staff (100%)
(20847, 5160, 1, 1, 2, 93.013288), -- Recipe: Spiritshot (B) Compressed Package (100%)
(20847, 8726, 1, 1, 2, 1076.133246), -- Life Stone - Level 55
(20847, 8736, 1, 1, 2, 269.128612), -- Mid-Grade Life Stone - Level 55
(20847, 8746, 1, 1, 2, 26.874741), -- High-Grade Life Stone - Level 55
(20847, 8756, 1, 1, 2, 5.527429), -- Top-Grade Life Stone - Level 55
-- Light Bringer
(20848, 1895, 1, 1, -1, 555409), -- Metallic Fiber
(20848, 1871, 1, 5, -1, 647978), -- Charcoal
(20848, 1908, 1, 1, -1, 184085), -- Moonstone Earring Wire
(20848, 57, 766, 1566, 0, 700000), -- Adena
(20848, 96, 1, 1, 1, 17.372215), -- Scythe
(20848, 2062, 1, 1, 1, 1200.9599), -- Scythe Edge
(20848, 298, 1, 1, 1, 17.372215), -- Orcish Glaive
(20848, 2075, 1, 1, 1, 1200.9599), -- Orcish Glaive Blade
(20848, 302, 1, 1, 1, 17.372215), -- Body Slasher
(20848, 2076, 1, 1, 1, 1200.963555), -- Body Slasher Blade
(20848, 1864, 1, 3, 2, 91873.219761), -- Stem
(20848, 1865, 1, 1, 2, 91873.219761), -- Varnish
(20848, 1866, 1, 1, 2, 61248.813174), -- Suede
(20848, 1873, 1, 1, 2, 36749.097), -- Silver Nugget
(20848, 1868, 1, 1, 2, 183745.962261), -- Thread
(20848, 2164, 1, 1, 2, 7067.280888), -- Recipe: Ring of Protection
(20848, 8723, 1, 1, 2, 3674.9097), -- Life Stone - Level 46
(20848, 8733, 1, 1, 2, 918.727425), -- Mid-Grade Life Stone - Level 46
(20848, 8743, 1, 1, 2, 92.111373), -- High-Grade Life Stone - Level 46
(20848, 8753, 1, 1, 2, 17.658657), -- Top-Grade Life Stone - Level 46
-- Light Worm
(20849, 4469, 1, 1, -1, 8784), -- Dye of STR (Str+1 Con-1)
(20849, 1956, 1, 1, -1, 174488), -- Square Shield Fragment
(20849, 1805, 1, 1, -1, 5124), -- Recipe: Soulshot (C-Grade)
(20849, 57, 623, 1246, 0, 700000), -- Adena
(20849, 438, 1, 1, 1, 210.560031), -- Sage's Rag
(20849, 1953, 1, 1, 1, 12362.439969), -- Sage's Rag Lining
(20849, 1869, 1, 1, 2, 85770.187359), -- Iron Ore
(20849, 1870, 1, 1, 2, 85770.187359), -- Coal
(20849, 1871, 1, 1, 2, 85770.187359), -- Charcoal
(20849, 1872, 1, 1, 2, 114360.413559), -- Animal Bone
(20849, 1867, 1, 1, 2, 114360.413559), -- Animal Skin
(20849, 2211, 1, 1, 2, 1923.208515), -- Recipe: Plated Leather Armor
(20849, 2205, 1, 1, 2, 2714.106525), -- Recipe: Chain Gaiters
(20849, 5274, 1, 1, 2, 285.902262), -- Recipe: Greater Spiritshot (C) Compressed Package(100%)
(20849, 5279, 1, 1, 2, 286.393503), -- Recipe: Greater Blessed Spiritshot (C) Compressed Package(100%)
-- Guardian Angel
(20859, 5479, 1, 1, -1, 99083), -- Sealed Tallum Leather Armor Pattern
(20859, 3035, 1, 1, -1, 22327), -- Recipe: Spiritshot A
(20859, 57, 8257, 16860, 0, 700000), -- Adena
(20859, 5287, 1, 1, 1, 57.858582), -- Sealed Dark Crystal breastplate
(20859, 5520, 1, 1, 1, 6645.455934), -- Sealed Dark Crystal Breastplate Pattern
(20859, 5293, 1, 1, 1, 35.616954), -- Sealed Tallum Plate Armor
(20859, 5521, 1, 1, 1, 4689.298248), -- Sealed Tallum Plate Armor Pattern
(20859, 5288, 1, 1, 1, 92.586738), -- Sealed Dark Crystal Gaiters
(20859, 5524, 1, 1, 1, 10157.183544), -- Sealed Dark Crystal Gaiters Pattern
(20859, 1872, 4, 12, 2, 103046.67411), -- Animal Bone
(20859, 1867, 7, 21, 2, 54958.3053), -- Animal Skin
(20859, 1881, 1, 1, 2, 82437.45795), -- Coarse Bone Powder
(20859, 1875, 1, 1, 2, 41218.728975), -- Stone of Purity
(20859, 4041, 1, 1, 2, 5376.278565), -- Mold Hardener
(20859, 3035, 1, 1, 2, 824.404245), -- Recipe: Spiritshot A
(20859, 8730, 1, 1, 2, 6869.639835), -- Life Stone - Level 67
(20859, 8740, 1, 1, 2, 1717.335795), -- Mid-Grade Life Stone - Level 67
(20859, 8750, 1, 1, 2, 171.763245), -- High-Grade Life Stone - Level 67
(20859, 8760, 1, 1, 2, 34.41198), -- Top-Grade Life Stone - Level 67
-- Seal Angel
(20860, 5482, 1, 1, -1, 310640), -- Sealed Dark Crystal Leggings Design
(20860, 5156, 1, 1, -1, 31381), -- Recipe: Soulshot (A) Compressed Package (100%)
(20860, 5485, 1, 1, -1, 197912), -- Sealed Tallum Tunic Texture
(20860, 57, 11622, 23663, 0, 700000), -- Adena
(20860, 5287, 1, 1, 1, 81.321761), -- Sealed Dark Crystal breastplate
(20860, 5520, 1, 1, 1, 9340.363357), -- Sealed Dark Crystal Breastplate Pattern
(20860, 5293, 1, 1, 1, 50.060567), -- Sealed Tallum Plate Armor
(20860, 5521, 1, 1, 1, 6590.932204), -- Sealed Tallum Plate Armor Pattern
(20860, 5288, 1, 1, 1, 130.133099), -- Sealed Dark Crystal Gaiters
(20860, 5524, 1, 1, 1, 14276.189012), -- Sealed Dark Crystal Gaiters Pattern
(20860, 1873, 2, 6, 2, 86900.8238), -- Silver Nugget
(20860, 1868, 15, 45, 2, 57934.13984), -- Thread
(20860, 1876, 1, 1, 2, 173802.03356), -- Mithril Ore
(20860, 1895, 3, 9, 2, 41381.47332), -- Metallic Fiber
(20860, 4042, 1, 1, 2, 14483.53496), -- Enria
(20860, 5271, 1, 1, 2, 1158.65192), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(20860, 8731, 1, 1, 2, 8046.49408), -- Life Stone - Level 70
(20860, 8741, 1, 1, 2, 2011.62352), -- Mid-Grade Life Stone - Level 70
(20860, 8751, 1, 1, 2, 201.08516), -- High-Grade Life Stone - Level 70
(20860, 8761, 1, 1, 2, 40.13984), -- Top-Grade Life Stone - Level 70
-- Maille Lizardman
(20919, 1865, 1, 1, -1, 121597), -- Varnish
(20919, 734, 1, 1, -1, 20266), -- Haste Potion
(20919, 5220, 1, 1, -1, 4864), -- Metal Hardener
(20919, 57, 56, 98, 0, 700000), -- Adena
(20919, 24, 1, 1, 1, 230.2898), -- Bone Breastplate
(20919, 390, 1, 1, 1, 230.2898), -- Cotton Shirt
(20919, 31, 1, 1, 1, 367.7102), -- Bone Gaiters
(20919, 412, 1, 1, 1, 367.7102), -- Cotton Pants
(20919, 1872, 1, 1, 2, 23945.309388), -- Animal Bone
(20919, 1867, 1, 1, 2, 23945.309388), -- Animal Skin
(20919, 1881, 1, 1, 2, 2394.509388), -- Coarse Bone Powder
(20919, 2141, 1, 1, 2, 3591.871836), -- Recipe: Silver Mold
-- Maille Lizardman Scout
(20920, 2014, 1, 1, -1, 3010), -- Iron Hammer Head
(20920, 5163, 1, 1, -1, 10474), -- Recipe: Blessed Spiritshot (D) Compressed Package (100%)
(20920, 1898, 1, 1, -1, 26897), -- Blue Diamond Necklace Gem
(20920, 57, 119, 213, 0, 700000), -- Adena
(20920, 273, 1, 1, 1, 82.310514), -- Composite Bow
(20920, 2016, 1, 1, 1, 906.689486), -- Composite Bow Shaft
(20920, 1865, 1, 1, 2, 25780.999642), -- Varnish
(20920, 1870, 1, 1, 2, 25780.999642), -- Coal
(20920, 1879, 1, 1, 2, 4296.775744), -- Cokes
(20920, 1060, 1, 1, 2, 57290.91855), -- Lesser Healing Potion
(20920, 735, 1, 1, 2, 2148.387872), -- Alacrity Potion
-- Maille Lizardman Guard
(20921, 1864, 1, 1, -1, 366638), -- Stem
(20921, 1928, 1, 1, -1, 26703), -- Piece Bone Gaiters Fragment
(20921, 1804, 1, 1, -1, 7333), -- Recipe: Soulshot (D-Grade)
(20921, 57, 81, 150, 0, 700000), -- Adena
(20921, 39, 1, 1, 1, 759.966624), -- Boots
(20921, 1930, 1, 1, 1, 9256.055976), -- Boot Lining
(20921, 51, 1, 1, 1, 759.9774), -- Bracer
(20921, 1880, 1, 1, 2, 2165.957945), -- Steel
(20921, 1881, 1, 1, 2, 2887.933129), -- Coarse Bone Powder
(20921, 1882, 1, 1, 2, 4813.211084), -- Leather
(20921, 3032, 1, 1, 2, 866.383178), -- Recipe: Spiritshot D
(20921, 6666, 1, 1, 2, 21659.514664), -- Deluxe Chest Key - Grade 2
-- Maille Lizardman Warrior
(20922, 1870, 1, 1, -1, 198933), -- Coal
(20922, 1932, 1, 1, -1, 31577), -- Bone Helmet Design
(20922, 1899, 1, 1, -1, 31083), -- Necklace of Devotion Chain
(20922, 57, 86, 165, 0, 700000), -- Adena
(20922, 123, 1, 1, 1, 17.72225), -- Saber
(20922, 2017, 1, 1, 1, 370.922125), -- Saber Blade
(20922, 5285, 1, 1, 1, 17.72225), -- Heavy Sword
(20922, 5531, 1, 1, 1, 468.633375), -- Heavy Sword Edge
(20922, 1874, 1, 1, 2, 1488.638052), -- Oriharukon Ore
(20922, 1878, 1, 1, 2, 8931.70575), -- Braided Hemp
(20922, 5220, 1, 1, 2, 893.170575), -- Metal Hardener
(20922, 2259, 1, 1, 2, 346.727898), -- Recipe: Spinebone Sword
(20922, 1060, 1, 1, 2, 49620.757725), -- Lesser Healing Potion
-- Maille Lizardman Shaman
(20923, 2263, 1, 1, -1, 4453), -- Recipe: Dwarven Trident
(20923, 2019, 1, 1, -1, 6166), -- Trident Edge
(20923, 2152, 1, 1, -1, 50483), -- Recipe: Enchanted Necklace
(20923, 57, 123, 241, 0, 700000), -- Adena
(20923, 432, 1, 1, 1, 334.060111), -- Cursed Tunic
(20923, 465, 1, 1, 1, 534.939889), -- Cursed Stockings
(20923, 1875, 1, 1, 2, 1788.05016), -- Stone of Purity
(20923, 1879, 1, 1, 2, 4470.1254), -- Cokes
(20923, 1885, 1, 1, 2, 2235.069584), -- High-Grade Suede
(20923, 5550, 1, 1, 2, 357.610032), -- Durable Metal Plate
(20923, 5549, 1, 1, 2, 2682.07524), -- Metallic Thread
(20923, 735, 1, 1, 2, 2235.069584), -- Alacrity Potion
-- Maille Lizardman Matriarch
(20924, 2250, 1, 1, -1, 86656), -- Recipe: Bone Arrow
(20924, 1937, 1, 1, -1, 29779), -- Scale Gaiters Fragment
(20924, 1900, 1, 1, -1, 37924), -- Enchanted Necklace Chain
(20924, 57, 146, 292, 0, 700000), -- Adena
(20924, 259, 1, 1, 1, 76), -- Single-Edged Jamadhr
(20924, 1876, 1, 1, 2, 4735.320325), -- Mithril Ore
(20924, 1880, 1, 1, 2, 2367.643666), -- Steel
(20924, 1877, 1, 1, 2, 947.064065), -- Adamantite Nugget
(20924, 1881, 1, 1, 2, 3156.869219), -- Coarse Bone Powder
(20924, 1882, 1, 1, 2, 5261.459696), -- Leather
(20924, 2183, 1, 1, 2, 1557.665516), -- Recipe: Mithril Banded Mail
(20924, 2274, 1, 1, 2, 169.122118), -- Recipe: Skull Breaker
(20924, 6667, 1, 1, 2, 14797.855395), -- Deluxe Chest Key - Grade 3
-- Giant Araneid
(20925, 2016, 1, 1, -1, 2190), -- Composite Bow Shaft
(20925, 2258, 1, 1, -1, 4570), -- Recipe: Temptation of Abyss
(20925, 1874, 1, 1, -1, 12461), -- Oriharukon Ore
(20925, 57, 83, 153, 0, 700000), -- Adena
(20925, 846, 1, 1, 1, 448.917695), -- Coral Earring
(20925, 909, 1, 1, 1, 336.689345), -- Blue Diamond Necklace
(20925, 1898, 1, 1, 1, 2836.009975), -- Blue Diamond Necklace Gem
(20925, 878, 1, 1, 1, 673.382985), -- Blue Coral Ring
(20925, 1872, 1, 1, 2, 24538.382522), -- Animal Bone
(20925, 1867, 1, 1, 2, 24538.382522), -- Animal Skin
(20925, 1881, 1, 1, 2, 2453.810168), -- Coarse Bone Powder
(20925, 5273, 1, 1, 2, 736.180496), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(20925, 8294, 1, 1, 2, 450.002498), -- Recipe: Steel Sword (100%)
(20925, 1060, 1, 1, 2, 40897.241794), -- Lesser Healing Potion
-- Poison Araneid
(20926, 2018, 1, 1, -1, 2844), -- Assassin Knife Edge
(20926, 1869, 1, 1, -1, 214041), -- Iron Ore
(20926, 1875, 1, 1, -1, 14269), -- Stone of Purity
(20926, 57, 94, 177, 0, 700000), -- Adena
(20926, 156, 1, 1, 1, 25.333308), -- Hand Axe
(20926, 167, 1, 1, 1, 25.333308), -- Scalpel
(20926, 178, 1, 1, 1, 25.333384), -- Bone Staff
(20926, 1875, 1, 1, 2, 1144.0568), -- Stone of Purity
(20926, 1879, 1, 1, 2, 2860.142), -- Cokes
(20926, 5549, 1, 1, 2, 1716.0852), -- Metallic Thread
(20926, 2178, 1, 1, 2, 2745.73632), -- Recipe: Dark Stockings
(20926, 5437, 1, 1, 2, 419.58578), -- Recipe: Heavy Sword(100%)
(20926, 1834, 1, 1, 2, 19067.490475), -- Emergency Dressing
(20926, 1831, 1, 1, 2, 45761.903425), -- Antidote
-- King of the Araneid
(20927, 1866, 1, 1, -1, 200876), -- Suede
(20927, 1932, 1, 1, -1, 47828), -- Bone Helmet Design
(20927, 1899, 1, 1, -1, 47080), -- Necklace of Devotion Chain
(20927, 57, 130, 251, 0, 700000), -- Adena
(20927, 220, 1, 1, 1, 107), -- Crafted Dagger
(20927, 1876, 1, 1, 2, 5636.799558), -- Mithril Ore
(20927, 1880, 1, 1, 2, 2818.399779), -- Steel
(20927, 1877, 1, 1, 2, 1127.355089), -- Adamantite Nugget
(20927, 1881, 1, 1, 2, 3757.866372), -- Coarse Bone Powder
(20927, 1882, 1, 1, 2, 6263.11062), -- Leather
(20927, 2178, 1, 1, 2, 4509.468582), -- Recipe: Dark Stockings
-- Hatu Weird Bee
(20928, 2183, 1, 1, -1, 19597), -- Recipe: Mithril Banded Mail
(20928, 2025, 1, 1, -1, 4126), -- Dwarven Trident Edge
(20928, 2153, 1, 1, -1, 46326), -- Recipe: Tiger's Eye Earring
(20928, 57, 126, 251, 0, 700000), -- Adena
(20928, 348, 1, 1, 1, 79.403112), -- Scale Mail
(20928, 1935, 1, 1, 1, 2273.473584), -- Scale Mail Fragment
(20928, 377, 1, 1, 1, 126.972072), -- Scale Gaiters
(20928, 1937, 1, 1, 1, 3496.151232), -- Scale Gaiters Fragment
(20928, 1872, 1, 1, 2, 27129.856536), -- Animal Bone
(20928, 1867, 1, 1, 2, 27129.856536), -- Animal Skin
(20928, 1881, 1, 1, 2, 2712.994248), -- Coarse Bone Powder
(20928, 1875, 1, 1, 2, 1356.454152), -- Stone of Purity
(20928, 2184, 1, 1, 2, 2137.341336), -- Recipe: Mithril Banded Gaiters
(20928, 2274, 1, 1, 2, 145.331304), -- Recipe: Skull Breaker
(20928, 2978, 1, 1, 2, 2723.909136), -- Recipe: Elven Mithril Boots
(20928, 1832, 1, 1, 2, 22608.256752), -- Greater Antidote
-- Hatu Dire Wolf
(20929, 1871, 1, 1, -1, 279467), -- Charcoal
(20929, 1900, 1, 1, -1, 30576), -- Enchanted Necklace Chain
(20929, 956, 1, 1, -1, 9316), -- Scroll: Enchant Armor (D-Grade)
(20929, 57, 118, 236, 0, 700000), -- Adena
(20929, 315, 1, 1, 1, 62), -- Divine Tome
(20929, 1865, 1, 1, 2, 21816.784359), -- Varnish
(20929, 1870, 1, 1, 2, 21816.784359), -- Coal
(20929, 1879, 1, 1, 2, 3636.182493), -- Cokes
(20929, 1875, 1, 1, 2, 1454.431584), -- Stone of Purity
(20929, 2250, 1, 1, 2, 5454.221973), -- Recipe: Bone Arrow
(20929, 6387, 1, 1, 2, 872.679657), -- Blessed Scroll of Resurrection for Pets
(20929, 1060, 1, 1, 2, 48481.915575), -- Lesser Healing Potion
-- Hatu Brown Bear
(20930, 2028, 1, 1, -1, 5182), -- Shilen Knife Edge
(20930, 2156, 1, 1, -1, 34888), -- Recipe: Elven Necklace
(20930, 2154, 1, 1, -1, 46692), -- Recipe: Elven Earring
(20930, 57, 184, 367, 0, 700000), -- Adena
(20930, 83, 1, 1, 1, 14.02224), -- Sword of Magic
(20930, 144, 1, 1, 1, 14.02224), -- Sword of Occult
(20930, 124, 1, 1, 1, 10.387776), -- Two-Handed Sword
(20930, 2026, 1, 1, 1, 464.791668), -- Two-Handed Sword Edge
(20930, 127, 1, 1, 1, 10.387776), -- Crimson Sword
(20930, 130, 1, 1, 1, 10.3883), -- Elven Sword
(20930, 1869, 1, 1, 2, 33124.743108), -- Iron Ore
(20930, 1864, 1, 1, 2, 66249.486216), -- Stem
(20930, 1880, 1, 1, 2, 3312.431766), -- Steel
(20930, 5550, 1, 1, 2, 441.615024), -- Durable Metal Plate
(20930, 2279, 1, 1, 2, 236.65545), -- Recipe: War Pick
(20930, 8317, 1, 1, 2, 236.65545), -- Recipe: Titan Hammer (100%)
(20930, 735, 1, 1, 2, 2760.412986), -- Alacrity Potion
-- Hatu Onyx Beast
(20931, 2271, 1, 1, -1, 3460), -- Recipe: Winged Spear
(20931, 1940, 1, 1, -1, 72301), -- Iron Boots Design
(20931, 1901, 1, 1, -1, 66909), -- Tiger's Eye Earring Stone
(20931, 57, 204, 409, 0, 700000), -- Adena
(20931, 293, 1, 1, 1, 34.5), -- War Hammer
(20931, 296, 1, 1, 1, 34.5), -- Dwarven Pike
(20931, 1865, 1, 1, 2, 36794.475256), -- Varnish
(20931, 1870, 1, 1, 2, 36794.475256), -- Coal
(20931, 1879, 1, 1, 2, 6132.440347), -- Cokes
(20931, 1875, 1, 1, 2, 2452.926091), -- Stone of Purity
(20931, 2276, 1, 1, 2, 262.834363), -- Recipe: Maingauche
(20931, 2286, 1, 1, 2, 204.445263), -- Recipe: Bonebreaker
(20931, 2197, 1, 1, 2, 771.403424), -- Recipe: Salamander Skin Mail
-- Hatu Crimson Bear
(20932, 1825, 1, 1, -1, 37742), -- Recipe: Oriharukon
(20932, 2032, 1, 1, -1, 4883), -- Goat Head Staff Head
(20932, 5220, 1, 1, -1, 21136), -- Metal Hardener
(20932, 57, 223, 446, 0, 700000), -- Adena
(20932, 850, 1, 1, 1, 126.629928), -- Elven Earring
(20932, 1902, 1, 1, 1, 4612.26069), -- Elven Earring Beads
(20932, 913, 1, 1, 1, 95.03991), -- Elven Necklace
(20932, 1904, 1, 1, 1, 4248.528534), -- Elven Necklace Beads
(20932, 881, 1, 1, 1, 190.07982), -- Elven Ring
(20932, 1903, 1, 1, 1, 7593.461118), -- Elven Ring Piece
(20932, 1866, 1, 1, 2, 26013.137496), -- Suede
(20932, 1871, 1, 1, 2, 39019.706244), -- Charcoal
(20932, 5220, 1, 1, 2, 1560.80127), -- Metal Hardener
(20932, 1885, 1, 1, 2, 3251.642187), -- High-Grade Suede
(20932, 2201, 1, 1, 2, 3788.401581), -- Recipe: Square Shield
(20932, 2159, 1, 1, 2, 2408.581647), -- Recipe: Necklace of Darkness
(20932, 1060, 1, 1, 2, 86710.729575), -- Lesser Healing Potion
-- Hatu Windsus
(20933, 1879, 1, 1, -1, 101112), -- Cokes
(20933, 1894, 1, 1, -1, 21287), -- Crafted Leather
(20933, 1880, 1, 1, -1, 60667), -- Steel
(20933, 57, 253, 505, 0, 700000), -- Adena
(20933, 261, 1, 1, 1, 29.207871), -- Bich'Hwa
(20933, 2039, 1, 1, 1, 1587.792129), -- Bich'Hwa Edge
(20933, 1865, 1, 1, 2, 52266.939944), -- Varnish
(20933, 1870, 1, 1, 2, 52266.939944), -- Coal
(20933, 1879, 1, 1, 2, 8711.176688), -- Cokes
(20933, 1875, 1, 1, 2, 3484.494712), -- Stone of Purity
(20933, 2159, 1, 1, 2, 3226.33948), -- Recipe: Necklace of Darkness
(20933, 2298, 1, 1, 2, 228.109232), -- Recipe: Stormbringer
-- Wasp Worker
(20934, 1868, 1, 1, -1, 654152), -- Thread
(20934, 2028, 1, 1, -1, 3886), -- Shilen Knife Edge
(20934, 1938, 1, 1, -1, 21988), -- Mithril Banded Mail Material
(20934, 57, 138, 276, 0, 700000), -- Adena
(20934, 436, 1, 1, 1, 148.555188), -- Tunic of Knowledge
(20934, 469, 1, 1, 1, 237.444812), -- Stockings of Knowledge
(20934, 1867, 1, 1, 2, 46374.15549), -- Animal Skin
(20934, 1872, 1, 1, 2, 46374.15549), -- Animal Bone
(20934, 1882, 1, 1, 2, 7728.99153), -- Leather
(20934, 2190, 1, 1, 2, 2484.281865), -- Recipe: Mithril Stockings
(20934, 3020, 1, 1, 2, 193.415625), -- Recipe: Elven Long Sword
-- Wasp Leader
(20935, 1872, 1, 1, -1, 475451), -- Animal Bone
(20935, 2040, 1, 1, -1, 4126), -- Reinforced Long Bow Shaft
(20935, 1825, 1, 1, -1, 25471), -- Recipe: Oriharukon
(20935, 57, 151, 301, 0, 700000), -- Adena
(20935, 629, 1, 1, 1, 101.89584), -- Kite Shield
(20935, 1947, 1, 1, 1, 4423.35942), -- Kite Shield Fragment
(20935, 2493, 1, 1, 1, 101.89584), -- Brigandine Shield
(20935, 2929, 1, 1, 1, 4423.35942), -- Brigandine Shield Fragment
(20935, 2411, 1, 1, 1, 71.362125), -- Brigandine Helmet
(20935, 2922, 1, 1, 1, 1183.127355), -- Brigandine Helmet Design
(20935, 1868, 1, 1, 2, 52665.454213), -- Thread
(20935, 1873, 1, 1, 2, 10533.105304), -- Silver Nugget
(20935, 5549, 1, 1, 2, 2633.276326), -- Metallic Thread
(20935, 1889, 1, 1, 2, 1755.541653), -- Compound Braid
(20935, 2148, 1, 1, 2, 1880.921991), -- Recipe: Crafted Leather
(20935, 2984, 1, 1, 2, 2692.495759), -- Recipe: Salamander Skin Boots
(20935, 2288, 1, 1, 2, 146.204754), -- Recipe: Ghost Staff
-- Tanor Silenos
(20936, 1874, 1, 1, -1, 45199), -- Oriharukon Ore
(20936, 1875, 1, 1, -1, 45199), -- Stone of Purity
(20936, 1902, 1, 1, -1, 68692), -- Elven Earring Beads
(20936, 57, 283, 565, 0, 700000), -- Adena
(20936, 437, 1, 1, 1, 101.881109), -- Mithril Tunic
(20936, 1944, 1, 1, 1, 4469.134758), -- Mithril Tunic Fabric
(20936, 470, 1, 1, 1, 162.708095), -- Mithril Stockings
(20936, 1945, 1, 1, 1, 6959.276038), -- Mithril Stocking Design
(20936, 1865, 1, 1, 2, 58411.514883), -- Varnish
(20936, 1870, 1, 1, 2, 58411.514883), -- Coal
(20936, 1879, 1, 1, 2, 9735.274866), -- Cokes
(20936, 1875, 1, 1, 2, 3894.136809), -- Stone of Purity
(20936, 2159, 1, 1, 2, 3605.632485), -- Recipe: Necklace of Darkness
(20936, 2298, 1, 1, 2, 254.926074), -- Recipe: Stormbringer
-- Tanor Silenos Grunt
(20937, 4480, 1, 1, -1, 5103), -- Dye of WIT (Wit+1 Men-1)
(20937, 2054, 1, 1, -1, 7601), -- Light Crossbow Shaft
(20937, 1805, 1, 1, -1, 2977), -- Recipe: Soulshot (C-Grade)
(20937, 57, 360, 727, 0, 700000), -- Adena
(20937, 1125, 1, 1, 1, 99.391617), -- Assault Boots
(20937, 1957, 1, 1, 1, 4171.091301), -- Assault Boots Part
(20937, 2427, 1, 1, 1, 99.391617), -- Salamander Skin Boots
(20937, 2931, 1, 1, 1, 4171.091301), -- Salamander Skin Boot Lining
(20937, 2428, 1, 1, 1, 99.391617), -- Plate Boots
(20937, 2932, 1, 1, 1, 4171.091301), -- Plate Boots Design
(20937, 61, 1, 1, 1, 99.391617), -- Mithril Plate Gloves
(20937, 1949, 1, 1, 1, 4171.091301), -- Mithril Gloves Design
(20937, 607, 1, 1, 1, 99.391617), -- Ogre Power Gauntlets
(20937, 1963, 1, 1, 1, 4171.091301), -- Ogre Power Gauntlets Part
(20937, 2451, 1, 1, 1, 99.391617), -- Sage's Worn Gloves
(20937, 2933, 1, 1, 1, 4171.193793), -- Sage's Worn Gloves Lining
(20937, 1866, 1, 1, 2, 42709.985513), -- Suede
(20937, 1871, 1, 1, 2, 64065.036868), -- Charcoal
(20937, 5220, 1, 1, 2, 2562.629602), -- Metal Hardener
(20937, 1885, 1, 1, 2, 5338.792138), -- High-Grade Suede
(20937, 2307, 1, 1, 2, 279.749239), -- Recipe: Heavy Doom Axe
(20937, 2205, 1, 1, 2, 2027.390903), -- Recipe: Chain Gaiters
(20937, 5164, 1, 1, 2, 213.415737), -- Recipe: Blessed Spiritshot (C) Compressed Package (100%)
-- Tanor Silenos Scout
(20938, 2323, 1, 1, -1, 3431), -- Recipe: Elemental Bow
(20938, 2070, 1, 1, -1, 7819), -- Cursed Dagger Blade
(20938, 1908, 1, 1, -1, 93255), -- Moonstone Earring Wire
(20938, 57, 388, 794, 0, 700000), -- Adena
(20938, 281, 1, 1, 1, 26.406375), -- Crystallized Ice Bow
(20938, 2074, 1, 1, 1, 1648.593625), -- Crystallized Ice Bow Shaft
(20938, 1867, 1, 1, 2, 56414.7238), -- Animal Skin
(20938, 1872, 1, 1, 2, 56414.7238), -- Animal Bone
(20938, 1882, 1, 1, 2, 9402.496075), -- Leather
(20938, 1894, 1, 1, 2, 1484.5714), -- Crafted Leather
(20938, 2315, 1, 1, 2, 147.421275), -- Recipe: Shamshir
(20938, 2321, 1, 1, 2, 147.421275), -- Recipe: Stiletto
(20938, 2317, 1, 1, 2, 147.421275), -- Recipe: Bec de Corbin
(20938, 8723, 1, 1, 2, 1692.50235), -- Life Stone - Level 46
(20938, 8733, 1, 1, 2, 423.062425), -- Mid-Grade Life Stone - Level 46
(20938, 8743, 1, 1, 2, 42.318875), -- High-Grade Life Stone - Level 46
(20938, 8753, 1, 1, 2, 8.33745), -- Top-Grade Life Stone - Level 46
-- Tanor Silenos Warrior
(20939, 2067, 1, 1, -1, 7925), -- Crystal Staff Head
(20939, 1873, 1, 1, -1, 439855), -- Silver Nugget
(20939, 1868, 1, 5, -1, 733092), -- Thread
(20939, 57, 433, 886, 0, 700000), -- Adena
(20939, 397, 1, 1, 1, 89.299392), -- Mithril Shirt
(20939, 1961, 1, 1, 1, 4158.036834), -- Mithril Shirt Fabric
(20939, 2387, 1, 1, 1, 142.716336), -- Reinforced Mithril Gaiters
(20939, 2935, 1, 1, 1, 6907.947438), -- Reinforced Mithril Gaiters Fragment
(20939, 1868, 1, 1, 2, 94492.38564), -- Thread
(20939, 1873, 1, 1, 2, 18898.477128), -- Silver Nugget
(20939, 5549, 1, 1, 2, 4724.556084), -- Metallic Thread
(20939, 1889, 1, 1, 2, 3149.78832), -- Compound Braid
(20939, 4044, 1, 1, 2, 1574.89416), -- Thons
(20939, 2225, 1, 1, 2, 1027.093896), -- Recipe: Demon's Stockings
(20939, 2343, 1, 1, 2, 109.838124), -- Recipe: Mace of Underworld
(20939, 8723, 1, 1, 2, 1889.872992), -- Life Stone - Level 46
(20939, 8733, 1, 1, 2, 472.468248), -- Mid-Grade Life Stone - Level 46
(20939, 8743, 1, 1, 2, 47.272104), -- High-Grade Life Stone - Level 46
(20939, 8753, 1, 1, 2, 9.353304), -- Top-Grade Life Stone - Level 46
-- Tanor Silenos Shaman
(20940, 1970, 1, 1, -1, 36908), -- Robe of Seal Fabric
(20940, 5550, 1, 1, -1, 22037), -- Durable Metal Plate
(20940, 4589, 1, 1, -1, 5509), -- Greater Dye of STR (Str+2 Con-2)
(20940, 57, 653, 1328, 0, 700000), -- Adena
(20940, 4233, 1, 1, 1, 33.134608), -- Knuckle Duster
(20940, 4438, 1, 1, 1, 2610.865392), -- Knuckle Duster Edge
(20940, 1869, 1, 1, 2, 61024.781804), -- Iron Ore
(20940, 1864, 1, 1, 2, 122049.563608), -- Stem
(20940, 1880, 1, 1, 2, 6102.538064), -- Steel
(20940, 5550, 1, 1, 2, 813.618512), -- Durable Metal Plate
(20940, 4043, 1, 1, 2, 2034.245892), -- Asofe
(20940, 2350, 1, 1, 2, 127.75168), -- Recipe: Pa'agrian Axe
(20940, 3005, 1, 1, 2, 2490.758536), -- Recipe: Demon's Boots
(20940, 4132, 1, 1, 2, 2365.202588), -- Recipe: Composite Shield (100%)
(20940, 8724, 1, 1, 2, 2034.245892), -- Life Stone - Level 49
(20940, 8734, 1, 1, 2, 508.611376), -- Mid-Grade Life Stone - Level 49
(20940, 8744, 1, 1, 2, 50.90106), -- High-Grade Life Stone - Level 49
(20940, 8754, 1, 1, 2, 9.780988), -- Top-Grade Life Stone - Level 49
-- Tanor Silenos Chieftain
(20941, 2233, 1, 1, -1, 12171), -- Recipe: Divine Tunic
(20941, 2109, 1, 1, -1, 7302), -- Akat Longbow Shaft
(20941, 4601, 1, 1, -1, 2894), -- Greater Dye of STR (Str+3 Con-3)
(20941, 57, 515, 1047, 0, 700000), -- Adena
(20941, 60, 1, 1, 1, 43.890273), -- Composite Armor
(20941, 1977, 1, 1, 1, 3983.109727), -- Composite Armor Temper
(20941, 1870, 1, 1, 2, 44877.48583), -- Coal
(20941, 1865, 1, 1, 2, 44877.48583), -- Varnish
(20941, 1874, 1, 1, 2, 2991.80543), -- Oriharukon Ore
(20941, 4043, 1, 1, 2, 1495.902715), -- Asofe
(20941, 4039, 1, 1, 2, 1495.902715), -- Mold Glue
(20941, 3013, 1, 1, 2, 1253.578), -- Recipe: Drake Leather Boots
(20941, 3014, 1, 1, 2, 1253.578), -- Recipe: Full Plate Boots
(20941, 8725, 1, 1, 2, 1246.602445), -- Life Stone - Level 52
(20941, 8735, 1, 1, 2, 311.675885), -- Mid-Grade Life Stone - Level 52
(20941, 8745, 1, 1, 2, 31.13726), -- High-Grade Life Stone - Level 52
(20941, 8755, 1, 1, 2, 6.26789), -- Top-Grade Life Stone - Level 52
-- Nightmare Guide
(20942, 2301, 1, 1, -1, 2863), -- Recipe: Battle Axe
(20942, 2931, 1, 1, -1, 73162), -- Salamander Skin Boot Lining
(20942, 1905, 1, 1, -1, 63768), -- Omen Beast's Eye Earring Gemstone
(20942, 57, 259, 526, 0, 700000), -- Adena
(20942, 225, 1, 1, 1, 23.731105), -- Mithril Dagger
(20942, 2052, 1, 1, 1, 1427.268895), -- Mithril Dagger Blade
(20942, 1871, 1, 1, 2, 41147.300372), -- Charcoal
(20942, 1866, 1, 1, 2, 27431.55799), -- Suede
(20942, 1877, 1, 1, 2, 1645.900802), -- Adamantite Nugget
(20942, 2225, 1, 1, 2, 894.528816), -- Recipe: Demon's Stockings
(20942, 8723, 1, 1, 2, 1645.900802), -- Life Stone - Level 46
(20942, 8733, 1, 1, 2, 411.456894), -- Mid-Grade Life Stone - Level 46
(20942, 8743, 1, 1, 2, 41.153012), -- High-Grade Life Stone - Level 46
(20942, 8753, 1, 1, 2, 8.201312), -- Top-Grade Life Stone - Level 46
-- Nightmare Keeper
(20943, 1874, 1, 1, -1, 62887), -- Oriharukon Ore
(20943, 1875, 1, 1, -1, 62887), -- Stone of Purity
(20943, 2163, 1, 1, -1, 48128), -- Recipe: Earring of Protection
(20943, 57, 373, 758, 0, 700000), -- Adena
(20943, 263, 1, 1, 1, 25.28482), -- Chakram
(20943, 2073, 1, 1, 1, 1722.71518), -- Chakram Edge
(20943, 1872, 1, 1, 2, 59442.614958), -- Animal Bone
(20943, 1867, 1, 1, 2, 59442.614958), -- Animal Skin
(20943, 1881, 1, 1, 2, 5944.287784), -- Coarse Bone Powder
(20943, 1875, 1, 1, 2, 2972.143892), -- Stone of Purity
(20943, 4041, 1, 1, 2, 387.619509), -- Mold Hardener
(20943, 2225, 1, 1, 2, 969.114493), -- Recipe: Demon's Stockings
(20943, 8723, 1, 1, 2, 1783.260047), -- Life Stone - Level 46
(20943, 8733, 1, 1, 2, 445.847872), -- Mid-Grade Life Stone - Level 46
(20943, 8743, 1, 1, 2, 44.558499), -- High-Grade Life Stone - Level 46
(20943, 8753, 1, 1, 2, 8.937988), -- Top-Grade Life Stone - Level 46
-- Nightmare Lord
(20944, 2947, 1, 1, -1, 57031), -- Dwarven Chain Shield Fragment
(20944, 2329, 1, 1, -1, 1857), -- Recipe: Tsurugi
(20944, 1911, 1, 1, -1, 59386), -- Earring of Protection Gemstone
(20944, 57, 315, 643, 0, 700000), -- Adena
(20944, 853, 1, 1, 1, 78.35292), -- Earring of Protection
(20944, 1911, 1, 1, 1, 4385.664), -- Earring of Protection Gemstone
(20944, 916, 1, 1, 1, 58.78656), -- Necklace of Protection
(20944, 1913, 1, 1, 1, 3585.60108), -- Necklace of Protection Gemstone
(20944, 884, 1, 1, 1, 117.57312), -- Ring of Protection
(20944, 1912, 1, 1, 1, 6354.02232), -- Ring of Protection Gemstone
(20944, 1873, 1, 1, 2, 14150.763066), -- Silver Nugget
(20944, 1868, 1, 1, 2, 70753.81533), -- Thread
(20944, 1876, 1, 1, 2, 7075.381533), -- Mithril Ore
(20944, 1895, 1, 1, 2, 10107.732591), -- Metallic Fiber
(20944, 4042, 1, 1, 2, 589.641195), -- Enria
(20944, 2328, 1, 1, 2, 82.268241), -- Recipe: Sword of Delusion
(20944, 8724, 1, 1, 2, 1179.28239), -- Life Stone - Level 49
(20944, 8734, 1, 1, 2, 294.768463), -- Mid-Grade Life Stone - Level 49
(20944, 8744, 1, 1, 2, 29.508127), -- High-Grade Life Stone - Level 49
(20944, 8754, 1, 1, 2, 5.839064), -- Top-Grade Life Stone - Level 49
-- Cadeine
(20945, 1868, 1, 3, -1, 897692), -- Thread
(20945, 1876, 1, 1, -1, 179538), -- Mithril Ore
(20945, 4601, 1, 1, -1, 1995), -- Greater Dye of STR (Str+3 Con-3)
(20945, 57, 355, 722, 0, 700000), -- Adena
(20945, 64, 1, 1, 1, 98.312175), -- Composite Boots
(20945, 2956, 1, 1, 1, 5459.187825), -- Composite Boots Part
(20945, 608, 1, 1, 1, 98.312175), -- Mithril Gauntlets
(20945, 1981, 1, 1, 1, 5459.187825), -- Mithril Gauntlets Design
(20945, 1873, 1, 1, 2, 13499.220456), -- Silver Nugget
(20945, 1868, 1, 1, 2, 67495.899996), -- Thread
(20945, 1876, 1, 1, 2, 6749.610228), -- Mithril Ore
(20945, 1895, 1, 1, 2, 9642.271428), -- Metallic Fiber
(20945, 4042, 1, 1, 2, 562.450662), -- Enria
(20945, 2170, 1, 1, 2, 795.98754), -- Recipe: Nassen's Earring
(20945, 2970, 1, 1, 2, 1196.712144), -- Recipe: Ring of Seal
(20945, 8725, 1, 1, 2, 937.485198), -- Life Stone - Level 52
(20945, 8735, 1, 1, 2, 234.346014), -- Mid-Grade Life Stone - Level 52
(20945, 8745, 1, 1, 2, 23.464944), -- High-Grade Life Stone - Level 52
(20945, 8755, 1, 1, 2, 4.55139), -- Top-Grade Life Stone - Level 52
-- Sanhidro
(20946, 1539, 1, 1, -1, 307481), -- Greater Healing Potion
(20946, 1914, 1, 1, -1, 77734), -- Earring of Seal Gemstone
(20946, 2169, 1, 1, -1, 24490), -- Recipe: Necklace of Seal
(20946, 57, 550, 1111, 0, 700000), -- Adena
(20946, 103, 1, 1, 1, 72.138022), -- Tower Shield
(20946, 1978, 1, 1, 1, 4584.843537), -- Tower Shield Fragment
(20946, 107, 1, 1, 1, 72.138022), -- Composite Shield
(20946, 4055, 1, 1, 1, 4584.843537), -- Composite Shield Fragment
(20946, 517, 1, 1, 1, 50.51858), -- Composite Helmet
(20946, 2957, 1, 1, 1, 3136.999861), -- Composite Helmet Design
(20946, 1149, 1, 1, 1, 50.51858), -- Shining Circlet
(20946, 1983, 1, 1, 1, 3136.999861), -- Shining Circlet Pattern
(20946, 1864, 1, 1, 2, 104035.737255), -- Stem
(20946, 1869, 1, 1, 2, 52017.759267), -- Iron Ore
(20946, 1878, 1, 1, 2, 20807.147451), -- Braided Hemp
(20946, 1884, 1, 1, 2, 32010.911955), -- Cord
(20946, 4039, 1, 1, 2, 1734.020088), -- Mold Glue
(20946, 2233, 1, 1, 2, 486.216783), -- Recipe: Divine Tunic
(20946, 4180, 1, 1, 2, 5779.702425), -- Recipe: Silver Arrow (100%)
(20946, 8725, 1, 1, 2, 1444.870926), -- Life Stone - Level 52
(20946, 8735, 1, 1, 2, 361.327092), -- Mid-Grade Life Stone - Level 52
(20946, 8745, 1, 1, 2, 36.088965), -- High-Grade Life Stone - Level 52
(20946, 8755, 1, 1, 2, 7.217793), -- Top-Grade Life Stone - Level 52
-- Connabi
(20947, 4967, 1, 1, -1, 1726), -- Recipe: Sword of Valhalla (60%)
(20947, 4938, 1, 1, -1, 37080), -- Recipe: Adamantite Ring (70%)
(20947, 1806, 1, 1, -1, 2996), -- Recipe: Soulshot (B-Grade)
(20947, 57, 592, 1205, 0, 700000), -- Adena
(20947, 356, 1, 1, 1, 30.932675), -- Full Plate Armor
(20947, 1986, 1, 1, 1, 2922.067325), -- Full Plate Armor Temper
(20947, 1869, 1, 1, 2, 46093.153575), -- Iron Ore
(20947, 1864, 1, 1, 2, 92186.454675), -- Stem
(20947, 1880, 1, 1, 2, 4609.2711), -- Steel
(20947, 5550, 1, 1, 2, 614.58915), -- Durable Metal Plate
(20947, 4043, 1, 1, 2, 1536.472875), -- Asofe
(20947, 4179, 1, 1, 2, 592.4604), -- Recipe: Zubei's Helmet (100%)
(20947, 4184, 1, 1, 2, 53.109), -- Recipe: Sprite's Staff (100%)
(20947, 4144, 1, 1, 2, 473.702775), -- Recipe: Zubei's Leather Gaiters (100%)
(20947, 8726, 1, 1, 2, 1066.9008), -- Life Stone - Level 55
(20947, 8736, 1, 1, 2, 266.7252), -- Mid-Grade Life Stone - Level 55
(20947, 8746, 1, 1, 2, 26.702025), -- High-Grade Life Stone - Level 55
(20947, 8756, 1, 1, 2, 5.458425), -- Top-Grade Life Stone - Level 55
-- Bartal
(20948, 4049, 1, 1, -1, 78274), -- Adamantite Earring Gemstone
(20948, 4129, 1, 1, -1, 16150), -- Recipe: Earrings of Black Ore (100%)
(20948, 4050, 1, 1, -1, 92459), -- Adamantite Ring Wire
(20948, 57, 589, 1202, 0, 700000), -- Adena
(20948, 11889, 1, 1, 1, 42.03066), -- Common Item - Great Sword
(20948, 4104, 1, 1, 1, 420.310722), -- Great Sword Blade
(20948, 11916, 1, 1, 1, 42.03066), -- Common Item - Keshanberk
(20948, 4107, 1, 1, 1, 413.797962), -- Keshanberk Blade
(20948, 11900, 1, 1, 1, 42.03066), -- Common Item - Sword of Valhalla
(20948, 4108, 1, 1, 1, 413.799336), -- Sword of Valhalla Blade
(20948, 1865, 1, 1, 2, 36733.092399), -- Varnish
(20948, 1870, 1, 1, 2, 36733.092399), -- Coal
(20948, 1879, 1, 1, 2, 6122.16801), -- Cokes
(20948, 1875, 1, 1, 2, 2448.867204), -- Stone of Purity
(20948, 4040, 1, 1, 2, 734.677029), -- Mold Lubricant
(20948, 948, 1, 1, 2, 91.845171), -- Scroll: Enchant Armor (B-Grade)
(20948, 4176, 1, 1, 2, 456.864363), -- Recipe: Sealed Doom Boots (100%)
(20948, 4158, 1, 1, 2, 78.013575), -- Recipe: Doom Plate Armor (100%)
(20948, 8727, 1, 1, 2, 734.677029), -- Life Stone - Level 58
(20948, 8737, 1, 1, 2, 183.690342), -- Mid-Grade Life Stone - Level 58
(20948, 8747, 1, 1, 2, 18.385902), -- High-Grade Life Stone - Level 58
(20948, 8757, 1, 1, 2, 3.626577), -- Top-Grade Life Stone - Level 58
-- Luminun
(20949, 947, 1, 1, -1, 706), -- Scroll: Enchant Weapon (B-Grade)
(20949, 4041, 1, 1, -1, 15347), -- Mold Hardener
(20949, 1866, 1, 3, -1, 588296), -- Suede
(20949, 57, 697, 1420, 0, 700000), -- Adena
(20949, 11918, 1, 1, 1, 74.601684), -- Common Item - Heavy War Axe
(20949, 4105, 1, 1, 1, 746.018469), -- Heavy War Axe Head
(20949, 11908, 1, 1, 1, 74.601684), -- Common Item - Sprite's Staff
(20949, 4106, 1, 1, 1, 733.778163), -- Sprite's Staff Head
(20949, 1866, 1, 1, 2, 28962.20029), -- Suede
(20949, 1871, 1, 1, 2, 43443.300435), -- Charcoal
(20949, 5220, 1, 1, 2, 1737.748142), -- Metal Hardener
(20949, 1885, 1, 1, 2, 3620.295192), -- High-Grade Suede
(20949, 4041, 1, 1, 2, 377.799378), -- Mold Hardener
(20949, 4129, 1, 1, 2, 470.193336), -- Recipe: Earrings of Black Ore (100%)
(20949, 4993, 1, 1, 2, 540.335346), -- Recipe: Sealed Doom Gloves (60%)
(20949, 4165, 1, 1, 2, 359.014219), -- Recipe: Blue Wolf Helmet (100%)
(20949, 8727, 1, 1, 2, 868.874071), -- Life Stone - Level 58
(20949, 8737, 1, 1, 2, 217.198362), -- Mid-Grade Life Stone - Level 58
(20949, 8747, 1, 1, 2, 21.687587), -- High-Grade Life Stone - Level 58
(20949, 8757, 1, 1, 2, 4.353642), -- Top-Grade Life Stone - Level 58
-- Innersen
(20950, 4056, 1, 1, -1, 34524), -- Zubei's Breastplate Part
(20950, 4049, 1, 1, -1, 100049), -- Adamantite Earring Gemstone
(20950, 947, 1, 1, -1, 763), -- Scroll: Enchant Weapon (B-Grade)
(20950, 57, 754, 1534, 0, 700000), -- Adena
(20950, 11890, 1, 1, 1, 161.225658), -- Common Item - Great Axe
(20950, 4113, 1, 1, 1, 1449.774342), -- Great Axe Head
(20950, 1869, 1, 1, 2, 51220.563425), -- Iron Ore
(20950, 1864, 1, 1, 2, 102440.964015), -- Stem
(20950, 1880, 1, 1, 2, 5121.974925), -- Steel
(20950, 5550, 1, 1, 2, 682.92999), -- Durable Metal Plate
(20950, 4043, 1, 1, 2, 1707.324975), -- Asofe
(20950, 4159, 1, 1, 2, 145.085985), -- Recipe: Blue Wolf Leather Armor (100%)
(20950, 4990, 1, 1, 2, 423.371), -- Recipe: Blue Wolf Helmet (60%)
(20950, 8728, 1, 1, 2, 853.743905), -- Life Stone - Level 61
(20950, 8738, 1, 1, 2, 213.476685), -- Mid-Grade Life Stone - Level 61
(20950, 8748, 1, 1, 2, 21.331385), -- High-Grade Life Stone - Level 61
(20950, 8758, 1, 1, 2, 4.23371), -- Top-Grade Life Stone - Level 61
-- Pobby's Maid
(20951, 1918, 1, 1, -1, 43851), -- Nassen's Earring Gemstone
(20951, 1806, 1, 1, -1, 2025), -- Recipe: Soulshot (B-Grade)
(20951, 1920, 1, 1, -1, 34646), -- Necklace of Seal Chain
(20951, 57, 401, 814, 0, 700000), -- Adena
(20951, 266, 1, 1, 1, 7.932936), -- Great Pata
(20951, 2120, 1, 1, 1, 898.067064), -- Great Pata Blade
(20951, 1867, 1, 1, 2, 41539.858702), -- Animal Skin
(20951, 1872, 1, 1, 2, 41539.858702), -- Animal Bone
(20951, 1882, 1, 1, 2, 6923.325236), -- Leather
(20951, 1894, 1, 1, 2, 1093.190774), -- Crafted Leather
(20951, 4042, 1, 1, 2, 519.291114), -- Enria
(20951, 1806, 1, 1, 2, 62.303808), -- Recipe: Soulshot (B-Grade)
(20951, 5270, 1, 1, 2, 62.303808), -- Recipe: Greater Soulshot (B) Compressed Package(100%)
(20951, 5436, 1, 1, 2, 50.807272), -- Recipe: Berserker Blade(100%)
(20951, 8726, 1, 1, 2, 721.222206), -- Life Stone - Level 55
(20951, 8736, 1, 1, 2, 180.32873), -- Mid-Grade Life Stone - Level 55
(20951, 8746, 1, 1, 2, 17.986516), -- High-Grade Life Stone - Level 55
(20951, 8756, 1, 1, 2, 3.523132), -- Top-Grade Life Stone - Level 55
-- Pobby Escort
(20952, 3034, 1, 1, -1, 3670), -- Recipe: Spiritshot B
(20952, 1984, 1, 1, -1, 39333), -- Theca Leather Armor Pattern
(20952, 4044, 1, 1, -1, 61163), -- Thons
(20952, 57, 725, 1477, 0, 700000), -- Adena
(20952, 286, 1, 1, 1, 14.372796), -- Eminence Bow
(20952, 2121, 1, 1, 1, 1557.627204), -- Eminence Bow Shaft
(20952, 1868, 1, 1, 2, 112917.336858), -- Thread
(20952, 1873, 1, 1, 2, 22583.49724), -- Silver Nugget
(20952, 5549, 1, 1, 2, 5645.87431), -- Metallic Thread
(20952, 1889, 1, 1, 2, 3763.866426), -- Compound Braid
(20952, 4044, 1, 1, 2, 1882.007884), -- Thons
(20952, 4128, 1, 1, 2, 698.771218), -- Recipe: Adamantite Necklace (100%)
(20952, 5275, 1, 1, 2, 112.902552), -- Recipe: Greater Spiritshot (B) Compressed Package(100%)
(20952, 4187, 1, 1, 2, 65.113112), -- Recipe: Kris (100%)
(20952, 8726, 1, 1, 2, 1306.891842), -- Life Stone - Level 55
(20952, 8736, 1, 1, 2, 326.760296), -- Mid-Grade Life Stone - Level 55
(20952, 8746, 1, 1, 2, 32.705898), -- High-Grade Life Stone - Level 55
(20952, 8756, 1, 1, 2, 6.272364), -- Top-Grade Life Stone - Level 55
-- Pobby
(20953, 4948, 1, 1, -1, 7508), -- Recipe: Avadon Leather Armor (60%)
(20953, 2962, 1, 1, -1, 93209), -- Drake Leather Gloves Design
(20953, 1864, 1, 7, -1, 855888), -- Stem
(20953, 57, 675, 1379, 0, 700000), -- Adena
(20953, 12338, 1, 1, 1, 690.734994), -- Common Item - Adamantite Earring
(20953, 4049, 1, 1, 1, 4420.076379), -- Adamantite Earring Gemstone
(20953, 12339, 1, 1, 1, 518.574231), -- Common Item - Adamantite Necklace
(20953, 4051, 1, 1, 1, 3268.12881), -- Adamantite Necklace Chain
(20953, 12340, 1, 1, 1, 1040.36217), -- Common Item - Adamantite Ring
(20953, 4050, 1, 1, 1, 5221.123416), -- Adamantite Ring Wire
(20953, 1864, 1, 1, 2, 84271.931253), -- Stem
(20953, 1869, 1, 1, 2, 42135.87924), -- Iron Ore
(20953, 1878, 1, 1, 2, 16854.351696), -- Braided Hemp
(20953, 1884, 1, 1, 2, 25929.77184), -- Cord
(20953, 4039, 1, 1, 2, 1404.471717), -- Mold Glue
(20953, 4962, 1, 1, 2, 541.643355), -- Recipe: Zubei's Helmet (60%)
(20953, 4999, 1, 1, 2, 524.020509), -- Recipe: Sealed Doom Boots (60%)
(20953, 8311, 1, 1, 2, 32.135778), -- Recipe: Kaim Vanul's Bones (100%)
(20953, 8727, 1, 1, 2, 842.786694), -- Life Stone - Level 58
(20953, 8737, 1, 1, 2, 210.610287), -- Mid-Grade Life Stone - Level 58
(20953, 8747, 1, 1, 2, 21.078306), -- High-Grade Life Stone - Level 58
(20953, 8757, 1, 1, 2, 4.319325), -- Top-Grade Life Stone - Level 58
-- Hungered Corpse
(20954, 4613, 1, 1, -1, 2805), -- Greater Dye of STR (Str+4 Con-4)
(20954, 4049, 1, 1, -1, 106679), -- Adamantite Earring Gemstone
(20954, 1869, 1, 5, -1, 677943), -- Iron Ore
(20954, 57, 804, 1635, 0, 700000), -- Adena
(20954, 11915, 1, 1, 1, 85.937856), -- Common Item - Kris
(20954, 4109, 1, 1, 1, 846.062144), -- Kris Edge
(20954, 11919, 1, 1, 1, 85.937856), -- Common Item - Hell Knife
(20954, 4110, 1, 1, 1, 846.062144), -- Hell Knife Edge
(20954, 1869, 1, 1, 2, 54614.611875), -- Iron Ore
(20954, 1864, 1, 1, 2, 109229.050125), -- Stem
(20954, 1880, 1, 1, 2, 5461.374375), -- Steel
(20954, 5550, 1, 1, 2, 728.18325), -- Durable Metal Plate
(20954, 4043, 1, 1, 2, 1820.458125), -- Asofe
(20954, 4159, 1, 1, 2, 154.699875), -- Recipe: Blue Wolf Leather Armor (100%)
(20954, 4990, 1, 1, 2, 451.425), -- Recipe: Blue Wolf Helmet (60%)
(20954, 8728, 1, 1, 2, 910.315875), -- Life Stone - Level 61
(20954, 8738, 1, 1, 2, 227.622375), -- Mid-Grade Life Stone - Level 61
(20954, 8748, 1, 1, 2, 22.744875), -- High-Grade Life Stone - Level 61
(20954, 8758, 1, 1, 2, 4.51425), -- Top-Grade Life Stone - Level 61
-- Ghostly Warrior
(20955, 5230, 1, 1, -1, 3164), -- Recipe: Mithril Arrow (100%)
(20955, 4052, 1, 1, -1, 84007), -- Earring of Black Ore Piece
(20955, 57, 941, 1906, 0, 700000), -- Adena
(20955, 12194, 1, 1, 1, 191.508928), -- Common Item - Blue Wolf Leather Armor
(20955, 4082, 1, 1, 1, 1979.991072), -- Blue Wolf Leather Armor Texture
(20955, 12186, 1, 1, 1, 191.508928), -- Common Item - Leather Armor of Doom
(20955, 4083, 1, 1, 1, 1979.991072), -- Leather Armor of Doom Design
(20955, 1870, 1, 1, 2, 63717.00321), -- Coal
(20955, 1865, 1, 1, 2, 63717.00321), -- Varnish
(20955, 1874, 1, 1, 2, 4247.800214), -- Oriharukon Ore
(20955, 4043, 1, 1, 2, 2123.900107), -- Asofe
(20955, 4039, 1, 1, 2, 2123.900107), -- Mold Glue
(20955, 1830, 1, 1, 2, 25486.801284), -- Scroll of Escape: Castle
(20955, 5276, 1, 1, 2, 85.034047), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20955, 8729, 1, 1, 2, 849.527525), -- Life Stone - Level 64
(20955, 8739, 1, 1, 2, 212.341234), -- Mid-Grade Life Stone - Level 64
(20955, 8749, 1, 1, 2, 21.299159), -- High-Grade Life Stone - Level 64
(20955, 8759, 1, 1, 2, 4.389903), -- Top-Grade Life Stone - Level 64
-- Past Knight
(20956, 4987, 1, 1, -1, 9891), -- Recipe: Tunic of Doom (60%)
(20956, 4106, 1, 1, -1, 13417), -- Sprite's Staff Head
(20956, 1884, 1, 3, -1, 733439), -- Cord
(20956, 57, 946, 1914, 0, 700000), -- Adena
(20956, 11939, 1, 1, 1, 114.995952), -- Common Item - Demon's Dagger
(20956, 4119, 1, 1, 1, 1541.004048), -- Demon's Dagger Edge
(20956, 1874, 1, 1, 2, 3911.681418), -- Oriharukon Ore
(20956, 1878, 1, 1, 2, 23469.967654), -- Braided Hemp
(20956, 1884, 1, 1, 2, 36107.670434), -- Cord
(20956, 1889, 1, 1, 2, 3911.681418), -- Compound Braid
(20956, 5220, 1, 1, 2, 2346.98468), -- Metal Hardener
(20956, 4175, 1, 1, 2, 1130.58917), -- Recipe: Sealed Avadon Boots (100%)
(20956, 2508, 1, 1, 2, 48895.836444), -- Cursed Bone
(20956, 3956, 1, 1, 2, 78.192538), -- Recipe: Blessed Spiritshot A
(20956, 8729, 1, 1, 2, 782.287942), -- Life Stone - Level 64
(20956, 8739, 1, 1, 2, 195.541772), -- Mid-Grade Life Stone - Level 64
(20956, 8749, 1, 1, 2, 19.578348), -- High-Grade Life Stone - Level 64
(20956, 8759, 1, 1, 2, 3.988182), -- Top-Grade Life Stone - Level 64
-- Nihil Invader
(20957, 4053, 1, 1, -1, 107147), -- Ring of Black Ore Gemstone
(20957, 1877, 1, 1, -1, 99989), -- Adamantite Nugget
(20957, 4052, 1, 1, -1, 88502), -- Earring of Black Ore Piece
(20957, 57, 990, 2008, 0, 700000), -- Adena
(20957, 12183, 1, 1, 1, 624.694206), -- Common Item - Doom Shield
(20957, 4077, 1, 1, 1, 5535.988494), -- Doom Shield Fragment
(20957, 12202, 1, 1, 1, 437.17812), -- Common Item - Blue Wolf Helmet
(20957, 4088, 1, 1, 1, 4650.98053), -- Blue Wolf Helmet Design
(20957, 12185, 1, 1, 1, 437.17812), -- Common Item - Doom Helmet
(20957, 4089, 1, 1, 1, 4650.98053), -- Doom Helmet Pattern
(20957, 1871, 1, 1, 2, 61532.00592), -- Charcoal
(20957, 1866, 1, 1, 2, 41021.33728), -- Suede
(20957, 1877, 1, 1, 2, 2461.33888), -- Adamantite Nugget
(20957, 4041, 1, 1, 2, 535.1192), -- Mold Hardener
(20957, 4040, 1, 1, 2, 1230.66944), -- Mold Lubricant
(20957, 1830, 1, 1, 2, 24612.76048), -- Scroll of Escape: Castle
(20957, 5276, 1, 1, 2, 82.10048), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20957, 8729, 1, 1, 2, 820.37648), -- Life Stone - Level 64
(20957, 8739, 1, 1, 2, 205.04176), -- Mid-Grade Life Stone - Level 64
(20957, 8749, 1, 1, 2, 20.52512), -- High-Grade Life Stone - Level 64
(20957, 8759, 1, 1, 2, 4.1888), -- Top-Grade Life Stone - Level 64
(20957, 1344, 10, 30, 2, 76914.53616), -- Mithril Arrow
-- Death Agent
(20958, 5478, 1, 1, -1, 15776), -- Sealed Dark Crystal Leather Armor Pattern
(20958, 1807, 1, 1, -1, 2501), -- Recipe: Soulshot (A-Grade)
(20958, 57, 742, 1509, 0, 700000), -- Adena
(20958, 12225, 1, 1, 1, 383.207895), -- Common Item - Sealed Dark Crystal Shield
(20958, 5494, 1, 1, 1, 1939.59099), -- Sealed Dark Crystal Shield Fragment
(20958, 12226, 1, 1, 1, 268.46784), -- Common Item - Sealed Dark Crystal Helmet
(20958, 5525, 1, 1, 1, 1427.62986), -- Sealed Dark Crystal Helmet Design
(20958, 12234, 1, 1, 1, 268.46784), -- Common Item - Sealed Tallum Helmet
(20958, 5526, 1, 1, 1, 1427.635575), -- Sealed Tallum Helm Design
(20958, 1872, 1, 1, 2, 73888.48786), -- Animal Bone
(20958, 1867, 1, 1, 2, 73888.48786), -- Animal Skin
(20958, 1881, 1, 1, 2, 7388.768684), -- Coarse Bone Powder
(20958, 1875, 1, 1, 2, 3694.464444), -- Stone of Purity
(20958, 4041, 1, 1, 2, 481.893632), -- Mold Hardener
(20958, 5156, 1, 1, 2, 73.854044), -- Recipe: Soulshot (A) Compressed Package (100%)
(20958, 8730, 1, 1, 2, 615.663972), -- Life Stone - Level 67
(20958, 8740, 1, 1, 2, 153.956044), -- Mid-Grade Life Stone - Level 67
(20958, 8750, 1, 1, 2, 15.379584), -- High-Grade Life Stone - Level 67
(20958, 8760, 1, 1, 2, 3.043876), -- Top-Grade Life Stone - Level 67
-- Dark Guard
(20959, 4054, 1, 1, -1, 59502), -- Necklace of Black Ore Beads
(20959, 5478, 1, 1, -1, 25403), -- Sealed Dark Crystal Leather Armor Pattern
(20959, 1807, 1, 1, -1, 4028), -- Recipe: Soulshot (A-Grade)
(20959, 57, 1195, 2431, 0, 700000), -- Adena
(20959, 12232, 1, 1, 1, 216.001044), -- Common Item - Sealed Tallum Tunic
(20959, 5485, 1, 1, 1, 1250.548992), -- Sealed Tallum Tunic Texture
(20959, 12223, 1, 1, 1, 132.780816), -- Common Item - Sealed Dark Crystal Robe
(20959, 5486, 1, 1, 1, 879.972156), -- Sealed Dark Crystal Robe Fabric
(20959, 12235, 1, 1, 1, 345.851604), -- Common Item - Sealed Tallum Stockings
(20959, 5489, 1, 1, 1, 1962.845388), -- Sealed Tallum Stockings Fabric
(20959, 1871, 1, 1, 2, 81120.798288), -- Charcoal
(20959, 1866, 1, 1, 2, 54080.532192), -- Suede
(20959, 1877, 1, 1, 2, 3244.763004), -- Adamantite Nugget
(20959, 4041, 1, 1, 2, 705.358288), -- Mold Hardener
(20959, 4040, 1, 1, 2, 1622.381502), -- Mold Lubricant
(20959, 4953, 1, 1, 2, 1563.075115), -- Recipe: Sealed Avadon Gloves (60%)
(20959, 5281, 1, 1, 2, 108.130047), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(20959, 8730, 1, 1, 2, 901.370923), -- Life Stone - Level 67
(20959, 8740, 1, 1, 2, 225.306831), -- Mid-Grade Life Stone - Level 67
(20959, 8750, 1, 1, 2, 22.545043), -- High-Grade Life Stone - Level 67
(20959, 8760, 1, 1, 2, 4.738767), -- Top-Grade Life Stone - Level 67
-- Bloody Ghost
(20960, 4052, 1, 1, -1, 58175), -- Earring of Black Ore Piece
(20960, 5230, 1, 1, -1, 2191), -- Recipe: Mithril Arrow (100%)
(20960, 4053, 1, 1, -1, 70431), -- Ring of Black Ore Gemstone
(20960, 57, 652, 1319, 0, 700000), -- Adena
(20960, 11932, 1, 1, 1, 79.271942), -- Common Item - Lance
(20960, 4115, 1, 1, 1, 1058.728058), -- Lance Blade
(20960, 1873, 1, 1, 2, 16178.77374), -- Silver Nugget
(20960, 1868, 1, 1, 2, 80893.516758), -- Thread
(20960, 1876, 1, 1, 2, 8089.38687), -- Mithril Ore
(20960, 1895, 1, 1, 2, 11556.191541), -- Metallic Fiber
(20960, 4042, 1, 1, 2, 674.144901), -- Enria
(20960, 5230, 1, 1, 2, 53.847126), -- Recipe: Mithril Arrow (100%)
(20960, 5276, 1, 1, 2, 53.847126), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20960, 8729, 1, 1, 2, 539.351115), -- Life Stone - Level 64
(20960, 8739, 1, 1, 2, 134.793786), -- Mid-Grade Life Stone - Level 64
(20960, 8749, 1, 1, 2, 13.549767), -- High-Grade Life Stone - Level 64
(20960, 8759, 1, 1, 2, 2.639565), -- Top-Grade Life Stone - Level 64
(20960, 1343, 10, 30, 2, 57780.957705), -- Silver Arrow
-- Bloody Knight
(20961, 1884, 1, 3, -1, 744103), -- Cord
(20961, 4053, 1, 1, -1, 103658), -- Ring of Black Ore Gemstone
(20961, 5230, 1, 1, -1, 3224), -- Recipe: Mithril Arrow (100%)
(20961, 57, 958, 1943, 0, 700000), -- Adena
(20961, 12188, 1, 1, 1, 474.972605), -- Common Item - Sealed Doom Boots
(20961, 4099, 1, 1, 1, 4008.777395), -- Sealed Doom Boots Part
(20961, 12189, 1, 1, 1, 474.972605), -- Common Item - Sealed Blue Wolf Boots
(20961, 4090, 1, 1, 1, 4008.777395), -- Sealed Blue Wolf Boots Design
(20961, 12187, 1, 1, 1, 474.972605), -- Common Item - Sealed Doom Gloves
(20961, 4091, 1, 1, 1, 4008.777395), -- Sealed Doom Gloves Part
(20961, 12190, 1, 1, 1, 474.972605), -- Common Item - Sealed Blue Wolf Gloves
(20961, 4096, 1, 1, 1, 4008.777395), -- Sealed Blue Wolf Gloves Fabric
(20961, 1864, 1, 1, 2, 119056.63003), -- Stem
(20961, 1869, 1, 1, 2, 59528.19391), -- Iron Ore
(20961, 1878, 1, 1, 2, 23811.42289), -- Braided Hemp
(20961, 1884, 1, 1, 2, 36632.80924), -- Cord
(20961, 4039, 1, 1, 2, 1984.18432), -- Mold Glue
(20961, 5230, 1, 1, 2, 79.44488), -- Recipe: Mithril Arrow (100%)
(20961, 3956, 1, 1, 2, 79.44488), -- Recipe: Blessed Spiritshot A
(20961, 8326, 1, 1, 2, 22.04111), -- Recipe: Doom Crusher (60%)
(20961, 8729, 1, 1, 2, 793.72217), -- Life Stone - Level 64
(20961, 8739, 1, 1, 2, 198.36999), -- Mid-Grade Life Stone - Level 64
(20961, 8749, 1, 1, 2, 19.86122), -- High-Grade Life Stone - Level 64
(20961, 8759, 1, 1, 2, 3.87536), -- Top-Grade Life Stone - Level 64
-- Bloody Priest
(20962, 4054, 1, 1, -1, 45467), -- Necklace of Black Ore Beads
(20962, 5230, 1, 1, -1, 3078), -- Recipe: Mithril Arrow (100%)
(20962, 4077, 1, 1, -1, 103839), -- Doom Shield Fragment
(20962, 57, 914, 1854, 0, 700000), -- Adena
(20962, 12194, 1, 1, 1, 186.3056), -- Common Item - Blue Wolf Leather Armor
(20962, 4082, 1, 1, 1, 1926.1944), -- Blue Wolf Leather Armor Texture
(20962, 12186, 1, 1, 1, 186.3056), -- Common Item - Leather Armor of Doom
(20962, 4083, 1, 1, 1, 1926.1944), -- Leather Armor of Doom Design
(20962, 1865, 1, 1, 2, 56821.062477), -- Varnish
(20962, 1870, 1, 1, 2, 56821.062477), -- Coal
(20962, 1879, 1, 1, 2, 9470.11249), -- Cokes
(20962, 1875, 1, 1, 2, 3788.044996), -- Stone of Purity
(20962, 4040, 1, 1, 2, 1136.387663), -- Mold Lubricant
(20962, 5230, 1, 1, 2, 75.698894), -- Recipe: Mithril Arrow (100%)
(20962, 3956, 1, 1, 2, 75.698894), -- Recipe: Blessed Spiritshot A
(20962, 8326, 1, 1, 2, 21.056177), -- Recipe: Doom Crusher (60%)
(20962, 8729, 1, 1, 2, 757.634835), -- Life Stone - Level 64
(20962, 8739, 1, 1, 2, 189.376414), -- Mid-Grade Life Stone - Level 64
(20962, 8749, 1, 1, 2, 18.989313), -- High-Grade Life Stone - Level 64
(20962, 8759, 1, 1, 2, 3.87537), -- Top-Grade Life Stone - Level 64
-- Bloody Lord
(20963, 4116, 1, 1, -1, 9589), -- Deadman's Glory Stone
(20963, 5479, 1, 1, -1, 12984), -- Sealed Tallum Leather Armor Pattern
(20963, 5478, 1, 1, -1, 18452), -- Sealed Dark Crystal Leather Armor Pattern
(20963, 57, 868, 1764, 0, 700000), -- Adena
(20963, 12224, 1, 1, 1, 353.041969), -- Common Item - Sealed Dark Crystal Boots
(20963, 5496, 1, 1, 1, 1899.708031), -- Sealed Dark Crystal Boots Lining
(20963, 12231, 1, 1, 1, 353.041969), -- Common Item - Sealed Tallum Boots
(20963, 5497, 1, 1, 1, 1899.708031), -- Sealed Tallum Boots Lining
(20963, 12221, 1, 1, 1, 353.041969), -- Common Item - Sealed Dark Crystal Gloves
(20963, 5508, 1, 1, 1, 1899.708031), -- Sealed Dark Crystal Gloves Design
(20963, 12229, 1, 1, 1, 353.041969), -- Common Item - Sealed Tallum Gloves
(20963, 5509, 1, 1, 1, 1899.708031), -- Sealed Tallum Gloves Design
(20963, 1869, 1, 1, 2, 64815.97998), -- Iron Ore
(20963, 1864, 1, 1, 2, 129632.16502), -- Stem
(20963, 1880, 1, 1, 2, 6481.53648), -- Steel
(20963, 5550, 1, 1, 2, 864.12284), -- Durable Metal Plate
(20963, 4043, 1, 1, 2, 2160.51216), -- Asofe
(20963, 4984, 1, 1, 2, 183.5287), -- Recipe: Blue Wolf Leather Armor (60%)
(20963, 8730, 1, 1, 2, 720.17072), -- Life Stone - Level 67
(20963, 8740, 1, 1, 2, 180.04268), -- Mid-Grade Life Stone - Level 67
(20963, 8750, 1, 1, 2, 18.04528), -- High-Grade Life Stone - Level 67
(20963, 8760, 1, 1, 2, 3.89614), -- Top-Grade Life Stone - Level 67
-- Chimera Piece
(20965, 4089, 1, 1, -1, 230094), -- Doom Helmet Pattern
(20965, 5482, 1, 1, -1, 80357), -- Sealed Dark Crystal Leggings Design
(20965, 4043, 1, 1, -1, 202943), -- Asofe
(20965, 57, 3002, 6130, 0, 700000), -- Adena
(20965, 12345, 1, 1, 1, 1446.571137), -- Common Item - Sealed Phoenix Earring
(20965, 6341, 1, 1, 1, 10362.734767), -- Sealed Phoenix Earring Gemstone
(20965, 12344, 1, 1, 1, 1085.966508), -- Common Item - Sealed Phoenix Necklace
(20965, 6343, 1, 1, 1, 8010.780019), -- Sealed Phoenix Necklace Beads
(20965, 12346, 1, 1, 1, 2171.970427), -- Common Item - Sealed Phoenix Ring
(20965, 6345, 1, 1, 1, 14332.977142), -- Sealed Phoenix Ring Gemstone
(20965, 1869, 1, 1, 2, 224798.068656), -- Iron Ore
(20965, 1864, 1, 3, 2, 224798.068656), -- Stem
(20965, 1880, 1, 1, 2, 22480.001544), -- Steel
(20965, 5550, 1, 1, 2, 2997.073968), -- Durable Metal Plate
(20965, 4043, 1, 1, 2, 7493.171616), -- Asofe
(20965, 4161, 1, 1, 2, 932.996232), -- Recipe: Blue Wolf Tunic (100%)
(20965, 8730, 1, 1, 2, 2497.723872), -- Life Stone - Level 67
(20965, 8740, 1, 1, 2, 624.430968), -- Mid-Grade Life Stone - Level 67
(20965, 8750, 1, 1, 2, 62.297088), -- High-Grade Life Stone - Level 67
(20965, 8760, 1, 1, 2, 12.1674), -- Top-Grade Life Stone - Level 67
-- Changed Creation
(20966, 4085, 1, 1, -1, 149386), -- Tunic of Doom Pattern
(20966, 4044, 1, 1, -1, 286523), -- Thons
(20966, 1894, 1, 1, -1, 301603), -- Crafted Leather
(20966, 57, 4242, 8646, 0, 700000), -- Adena
(20966, 12222, 1, 1, 1, 768.27439), -- Common Item - Sealed Dark Crystal Leather Armor
(20966, 5478, 1, 1, 1, 4447.96352), -- Sealed Dark Crystal Leather Armor Pattern
(20966, 12230, 1, 1, 1, 472.27596), -- Common Item - Sealed Tallum Leather Armor
(20966, 5479, 1, 1, 1, 3129.89261), -- Sealed Tallum Leather Armor Pattern
(20966, 12228, 1, 1, 1, 1230.12799), -- Common Item - Sealed Dark Crystal Leggings
(20966, 5482, 1, 1, 1, 6981.46553), -- Sealed Dark Crystal Leggings Design
(20966, 1894, 1, 1, 2, 11136.12838), -- Crafted Leather
(20966, 4039, 1, 1, 2, 10579.07232), -- Mold Glue
(20966, 4041, 1, 1, 2, 2759.95957), -- Mold Hardener
(20966, 4044, 1, 1, 2, 10579.07232), -- Thons
(20966, 4617, 1, 1, 2, 437.58501), -- Greater Dye of DEX (Dex+4 Str-4)
(20966, 6037, 1, 3, 2, 317376.44916), -- Waking Scroll
(20966, 8731, 1, 1, 2, 2938.6312), -- Life Stone - Level 70
(20966, 8741, 1, 1, 2, 734.6578), -- Mid-Grade Life Stone - Level 70
(20966, 8751, 1, 1, 2, 73.46578), -- High-Grade Life Stone - Level 70
(20966, 8761, 1, 1, 2, 14.97846), -- Top-Grade Life Stone - Level 70
-- Ancient Creature
(20967, 5485, 1, 1, -1, 53992), -- Sealed Tallum Tunic Texture
(20967, 5156, 1, 1, -1, 8561), -- Recipe: Soulshot (A) Compressed Package (100%)
(20967, 4041, 1, 1, -1, 55832), -- Mold Hardener
(20967, 57, 3159, 6468, 0, 700000), -- Adena
(20967, 12345, 1, 1, 1, 1525.567818), -- Common Item - Sealed Phoenix Earring
(20967, 6341, 1, 1, 1, 10928.639638), -- Sealed Phoenix Earring Gemstone
(20967, 12344, 1, 1, 1, 1145.270712), -- Common Item - Sealed Phoenix Necklace
(20967, 6343, 1, 1, 1, 8448.245566), -- Sealed Phoenix Necklace Beads
(20967, 12346, 1, 1, 1, 2290.580878), -- Common Item - Sealed Phoenix Ring
(20967, 6345, 1, 1, 1, 15115.695388), -- Sealed Phoenix Ring Gemstone
(20967, 1867, 1, 3, 2, 175609.124592), -- Animal Skin
(20967, 1872, 1, 3, 2, 117072.627111), -- Animal Bone
(20967, 1882, 1, 1, 2, 58536.497481), -- Leather
(20967, 1894, 1, 1, 2, 9242.624226), -- Crafted Leather
(20967, 4042, 1, 1, 2, 4390.301685), -- Enria
(20967, 5001, 1, 1, 2, 201.214497), -- Recipe: Lance (60%)
(20967, 8732, 1, 1, 2, 2194.966917), -- Life Stone - Level 76
(20967, 8742, 1, 1, 2, 548.833692), -- Mid-Grade Life Stone - Level 76
(20967, 8752, 1, 1, 2, 54.809799), -- High-Grade Life Stone - Level 76
-- Forgotten Face
(20968, 5486, 1, 1, -1, 46360), -- Sealed Dark Crystal Robe Fabric
(20968, 5480, 1, 1, -1, 35156), -- Sealed Leather Armor of Nightmare Fabric
(20968, 5481, 1, 1, -1, 35156), -- Sealed Majestic Leather Armor Fabric
(20968, 57, 3864, 7887, 0, 700000), -- Adena
(20968, 12224, 1, 1, 1, 1575.622664), -- Common Item - Sealed Dark Crystal Boots
(20968, 5496, 1, 1, 1, 8478.377336), -- Sealed Dark Crystal Boots Lining
(20968, 12231, 1, 1, 1, 1575.622664), -- Common Item - Sealed Tallum Boots
(20968, 5497, 1, 1, 1, 8478.377336), -- Sealed Tallum Boots Lining
(20968, 12221, 1, 1, 1, 1575.622664), -- Common Item - Sealed Dark Crystal Gloves
(20968, 5508, 1, 1, 1, 8478.377336), -- Sealed Dark Crystal Gloves Design
(20968, 12229, 1, 1, 1, 1575.622664), -- Common Item - Sealed Tallum Gloves
(20968, 5509, 1, 1, 1, 8478.377336), -- Sealed Tallum Gloves Design
(20968, 1868, 1, 3, 2, 262985.596155), -- Thread
(20968, 1873, 1, 1, 2, 105194.238462), -- Silver Nugget
(20968, 5549, 1, 1, 2, 26298.343332), -- Metallic Thread
(20968, 1889, 1, 1, 2, 17532.373077), -- Compound Braid
(20968, 4044, 1, 1, 2, 8765.970255), -- Thons
(20968, 5007, 1, 1, 2, 200.711088), -- Recipe: Bow of Peril (60%)
(20968, 729, 1, 1, 2, 29.414556), -- Scroll: Enchant Weapon (A-Grade)
(20968, 8732, 1, 1, 2, 2191.384422), -- Life Stone - Level 76
(20968, 8742, 1, 1, 2, 548.062389), -- Mid-Grade Life Stone - Level 76
(20968, 8752, 1, 1, 2, 54.936009), -- High-Grade Life Stone - Level 76
(20968, 6036, 1, 1, 2, 8765.970255), -- Greater Magic Haste Potion
-- Giant's Shadow
(20969, 5161, 1, 1, -1, 13821), -- Recipe: Spiritshot (A) Compressed Package (100%)
(20969, 5487, 1, 1, -1, 46678), -- Sealed Robe of Nightmare Fabric
(20969, 729, 1, 1, -1, 1152), -- Scroll: Enchant Weapon (A-Grade)
(20969, 57, 5111, 10430, 0, 700000), -- Adena
(20969, 12267, 1, 1, 1, 1301.84632), -- Common Item - Sealed Boots of Nightmare
(20969, 5502, 1, 1, 1, 8080.15368), -- Sealed Boots of Nightmare Lining
(20969, 12260, 1, 1, 1, 1301.84632), -- Common Item - Sealed Majestic Boots
(20969, 5503, 1, 1, 1, 8080.15368), -- Sealed Majestic Boots Lining
(20969, 12264, 1, 1, 1, 1301.84632), -- Common Item - Sealed Gauntlet of Nightmare
(20969, 5514, 1, 1, 1, 8080.15368), -- Sealed Gauntlets of Nightmare Design
(20969, 12257, 1, 1, 1, 1301.84632), -- Common Item - Sealed Majestic Gauntlet
(20969, 5515, 1, 1, 1, 8080.15368), -- Sealed Majestic Gauntlets Design
(20969, 1894, 1, 1, 2, 16786.690002), -- Crafted Leather
(20969, 4039, 1, 1, 2, 15947.402502), -- Mold Glue
(20969, 4041, 1, 1, 2, 4160.18028), -- Mold Hardener
(20969, 4044, 1, 1, 2, 15947.402502), -- Thons
(20969, 4150, 1, 1, 2, 9218.129613), -- Recipe: Sealed Avadon Gloves (100%)
(20969, 8732, 1, 1, 2, 3986.817054), -- Life Stone - Level 76
(20969, 8742, 1, 1, 2, 996.737835), -- Mid-Grade Life Stone - Level 76
(20969, 8752, 1, 1, 2, 99.640212), -- High-Grade Life Stone - Level 76
-- Soldier of Ancient Times
(20970, 5489, 1, 1, -1, 82857), -- Sealed Tallum Stockings Fabric
(20970, 1895, 1, 3, -1, 896811), -- Metallic Fiber
(20970, 4042, 1, 1, -1, 104628), -- Enria
(20970, 57, 3100, 6312, 0, 700000), -- Adena
(20970, 12224, 1, 1, 1, 1262.464917), -- Common Item - Sealed Dark Crystal Boots
(20970, 5496, 1, 1, 1, 6793.285083), -- Sealed Dark Crystal Boots Lining
(20970, 12231, 1, 1, 1, 1262.464917), -- Common Item - Sealed Tallum Boots
(20970, 5497, 1, 1, 1, 6793.285083), -- Sealed Tallum Boots Lining
(20970, 12221, 1, 1, 1, 1262.464917), -- Common Item - Sealed Dark Crystal Gloves
(20970, 5508, 1, 1, 1, 6793.285083), -- Sealed Dark Crystal Gloves Design
(20970, 12229, 1, 1, 1, 1262.464917), -- Common Item - Sealed Tallum Gloves
(20970, 5509, 1, 1, 1, 6793.285083), -- Sealed Tallum Gloves Design
(20970, 10581, 1, 1, 2, 12010), -- Forgotten Scroll - Improve Condition
(20970, 10584, 1, 1, 2, 12010), -- Forgotten Scroll - Improve Movement
(20970, 10609, 1, 1, 2, 12010), -- Forgotten Scroll - Chant of Critical
(20970, 14217, 1, 1, 2, 12010), -- Forgotten Scroll - Condition of Pa'agrio
-- Warrior of Ancient Times
(20971, 1877, 1, 1, -1, 266382), -- Adamantite Nugget
(20971, 1876, 1, 3, -1, 665954), -- Mithril Ore
(20971, 1895, 1, 5, -1, 634242), -- Metallic Fiber
(20971, 57, 3285, 6703, 0, 700000), -- Adena
(20971, 12225, 1, 1, 1, 1700.46408), -- Common Item - Sealed Dark Crystal Shield
(20971, 5494, 1, 1, 1, 8606.82896), -- Sealed Dark Crystal Shield Fragment
(20971, 12226, 1, 1, 1, 1191.31136), -- Common Item - Sealed Dark Crystal Helmet
(20971, 5525, 1, 1, 1, 6335.02944), -- Sealed Dark Crystal Helmet Design
(20971, 12234, 1, 1, 1, 1191.31136), -- Common Item - Sealed Tallum Helmet
(20971, 5526, 1, 1, 1, 6335.0548), -- Sealed Tallum Helm Design
(20971, 12768, 1, 1, 2, 19671.5), -- Forgotten Scroll - Evasion Counter
(20971, 12769, 1, 1, 2, 19671.5), -- Forgotten Scroll - Evasion Chance
-- Shaman of Ancient Times
(20972, 4077, 1, 1, -1, 310559), -- Doom Shield Fragment
(20972, 4087, 1, 1, -1, 162002), -- Stockings of Doom Pattern
(20972, 5494, 1, 1, -1, 144990), -- Sealed Dark Crystal Shield Fragment
(20972, 57, 3405, 6948, 0, 700000), -- Adena
(20972, 12224, 1, 1, 1, 1388.386223), -- Common Item - Sealed Dark Crystal Boots
(20972, 5496, 1, 1, 1, 7470.863777), -- Sealed Dark Crystal Boots Lining
(20972, 12231, 1, 1, 1, 1388.386223), -- Common Item - Sealed Tallum Boots
(20972, 5497, 1, 1, 1, 7470.863777), -- Sealed Tallum Boots Lining
(20972, 12221, 1, 1, 1, 1388.386223), -- Common Item - Sealed Dark Crystal Gloves
(20972, 5508, 1, 1, 1, 7470.863777), -- Sealed Dark Crystal Gloves Design
(20972, 12229, 1, 1, 1, 1388.386223), -- Common Item - Sealed Tallum Gloves
(20972, 5509, 1, 1, 1, 7470.863777), -- Sealed Tallum Gloves Design
(20972, 12771, 1, 1, 2, 20392.5), -- Forgotten Scroll - Shadow Step
(20972, 12770, 1, 1, 2, 20392.5), -- Forgotten Scroll - Evasion Haste
-- Forgotten Ancient People
(20973, 4078, 1, 1, -1, 128365), -- Blue Wolf Breastplate Part
(20973, 5166, 1, 1, -1, 11717), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(20973, 5496, 1, 1, -1, 206046), -- Sealed Dark Crystal Boots Lining
(20973, 57, 4332, 8850, 0, 700000), -- Adena
(20973, 12345, 1, 1, 1, 2088.018), -- Common Item - Sealed Phoenix Earring
(20973, 6341, 1, 1, 1, 14957.838), -- Sealed Phoenix Earring Gemstone
(20973, 12344, 1, 1, 1, 1567.512), -- Common Item - Sealed Phoenix Necklace
(20973, 6343, 1, 1, 1, 11562.966), -- Sealed Phoenix Necklace Beads
(20973, 12346, 1, 1, 1, 3135.078), -- Common Item - Sealed Phoenix Ring
(20973, 6345, 1, 1, 1, 20688.588), -- Sealed Phoenix Ring Gemstone
(20973, 1872, 1, 3, 2, 180263.991168), -- Animal Bone
(20973, 1867, 1, 3, 2, 120175.994112), -- Animal Skin
(20973, 1881, 1, 1, 2, 36052.94301), -- Coarse Bone Powder
(20973, 1875, 1, 1, 2, 18026.471505), -- Stone of Purity
(20973, 4041, 1, 1, 2, 2351.168736), -- Mold Hardener
(20973, 4982, 1, 1, 2, 1345.334697), -- Recipe: Blue Wolf Gaiters (60%)
(20973, 4624, 1, 1, 2, 372.79923), -- Greater Dye of WIT (Wit+4 Men-4)
(20973, 8314, 1, 1, 2, 147.671928), -- Recipe: Spiritual Eye (60%)
(20973, 8731, 1, 1, 2, 2503.545897), -- Life Stone - Level 70
(20973, 8741, 1, 1, 2, 625.795989), -- Mid-Grade Life Stone - Level 70
(20973, 8751, 1, 1, 2, 62.615793), -- High-Grade Life Stone - Level 70
(20973, 8761, 1, 1, 2, 12.667935), -- Top-Grade Life Stone - Level 70
-- Spiteful Soul Leader
(20974, 5230, 1, 1, -1, 6478), -- Recipe: Mithril Arrow (100%)
(20974, 4052, 1, 1, -1, 172021), -- Earring of Black Ore Piece
(20974, 57, 1925, 3904, 0, 700000), -- Adena
(20974, 268, 1, 1, 1, 14.22225), -- Bellion Cestus
(20974, 4120, 1, 1, 1, 3135.77775), -- Bellion Cestus Edge
(20974, 1871, 1, 1, 2, 130472.173904), -- Charcoal
(20974, 1866, 1, 1, 2, 86981.525808), -- Suede
(20974, 1877, 1, 1, 2, 5218.942064), -- Adamantite Nugget
(20974, 4041, 1, 1, 2, 1134.532656), -- Mold Hardener
(20974, 4040, 1, 1, 2, 2609.356224), -- Mold Lubricant
(20974, 4164, 1, 1, 2, 864.045008), -- Recipe: Stockings of Doom (100%)
(20974, 730, 1, 1, 2, 108.837984), -- Scroll: Enchant Armor (A-Grade)
(20974, 8729, 1, 1, 2, 1739.570816), -- Life Stone - Level 64
(20974, 8739, 1, 1, 2, 434.892704), -- Mid-Grade Life Stone - Level 64
(20974, 8749, 1, 1, 2, 43.397424), -- High-Grade Life Stone - Level 64
(20974, 8759, 1, 1, 2, 8.725408), -- Top-Grade Life Stone - Level 64
-- Spiteful Soul Wizard
(20975, 5230, 1, 1, -1, 5745), -- Recipe: Mithril Arrow (100%)
(20975, 4078, 1, 1, -1, 62938), -- Blue Wolf Breastplate Part
(20975, 4053, 1, 1, -1, 184685), -- Ring of Black Ore Gemstone
(20975, 57, 1709, 3460, 0, 700000), -- Adena
(20975, 110, 1, 1, 1, 65.287158), -- Doom Shield
(20975, 4077, 1, 1, 1, 9542.81055), -- Doom Shield Fragment
(20975, 2416, 1, 1, 1, 45.703584), -- Blue Wolf Helmet
(20975, 4088, 1, 1, 1, 8017.247562), -- Blue Wolf Helmet Design
(20975, 2417, 1, 1, 1, 45.703584), -- Doom Helmet
(20975, 4089, 1, 1, 1, 8017.247562), -- Doom Helmet Pattern
(20975, 1866, 1, 1, 2, 77134.926962), -- Suede
(20975, 1871, 1, 1, 2, 115702.390443), -- Charcoal
(20975, 5220, 1, 1, 2, 4628.187966), -- Metal Hardener
(20975, 1885, 1, 1, 2, 9641.930001), -- High-Grade Suede
(20975, 4041, 1, 1, 2, 1006.083206), -- Mold Hardener
(20975, 1830, 1, 1, 2, 46280.853568), -- Scroll of Escape: Castle
(20975, 5276, 1, 1, 2, 154.170323), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20975, 8729, 1, 1, 2, 1542.729322), -- Life Stone - Level 64
(20975, 8739, 1, 1, 2, 385.554069), -- Mid-Grade Life Stone - Level 64
(20975, 8749, 1, 1, 2, 38.47845), -- High-Grade Life Stone - Level 64
(20975, 8759, 1, 1, 2, 7.69569), -- Top-Grade Life Stone - Level 64
-- Spiteful Soul Fighter
(20976, 4080, 1, 1, -1, 75035), -- Blue Wolf Gaiters Material
(20976, 5230, 1, 1, -1, 4864), -- Recipe: Mithril Arrow (100%)
(20976, 4054, 1, 1, -1, 71850), -- Necklace of Black Ore Beads
(20976, 57, 1447, 2930, 0, 700000), -- Adena
(20976, 358, 1, 1, 1, 14.51284), -- Blue Wolf Breastplate
(20976, 4078, 1, 1, 1, 2623.561905), -- Blue Wolf Breastplate Part
(20976, 2381, 1, 1, 1, 8.93223), -- Doom Plate Armor
(20976, 4081, 1, 1, 1, 1770.249215), -- Doom Plate Armor Temper
(20976, 2380, 1, 1, 1, 23.21729), -- Blue Wolf Gaiters
(20976, 4080, 1, 1, 1, 3694.52652), -- Blue Wolf Gaiters Material
(20976, 1867, 1, 1, 2, 119724.213714), -- Animal Skin
(20976, 1872, 1, 1, 2, 119724.213714), -- Animal Bone
(20976, 1882, 1, 1, 2, 19953.969936), -- Leather
(20976, 1894, 1, 1, 2, 3150.81351), -- Crafted Leather
(20976, 4042, 1, 1, 2, 1496.390106), -- Enria
(20976, 5230, 1, 1, 2, 119.805792), -- Recipe: Mithril Arrow (100%)
(20976, 5276, 1, 1, 2, 119.805792), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20976, 8729, 1, 1, 2, 1197.269724), -- Life Stone - Level 64
(20976, 8739, 1, 1, 2, 299.120382), -- Mid-Grade Life Stone - Level 64
(20976, 8749, 1, 1, 2, 29.951448), -- High-Grade Life Stone - Level 64
(20976, 8759, 1, 1, 2, 5.91147), -- Top-Grade Life Stone - Level 64
(20976, 1343, 10, 30, 2, 128276.534412), -- Silver Arrow
-- Elmoreden's Lady
(20977, 947, 1, 1, -1, 2297), -- Scroll: Enchant Weapon (B-Grade)
(20977, 1876, 1, 3, -1, 574367), -- Mithril Ore
(20977, 4052, 1, 1, -1, 203352), -- Earring of Black Ore Piece
(20977, 57, 2276, 4615, 0, 700000), -- Adena
(20977, 864, 1, 1, 1, 79.54051), -- Earring of Black Ore
(20977, 4052, 1, 1, 1, 10010.64148), -- Earring of Black Ore Piece
(20977, 926, 1, 1, 1, 59.662372), -- Necklace of Black Ore
(20977, 4054, 1, 1, 1, 5569.2336), -- Necklace of Black Ore Beads
(20977, 895, 1, 1, 1, 119.296786), -- Ring of Black Ore
(20977, 4053, 1, 1, 1, 12119.625252), -- Ring of Black Ore Gemstone
(20977, 1871, 1, 1, 2, 154235.660703), -- Charcoal
(20977, 1866, 1, 1, 2, 102823.864281), -- Suede
(20977, 1877, 1, 1, 2, 6169.491573), -- Adamantite Nugget
(20977, 4041, 1, 1, 2, 1341.170217), -- Mold Hardener
(20977, 4040, 1, 1, 2, 3084.610068), -- Mold Lubricant
(20977, 4164, 1, 1, 2, 1021.417431), -- Recipe: Stockings of Doom (100%)
(20977, 730, 1, 1, 2, 128.661138), -- Scroll: Enchant Armor (A-Grade)
(20977, 8729, 1, 1, 2, 2056.406712), -- Life Stone - Level 64
(20977, 8739, 1, 1, 2, 514.101678), -- Mid-Grade Life Stone - Level 64
(20977, 8749, 1, 1, 2, 51.301593), -- High-Grade Life Stone - Level 64
(20977, 8759, 1, 1, 2, 10.314606), -- Top-Grade Life Stone - Level 64
-- Elmoreden's Archer Escort
(20978, 5230, 1, 1, -1, 8195), -- Recipe: Mithril Arrow (100%)
(20978, 4081, 1, 1, -1, 60581), -- Doom Plate Armor Temper
(20978, 57, 2440, 4935, 0, 700000), -- Adena
(20978, 79, 1, 1, 1, 5.99697), -- Sword of Damascus
(20978, 4114, 1, 1, 1, 1324.74384), -- Sword of Damascus Blade
(20978, 7883, 1, 1, 1, 5.99697), -- Guardian Sword
(20978, 8330, 1, 1, 1, 1322.51742), -- Guardian Sword Blade
(20978, 7889, 1, 1, 1, 5.99697), -- Wizard's Tear
(20978, 8336, 1, 1, 1, 1324.74783), -- Blade of the Wizard's Tear
(20978, 1868, 1, 1, 2, 330107.489394), -- Thread
(20978, 1873, 1, 1, 2, 66021.697158), -- Silver Nugget
(20978, 5549, 1, 1, 2, 16505.29974), -- Metallic Thread
(20978, 1889, 1, 1, 2, 11003.699226), -- Compound Braid
(20978, 4044, 1, 1, 2, 5501.600514), -- Thons
(20978, 1830, 1, 1, 2, 66021.697158), -- Scroll of Escape: Castle
(20978, 3956, 1, 1, 2, 220.203516), -- Recipe: Blessed Spiritshot A
(20978, 8729, 1, 1, 2, 2200.540566), -- Life Stone - Level 64
(20978, 8739, 1, 1, 2, 550.010592), -- Mid-Grade Life Stone - Level 64
(20978, 8749, 1, 1, 2, 54.80178), -- High-Grade Life Stone - Level 64
(20978, 8759, 1, 1, 2, 10.960356), -- Top-Grade Life Stone - Level 64
-- Elmoreden's Maid
(20979, 4082, 1, 1, -1, 61486), -- Blue Wolf Leather Armor Texture
(20979, 5550, 1, 1, -1, 72554), -- Durable Metal Plate
(20979, 57, 2160, 4369, 0, 700000), -- Adena
(20979, 171, 1, 1, 1, 5.309912), -- Deadman's Glory
(20979, 4116, 1, 1, 1, 1170.530588), -- Deadman's Glory Stone
(20979, 175, 1, 1, 1, 5.309912), -- Art of Battle Axe
(20979, 4117, 1, 1, 1, 1170.530588), -- Art of Battle Axe Blade
(20979, 210, 1, 1, 1, 5.309912), -- Staff of Evil Spirits
(20979, 4118, 1, 1, 1, 1109.009088), -- Evil Spirit Head
(20979, 1869, 1, 1, 2, 133945.27398), -- Iron Ore
(20979, 1864, 1, 3, 2, 133945.27398), -- Stem
(20979, 1880, 1, 1, 2, 13394.72001), -- Steel
(20979, 5550, 1, 1, 2, 1785.99477), -- Durable Metal Plate
(20979, 4043, 1, 1, 2, 4464.74616), -- Asofe
(20979, 5230, 1, 1, 2, 178.64763), -- Recipe: Mithril Arrow (100%)
(20979, 5276, 1, 1, 2, 178.64763), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(20979, 8729, 1, 1, 2, 1785.99477), -- Life Stone - Level 64
(20979, 8739, 1, 1, 2, 446.37831), -- Mid-Grade Life Stone - Level 64
(20979, 8749, 1, 1, 2, 44.78229), -- High-Grade Life Stone - Level 64
(20979, 8759, 1, 1, 2, 9.14907), -- Top-Grade Life Stone - Level 64
(20979, 1343, 10, 30, 2, 191350.3914), -- Silver Arrow
-- Hallate's Follower Mul
(20980, 4041, 1, 1, -1, 55038), -- Mold Hardener
(20980, 4039, 1, 1, -1, 210979), -- Mold Glue
(20980, 4085, 1, 1, -1, 109999), -- Tunic of Doom Pattern
(20980, 57, 2504, 5090, 0, 700000), -- Adena
(20980, 5287, 1, 1, 1, 17.495295), -- Sealed Dark Crystal breastplate
(20980, 5520, 1, 1, 1, 2009.454915), -- Sealed Dark Crystal Breastplate Pattern
(20980, 5293, 1, 1, 1, 10.769865), -- Sealed Tallum Plate Armor
(20980, 5521, 1, 1, 1, 1417.95138), -- Sealed Tallum Plate Armor Pattern
(20980, 5288, 1, 1, 1, 27.996405), -- Sealed Dark Crystal Gaiters
(20980, 5524, 1, 1, 1, 3071.33214), -- Sealed Dark Crystal Gaiters Pattern
(20980, 1869, 2, 6, 2, 42490.85418), -- Iron Ore
(20980, 1870, 2, 6, 2, 33992.50803), -- Coal
(20980, 1871, 1, 1, 2, 169962.54015), -- Charcoal
(20980, 1872, 1, 3, 2, 113308.506195), -- Animal Bone
(20980, 1867, 1, 3, 2, 75538.858035), -- Animal Skin
(20980, 4985, 1, 1, 2, 481.675215), -- Recipe: Leather Armor of Doom (60%)
(20980, 8314, 1, 1, 2, 92.91642), -- Recipe: Spiritual Eye (60%)
(20980, 8730, 1, 1, 2, 1888.570065), -- Life Stone - Level 67
(20980, 8740, 1, 1, 2, 472.032945), -- Mid-Grade Life Stone - Level 67
(20980, 8750, 1, 1, 2, 47.33478), -- High-Grade Life Stone - Level 67
(20980, 8760, 1, 1, 2, 9.203985), -- Top-Grade Life Stone - Level 67
-- Mul's Wizard
(20981, 4083, 1, 1, -1, 67397), -- Leather Armor of Doom Design
(20981, 5230, 1, 1, -1, 7953), -- Recipe: Mithril Arrow (100%)
(20981, 4085, 1, 1, -1, 103660), -- Tunic of Doom Pattern
(20981, 57, 2351, 4805, 0, 700000), -- Adena
(20981, 358, 1, 1, 1, 23.728984), -- Blue Wolf Breastplate
(20981, 4078, 1, 1, 1, 4289.612403), -- Blue Wolf Breastplate Part
(20981, 2381, 1, 1, 1, 14.604498), -- Doom Plate Armor
(20981, 4081, 1, 1, 1, 2894.417309), -- Doom Plate Armor Temper
(20981, 2380, 1, 1, 1, 37.961054), -- Blue Wolf Gaiters
(20981, 4080, 1, 1, 1, 6040.675752), -- Blue Wolf Gaiters Material
(20981, 1869, 1, 1, 2, 160168.355966), -- Iron Ore
(20981, 1864, 1, 3, 2, 160168.355966), -- Stem
(20981, 1880, 1, 1, 2, 16016.999701), -- Steel
(20981, 5550, 1, 1, 2, 2135.408505), -- Durable Metal Plate
(20981, 4043, 1, 1, 2, 5339.136654), -- Asofe
(20981, 1830, 1, 1, 2, 64067.178282), -- Scroll of Escape: Castle
(20981, 8487, 1, 1, 2, 87.385593), -- Recipe: Destroyer Hammer (60%)
(20981, 8730, 1, 1, 2, 1779.712218), -- Life Stone - Level 67
(20981, 8740, 1, 1, 2, 444.722924), -- Mid-Grade Life Stone - Level 67
(20981, 8750, 1, 1, 2, 44.308188), -- High-Grade Life Stone - Level 67
(20981, 8760, 1, 1, 2, 9.436003), -- Top-Grade Life Stone - Level 67
-- Mul's Knight
(20982, 4084, 1, 1, -1, 96257), -- Blue Wolf Tunic Fabric
(20982, 5418, 1, 1, -1, 8181), -- Recipe: Sealed Tallum Plate Armor(60%)
(20982, 4085, 1, 1, -1, 96257), -- Tunic of Doom Pattern
(20982, 57, 2184, 4462, 0, 700000), -- Adena
(20982, 2398, 1, 1, 1, 22.025234), -- Blue Wolf Tunic
(20982, 4084, 1, 1, 1, 3555.266496), -- Blue Wolf Tunic Fabric
(20982, 2399, 1, 1, 1, 22.025234), -- Tunic of Doom
(20982, 4085, 1, 1, 1, 3555.266496), -- Tunic of Doom Pattern
(20982, 2403, 1, 1, 1, 35.267296), -- Blue Wolf Stockings
(20982, 4086, 1, 1, 1, 4800.424148), -- Blue Wolf Stockings Pattern
(20982, 2404, 1, 1, 1, 35.267296), -- Stockings of Doom
(20982, 4087, 1, 1, 1, 4800.4578), -- Stockings of Doom Pattern
(20982, 1869, 1, 1, 2, 136335.691248), -- Iron Ore
(20982, 1864, 1, 3, 2, 136335.691248), -- Stem
(20982, 1880, 1, 1, 2, 13633.406716), -- Steel
(20982, 5550, 1, 1, 2, 1817.760494), -- Durable Metal Plate
(20982, 4043, 1, 1, 2, 4544.604246), -- Asofe
(20982, 1830, 1, 1, 2, 54534.438908), -- Scroll of Escape: Castle
(20982, 8487, 1, 1, 2, 74.302026), -- Recipe: Destroyer Hammer (60%)
(20982, 8730, 1, 1, 2, 1514.868082), -- Life Stone - Level 67
(20982, 8740, 1, 1, 2, 378.818526), -- Mid-Grade Life Stone - Level 67
(20982, 8750, 1, 1, 2, 37.760046), -- High-Grade Life Stone - Level 67
(20982, 8760, 1, 1, 2, 7.714418), -- Top-Grade Life Stone - Level 67
(20982, 1344, 30, 90, 2, 56806.944042), -- Mithril Arrow
-- Binder
(20983, 4080, 1, 1, -1, 136641), -- Blue Wolf Gaiters Material
(20983, 5549, 1, 1, -1, 664283), -- Metallic Thread
(20983, 5478, 1, 1, -1, 55860), -- Sealed Dark Crystal Leather Armor Pattern
(20983, 57, 3280, 6679, 0, 700000), -- Adena
(20983, 5297, 1, 1, 1, 30.608253), -- Sealed Dark Crystal Leather Armor
(20983, 5478, 1, 1, 1, 3437.124093), -- Sealed Dark Crystal Leather Armor Pattern
(20983, 5301, 1, 1, 1, 18.827991), -- Sealed Tallum Leather Armor
(20983, 5479, 1, 1, 1, 2418.596739), -- Sealed Tallum Leather Armor Pattern
(20983, 5298, 1, 1, 1, 48.948237), -- Sealed Dark Crystal Leggings
(20983, 5482, 1, 1, 1, 5394.894687), -- Sealed Dark Crystal Leggings Design
(20983, 1867, 1, 3, 2, 148650.69776), -- Animal Skin
(20983, 1872, 1, 3, 2, 99100.56912), -- Animal Bone
(20983, 1882, 1, 1, 2, 49550.12864), -- Leather
(20983, 1894, 1, 1, 2, 7823.75376), -- Crafted Leather
(20983, 4042, 1, 1, 2, 3716.19728), -- Enria
(20983, 4199, 1, 1, 2, 170.26464), -- Recipe: Bow of Peril (100%)
(20983, 730, 1, 1, 2, 185.85664), -- Scroll: Enchant Armor (A-Grade)
(20983, 8731, 1, 1, 2, 2064.69264), -- Life Stone - Level 70
(20983, 8741, 1, 1, 2, 516.0952), -- Mid-Grade Life Stone - Level 70
(20983, 8751, 1, 1, 2, 51.76544), -- High-Grade Life Stone - Level 70
(20983, 8761, 1, 1, 2, 9.97888), -- Top-Grade Life Stone - Level 70
-- Bound Warrior
(20984, 5478, 1, 1, -1, 51267), -- Sealed Dark Crystal Leather Armor Pattern
(20984, 4041, 1, 1, -1, 53015), -- Mold Hardener
(20984, 57, 3006, 6139, 0, 700000), -- Adena
(20984, 5304, 1, 1, 1, 28.091952), -- Sealed Tallum Tunic
(20984, 5485, 1, 1, 1, 3154.558512), -- Sealed Tallum Tunic Texture
(20984, 5308, 1, 1, 1, 17.280144), -- Sealed Dark Crystal Robe
(20984, 5486, 1, 1, 1, 2219.764176), -- Sealed Dark Crystal Robe Fabric
(20984, 5305, 1, 1, 1, 44.924208), -- Sealed Tallum Stockings
(20984, 5489, 1, 1, 1, 4951.381008), -- Sealed Tallum Stockings Fabric
(20984, 1870, 1, 1, 2, 187591.547868), -- Coal
(20984, 1865, 1, 1, 2, 187591.547868), -- Varnish
(20984, 1874, 1, 1, 2, 12506.022528), -- Oriharukon Ore
(20984, 4043, 1, 1, 2, 6253.011264), -- Asofe
(20984, 4039, 1, 1, 2, 6253.011264), -- Mold Glue
(20984, 5156, 1, 1, 2, 250.05592), -- Recipe: Soulshot (A) Compressed Package (100%)
(20984, 729, 1, 1, 2, 20.972432), -- Scroll: Enchant Weapon (A-Grade)
(20984, 5420, 1, 1, 2, 182.298832), -- Recipe: Sealed Armor of Nightmare(60%)
(20984, 8730, 1, 1, 2, 2084.337088), -- Life Stone - Level 67
(20984, 8740, 1, 1, 2, 521.084272), -- Mid-Grade Life Stone - Level 67
(20984, 8750, 1, 1, 2, 52.027764), -- High-Grade Life Stone - Level 67
(20984, 8760, 1, 1, 2, 10.0829), -- Top-Grade Life Stone - Level 67
-- Bound Archer
(20985, 1807, 1, 1, -1, 8655), -- Recipe: Soulshot (A-Grade)
(20985, 5479, 1, 1, -1, 38410), -- Sealed Tallum Leather Armor Pattern
(20985, 3035, 1, 1, -1, 8655), -- Recipe: Spiritshot A
(20985, 57, 3201, 6536, 0, 700000), -- Adena
(20985, 6324, 1, 1, 1, 79.494664), -- Sealed Phoenix Earring
(20985, 6341, 1, 1, 1, 11048.10728), -- Sealed Phoenix Earring Gemstone
(20985, 6323, 1, 1, 1, 59.612216), -- Sealed Phoenix Necklace
(20985, 6343, 1, 1, 1, 8540.600384), -- Sealed Phoenix Necklace Beads
(20985, 6325, 1, 1, 1, 119.224432), -- Sealed Phoenix Ring
(20985, 6345, 1, 1, 1, 15280.961024), -- Sealed Phoenix Ring Gemstone
(20985, 1871, 1, 3, 2, 72629.206225), -- Charcoal
(20985, 1866, 1, 1, 2, 145258.41245), -- Suede
(20985, 1877, 1, 1, 2, 8715.48985), -- Adamantite Nugget
(20985, 4041, 1, 1, 2, 1894.525975), -- Mold Hardener
(20985, 4040, 1, 1, 2, 4357.744925), -- Mold Lubricant
(20985, 5161, 1, 1, 2, 290.4915), -- Recipe: Spiritshot (A) Compressed Package (100%)
(20985, 8730, 1, 1, 2, 2421.134925), -- Life Stone - Level 67
(20985, 8740, 1, 1, 2, 605.190625), -- Mid-Grade Life Stone - Level 67
(20985, 8750, 1, 1, 2, 60.705275), -- High-Grade Life Stone - Level 67
(20985, 8760, 1, 1, 2, 12.290025), -- Top-Grade Life Stone - Level 67
(20985, 1344, 20, 60, 2, 136179.808225), -- Mithril Arrow
-- Sairon
(20986, 1984, 1, 1, -1, 95413), -- Theca Leather Armor Pattern
(20986, 4043, 1, 1, -1, 148367), -- Asofe
(20986, 1806, 1, 1, -1, 8902), -- Recipe: Soulshot (B-Grade)
(20986, 57, 1758, 3581, 0, 700000), -- Adena
(20986, 2497, 1, 1, 1, 284.530887), -- Full Plate Shield
(20986, 2966, 1, 1, 1, 22482.996417), -- Full Plate Shield Fragment
(20986, 2414, 1, 1, 1, 199.167903), -- Full Plate Helmet
(20986, 2959, 1, 1, 1, 14212.304793), -- Full Plate Helmet Design
(20986, 1894, 1, 1, 2, 5242.291475), -- Crafted Leather
(20986, 4039, 1, 1, 2, 4980.167415), -- Mold Glue
(20986, 4041, 1, 1, 2, 1299.16091), -- Mold Hardener
(20986, 4044, 1, 1, 2, 4980.167415), -- Thons
(20986, 4180, 1, 1, 2, 16600.55805), -- Recipe: Silver Arrow (100%)
(20986, 4184, 1, 1, 2, 172.11852), -- Recipe: Sprite's Staff (100%)
(20986, 5436, 1, 1, 2, 243.720735), -- Recipe: Berserker Blade(100%)
(20986, 8726, 1, 1, 2, 3458.45908), -- Life Stone - Level 55
(20986, 8736, 1, 1, 2, 864.61477), -- Mid-Grade Life Stone - Level 55
(20986, 8746, 1, 1, 2, 86.476655), -- High-Grade Life Stone - Level 55
(20986, 8756, 1, 1, 2, 17.264975), -- Top-Grade Life Stone - Level 55
-- Sairon's Doll
(20987, 1918, 1, 1, -1, 174977), -- Nassen's Earring Gemstone
(20987, 4039, 1, 1, -1, 134674), -- Mold Glue
(20987, 1864, 1, 17, -1, 897829), -- Stem
(20987, 57, 1599, 3249, 0, 700000), -- Adena
(20987, 301, 1, 1, 1, 13.521856), -- Scorpion
(20987, 2113, 1, 1, 1, 1204.200775), -- Scorpion Blade
(20987, 303, 1, 1, 1, 13.521856), -- Widow Maker
(20987, 2114, 1, 1, 1, 1204.200775), -- Widowmaker Head
(20987, 299, 1, 1, 1, 10.549626), -- Orcish Poleaxe
(20987, 2122, 1, 1, 1, 1135.005112), -- Orcish Poleaxe Blade
(20987, 1864, 1, 3, 2, 124314.583522), -- Stem
(20987, 1869, 1, 1, 2, 124314.583522), -- Iron Ore
(20987, 1878, 1, 1, 2, 49725.756723), -- Braided Hemp
(20987, 1884, 1, 1, 2, 76501.370651), -- Cord
(20987, 4039, 1, 1, 2, 4143.717203), -- Mold Glue
(20987, 3034, 1, 1, 2, 248.461992), -- Recipe: Spiritshot B
(20987, 5270, 1, 1, 2, 248.461992), -- Recipe: Greater Soulshot (B) Compressed Package(100%)
(20987, 3955, 1, 1, 2, 248.461992), -- Recipe: Blessed Spiritshot B
(20987, 8726, 1, 1, 2, 2877.634645), -- Life Stone - Level 55
(20987, 8736, 1, 1, 2, 719.312804), -- Mid-Grade Life Stone - Level 55
(20987, 8746, 1, 1, 2, 72.084652), -- High-Grade Life Stone - Level 55
(20987, 8756, 1, 1, 2, 14.570302), -- Top-Grade Life Stone - Level 55
-- Sairon's Puppet
(20988, 1920, 1, 1, -1, 152063), -- Necklace of Seal Chain
(20988, 1806, 1, 1, -1, 8888), -- Recipe: Soulshot (B-Grade)
(20988, 1984, 1, 1, -1, 95264), -- Theca Leather Armor Pattern
(20988, 57, 1759, 3573, 0, 700000), -- Adena
(20988, 400, 1, 1, 1, 86.136814), -- Theca Leather Armor
(20988, 1984, 1, 1, 1, 5862.097499), -- Theca Leather Armor Pattern
(20988, 401, 1, 1, 1, 40.779843), -- Drake Leather Armor
(20988, 1987, 1, 1, 1, 4172.210004), -- Drake Leather Armor Texture
(20988, 420, 1, 1, 1, 137.866252), -- Theca Leather Gaiters
(20988, 1985, 1, 1, 1, 9429.909588), -- Theca Leather Gaiters Pattern
(20988, 1865, 1, 1, 2, 136739.952216), -- Varnish
(20988, 1870, 1, 1, 2, 136739.952216), -- Coal
(20988, 1879, 1, 1, 2, 22790.150088), -- Cokes
(20988, 1875, 1, 1, 2, 9116.123256), -- Stone of Purity
(20988, 4040, 1, 1, 2, 2734.931808), -- Mold Lubricant
(20988, 3955, 1, 1, 2, 273.42996), -- Recipe: Blessed Spiritshot B
(20988, 5270, 1, 1, 2, 273.42996), -- Recipe: Greater Soulshot (B) Compressed Package(100%)
(20988, 4127, 1, 1, 2, 3384.525528), -- Recipe: Adamantite Ring (100%)
(20988, 8726, 1, 1, 2, 3165.149352), -- Life Stone - Level 55
(20988, 8736, 1, 1, 2, 791.208312), -- Mid-Grade Life Stone - Level 55
(20988, 8746, 1, 1, 2, 79.026), -- High-Grade Life Stone - Level 55
(20988, 8756, 1, 1, 2, 16.121304), -- Top-Grade Life Stone - Level 55
-- Lageos
(20989, 1825, 1, 1, -1, 77195), -- Recipe: Oriharukon
(20989, 1902, 1, 1, -1, 109496), -- Elven Earring Beads
(20989, 1871, 1, 3, -1, 540365), -- Charcoal
(20989, 57, 457, 912, 0, 700000), -- Adena
(20989, 352, 1, 1, 1, 81.068852), -- Brigandine Tunic
(20989, 1941, 1, 1, 1, 3702.742851), -- Brigandine Temper
(20989, 2377, 1, 1, 1, 129.676963), -- Mithril Scale Gaiters
(20989, 2918, 1, 1, 1, 5523.924731), -- Mithril Scale Gaiters Material
(20989, 2378, 1, 1, 1, 129.676963), -- Brigandine Gaiters
(20989, 2919, 1, 1, 1, 5523.90964), -- Brigandine Gaiters Material
(20989, 1866, 1, 1, 2, 62072.612958), -- Suede
(20989, 1871, 1, 1, 2, 93108.829454), -- Charcoal
(20989, 5220, 1, 1, 2, 3724.39637), -- Metal Hardener
(20989, 1885, 1, 1, 2, 7759.054124), -- High-Grade Suede
(20989, 2146, 1, 1, 2, 6650.64353), -- Recipe: Artisan's frame
(20989, 5473, 1, 1, 2, 6650.463564), -- Recipe: Durable Metal Plate(100%)
-- Pageos
(20990, 1882, 1, 1, -1, 227993), -- Leather
(20990, 1903, 1, 1, -1, 171137), -- Elven Ring Piece
(20990, 2145, 1, 1, -1, 73283), -- Recipe: Mithril Alloy
(20990, 57, 434, 866, 0, 700000), -- Adena
(20990, 437, 1, 1, 1, 154.167822), -- Mithril Tunic
(20990, 1944, 1, 1, 1, 6762.752964), -- Mithril Tunic Fabric
(20990, 470, 1, 1, 1, 246.21201), -- Mithril Stockings
(20990, 1945, 1, 1, 1, 10530.867204), -- Mithril Stocking Design
(20990, 1867, 1, 1, 2, 101018.567302), -- Animal Skin
(20990, 1872, 1, 1, 2, 101018.567302), -- Animal Bone
(20990, 1882, 1, 1, 2, 16836.50909), -- Leather
(20990, 1894, 1, 1, 2, 2658.370528), -- Crafted Leather
(20990, 2147, 1, 1, 2, 5411.752466), -- Recipe: Blacksmith's frame
(20990, 2194, 1, 1, 2, 7746.596962), -- Recipe: Mithril Gloves
(20990, 1341, 10, 30, 2, 252547.63635), -- Bone Arrow
-- Swamp Tribe
(20991, 2064, 1, 1, -1, 31742), -- Silver Axe Head
(20991, 1908, 1, 1, -1, 388880), -- Moonstone Earring Wire
(20991, 1909, 1, 1, -1, 554567), -- Aquastone Ring Wire
(20991, 57, 1624, 3299, 0, 700000), -- Adena
(20991, 354, 1, 1, 1, 249.723584), -- Chain Mail Shirt
(20991, 1959, 1, 1, 1, 13069.055648), -- Chain Mail Shirt Material
(20991, 381, 1, 1, 1, 399.493248), -- Chain Gaiters
(20991, 1960, 1, 1, 1, 26585.72752), -- Chain Gaiters Part
(20991, 1875, 1, 1, 2, 11762.627883), -- Stone of Purity
(20991, 1879, 1, 1, 2, 29406.526596), -- Cokes
(20991, 1885, 1, 1, 2, 14703.263298), -- High-Grade Suede
(20991, 5550, 1, 1, 2, 2352.508332), -- Durable Metal Plate
(20991, 5549, 1, 1, 2, 17643.898713), -- Metallic Thread
(20991, 4556, 1, 1, 2, 705.735255), -- Greater Dye of CON (Con+1 Dex-1)
(20991, 3021, 1, 1, 2, 614.76999), -- Recipe: Dwarven War Hammer
(20991, 8723, 1, 1, 2, 7057.524996), -- Life Stone - Level 46
(20991, 8733, 1, 1, 2, 1764.381249), -- Mid-Grade Life Stone - Level 46
(20991, 8743, 1, 1, 2, 176.412258), -- High-Grade Life Stone - Level 46
(20991, 8753, 1, 1, 2, 35.35143), -- Top-Grade Life Stone - Level 46
-- Swamp Alligator
(20992, 1908, 1, 1, -1, 347561), -- Moonstone Earring Wire
(20992, 2163, 1, 1, -1, 187257), -- Recipe: Earring of Protection
(20992, 1909, 1, 1, -1, 495644), -- Aquastone Ring Wire
(20992, 57, 1445, 2961, 0, 700000), -- Adena
(20992, 852, 1, 1, 1, 484.662831), -- Moonstone Earring
(20992, 1908, 1, 1, 1, 27378.64731), -- Moonstone Earring Wire
(20992, 915, 1, 1, 1, 363.654219), -- Aquastone Necklace
(20992, 1910, 1, 1, 1, 21770.957418), -- Aquastone Necklace Chain
(20992, 883, 1, 1, 1, 727.308438), -- Aquastone Ring
(20992, 1909, 1, 1, 1, 39043.769784), -- Aquastone Ring Wire
(20992, 1868, 1, 1, 2, 346922.71589), -- Thread
(20992, 1873, 1, 1, 2, 69384.543178), -- Silver Nugget
(20992, 5549, 1, 1, 2, 17346.252806), -- Metallic Thread
(20992, 1889, 1, 1, 2, 11564.012522), -- Compound Braid
(20992, 2164, 1, 1, 2, 13343.055368), -- Recipe: Ring of Protection
(20992, 2319, 1, 1, 2, 604.247386), -- Recipe: Raid Sword
(20992, 8723, 1, 1, 2, 6938.313904), -- Life Stone - Level 46
(20992, 8733, 1, 1, 2, 1734.578476), -- Mid-Grade Life Stone - Level 46
(20992, 8743, 1, 1, 2, 173.645066), -- High-Grade Life Stone - Level 46
(20992, 8753, 1, 1, 2, 34.635404), -- Top-Grade Life Stone - Level 46
-- Swamp Warrior
(20993, 1869, 1, 9, -1, 778937), -- Iron Ore
(20993, 1864, 1, 17, -1, 865485), -- Stem
(20993, 2163, 1, 1, -1, 198708), -- Recipe: Earring of Protection
(20993, 57, 1533, 3142, 0, 700000), -- Adena
(20993, 62, 1, 1, 1, 210.629136), -- Reinforced Mithril Boots
(20993, 1958, 1, 1, 1, 9192.028128), -- Reinforced Mithril Boots Design
(20993, 2429, 1, 1, 1, 210.629136), -- Chain Boots
(20993, 2937, 1, 1, 1, 9192.028128), -- Chain Boots Part
(20993, 2430, 1, 1, 1, 210.629136), -- Karmian Boots
(20993, 2938, 1, 1, 1, 9192.028128), -- Karmian Boots Fabric
(20993, 2431, 1, 1, 1, 210.629136), -- Plated Leather Boots
(20993, 2939, 1, 1, 1, 9192.028128), -- Plate Leather Boots Lining
(20993, 2432, 1, 1, 1, 210.629136), -- Dwarven Chain Boots
(20993, 2940, 1, 1, 1, 9192.028128), -- Dwarven Chain Boots Part
(20993, 2433, 1, 1, 1, 210.629136), -- Boots of Seal
(20993, 2941, 1, 1, 1, 9192.028128), -- Boots of Seal Pattern
(20993, 2452, 1, 1, 1, 210.629136), -- Reinforced Mithril Gloves
(20993, 2942, 1, 1, 1, 9192.028128), -- Reinforced Mithril Gloves Design
(20993, 2453, 1, 1, 1, 210.629136), -- Chain Gloves
(20993, 2943, 1, 1, 1, 9192.028128), -- Chain Gloves Design
(20993, 2454, 1, 1, 1, 210.629136), -- Karmian Gloves
(20993, 2944, 1, 1, 1, 9192.112752), -- Karmian Gloves Fabric
(20993, 1869, 1, 1, 2, 184068.875197), -- Iron Ore
(20993, 1864, 1, 3, 2, 184068.875197), -- Stem
(20993, 1880, 1, 1, 2, 18406.846908), -- Steel
(20993, 5550, 1, 1, 2, 2454.165031), -- Durable Metal Plate
(20993, 2165, 1, 1, 2, 7052.627822), -- Recipe: Necklace of Protection
(20993, 2318, 1, 1, 2, 641.258743), -- Recipe: Spirit Sword
(20993, 8723, 1, 1, 2, 7362.90121), -- Life Stone - Level 46
(20993, 8733, 1, 1, 2, 1840.522244), -- Mid-Grade Life Stone - Level 46
(20993, 8743, 1, 1, 2, 183.971001), -- High-Grade Life Stone - Level 46
(20993, 8753, 1, 1, 2, 36.956647), -- Top-Grade Life Stone - Level 46
-- Garden Guard Leader
(20994, 4043, 1, 1, -1, 148005), -- Asofe
(20994, 4044, 1, 1, -1, 148005), -- Thons
(20994, 2169, 1, 1, -1, 78587), -- Recipe: Necklace of Seal
(20994, 57, 1756, 3570, 0, 700000), -- Adena
(20994, 265, 1, 1, 1, 55.568302), -- Fisted Blade
(20994, 2108, 1, 1, 1, 4917.431698), -- Fisted Blade Piece
(20994, 1894, 1, 1, 2, 5857.07314), -- Crafted Leather
(20994, 4039, 1, 1, 2, 5564.22965), -- Mold Glue
(20994, 4041, 1, 1, 2, 1451.54259), -- Mold Hardener
(20994, 4044, 1, 1, 2, 5564.22965), -- Thons
(20994, 3015, 1, 1, 2, 4662.75565), -- Recipe: Drake Leather Gloves
(20994, 4186, 1, 1, 2, 192.32575), -- Recipe: Sword of Valhalla (100%)
(20994, 3016, 1, 1, 2, 4662.75565), -- Recipe: Full Plate Gauntlets
(20994, 8725, 1, 1, 2, 4636.8298), -- Life Stone - Level 52
(20994, 8735, 1, 1, 2, 1159.20745), -- Mid-Grade Life Stone - Level 52
(20994, 8745, 1, 1, 2, 115.93769), -- High-Grade Life Stone - Level 52
(20994, 8755, 1, 1, 2, 23.11298), -- Top-Grade Life Stone - Level 52
-- Garden Guard
(20995, 1911, 1, 1, -1, 250980), -- Earring of Protection Gemstone
(20995, 2166, 1, 1, -1, 114387), -- Recipe: Earrings of Binding (100%)
(20995, 1966, 1, 1, -1, 123199), -- Plated Leather Fragment
(20995, 57, 1334, 2712, 0, 700000), -- Adena
(20995, 2496, 1, 1, 1, 414.964881), -- Dwarven Chain Shield
(20995, 2947, 1, 1, 1, 17798.409681), -- Dwarven Chain Shield Fragment
(20995, 632, 1, 1, 1, 383.073611), -- Knight's Shield
(20995, 1972, 1, 1, 1, 19934.20587), -- Knight's Shield Fragment
(20995, 500, 1, 1, 1, 268.210986), -- Great Helmet
(20995, 1971, 1, 1, 1, 15254.134971), -- Great Helmet Material
(20995, 1870, 1, 1, 2, 135920.991656), -- Coal
(20995, 1865, 1, 1, 2, 135920.991656), -- Varnish
(20995, 1874, 1, 1, 2, 9061.355868), -- Oriharukon Ore
(20995, 4043, 1, 1, 2, 4530.677934), -- Asofe
(20995, 4039, 1, 1, 2, 4530.677934), -- Mold Glue
(20995, 2222, 1, 1, 2, 849.399982), -- Recipe: Composite Armor
(20995, 8724, 1, 1, 2, 4530.677934), -- Life Stone - Level 49
(20995, 8734, 1, 1, 2, 1132.751188), -- Mid-Grade Life Stone - Level 49
(20995, 8744, 1, 1, 2, 113.405846), -- High-Grade Life Stone - Level 49
(20995, 8754, 1, 1, 2, 22.550442), -- Top-Grade Life Stone - Level 49
(20995, 1539, 1, 1, 2, 30204.51956); -- Greater Healing Potion

INSERT INTO `droplist` VALUES
-- Spiteful Ghost of Ruins
(20996, 1914, 1, 1, -1, 95679), -- Earring of Seal Gemstone
(20996, 1864, 1, 7, -1, 851546), -- Stem
(20996, 1869, 1, 3, -1, 851546), -- Iron Ore
(20996, 57, 674, 1369, 0, 700000), -- Adena
(20996, 265, 1, 1, 1, 21.319992), -- Fisted Blade
(20996, 2108, 1, 1, 1, 1886.680008), -- Fisted Blade Piece
(20996, 1864, 1, 1, 2, 128053.300403), -- Stem
(20996, 1869, 1, 1, 2, 64026.782373), -- Iron Ore
(20996, 1878, 1, 1, 2, 25610.607212), -- Braided Hemp
(20996, 1884, 1, 1, 2, 39401.117179), -- Cord
(20996, 4039, 1, 1, 2, 2134.305382), -- Mold Glue
(20996, 2169, 1, 1, 2, 1133.238441), -- Recipe: Necklace of Seal
(20996, 3019, 1, 1, 2, 1707.391437), -- Recipe: Full Plate Shield
(20996, 8725, 1, 1, 2, 1778.499704), -- Life Stone - Level 52
(20996, 8735, 1, 1, 2, 444.624926), -- Mid-Grade Life Stone - Level 52
(20996, 8745, 1, 1, 2, 44.409624), -- High-Grade Life Stone - Level 52
(20996, 8755, 1, 1, 2, 8.723319), -- Top-Grade Life Stone - Level 52
-- Soldier of Grief
(20997, 4601, 1, 1, -1, 3371), -- Greater Dye of STR (Str+3 Con-3)
(20997, 1539, 1, 1, -1, 337056), -- Greater Healing Potion
(20997, 1915, 1, 1, -1, 133634), -- Ring of Ages Gemstone
(20997, 57, 601, 1220, 0, 700000), -- Adena
(20997, 60, 1, 1, 1, 51.11631), -- Composite Armor
(20997, 1977, 1, 1, 1, 4638.88369), -- Composite Armor Temper
(20997, 1873, 1, 1, 2, 22808.54148), -- Silver Nugget
(20997, 1868, 1, 1, 2, 114042.877334), -- Thread
(20997, 1876, 1, 1, 2, 11404.27074), -- Mithril Ore
(20997, 1895, 1, 1, 2, 16291.912448), -- Metallic Fiber
(20997, 4042, 1, 1, 2, 950.440862), -- Enria
(20997, 2170, 1, 1, 2, 1344.857676), -- Recipe: Nassen's Earring
(20997, 3012, 1, 1, 2, 1063.78684), -- Recipe: Full Plate Helmet
(20997, 8725, 1, 1, 2, 1583.954814), -- Life Stone - Level 52
(20997, 8735, 1, 1, 2, 395.94622), -- Mid-Grade Life Stone - Level 52
(20997, 8745, 1, 1, 2, 39.594622), -- High-Grade Life Stone - Level 52
(20997, 8755, 1, 1, 2, 7.816964), -- Top-Grade Life Stone - Level 52
-- Cruel Punisher
(20998, 2169, 1, 1, -1, 29606), -- Recipe: Necklace of Seal
(20998, 1916, 1, 1, -1, 71182), -- Necklace of Mermaid Teardrop
(20998, 2170, 1, 1, -1, 39452), -- Recipe: Nassen's Earring
(20998, 57, 664, 1343, 0, 700000), -- Adena
(20998, 162, 1, 1, 1, 2.617434), -- War Axe
(20998, 2097, 1, 1, 1, 231.636168), -- War Axe Blade
(20998, 174, 1, 1, 1, 2.617434), -- Nirvana Axe
(20998, 2098, 1, 1, 1, 231.636168), -- Nirvana Axe Blade
(20998, 196, 1, 1, 1, 2.617434), -- Stick of Eternity
(20998, 2099, 1, 1, 1, 243.779598), -- Stick of Eternity Shaft
(20998, 197, 1, 1, 1, 2.617434), -- Paradia Staff
(20998, 2100, 1, 1, 1, 243.779598), -- Paradia Staff Head
(20998, 199, 1, 1, 1, 2.617434), -- Pa'agrian Hammer
(20998, 2102, 1, 1, 1, 235.035558), -- Pa'agrian Hammer Head
(20998, 200, 1, 1, 1, 2.617434), -- Sage's Staff
(20998, 2103, 1, 1, 1, 243.779598), -- Sage's Staff Head
(20998, 201, 1, 1, 1, 2.617434), -- Club of Nature
(20998, 2104, 1, 1, 1, 243.779598), -- Club of Nature Head
(20998, 202, 1, 1, 1, 2.617434), -- Mace of Underworld
(20998, 2105, 1, 1, 1, 231.634242), -- Mace of Underworld Head
(20998, 1871, 1, 1, 2, 53211.674628), -- Charcoal
(20998, 1866, 1, 1, 2, 35474.449752), -- Suede
(20998, 1877, 1, 1, 2, 2128.493556), -- Adamantite Nugget
(20998, 4041, 1, 1, 2, 462.665448), -- Mold Hardener
(20998, 4040, 1, 1, 2, 1064.163744), -- Mold Lubricant
(20998, 2231, 1, 1, 2, 229.339908), -- Recipe: Full Plate Armor
(20998, 5155, 1, 1, 2, 106.449588), -- Recipe: Soulshot (B) Compressed Package (100%)
(20998, 6669, 1, 1, 2, 12374.723088), -- Deluxe Chest Key - Grade 5
(20998, 8725, 1, 1, 2, 1478.171268), -- Life Stone - Level 52
(20998, 8735, 1, 1, 2, 369.5013), -- Mid-Grade Life Stone - Level 52
(20998, 8745, 1, 1, 2, 37.033164), -- High-Grade Life Stone - Level 52
(20998, 8755, 1, 1, 2, 7.47306), -- Top-Grade Life Stone - Level 52
(20998, 1832, 1, 1, 2, 59123.861496), -- Greater Antidote
-- Roving Soul
(20999, 1918, 1, 1, -1, 86067), -- Nassen's Earring Gemstone
(20999, 1868, 1, 9, -1, 794915), -- Thread
(20999, 1873, 1, 1, -1, 794915), -- Silver Nugget
(20999, 57, 787, 1598, 0, 700000), -- Adena
(20999, 228, 1, 1, 1, 15.564262), -- Crystal Dagger
(20999, 2119, 1, 1, 1, 1671.435738), -- Crystal Dagger Blade
(20999, 1868, 1, 1, 2, 122294.882784), -- Thread
(20999, 1873, 1, 1, 2, 24458.912092), -- Silver Nugget
(20999, 5549, 1, 1, 2, 6114.808604), -- Metallic Thread
(20999, 1889, 1, 1, 2, 4076.431628), -- Compound Braid
(20999, 4044, 1, 1, 2, 2038.215814), -- Thons
(20999, 1806, 1, 1, 2, 122.321958), -- Recipe: Soulshot (B-Grade)
(20999, 5270, 1, 1, 2, 122.321958), -- Recipe: Greater Soulshot (B) Compressed Package(100%)
(20999, 5280, 1, 1, 2, 122.321958), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(20999, 8726, 1, 1, 2, 1415.485846), -- Life Stone - Level 55
(20999, 8736, 1, 1, 2, 353.911752), -- Mid-Grade Life Stone - Level 55
(20999, 8746, 1, 1, 2, 35.45564), -- High-Grade Life Stone - Level 55
(20999, 8756, 1, 1, 2, 6.929966), -- Top-Grade Life Stone - Level 55
-- Soul of Ruins
(21000, 1865, 1, 3, -1, 871346), -- Varnish
(21000, 1986, 1, 1, -1, 18415), -- Full Plate Armor Temper
(21000, 1918, 1, 1, -1, 75474), -- Nassen's Earring Gemstone
(21000, 57, 688, 1402, 0, 700000), -- Adena
(21000, 301, 1, 1, 1, 5.83392), -- Scorpion
(21000, 2113, 1, 1, 1, 519.544875), -- Scorpion Blade
(21000, 303, 1, 1, 1, 5.83392), -- Widow Maker
(21000, 2114, 1, 1, 1, 519.544875), -- Widowmaker Head
(21000, 299, 1, 1, 1, 4.55157), -- Orcish Poleaxe
(21000, 2122, 1, 1, 1, 489.69084), -- Orcish Poleaxe Blade
(21000, 1865, 1, 1, 2, 49496.61717), -- Varnish
(21000, 1870, 1, 1, 2, 49496.61717), -- Coal
(21000, 1879, 1, 1, 2, 8249.398344), -- Cokes
(21000, 1875, 1, 1, 2, 3299.736627), -- Stone of Purity
(21000, 4040, 1, 1, 2, 989.955054), -- Mold Lubricant
(21000, 4182, 1, 1, 2, 57.003606), -- Recipe: Great Sword (100%)
(21000, 5160, 1, 1, 2, 99.018216), -- Recipe: Spiritshot (B) Compressed Package (100%)
(21000, 5436, 1, 1, 2, 80.736183), -- Recipe: Berserker Blade(100%)
(21000, 4146, 1, 1, 2, 317.267082), -- Recipe: Tunic of Zubei (100%)
(21000, 8726, 1, 1, 2, 1145.74977), -- Life Stone - Level 55
(21000, 8736, 1, 1, 2, 286.494219), -- Mid-Grade Life Stone - Level 55
(21000, 8746, 1, 1, 2, 28.615356), -- High-Grade Life Stone - Level 55
(21000, 8756, 1, 1, 2, 5.791203), -- Top-Grade Life Stone - Level 55
-- Wretched Archer
(21001, 1988, 1, 1, -1, 45373), -- Divine Tunic Fabric
(21001, 1895, 1, 1, -1, 674702), -- Metallic Fiber
(21001, 4042, 1, 1, -1, 39358), -- Enria
(21001, 57, 933, 1901, 0, 700000), -- Adena
(21001, 286, 1, 1, 1, 18.496289), -- Eminence Bow
(21001, 2121, 1, 1, 1, 2004.503711), -- Eminence Bow Shaft
(21001, 1873, 1, 1, 2, 24912.121482), -- Silver Nugget
(21001, 1868, 1, 1, 2, 124560.988542), -- Thread
(21001, 1876, 1, 1, 2, 12456.156024), -- Mithril Ore
(21001, 1895, 1, 1, 2, 17794.481382), -- Metallic Fiber
(21001, 4042, 1, 1, 2, 1038.013002), -- Enria
(21001, 4939, 1, 1, 2, 770.83947), -- Recipe: Adamantite Necklace (70%)
(21001, 4966, 1, 1, 2, 71.843382), -- Recipe: Keshanberk (60%)
(21001, 5165, 1, 1, 2, 124.630164), -- Recipe: Blessed Spiritshot (B) Compressed Package (100%)
(21001, 4180, 1, 1, 2, 6920.023158), -- Recipe: Silver Arrow (100%)
(21001, 4971, 1, 1, 2, 71.843382), -- Recipe: Dark Elven Long Bow (60%)
(21001, 8726, 1, 1, 2, 1441.63179), -- Life Stone - Level 55
(21001, 8736, 1, 1, 2, 360.360306), -- Mid-Grade Life Stone - Level 55
(21001, 8746, 1, 1, 2, 36.016974), -- High-Grade Life Stone - Level 55
(21001, 8756, 1, 1, 2, 7.050942), -- Top-Grade Life Stone - Level 55
-- Doom Scout
(21002, 1874, 1, 1, -1, 139115), -- Oriharukon Ore
(21002, 2960, 1, 1, -1, 113625), -- Drake Leather Boots Design
(21002, 4613, 1, 1, -1, 2878), -- Greater Dye of STR (Str+4 Con-4)
(21002, 57, 823, 1681, 0, 700000), -- Adena
(21002, 11896, 1, 1, 1, 176.338195), -- Common Item - Dark Elven Long Bow
(21002, 4112, 1, 1, 1, 1744.661805), -- Dark Elven Longbow Shaft
(21002, 1872, 1, 1, 2, 68487.411027), -- Animal Bone
(21002, 1867, 1, 1, 2, 68487.411027), -- Animal Skin
(21002, 1881, 1, 1, 2, 6848.726101), -- Coarse Bone Powder
(21002, 1875, 1, 1, 2, 3424.438059), -- Stone of Purity
(21002, 4041, 1, 1, 2, 446.600609), -- Mold Hardener
(21002, 4949, 1, 1, 2, 329.287315), -- Recipe: Tunic of Zubei (60%)
(21002, 4992, 1, 1, 2, 638.922403), -- Recipe: Sealed Blue Wolf Boots (60%)
(21002, 8311, 1, 1, 2, 39.154437), -- Recipe: Kaim Vanul's Bones (100%)
(21002, 8727, 1, 1, 2, 1027.316416), -- Life Stone - Level 58
(21002, 8737, 1, 1, 2, 256.829104), -- Mid-Grade Life Stone - Level 58
(21002, 8747, 1, 1, 2, 25.652907), -- High-Grade Life Stone - Level 58
(21002, 8757, 1, 1, 2, 5.250595), -- Top-Grade Life Stone - Level 58
-- Grave Lich
(21003, 2963, 1, 1, -1, 104221), -- Full Plate Gauntlets Part
(21003, 4949, 1, 1, -1, 12269), -- Recipe: Tunic of Zubei (60%)
(21003, 4049, 1, 1, -1, 100394), -- Adamantite Earring Gemstone
(21003, 57, 755, 1542, 0, 700000), -- Adena
(21003, 12159, 1, 1, 1, 645.406589), -- Common Item - Zubei's Shield
(21003, 4101, 1, 1, 1, 4096.903655), -- Zubei's Shield Fragment
(21003, 12171, 1, 1, 1, 645.406589), -- Common Item - Avadon Shield
(21003, 4439, 1, 1, 1, 4873.902926), -- Avadon Shield Fragment
(21003, 12160, 1, 1, 1, 451.572705), -- Common Item - Zubei's Helmet
(21003, 4102, 1, 1, 1, 3174.108659), -- Zubei's Helmet Design
(21003, 12170, 1, 1, 1, 451.572705), -- Common Item - Avadon Circlet
(21003, 4072, 1, 1, 1, 3174.126172), -- Avadon Circlet Pattern
(21003, 1866, 1, 1, 2, 28993.364988), -- Suede
(21003, 1871, 1, 1, 2, 43490.047482), -- Charcoal
(21003, 5220, 1, 1, 2, 1739.607051), -- Metal Hardener
(21003, 1885, 1, 1, 2, 3624.23502), -- High-Grade Suede
(21003, 4041, 1, 1, 2, 378.136248), -- Mold Hardener
(21003, 4963, 1, 1, 2, 50.100477), -- Recipe: Great Sword (60%)
(21003, 4999, 1, 1, 2, 540.9306), -- Recipe: Sealed Doom Boots (60%)
(21003, 4993, 1, 1, 2, 540.9306), -- Recipe: Sealed Doom Gloves (60%)
(21003, 8727, 1, 1, 2, 869.739129), -- Life Stone - Level 58
(21003, 8737, 1, 1, 2, 217.402584), -- Mid-Grade Life Stone - Level 58
(21003, 8747, 1, 1, 2, 21.766017), -- High-Grade Life Stone - Level 58
(21003, 8757, 1, 1, 2, 4.378962), -- Top-Grade Life Stone - Level 58
(21003, 1832, 1, 1, 2, 48322.360842), -- Greater Antidote
-- Dismal Pole
(21004, 4951, 1, 1, -1, 9324), -- Recipe: Avadon Robe (60%)
(21004, 1920, 1, 1, -1, 72742), -- Necklace of Seal Chain
(21004, 4129, 1, 1, -1, 23007), -- Recipe: Earrings of Black Ore (100%)
(21004, 57, 840, 1710, 0, 700000), -- Adena
(21004, 12151, 1, 1, 1, 334.38911), -- Common Item - Zubei's Leather Shirt
(21004, 4066, 1, 1, 1, 2467.60536), -- Zubei's Leather Shirt Fabric
(21004, 12165, 1, 1, 1, 205.220455), -- Common Item - Avadon Leather Armor
(21004, 4068, 1, 1, 1, 1895.738075), -- Avadon Leather Armor Lining
(21004, 12150, 1, 1, 1, 535.366095), -- Common Item - Zubei's Leather Gaiters
(21004, 4067, 1, 1, 1, 3746.680905), -- Zubei's Leather Gaiter Texture
(21004, 1873, 1, 1, 2, 20931.805038), -- Silver Nugget
(21004, 1868, 1, 1, 2, 104659.179444), -- Thread
(21004, 1876, 1, 1, 2, 10465.979646), -- Mithril Ore
(21004, 1895, 1, 1, 2, 14951.377458), -- Metallic Fiber
(21004, 4042, 1, 1, 2, 872.152116), -- Enria
(21004, 4129, 1, 1, 2, 566.266434), -- Recipe: Earrings of Black Ore (100%)
(21004, 4167, 1, 1, 2, 650.797626), -- Recipe: Sealed Blue Wolf Boots (100%)
(21004, 4197, 1, 1, 2, 39.951786), -- Recipe: Demon's Dagger (100%)
(21004, 8728, 1, 1, 2, 872.152116), -- Life Stone - Level 61
(21004, 8738, 1, 1, 2, 218.115156), -- Mid-Grade Life Stone - Level 61
(21004, 8748, 1, 1, 2, 21.749814), -- High-Grade Life Stone - Level 61
(21004, 8758, 1, 1, 2, 4.473366), -- Top-Grade Life Stone - Level 61
-- Grave Predator
(21005, 947, 1, 1, -1, 932), -- Scroll: Enchant Weapon (B-Grade)
(21005, 1880, 1, 1, -1, 233106), -- Steel
(21005, 4050, 1, 1, -1, 144427), -- Adamantite Ring Wire
(21005, 57, 920, 1876, 0, 700000), -- Adena
(21005, 11889, 1, 1, 1, 65.67673), -- Common Item - Great Sword
(21005, 4104, 1, 1, 1, 656.773741), -- Great Sword Blade
(21005, 11916, 1, 1, 1, 65.67673), -- Common Item - Keshanberk
(21005, 4107, 1, 1, 1, 646.596961), -- Keshanberk Blade
(21005, 11900, 1, 1, 1, 65.67673), -- Common Item - Sword of Valhalla
(21005, 4108, 1, 1, 1, 646.599108), -- Sword of Valhalla Blade
(21005, 1873, 1, 1, 2, 22951.926277), -- Silver Nugget
(21005, 1868, 1, 1, 2, 114759.800526), -- Thread
(21005, 1876, 1, 1, 2, 11476.047709), -- Mithril Ore
(21005, 1895, 1, 1, 2, 16394.329707), -- Metallic Fiber
(21005, 4042, 1, 1, 2, 956.323214), -- Enria
(21005, 4129, 1, 1, 2, 620.916611), -- Recipe: Earrings of Black Ore (100%)
(21005, 4167, 1, 1, 2, 713.605879), -- Recipe: Sealed Blue Wolf Boots (100%)
(21005, 4197, 1, 1, 2, 43.807519), -- Recipe: Demon's Dagger (100%)
(21005, 8728, 1, 1, 2, 956.323214), -- Life Stone - Level 61
(21005, 8738, 1, 1, 2, 239.165374), -- Mid-Grade Life Stone - Level 61
(21005, 8748, 1, 1, 2, 23.848881), -- High-Grade Life Stone - Level 61
(21005, 8758, 1, 1, 2, 4.905089), -- Top-Grade Life Stone - Level 61
-- Doom Servant
(21006, 4066, 1, 1, -1, 52315), -- Zubei's Leather Shirt Fabric
(21006, 948, 1, 1, -1, 5547), -- Scroll: Enchant Armor (B-Grade)
(21006, 4130, 1, 1, -1, 36022), -- Recipe: Ring of Black Ore (100%)
(21006, 57, 878, 1784, 0, 700000), -- Adena
(21006, 357, 1, 1, 1, 10.26675), -- Zubei's Breastplate
(21006, 4056, 1, 1, 1, 1483.347645), -- Zubei's Breastplate Part
(21006, 2376, 1, 1, 1, 10.26675), -- Avadon Breastplate
(21006, 4064, 1, 1, 1, 1483.347645), -- Avadon Breastplate Part
(21006, 383, 1, 1, 1, 16.4268), -- Zubei's Gaiters
(21006, 4057, 1, 1, 1, 2292.4512), -- Zubei's Gaiter Material
(21006, 2379, 1, 1, 1, 16.4268), -- Avadon Gaiters
(21006, 4065, 1, 1, 1, 2292.46641), -- Avadon Gaiters Material
(21006, 1869, 1, 1, 2, 54620.614071), -- Iron Ore
(21006, 1864, 1, 1, 2, 109241.401943), -- Stem
(21006, 1880, 1, 1, 2, 5462.044027), -- Steel
(21006, 5550, 1, 1, 2, 728.22619), -- Durable Metal Plate
(21006, 4043, 1, 1, 2, 1820.739276), -- Asofe
(21006, 4193, 1, 1, 2, 41.71224), -- Recipe: Lance (100%)
(21006, 4173, 1, 1, 2, 679.388109), -- Recipe: Sealed Blue Wolf Gloves (100%)
(21006, 5003, 1, 1, 2, 41.71224), -- Recipe: Art of Battle Axe (60%)
(21006, 8728, 1, 1, 2, 910.369638), -- Life Stone - Level 61
(21006, 8738, 1, 1, 2, 227.505509), -- Mid-Grade Life Stone - Level 61
(21006, 8748, 1, 1, 2, 22.767931), -- High-Grade Life Stone - Level 61
(21006, 8758, 1, 1, 2, 4.518826), -- Top-Grade Life Stone - Level 61
-- Doom Guard
(21007, 4981, 1, 1, -1, 7411), -- Recipe: Blue Wolf Breastplate (60%)
(21007, 4051, 1, 1, -1, 92552), -- Adamantite Necklace Chain
(21007, 948, 1, 1, -1, 5966), -- Scroll: Enchant Armor (B-Grade)
(21007, 57, 946, 1918, 0, 700000), -- Adena
(21007, 11918, 1, 1, 1, 100.842792), -- Common Item - Heavy War Axe
(21007, 4105, 1, 1, 1, 1008.430122), -- Heavy War Axe Head
(21007, 11908, 1, 1, 1, 100.842792), -- Common Item - Sprite's Staff
(21007, 4106, 1, 1, 1, 991.884294), -- Sprite's Staff Head
(21007, 1894, 1, 1, 2, 2061.183042), -- Crafted Leather
(21007, 4039, 1, 1, 2, 1958.116459), -- Mold Glue
(21007, 4041, 1, 1, 2, 510.800066), -- Mold Hardener
(21007, 4044, 1, 1, 2, 1958.116459), -- Thons
(21007, 4621, 1, 1, 2, 80.99681), -- Greater Dye of MEN (Men+4 Int-4)
(21007, 4998, 1, 1, 2, 730.606088), -- Recipe: Sealed Blue Wolf Gloves (60%)
(21007, 4166, 1, 1, 2, 485.460697), -- Recipe: Doom Helmet (100%)
(21007, 8728, 1, 1, 2, 979.021075), -- Life Stone - Level 61
(21007, 8738, 1, 1, 2, 244.773846), -- Mid-Grade Life Stone - Level 61
(21007, 8748, 1, 1, 2, 24.447661), -- High-Grade Life Stone - Level 61
(21007, 8758, 1, 1, 2, 4.904394), -- Top-Grade Life Stone - Level 61
(21007, 1832, 1, 1, 2, 65270.573403), -- Greater Antidote
-- Doom Archer
(21008, 4983, 1, 1, -1, 6493), -- Recipe: Doom Plate Armor (60%)
(21008, 5230, 1, 1, -1, 4078), -- Recipe: Mithril Arrow (100%)
(21008, 4052, 1, 1, -1, 108272), -- Earring of Black Ore Piece
(21008, 57, 1213, 2457, 0, 700000), -- Adena
(21008, 12188, 1, 1, 1, 600.607957), -- Common Item - Sealed Doom Boots
(21008, 4099, 1, 1, 1, 5069.142043), -- Sealed Doom Boots Part
(21008, 12189, 1, 1, 1, 600.607957), -- Common Item - Sealed Blue Wolf Boots
(21008, 4090, 1, 1, 1, 5069.142043), -- Sealed Blue Wolf Boots Design
(21008, 12187, 1, 1, 1, 600.607957), -- Common Item - Sealed Doom Gloves
(21008, 4091, 1, 1, 1, 5069.142043), -- Sealed Doom Gloves Part
(21008, 12190, 1, 1, 1, 600.607957), -- Common Item - Sealed Blue Wolf Gloves
(21008, 4096, 1, 1, 1, 5069.142043), -- Sealed Blue Wolf Gloves Fabric
(21008, 1867, 1, 1, 2, 109494.236229), -- Animal Skin
(21008, 1872, 1, 1, 2, 109494.236229), -- Animal Bone
(21008, 1882, 1, 1, 2, 18249.160958), -- Leather
(21008, 1894, 1, 1, 2, 2881.356877), -- Crafted Leather
(21008, 4042, 1, 1, 2, 1368.577644), -- Enria
(21008, 4983, 1, 1, 2, 174.355041), -- Recipe: Doom Plate Armor (60%)
(21008, 5276, 1, 1, 2, 109.42785), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21008, 8729, 1, 1, 2, 1095.008019), -- Life Stone - Level 64
(21008, 8739, 1, 1, 2, 273.812798), -- Mid-Grade Life Stone - Level 64
(21008, 8749, 1, 1, 2, 27.478549), -- High-Grade Life Stone - Level 64
(21008, 8759, 1, 1, 2, 5.349806), -- Top-Grade Life Stone - Level 64
-- Doom Trooper 
(21009, 4104, 1, 1, -1, 18708), -- Great Sword Blade
(21009, 948, 1, 1, -1, 8173), -- Scroll: Enchant Armor (B-Grade)
(21009, 4052, 1, 1, -1, 115743), -- Earring of Black Ore Piece
(21009, 57, 1297, 2625, 0, 700000), -- Adena
(21009, 12204, 1, 1, 1, 214.314874), -- Common Item - Blue Wolf Breastplate
(21009, 4078, 1, 1, 1, 2350.979085), -- Blue Wolf Breastplate Part
(21009, 12184, 1, 1, 1, 131.920877), -- Common Item - Doom Plate Armor
(21009, 4081, 1, 1, 1, 1586.320568), -- Doom Plate Armor Temper
(21009, 12193, 1, 1, 1, 342.806967), -- Common Item - Blue Wolf Gaiters
(21009, 4080, 1, 1, 1, 3310.657629), -- Blue Wolf Gaiters Material
(21009, 1865, 1, 1, 2, 87787.21732), -- Varnish
(21009, 1870, 1, 1, 2, 87787.21732), -- Coal
(21009, 1879, 1, 1, 2, 14631.236136), -- Cokes
(21009, 1875, 1, 1, 2, 5852.414656), -- Stone of Purity
(21009, 4040, 1, 1, 2, 1755.764296), -- Mold Lubricant
(21009, 5004, 1, 1, 2, 67.030656), -- Recipe: Staff of Evil Spirits (60%)
(21009, 5281, 1, 1, 2, 117.104152), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21009, 8729, 1, 1, 2, 1170.443032), -- Life Stone - Level 64
(21009, 8739, 1, 1, 2, 292.660632), -- Mid-Grade Life Stone - Level 64
(21009, 8749, 1, 1, 2, 29.325912), -- High-Grade Life Stone - Level 64
(21009, 8759, 1, 1, 2, 5.585888), -- Top-Grade Life Stone - Level 64
-- Doom Warrior
(21010, 4621, 1, 1, -1, 3620), -- Greater Dye of MEN (Men+4 Int-4)
(21010, 5230, 1, 1, -1, 3500), -- Recipe: Mithril Arrow (100%)
(21010, 57, 1042, 2108, 0, 700000), -- Adena
(21010, 11933, 1, 1, 1, 126.65055), -- Common Item - Bellion Cestus
(21010, 4120, 1, 1, 1, 1694.34945), -- Bellion Cestus Edge
(21010, 1868, 1, 1, 2, 119273.46406), -- Thread
(21010, 1873, 1, 1, 2, 23854.75954), -- Silver Nugget
(21010, 5549, 1, 1, 2, 5963.64818), -- Metallic Thread
(21010, 1889, 1, 1, 2, 3975.82106), -- Compound Braid
(21010, 4044, 1, 1, 2, 1987.82712), -- Thons
(21010, 4129, 1, 1, 2, 645.42658), -- Recipe: Earrings of Black Ore (100%)
(21010, 4624, 1, 1, 2, 82.24226), -- Greater Dye of WIT (Wit+4 Men-4)
(21010, 3956, 1, 1, 2, 79.57314), -- Recipe: Blessed Spiritshot A
(21010, 6670, 1, 1, 2, 9939.46924), -- Deluxe Chest Key - Grade 6
(21010, 8729, 1, 1, 2, 795.23094), -- Life Stone - Level 64
(21010, 8739, 1, 1, 2, 198.84944), -- Mid-Grade Life Stone - Level 64
(21010, 8749, 1, 1, 2, 19.85158), -- High-Grade Life Stone - Level 64
(21010, 8759, 1, 1, 2, 3.83686), -- Top-Grade Life Stone - Level 64
-- Ol Mahum Van Grunt
(21011, 1884, 1, 1, -1, 326755), -- Cord
(21011, 1832, 1, 1, -1, 589975), -- Greater Antidote
(21011, 1900, 1, 1, -1, 58094), -- Enchanted Necklace Chain
(21011, 57, 224, 448, 0, 700000), -- Adena
(21011, 627, 1, 1, 1, 1078.49287), -- Aspis
(21011, 46, 1, 1, 1, 755.50713), -- Bronze Helmet
(21011, 1864, 1, 1, 2, 72539.733448), -- Stem
(21011, 1865, 1, 1, 2, 36269.866724), -- Varnish
(21011, 1866, 1, 1, 2, 24179.82801), -- Suede
(21011, 1873, 1, 1, 2, 14507.896806), -- Silver Nugget
(21011, 1868, 1, 1, 2, 72539.733448), -- Thread
(21011, 2185, 1, 1, 2, 7139.839668), -- Recipe: Iron Boots
(21011, 2274, 1, 1, 2, 259.145302), -- Recipe: Skull Breaker
(21011, 1061, 1, 1, 2, 21981.956594), -- Greater Healing Potion
-- Magical Eye
(21012, 1936, 1, 1, -1, 53457), -- White Tunic Pattern
(21012, 2185, 1, 1, -1, 128592), -- Recipe: Iron Boots
(21012, 2153, 1, 1, -1, 101594), -- Recipe: Tiger's Eye Earring
(21012, 57, 276, 551, 0, 700000), -- Adena
(21012, 275, 1, 1, 1, 48.025665), -- Long Bow
(21012, 276, 1, 1, 1, 48.025665), -- Elven Bow
(21012, 2024, 1, 1, 1, 1694.94867), -- Elven Bow Shaft
(21012, 1868, 1, 1, 2, 101992.861289), -- Thread
(21012, 1873, 1, 1, 2, 20398.679367), -- Silver Nugget
(21012, 5549, 1, 1, 2, 5099.736785), -- Metallic Thread
(21012, 1889, 1, 1, 2, 3399.646008), -- Compound Braid
(21012, 2264, 1, 1, 2, 527.245037), -- Recipe: Two-handed Sword
(21012, 2273, 1, 1, 2, 364.17128), -- Recipe: Tarbar
(21012, 1833, 1, 1, 2, 135990.660234), -- Bandage
-- Ol Mahum Van Archer
(21013, 1061, 1, 1, -1, 466705), -- Greater Healing Potion
(21013, 2023, 1, 1, -1, 9542), -- Conjuror's Staff Head
(21013, 1933, 1, 1, -1, 90596), -- Dark Stockings Fabric
(21013, 57, 324, 651, 0, 700000), -- Adena
(21013, 848, 1, 1, 1, 641.472052), -- Enchanted Earring
(21013, 911, 1, 1, 1, 481.464386), -- Enchanted Necklace
(21013, 1900, 1, 1, 1, 11509.918316), -- Enchanted Necklace Chain
(21013, 879, 1, 1, 1, 965.145246), -- Enchanted Ring
(21013, 1871, 1, 1, 2, 70135.122772), -- Charcoal
(21013, 1866, 1, 1, 2, 46756.805964), -- Suede
(21013, 1877, 1, 1, 2, 2805.480744), -- Adamantite Nugget
(21013, 737, 1, 1, 2, 7013.529512), -- Scroll of Resurrection
(21013, 2187, 1, 1, 2, 3131.046116), -- Recipe: Manticore Skin Shirt
(21013, 1061, 1, 1, 2, 42506.014892), -- Greater Healing Potion
-- Lesser Warlike Tyrant
(21014, 2977, 1, 1, -1, 106414), -- Recipe: Brigandine Boots
(21014, 1958, 1, 1, -1, 71453), -- Reinforced Mithril Boots Design
(21014, 1865, 1, 1, -1, 794911), -- Varnish
(21014, 57, 336, 672, 0, 700000), -- Adena
(21014, 316, 1, 1, 1, 37.907312), -- Sage's Blood
(21014, 317, 1, 1, 1, 37.907312), -- Tome of Blood
(21014, 2030, 1, 1, 1, 1648.185376), -- Tome of Blood Page
(21014, 1865, 1, 1, 2, 70441.29989), -- Varnish
(21014, 1870, 1, 1, 2, 70441.29989), -- Coal
(21014, 1879, 1, 1, 2, 11740.16303), -- Cokes
(21014, 1875, 1, 1, 2, 4696.161725), -- Stone of Purity
(21014, 2189, 1, 1, 2, 3144.71525), -- Recipe: Mithril Tunic
(21014, 2286, 1, 1, 2, 391.360215), -- Recipe: Bonebreaker
-- Ol Mahum Van Leader
(21015, 1940, 1, 1, -1, 121028), -- Iron Boots Design
(21015, 1869, 1, 1, -1, 810885), -- Iron Ore
(21015, 1873, 1, 1, -1, 324354), -- Silver Nugget
(21015, 57, 342, 683, 0, 700000), -- Adena
(21015, 83, 1, 1, 1, 26.091), -- Sword of Magic
(21015, 144, 1, 1, 1, 26.091), -- Sword of Occult
(21015, 124, 1, 1, 1, 19.3284), -- Two-Handed Sword
(21015, 2026, 1, 1, 1, 864.831825), -- Two-Handed Sword Edge
(21015, 127, 1, 1, 1, 19.3284), -- Crimson Sword
(21015, 130, 1, 1, 1, 19.329375), -- Elven Sword
(21015, 1873, 1, 1, 2, 34491.320064), -- Silver Nugget
(21015, 1868, 1, 1, 2, 172456.127616), -- Thread
(21015, 1876, 1, 1, 2, 17245.660032), -- Mithril Ore
(21015, 2280, 1, 1, 2, 615.933312), -- Recipe: Crucifix of Blood
(21015, 2978, 1, 1, 2, 11542.958976), -- Recipe: Elven Mithril Boots
-- Warlike Tyrant
(21016, 1870, 1, 1, -1, 868501), -- Coal
(21016, 1882, 1, 1, -1, 193000), -- Leather
(21016, 1901, 1, 1, -1, 119959), -- Tiger's Eye Earring Stone
(21016, 57, 367, 732, 0, 700000), -- Adena
(21016, 58, 1, 1, 1, 93.563163), -- Mithril Breastplate
(21016, 349, 1, 1, 1, 93.563163), -- Compound Scale Mail
(21016, 350, 1, 1, 1, 93.563163), -- Dwarven Scale Mail
(21016, 351, 1, 1, 1, 84.518562), -- Blast Plate
(21016, 59, 1, 1, 1, 135.26424), -- Mithril Gaiters
(21016, 378, 1, 1, 1, 135.26424), -- Compound Scale Gaiters
(21016, 379, 1, 1, 1, 135.263469), -- Dwarven Scale Gaiters
(21016, 1869, 1, 1, 2, 65968.001142), -- Iron Ore
(21016, 1864, 1, 1, 2, 131936.002284), -- Stem
(21016, 1880, 1, 1, 2, 6596.843124), -- Steel
(21016, 5550, 1, 1, 2, 879.55041), -- Durable Metal Plate
(21016, 2191, 1, 1, 2, 8830.987185), -- Recipe: RIP Gauntlets
(21016, 2293, 1, 1, 2, 366.443496), -- Recipe: Glaive
(21016, 2276, 1, 1, 2, 471.172359), -- Recipe: Maingauche
-- Fallen Orc
(21017, 1989, 1, 1, -1, 53465), -- Divine Stocking Pattern
(21017, 1880, 1, 1, -1, 177397), -- Steel
(21017, 1806, 1, 1, -1, 3548), -- Recipe: Soulshot (B-Grade)
(21017, 57, 701, 1428, 0, 700000), -- Adena
(21017, 400, 1, 1, 1, 34.38225), -- Theca Leather Armor
(21017, 1984, 1, 1, 1, 2339.906625), -- Theca Leather Armor Pattern
(21017, 401, 1, 1, 1, 16.277625), -- Drake Leather Armor
(21017, 1987, 1, 1, 1, 1665.3735), -- Drake Leather Armor Texture
(21017, 420, 1, 1, 1, 55.0305), -- Theca Leather Gaiters
(21017, 1985, 1, 1, 1, 3764.0295), -- Theca Leather Gaiters Pattern
(21017, 1866, 1, 1, 2, 36389.065012), -- Suede
(21017, 1871, 1, 1, 2, 54583.597518), -- Charcoal
(21017, 5220, 1, 1, 2, 2183.331873), -- Metal Hardener
(21017, 1885, 1, 1, 2, 4548.583011), -- High-Grade Suede
(21017, 4041, 1, 1, 2, 474.593785), -- Mold Hardener
(21017, 4940, 1, 1, 2, 262.404758), -- Recipe: Zubei's Breastplate (60%)
(21017, 5280, 1, 1, 2, 109.151559), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(21017, 4189, 1, 1, 2, 62.844837), -- Recipe: Arthro Nail (100%)
(21017, 8726, 1, 1, 2, 1263.511986), -- Life Stone - Level 55
(21017, 8736, 1, 1, 2, 315.827881), -- Mid-Grade Life Stone - Level 55
(21017, 8746, 1, 1, 2, 31.572765), -- High-Grade Life Stone - Level 55
(21017, 8756, 1, 1, 2, 6.515015), -- Top-Grade Life Stone - Level 55
-- Ancient Gargoyle
(21018, 4947, 1, 1, -1, 22992), -- Recipe: Zubei's Leather Gaiters (60%)
(21018, 2961, 1, 1, -1, 121815), -- Full Plate Boots Part
(21018, 4049, 1, 1, -1, 117342), -- Adamantite Earring Gemstone
(21018, 57, 883, 1802, 0, 700000), -- Adena
(21018, 11918, 1, 1, 1, 94.522944), -- Common Item - Heavy War Axe
(21018, 4105, 1, 1, 1, 945.231504), -- Heavy War Axe Head
(21018, 11908, 1, 1, 1, 94.522944), -- Common Item - Sprite's Staff
(21018, 4106, 1, 1, 1, 929.722608), -- Sprite's Staff Head
(21018, 1872, 1, 1, 2, 73423.762488), -- Animal Bone
(21018, 1867, 1, 1, 2, 73423.762488), -- Animal Skin
(21018, 1881, 1, 1, 2, 7342.424568), -- Coarse Bone Powder
(21018, 1875, 1, 1, 2, 3671.131752), -- Stone of Purity
(21018, 4041, 1, 1, 2, 478.843272), -- Mold Hardener
(21018, 4950, 1, 1, 2, 565.978896), -- Recipe: Stockings of Zubei (60%)
(21018, 4999, 1, 1, 2, 684.844128), -- Recipe: Sealed Doom Boots (60%)
(21018, 8309, 1, 1, 2, 63.459216), -- Recipe: Spell Breaker (100%)
(21018, 8727, 1, 1, 2, 1101.355632), -- Life Stone - Level 58
(21018, 8737, 1, 1, 2, 275.41944), -- Mid-Grade Life Stone - Level 58
(21018, 8747, 1, 1, 2, 27.541944), -- High-Grade Life Stone - Level 58
(21018, 8757, 1, 1, 2, 5.476176), -- Top-Grade Life Stone - Level 58
-- Fallen Orc Archer
(21019, 2964, 1, 1, -1, 134399), -- Divine Gloves Pattern
(21019, 4950, 1, 1, -1, 25367), -- Recipe: Stockings of Zubei (60%)
(21019, 4129, 1, 1, -1, 26713), -- Recipe: Earrings of Black Ore (100%)
(21019, 57, 973, 1988, 0, 700000), -- Adena
(21019, 11903, 1, 1, 1, 208.636155), -- Common Item - Arthro Nail
(21019, 4111, 1, 1, 1, 2086.363845), -- Arthro Nail Blade
(21019, 1870, 1, 1, 2, 60756.881586), -- Coal
(21019, 1865, 1, 1, 2, 60756.881586), -- Varnish
(21019, 1874, 1, 1, 2, 4050.520392), -- Oriharukon Ore
(21019, 4043, 1, 1, 2, 2025.260196), -- Asofe
(21019, 4039, 1, 1, 2, 2025.260196), -- Mold Glue
(21019, 4964, 1, 1, 2, 69.98226), -- Recipe: Heavy War Axe (60%)
(21019, 4176, 1, 1, 2, 755.676366), -- Recipe: Sealed Doom Boots (100%)
(21019, 5003, 1, 1, 2, 46.346742), -- Recipe: Art of Battle Axe (60%)
(21019, 8727, 1, 1, 2, 1215.182526), -- Life Stone - Level 58
(21019, 8737, 1, 1, 2, 303.828642), -- Mid-Grade Life Stone - Level 58
(21019, 8747, 1, 1, 2, 30.36966), -- High-Grade Life Stone - Level 58
(21019, 8757, 1, 1, 2, 5.809848), -- Top-Grade Life Stone - Level 58
-- Fallen Orc Shaman
(21020, 4952, 1, 1, -1, 35974), -- Recipe: Avadon Circlet (60%)
(21020, 1987, 1, 1, -1, 42700), -- Drake Leather Armor Texture
(21020, 4050, 1, 1, -1, 173407), -- Adamantite Ring Wire
(21020, 57, 1105, 2252, 0, 700000), -- Adena
(21020, 78, 1, 1, 1, 4.124809), -- Great Sword
(21020, 4104, 1, 1, 1, 788.351473), -- Great Sword Blade
(21020, 142, 1, 1, 1, 4.124809), -- Keshanberk
(21020, 4107, 1, 1, 1, 776.13705), -- Keshanberk Blade
(21020, 148, 1, 1, 1, 4.124809), -- Sword of Valhalla
(21020, 4108, 1, 1, 1, 776.13705), -- Sword of Valhalla Blade
(21020, 4167, 1, 1, 2, 5141.29545), -- Recipe: Sealed Blue Wolf Boots (100%)
(21020, 1832, 1, 1, 2, 459293.70455), -- Greater Antidote
-- Sharp Talon Tiger
(21021, 4040, 1, 1, -1, 51678), -- Mold Lubricant
(21021, 4613, 1, 1, -1, 3564), -- Greater Dye of STR (Str+4 Con-4)
(21021, 947, 1, 1, -1, 1034), -- Scroll: Enchant Weapon (B-Grade)
(21021, 57, 1020, 2079, 0, 700000), -- Adena
(21021, 11896, 1, 1, 1, 218.380305), -- Common Item - Dark Elven Long Bow
(21021, 4112, 1, 1, 1, 2160.619695), -- Dark Elven Longbow Shaft
(21021, 1869, 1, 1, 2, 63603.8396), -- Iron Ore
(21021, 1870, 1, 1, 2, 63603.8396), -- Coal
(21021, 1871, 1, 1, 2, 63603.8396), -- Charcoal
(21021, 1872, 1, 1, 2, 84804.99825), -- Animal Bone
(21021, 1867, 1, 1, 2, 84804.99825), -- Animal Skin
(21021, 4130, 1, 1, 2, 1032.40235), -- Recipe: Ring of Black Ore (100%)
(21021, 4998, 1, 1, 2, 790.93875), -- Recipe: Sealed Blue Wolf Gloves (60%)
(21021, 5001, 1, 1, 2, 48.7291), -- Recipe: Lance (60%)
(21021, 8728, 1, 1, 2, 1060.03975), -- Life Stone - Level 61
(21021, 8738, 1, 1, 2, 265.10085), -- Mid-Grade Life Stone - Level 61
(21021, 8748, 1, 1, 2, 26.54645), -- High-Grade Life Stone - Level 61
(21021, 8758, 1, 1, 2, 4.72745), -- Top-Grade Life Stone - Level 61
-- Fallen Orc Captain
(21022, 4049, 1, 1, -1, 138069), -- Adamantite Earring Gemstone
(21022, 947, 1, 1, -1, 1053), -- Scroll: Enchant Weapon (B-Grade)
(21022, 4613, 1, 1, -1, 3631), -- Greater Dye of STR (Str+4 Con-4)
(21022, 57, 1041, 2116, 0, 700000), -- Adena
(21022, 12175, 1, 1, 1, 414.009032), -- Common Item - Tunic of Zubei
(21022, 4069, 1, 1, 1, 3055.156032), -- Tunic of Zubei Fabric
(21022, 12166, 1, 1, 1, 254.084596), -- Common Item - Avadon Robe
(21022, 4071, 1, 1, 1, 2347.12394), -- Avadon Robe Fabric
(21022, 12176, 1, 1, 1, 662.839764), -- Common Item - Stockings of Zubei
(21022, 4070, 1, 1, 1, 4638.786636), -- Stockings of Zubei Fabric
(21022, 1869, 1, 1, 2, 64794.760936), -- Iron Ore
(21022, 1870, 1, 1, 2, 64794.760936), -- Coal
(21022, 1871, 1, 1, 2, 64794.760936), -- Charcoal
(21022, 1872, 1, 1, 2, 86392.891095), -- Animal Bone
(21022, 1867, 1, 1, 2, 86392.891095), -- Animal Skin
(21022, 4130, 1, 1, 2, 1051.733101), -- Recipe: Ring of Black Ore (100%)
(21022, 4998, 1, 1, 2, 805.748325), -- Recipe: Sealed Blue Wolf Gloves (60%)
(21022, 5001, 1, 1, 2, 49.641506), -- Recipe: Lance (60%)
(21022, 8728, 1, 1, 2, 1079.887985), -- Life Stone - Level 61
(21022, 8738, 1, 1, 2, 270.064611), -- Mid-Grade Life Stone - Level 61
(21022, 8748, 1, 1, 2, 27.043507), -- High-Grade Life Stone - Level 61
(21022, 8758, 1, 1, 2, 4.815967), -- Top-Grade Life Stone - Level 61
-- Sobbing Wind
(21023, 2019, 1, 1, -1, 9507), -- Trident Edge
(21023, 2263, 1, 1, -1, 6865), -- Recipe: Dwarven Trident
(21023, 1866, 1, 1, -1, 294716), -- Suede
(21023, 57, 192, 367, 0, 700000), -- Adena
(21023, 156, 1, 1, 1, 52.666614), -- Hand Axe
(21023, 167, 1, 1, 1, 52.666614), -- Scalpel
(21023, 178, 1, 1, 1, 52.666772), -- Bone Staff
(21023, 1864, 1, 1, 2, 82701.808816), -- Stem
(21023, 1865, 1, 1, 2, 41350.778656), -- Varnish
(21023, 1866, 1, 1, 2, 27567.35344), -- Suede
(21023, 1873, 1, 1, 2, 16540.412064), -- Silver Nugget
(21023, 1868, 1, 1, 2, 82701.808816), -- Thread
(21023, 2260, 1, 1, 2, 641.838208), -- Recipe: Mace of Judgment
-- Babbling Wind
(21024, 2178, 1, 1, -1, 73852), -- Recipe: Dark Stockings
(21024, 1934, 1, 1, -1, 60336), -- Crafted Leather Gloves Lining
(21024, 1899, 1, 1, -1, 72121), -- Necklace of Devotion Chain
(21024, 57, 199, 384, 0, 700000), -- Adena
(21024, 220, 1, 1, 1, 164), -- Crafted Dagger
(21024, 1864, 1, 1, 2, 103619.211899), -- Stem
(21024, 1869, 1, 1, 2, 51809.711915), -- Iron Ore
(21024, 1878, 1, 1, 2, 20723.884766), -- Braided Hemp
(21024, 1884, 1, 1, 2, 31882.89964), -- Cord
(21024, 2180, 1, 1, 2, 3895.29178), -- Recipe: Scale Mail
-- Giggling Wind
(21025, 1871, 1, 1, -1, 485180), -- Charcoal
(21025, 1868, 1, 3, -1, 485180), -- Thread
(21025, 2152, 1, 1, -1, 85419), -- Recipe: Enchanted Necklace
(21025, 57, 208, 407, 0, 700000), -- Adena
(21025, 291, 1, 1, 1, 86.432478), -- Trident
(21025, 2019, 1, 1, 1, 2927.567522), -- Trident Edge
(21025, 1864, 1, 1, 2, 90765.871725), -- Stem
(21025, 1865, 1, 1, 2, 45382.796495), -- Varnish
(21025, 1866, 1, 1, 2, 30255.290575), -- Suede
(21025, 1873, 1, 1, 2, 18153.174345), -- Silver Nugget
(21025, 1868, 1, 1, 2, 90765.871725), -- Thread
(21025, 2180, 1, 1, 2, 3411.995135), -- Recipe: Scale Mail
-- Singing Wind
(21026, 1834, 1, 1, -1, 575495), -- Emergency Dressing
(21026, 2025, 1, 1, -1, 7174), -- Dwarven Trident Edge
(21026, 1900, 1, 1, -1, 56668), -- Enchanted Necklace Chain
(21026, 57, 220, 435, 0, 700000), -- Adena
(21026, 275, 1, 1, 1, 38.0773), -- Long Bow
(21026, 276, 1, 1, 1, 38.0773), -- Elven Bow
(21026, 2024, 1, 1, 1, 1343.8454), -- Elven Bow Shaft
(21026, 1872, 1, 1, 2, 53911.649475), -- Animal Bone
(21026, 1867, 1, 1, 2, 53911.649475), -- Animal Skin
(21026, 1881, 1, 1, 2, 5391.10212), -- Coarse Bone Powder
(21026, 1875, 1, 1, 2, 2695.55106), -- Stone of Purity
(21026, 737, 1, 1, 2, 4043.32659), -- Scroll of Resurrection
(21026, 2274, 1, 1, 2, 288.75519), -- Recipe: Skull Breaker
(21026, 2191, 1, 1, 2, 5412.96609), -- Recipe: RIP Gauntlets
-- Ogre
(21034, 2302, 1, 1, -1, 3085), -- Recipe: Silver Axe
(21034, 1956, 1, 1, -1, 80198), -- Square Shield Fragment
(21034, 2154, 1, 1, -1, 75647), -- Recipe: Elven Earring
(21034, 57, 299, 596, 0, 700000), -- Adena
(21034, 88, 1, 1, 1, 6.8006), -- Morning Star
(21034, 2031, 1, 1, 1, 369.64295), -- Morning Star Head
(21034, 90, 1, 1, 1, 6.8006), -- Goat Head Staff
(21034, 2032, 1, 1, 1, 337.43075), -- Goat Head Staff Head
(21034, 158, 1, 1, 1, 6.8006), -- Tarbar
(21034, 2035, 1, 1, 1, 369.64295), -- Tarbar Head
(21034, 169, 1, 1, 1, 6.8006), -- Skull Breaker
(21034, 2036, 1, 1, 1, 369.64295), -- Skull Breaker Head
(21034, 172, 1, 1, 1, 6.8006), -- Heavy Bone Club
(21034, 2037, 1, 1, 1, 369.6374), -- Heavy Bone Club Head
(21034, 1874, 1, 1, 2, 3043.573712), -- Oriharukon Ore
(21034, 1878, 1, 1, 2, 18261.23224), -- Braided Hemp
(21034, 1884, 1, 1, 2, 28094.090352), -- Cord
(21034, 1889, 1, 1, 2, 3043.573712), -- Compound Braid
(21034, 5220, 1, 1, 2, 1826.018208), -- Metal Hardener
(21034, 2190, 1, 1, 2, 3260.956832), -- Recipe: Mithril Stockings
(21034, 2279, 1, 1, 2, 326.179696), -- Recipe: War Pick
(21034, 1341, 10, 30, 2, 152176.375248), -- Bone Arrow
-- Catherok
(21035, 1952, 1, 1, -1, 72876), -- Salamander Skin Mail Texture
(21035, 1873, 1, 1, -1, 910076), -- Silver Nugget
(21035, 1905, 1, 1, -1, 221322), -- Omen Beast's Eye Earring Gemstone
(21035, 57, 916, 1852, 0, 700000), -- Adena
(21035, 396, 1, 1, 1, 311.644923), -- Salamander Skin Mail
(21035, 1952, 1, 1, 1, 18297.355077), -- Salamander Skin Mail Texture
(21035, 1865, 1, 1, 2, 126944.108529), -- Varnish
(21035, 1870, 1, 1, 2, 126944.108529), -- Coal
(21035, 1879, 1, 1, 2, 21157.526526), -- Cokes
(21035, 1875, 1, 1, 2, 8462.800485), -- Stone of Purity
(21035, 2308, 1, 1, 2, 554.380847), -- Recipe: Cursed Dagger
(21035, 2205, 1, 1, 2, 4017.247439), -- Recipe: Chain Gaiters
(21035, 2989, 1, 1, 2, 6716.658411), -- Recipe: Chain Hood
(21035, 2997, 1, 1, 2, 10074.812512), -- Recipe: Karmian Gloves
(21035, 6668, 1, 1, 2, 45337.356722), -- Deluxe Chest Key - Grade 4
-- Shindebarn
(21036, 2070, 1, 1, -1, 21261), -- Cursed Dagger Blade
(21036, 2316, 1, 1, -1, 9330), -- Recipe: Katana
(21036, 1895, 1, 1, -1, 765042), -- Metallic Fiber
(21036, 57, 1054, 2160, 0, 700000), -- Adena
(21036, 354, 1, 1, 1, 162.83088), -- Chain Mail Shirt
(21036, 1959, 1, 1, 1, 8521.60536), -- Chain Mail Shirt Material
(21036, 381, 1, 1, 1, 260.48736), -- Chain Gaiters
(21036, 1960, 1, 1, 1, 17335.0764), -- Chain Gaiters Part
(21036, 1895, 1, 1, 2, 60262.116192), -- Metallic Fiber
(21036, 2318, 1, 1, 2, 734.903856), -- Recipe: Spirit Sword
(21036, 8723, 1, 1, 2, 8436.676164), -- Life Stone - Level 46
(21036, 8733, 1, 1, 2, 2109.151092), -- Mid-Grade Life Stone - Level 46
(21036, 8743, 1, 1, 2, 210.936648), -- High-Grade Life Stone - Level 46
(21036, 8753, 1, 1, 2, 42.216048), -- Top-Grade Life Stone - Level 46
-- Ossiud
(21037, 5231, 1, 1, -1, 247709), -- Recipe: Metal Hardener (100%)
(21037, 4040, 1, 1, -1, 69359), -- Mold Lubricant
(21037, 2166, 1, 1, -1, 117557), -- Recipe: Earrings of Binding (100%)
(21037, 57, 1369, 2792, 0, 700000), -- Adena
(21037, 1126, 1, 1, 1, 206.69324), -- Crimson Boots
(21037, 1974, 1, 1, 1, 10768.531033), -- Crimson Boot Fabric
(21037, 2434, 1, 1, 1, 206.69324), -- Rind Leather Boots
(21037, 2948, 1, 1, 1, 10768.531033), -- Rind Leather Boots Lining
(21037, 2455, 1, 1, 1, 223.813915), -- Plated Leather Gloves
(21037, 2946, 1, 1, 1, 7156.940206), -- Plate Leather Gloves Design
(21037, 2456, 1, 1, 1, 206.69324), -- Dwarven Chain Gloves
(21037, 2949, 1, 1, 1, 10768.531033), -- Dwarven Chain Gloves Design
(21037, 2457, 1, 1, 1, 206.69324), -- Gloves of Seal
(21037, 2950, 1, 1, 1, 10768.531033), -- Gloves of Seal Pattern
(21037, 2458, 1, 1, 1, 206.69324), -- Rind Leather Gloves
(21037, 2951, 1, 1, 1, 10768.655547), -- Rind Leather Gloves Design
(21037, 1895, 1, 1, 2, 36584.521984), -- Metallic Fiber
(21037, 4040, 1, 1, 2, 2560.929664), -- Mold Lubricant
(21037, 4042, 1, 1, 2, 2134.089824), -- Enria
(21037, 4043, 1, 1, 2, 4268.179648), -- Asofe
(21037, 2329, 1, 1, 2, 297.77616), -- Recipe: Tsurugi
(21037, 2225, 1, 1, 2, 2783.6192), -- Recipe: Demon's Stockings
(21037, 2345, 1, 1, 2, 297.77616), -- Recipe: Dark Screamer
(21037, 2344, 1, 1, 2, 297.77616), -- Recipe: Grace Dagger
(21037, 8724, 1, 1, 2, 4268.179648), -- Life Stone - Level 49
(21037, 8734, 1, 1, 2, 1067.072256), -- Mid-Grade Life Stone - Level 49
(21037, 8744, 1, 1, 2, 106.696288), -- High-Grade Life Stone - Level 49
(21037, 8754, 1, 1, 2, 21.383008), -- Top-Grade Life Stone - Level 49
-- Liangma
(21038, 5231, 1, 1, -1, 187644), -- Recipe: Metal Hardener (100%)
(21038, 1911, 1, 1, -1, 195390), -- Earring of Protection Gemstone
(21038, 2166, 1, 1, -1, 89051), -- Recipe: Earrings of Binding (100%)
(21038, 57, 1037, 2115, 0, 700000), -- Adena
(21038, 2496, 1, 1, 1, 323.055837), -- Dwarven Chain Shield
(21038, 2947, 1, 1, 1, 13856.305437), -- Dwarven Chain Shield Fragment
(21038, 632, 1, 1, 1, 298.228047), -- Knight's Shield
(21038, 1972, 1, 1, 1, 15519.05199), -- Knight's Shield Fragment
(21038, 500, 1, 1, 1, 208.805922), -- Great Helmet
(21038, 1971, 1, 1, 1, 11875.552767), -- Great Helmet Material
(21038, 1872, 1, 1, 2, 141087.342613), -- Animal Bone
(21038, 1867, 1, 1, 2, 141087.342613), -- Animal Skin
(21038, 1881, 1, 1, 2, 14108.640775), -- Coarse Bone Powder
(21038, 1875, 1, 1, 2, 7054.476198), -- Stone of Purity
(21038, 4041, 1, 1, 2, 920.216813), -- Mold Hardener
(21038, 2224, 1, 1, 2, 1437.819294), -- Recipe: Demon's Tunic
(21038, 952, 1, 1, 2, 1411.019888), -- Scroll: Enchant Armor (C-Grade)
(21038, 8724, 1, 1, 2, 3527.238099), -- Life Stone - Level 49
(21038, 8734, 1, 1, 2, 881.88743), -- Mid-Grade Life Stone - Level 49
(21038, 8744, 1, 1, 2, 88.188743), -- High-Grade Life Stone - Level 49
(21038, 8754, 1, 1, 2, 16.827534), -- Top-Grade Life Stone - Level 49
-- Snipe Cohort
(21039, 1805, 1, 1, -1, 8706), -- Recipe: Soulshot (C-Grade)
(21039, 1905, 1, 1, -1, 254068), -- Omen Beast's Eye Earring Gemstone
(21039, 1871, 1, 5, -1, 870607), -- Charcoal
(21039, 57, 1033, 2097, 0, 700000), -- Adena
(21039, 70, 1, 1, 1, 47.27586), -- Claymore
(21039, 2047, 1, 1, 1, 2882.22114), -- Claymore Blade
(21039, 2499, 1, 1, 1, 47.27586), -- Elven Long Sword
(21039, 2967, 1, 1, 1, 2843.22714), -- Elven Long Sword Blade
(21039, 1871, 1, 1, 2, 218589.145338), -- Charcoal
(21039, 1866, 1, 1, 2, 145726.225326), -- Suede
(21039, 1877, 1, 1, 2, 8743.658286), -- Adamantite Nugget
(21039, 2162, 1, 1, 2, 10559.971914), -- Recipe: Aquastone Necklace
(21039, 5159, 1, 1, 2, 728.606082), -- Recipe: Spiritshot (C) Compressed Package (100%)
(21039, 2312, 1, 1, 2, 954.393054), -- Recipe: Crystallized Ice Bow
-- Soldier of Darkness
(21040, 1875, 1, 1, -1, 277649), -- Stone of Purity
(21040, 1911, 1, 1, -1, 309761), -- Earring of Protection Gemstone
(21040, 1967, 1, 1, -1, 227147), -- Plated Leather Gaiters Material
(21040, 57, 1644, 3353, 0, 700000), -- Adena
(21040, 195, 1, 1, 1, 41.757248), -- Cursed Staff
(21040, 2082, 1, 1, 1, 3251.674816), -- Cursed Staff Head
(21040, 2502, 1, 1, 1, 41.757248), -- Dwarven War Hammer
(21040, 2968, 1, 1, 1, 3112.810688), -- Dwarven War Hammer Head
(21040, 1872, 1, 1, 2, 223672.659084), -- Animal Bone
(21040, 1867, 1, 1, 2, 223672.659084), -- Animal Skin
(21040, 1881, 1, 1, 2, 22367.1177), -- Coarse Bone Powder
(21040, 1875, 1, 1, 2, 11183.805864), -- Stone of Purity
(21040, 4041, 1, 1, 2, 1458.864684), -- Mold Hardener
(21040, 2224, 1, 1, 2, 2279.445192), -- Recipe: Demon's Tunic
(21040, 952, 1, 1, 2, 2236.958784), -- Scroll: Enchant Armor (C-Grade)
(21040, 8724, 1, 1, 2, 5591.902932), -- Life Stone - Level 49
(21040, 8734, 1, 1, 2, 1398.09924), -- Mid-Grade Life Stone - Level 49
(21040, 8744, 1, 1, 2, 139.809924), -- High-Grade Life Stone - Level 49
(21040, 8754, 1, 1, 2, 26.677512), -- Top-Grade Life Stone - Level 49
-- Beast Lord
(21058, 4617, 1, 1, -1, 8254), -- Greater Dye of DEX (Dex+4 Str-4)
(21058, 4049, 1, 1, -1, 313879), -- Adamantite Earring Gemstone
(21058, 4129, 1, 1, -1, 64763), -- Recipe: Earrings of Black Ore (100%)
(21058, 57, 2367, 4811, 0, 700000), -- Adena
(21058, 78, 1, 1, 1, 8.819343), -- Great Sword
(21058, 4104, 1, 1, 1, 1685.591271), -- Great Sword Blade
(21058, 142, 1, 1, 1, 8.819343), -- Keshanberk
(21058, 4107, 1, 1, 1, 1659.47535), -- Keshanberk Blade
(21058, 148, 1, 1, 1, 8.819343), -- Sword of Valhalla
(21058, 4108, 1, 1, 1, 1659.47535), -- Sword of Valhalla Blade
(21058, 1895, 1, 1, 2, 45911.986758), -- Metallic Fiber
(21058, 4040, 1, 1, 2, 3213.826956), -- Mold Lubricant
(21058, 4042, 1, 1, 2, 2678.18913), -- Enria
(21058, 4043, 1, 1, 2, 5356.37826), -- Asofe
(21058, 4195, 1, 1, 2, 122.637402), -- Recipe: Art of Battle Axe (100%)
(21058, 4999, 1, 1, 2, 1998.67716), -- Recipe: Sealed Doom Boots (60%)
(21058, 4163, 1, 1, 2, 1064.196738), -- Recipe: Blue Wolf Stockings (100%)
(21058, 8728, 1, 1, 2, 2678.18913), -- Life Stone - Level 61
(21058, 8738, 1, 1, 2, 669.563226), -- Mid-Grade Life Stone - Level 61
(21058, 8748, 1, 1, 2, 66.9627), -- High-Grade Life Stone - Level 61
(21058, 8758, 1, 1, 2, 13.39254), -- Top-Grade Life Stone - Level 61
-- Beast Guardian
(21059, 4129, 1, 1, -1, 55362), -- Recipe: Earrings of Black Ore (100%)
(21059, 4049, 1, 1, -1, 268315), -- Adamantite Earring Gemstone
(21059, 4130, 1, 1, -1, 83043), -- Recipe: Ring of Black Ore (100%)
(21059, 57, 2020, 4116, 0, 700000), -- Adena
(21059, 284, 1, 1, 1, 22.618), -- Dark Elven Long Bow
(21059, 4112, 1, 1, 1, 4277.382), -- Dark Elven Longbow Shaft
(21059, 1864, 1, 3, 2, 125918.281528), -- Stem
(21059, 1869, 1, 1, 2, 125918.281528), -- Iron Ore
(21059, 1878, 1, 1, 2, 50367.157308), -- Braided Hemp
(21059, 1884, 1, 1, 2, 77488.143382), -- Cord
(21059, 4039, 1, 1, 2, 4197.457238), -- Mold Glue
(21059, 4154, 1, 1, 2, 1490.134204), -- Recipe: Doom Shield (100%)
(21059, 4198, 1, 1, 2, 96.287984), -- Recipe: Bellion Cestus (100%)
(21059, 4194, 1, 1, 2, 96.287984), -- Recipe: Deadman's Glory (100%)
(21059, 8728, 1, 1, 2, 2098.53449), -- Life Stone - Level 61
(21059, 8738, 1, 1, 2, 524.536558), -- Mid-Grade Life Stone - Level 61
(21059, 8748, 1, 1, 2, 52.41483), -- High-Grade Life Stone - Level 61
(21059, 8758, 1, 1, 2, 10.482966), -- Top-Grade Life Stone - Level 61
-- Beast Seer
(21060, 4050, 1, 1, -1, 316941), -- Adamantite Ring Wire
(21060, 947, 1, 1, -1, 2046), -- Scroll: Enchant Weapon (B-Grade)
(21060, 1865, 1, 11, -1, 852572), -- Varnish
(21060, 57, 2020, 4116, 0, 700000), -- Adena
(21060, 229, 1, 1, 1, 11.309397), -- Kris
(21060, 4109, 1, 1, 1, 2128.190603), -- Kris Edge
(21060, 243, 1, 1, 1, 11.309397), -- Hell Knife
(21060, 4110, 1, 1, 1, 2128.190603), -- Hell Knife Edge
(21060, 1865, 1, 1, 2, 137365.603308), -- Varnish
(21060, 1870, 1, 1, 2, 137365.603308), -- Coal
(21060, 1879, 1, 1, 2, 22894.267218), -- Cokes
(21060, 1875, 1, 1, 2, 9157.624686), -- Stone of Purity
(21060, 4040, 1, 1, 2, 2747.164104), -- Mold Lubricant
(21060, 4155, 1, 1, 2, 426.624228), -- Recipe: Blue Wolf Breastplate (100%)
(21060, 8728, 1, 1, 2, 2289.30342), -- Life Stone - Level 61
(21060, 8738, 1, 1, 2, 572.531358), -- Mid-Grade Life Stone - Level 61
(21060, 8748, 1, 1, 2, 57.129834), -- High-Grade Life Stone - Level 61
(21060, 8758, 1, 1, 2, 11.508168), -- Top-Grade Life Stone - Level 61
(21060, 1343, 20, 60, 2, 98118.640368), -- Silver Arrow
-- Hallate's Guardian
(21061, 5478, 1, 1, -1, 85417), -- Sealed Dark Crystal Leather Armor Pattern
(21061, 1895, 1, 7, -1, 725557), -- Metallic Fiber
(21061, 57, 4020, 8164, 0, 700000), -- Adena
(21061, 5287, 1, 1, 1, 28.07788), -- Sealed Dark Crystal breastplate
(21061, 5520, 1, 1, 1, 3224.93756), -- Sealed Dark Crystal Breastplate Pattern
(21061, 5293, 1, 1, 1, 17.28436), -- Sealed Tallum Plate Armor
(21061, 5521, 1, 1, 1, 2275.64432), -- Sealed Tallum Plate Armor Pattern
(21061, 5288, 1, 1, 1, 44.93092), -- Sealed Dark Crystal Gaiters
(21061, 5524, 1, 1, 1, 4929.12496), -- Sealed Dark Crystal Gaiters Pattern
(21061, 1873, 1, 1, 2, 100015.319741), -- Silver Nugget
(21061, 1868, 1, 3, 2, 250038.539286), -- Thread
(21061, 1876, 1, 1, 2, 50007.899804), -- Mithril Ore
(21061, 1895, 1, 1, 2, 71439.719758), -- Metallic Fiber
(21061, 4042, 1, 1, 2, 4167.165028), -- Enria
(21061, 5000, 1, 1, 2, 190.987066), -- Recipe: Sword of Damascus (60%)
(21061, 730, 1, 1, 2, 208.262278), -- Scroll: Enchant Armor (A-Grade)
(21061, 5422, 1, 1, 2, 242.812702), -- Recipe: Sealed Majestic Plate Armor(60%)
(21061, 8730, 1, 1, 2, 2778.42993), -- Life Stone - Level 67
(21061, 8740, 1, 1, 2, 694.367549), -- Mid-Grade Life Stone - Level 67
(21061, 8750, 1, 1, 2, 69.580715), -- High-Grade Life Stone - Level 67
(21061, 8760, 1, 1, 2, 13.916143), -- Top-Grade Life Stone - Level 67
-- Messenger Angel
(21063, 5220, 1, 1, -1, 875838), -- Metal Hardener
(21063, 5478, 1, 1, -1, 184123), -- Sealed Dark Crystal Leather Armor Pattern
(21063, 1807, 1, 1, -1, 29195), -- Recipe: Soulshot (A-Grade)
(21063, 57, 8659, 17618, 0, 700000), -- Adena
(21063, 5287, 1, 1, 1, 60.524913), -- Sealed Dark Crystal breastplate
(21063, 5520, 1, 1, 1, 6951.702381), -- Sealed Dark Crystal Breastplate Pattern
(21063, 5293, 1, 1, 1, 37.258311), -- Sealed Tallum Plate Armor
(21063, 5521, 1, 1, 1, 4905.397932), -- Sealed Tallum Plate Armor Pattern
(21063, 5288, 1, 1, 1, 96.853467), -- Sealed Dark Crystal Gaiters
(21063, 5524, 1, 1, 1, 10625.262996), -- Sealed Dark Crystal Gaiters Pattern
(21063, 1864, 4, 12, 2, 134744.464995), -- Stem
(21063, 1865, 2, 6, 2, 107795.649885), -- Varnish
(21063, 1866, 3, 9, 2, 59886.51543), -- Suede
(21063, 1873, 4, 12, 2, 26948.81511), -- Silver Nugget
(21063, 1868, 10, 30, 2, 51331.18767), -- Thread
(21063, 5281, 1, 1, 2, 718.526025), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21063, 729, 1, 1, 2, 59.97453), -- Scroll: Enchant Weapon (A-Grade)
(21063, 8314, 1, 1, 2, 294.42042), -- Recipe: Spiritual Eye (60%)
(21063, 8730, 1, 1, 2, 5988.495765), -- Life Stone - Level 67
(21063, 8740, 1, 1, 2, 1497.02658), -- Mid-Grade Life Stone - Level 67
(21063, 8750, 1, 1, 2, 149.54688), -- High-Grade Life Stone - Level 67
(21063, 8760, 1, 1, 2, 30.37671), -- Top-Grade Life Stone - Level 67
-- Platinum Guardian Archer
(21064, 4119, 1, 1, -1, 39452), -- Demon's Dagger Edge
(21064, 5230, 1, 1, -1, 12018), -- Recipe: Mithril Arrow (100%)
(21064, 5479, 1, 1, -1, 53333), -- Sealed Tallum Leather Armor Pattern
(21064, 57, 4448, 9066, 0, 700000), -- Adena
(21064, 5287, 1, 1, 1, 31.144561), -- Sealed Dark Crystal breastplate
(21064, 5520, 1, 1, 1, 3577.166957), -- Sealed Dark Crystal Breastplate Pattern
(21064, 5293, 1, 1, 1, 19.172167), -- Sealed Tallum Plate Armor
(21064, 5521, 1, 1, 1, 2524.191404), -- Sealed Tallum Plate Armor Pattern
(21064, 5288, 1, 1, 1, 49.838299), -- Sealed Dark Crystal Gaiters
(21064, 5524, 1, 1, 1, 5467.486612), -- Sealed Dark Crystal Gaiters Pattern
(21064, 1872, 1, 3, 2, 184888.594158), -- Animal Bone
(21064, 1867, 1, 3, 2, 123259.370568), -- Animal Skin
(21064, 1881, 1, 1, 2, 36977.534154), -- Coarse Bone Powder
(21064, 1875, 1, 1, 2, 18488.997924), -- Stone of Purity
(21064, 4041, 1, 1, 2, 2411.427762), -- Mold Hardener
(21064, 4130, 1, 1, 2, 4501.978194), -- Recipe: Ring of Black Ore (100%)
(21064, 4403, 1, 1, 2, 554.494494), -- Red Dimensional Stone
(21064, 8730, 1, 1, 2, 3081.345756), -- Life Stone - Level 67
(21064, 8740, 1, 1, 2, 770.567286), -- Mid-Grade Life Stone - Level 67
(21064, 8750, 1, 1, 2, 77.102898), -- High-Grade Life Stone - Level 67
(21064, 8760, 1, 1, 2, 15.235902), -- Top-Grade Life Stone - Level 67
(21064, 1344, 40, 120, 2, 86667.350904), -- Mithril Arrow
-- Platinum Guardian Warrior
(21065, 4120, 1, 1, -1, 44373), -- Bellion Cestus Edge
(21065, 1807, 1, 1, -1, 13539), -- Recipe: Soulshot (A-Grade)
(21065, 57, 5007, 10224, 0, 700000), -- Adena
(21065, 5291, 1, 1, 1, 105.318486), -- Sealed Dark Crystal Boots
(21065, 5496, 1, 1, 1, 10990.181514), -- Sealed Dark Crystal Boots Lining
(21065, 5296, 1, 1, 1, 105.318486), -- Sealed Tallum Boots
(21065, 5497, 1, 1, 1, 10990.181514), -- Sealed Tallum Boots Lining
(21065, 5290, 1, 1, 1, 105.318486), -- Sealed Dark Crystal Gloves
(21065, 5508, 1, 1, 1, 10990.181514), -- Sealed Dark Crystal Gloves Design
(21065, 5295, 1, 1, 1, 105.318486), -- Sealed Tallum Gloves
(21065, 5509, 1, 1, 1, 10990.181514), -- Sealed Tallum Gloves Design
(21065, 1872, 1, 3, 2, 227233.97532), -- Animal Bone
(21065, 1867, 1, 3, 2, 151489.31688), -- Animal Skin
(21065, 1881, 1, 1, 2, 45446.795064), -- Coarse Bone Powder
(21065, 1875, 1, 1, 2, 22723.397532), -- Stone of Purity
(21065, 4041, 1, 1, 2, 2963.702544), -- Mold Hardener
(21065, 4164, 1, 1, 2, 2257.100208), -- Recipe: Stockings of Doom (100%)
(21065, 4401, 1, 1, 2, 681.88956), -- Green Dimensional Stone
(21065, 8730, 1, 1, 2, 3787.0041), -- Life Stone - Level 67
(21065, 8740, 1, 1, 2, 946.865436), -- Mid-Grade Life Stone - Level 67
(21065, 8750, 1, 1, 2, 94.732308), -- High-Grade Life Stone - Level 67
(21065, 8760, 1, 1, 2, 19.221048), -- Top-Grade Life Stone - Level 67
-- Platinum Guardian Shaman
(21066, 5230, 1, 1, -1, 13627), -- Recipe: Mithril Arrow (100%)
(21066, 4081, 1, 1, -1, 100730), -- Doom Plate Armor Temper
(21066, 5482, 1, 1, -1, 134892), -- Sealed Dark Crystal Leggings Design
(21066, 57, 5047, 10276, 0, 700000), -- Adena
(21066, 5292, 1, 1, 1, 134.52984), -- Sealed Dark Crystal Shield
(21066, 5494, 1, 1, 1, 13207.500015), -- Sealed Dark Crystal Shield Fragment
(21066, 5289, 1, 1, 1, 94.137915), -- Sealed Dark Crystal Helmet
(21066, 5525, 1, 1, 1, 9721.363644), -- Sealed Dark Crystal Helmet Design
(21066, 5294, 1, 1, 1, 94.137915), -- Sealed Tallum Helmet
(21066, 5526, 1, 1, 1, 9721.330671), -- Sealed Tallum Helm Design
(21066, 1868, 3, 9, 2, 104821.254228), -- Thread
(21066, 1873, 1, 1, 2, 125785.638128), -- Silver Nugget
(21066, 5549, 1, 1, 2, 31446.409532), -- Metallic Thread
(21066, 1889, 1, 1, 2, 20964.3839), -- Compound Braid
(21066, 4044, 1, 1, 2, 10482.025632), -- Thons
(21066, 4613, 1, 1, 2, 433.757344), -- Greater Dye of STR (Str+4 Con-4)
(21066, 729, 1, 1, 2, 34.92678), -- Scroll: Enchant Weapon (A-Grade)
(21066, 6671, 1, 1, 2, 34940.418076), -- Deluxe Chest Key - Grade 7
(21066, 8731, 1, 1, 2, 2911.562908), -- Life Stone - Level 70
(21066, 8741, 1, 1, 2, 727.807568), -- Mid-Grade Life Stone - Level 70
(21066, 8751, 1, 1, 2, 72.847284), -- High-Grade Life Stone - Level 70
(21066, 8761, 1, 1, 2, 14.96862), -- Top-Grade Life Stone - Level 70
-- Guardian Archangel
(21068, 3035, 1, 1, -1, 32034), -- Recipe: Spiritshot A
(21068, 5485, 1, 1, -1, 202033), -- Sealed Tallum Tunic Texture
(21068, 5479, 1, 1, -1, 142164), -- Sealed Tallum Leather Armor Pattern
(21068, 57, 11856, 24167, 0, 700000), -- Adena
(21068, 5287, 1, 1, 1, 83.016576), -- Sealed Dark Crystal breastplate
(21068, 5520, 1, 1, 1, 9535.024512), -- Sealed Dark Crystal Breastplate Pattern
(21068, 5293, 1, 1, 1, 51.103872), -- Sealed Tallum Plate Armor
(21068, 5521, 1, 1, 1, 6728.292864), -- Sealed Tallum Plate Armor Pattern
(21068, 5288, 1, 1, 1, 132.845184), -- Sealed Dark Crystal Gaiters
(21068, 5524, 1, 1, 1, 14573.716992), -- Sealed Dark Crystal Gaiters Pattern
(21068, 1869, 18, 54, 2, 22401.583128), -- Iron Ore
(21068, 1870, 2, 6, 2, 161291.488716), -- Coal
(21068, 1871, 3, 9, 2, 134409.498768), -- Charcoal
(21068, 1872, 7, 21, 2, 76805.492292), -- Animal Bone
(21068, 1867, 12, 36, 2, 44803.166256), -- Animal Skin
(21068, 4402, 1, 1, 2, 1613.126844), -- Blue Dimensional Stone
(21068, 729, 1, 1, 2, 89.743428), -- Scroll: Enchant Weapon (A-Grade)
(21068, 8731, 1, 1, 2, 7467.194376), -- Life Stone - Level 70
(21068, 8741, 1, 1, 2, 1867.02408), -- Mid-Grade Life Stone - Level 70
(21068, 8751, 1, 1, 2, 186.702408), -- High-Grade Life Stone - Level 70
(21068, 8761, 1, 1, 2, 36.979704), -- Top-Grade Life Stone - Level 70
-- Platinum Guardian Prefect
(21069, 4080, 1, 1, -1, 265874), -- Blue Wolf Gaiters Material
(21069, 4041, 1, 1, -1, 112395), -- Mold Hardener
(21069, 3035, 1, 1, -1, 17234), -- Recipe: Spiritshot A
(21069, 57, 6379, 13001, 0, 700000), -- Adena
(21069, 5291, 1, 1, 1, 134.057889), -- Sealed Dark Crystal Boots
(21069, 5496, 1, 1, 1, 13989.192111), -- Sealed Dark Crystal Boots Lining
(21069, 5296, 1, 1, 1, 134.057889), -- Sealed Tallum Boots
(21069, 5497, 1, 1, 1, 13989.192111), -- Sealed Tallum Boots Lining
(21069, 5290, 1, 1, 1, 134.057889), -- Sealed Dark Crystal Gloves
(21069, 5508, 1, 1, 1, 13989.192111), -- Sealed Dark Crystal Gloves Design
(21069, 5295, 1, 1, 1, 134.057889), -- Sealed Tallum Gloves
(21069, 5509, 1, 1, 1, 13989.192111), -- Sealed Tallum Gloves Design
(21069, 1871, 1, 3, 2, 198852.888312), -- Charcoal
(21069, 1866, 1, 1, 2, 265137.184416), -- Suede
(21069, 1877, 1, 1, 2, 15908.072024), -- Adamantite Nugget
(21069, 4041, 1, 1, 2, 3458.146874), -- Mold Hardener
(21069, 4040, 1, 1, 2, 7954.036012), -- Mold Lubricant
(21069, 4619, 1, 1, 2, 548.691312), -- Greater Dye of INT (Int+4 Men-4)
(21069, 5422, 1, 1, 2, 386.171331), -- Recipe: Sealed Majestic Plate Armor(60%)
(21069, 729, 1, 1, 2, 44.233267), -- Scroll: Enchant Weapon (A-Grade)
(21069, 8731, 1, 1, 2, 3682.295227), -- Life Stone - Level 70
(21069, 8741, 1, 1, 2, 920.449556), -- Mid-Grade Life Stone - Level 70
(21069, 8751, 1, 1, 2, 91.945555), -- High-Grade Life Stone - Level 70
(21069, 8761, 1, 1, 2, 18.886114), -- Top-Grade Life Stone - Level 70
-- Seal Archangel
(21071, 5486, 1, 1, -1, 147834), -- Sealed Dark Crystal Robe Fabric
(21071, 5156, 1, 1, -1, 33312), -- Recipe: Soulshot (A) Compressed Package (100%)
(21071, 5489, 1, 1, -1, 329756), -- Sealed Tallum Stockings Fabric
(21071, 57, 12324, 25146, 0, 700000), -- Adena
(21071, 5297, 1, 1, 1, 115.124142), -- Sealed Dark Crystal Leather Armor
(21071, 5478, 1, 1, 1, 12927.753902), -- Sealed Dark Crystal Leather Armor Pattern
(21071, 5301, 1, 1, 1, 70.816074), -- Sealed Tallum Leather Armor
(21071, 5479, 1, 1, 1, 9096.856146), -- Sealed Tallum Leather Armor Pattern
(21071, 5298, 1, 1, 1, 184.104718), -- Sealed Dark Crystal Leggings
(21071, 5482, 1, 1, 1, 20291.345018), -- Sealed Dark Crystal Leggings Design
(21071, 1894, 1, 1, 2, 32367.841994), -- Crafted Leather
(21071, 4039, 1, 1, 2, 30749.484325), -- Mold Glue
(21071, 4041, 1, 1, 2, 8021.549717), -- Mold Hardener
(21071, 4044, 1, 1, 2, 30749.484325), -- Thons
(21071, 4403, 1, 1, 2, 1844.911675), -- Red Dimensional Stone
(21071, 729, 1, 1, 2, 102.488717), -- Scroll: Enchant Weapon (A-Grade)
(21071, 8731, 1, 1, 2, 8541.568056), -- Life Stone - Level 70
(21071, 8741, 1, 1, 2, 2135.392014), -- Mid-Grade Life Stone - Level 70
(21071, 8751, 1, 1, 2, 213.585109), -- High-Grade Life Stone - Level 70
(21071, 8761, 1, 1, 2, 42.694068), -- Top-Grade Life Stone - Level 70
-- Platinum Guardian Chief
(21072, 4083, 1, 1, -1, 119814), -- Leather Armor of Doom Design
(21072, 5230, 1, 1, -1, 14138), -- Recipe: Mithril Arrow (100%)
(21072, 5161, 1, 1, -1, 14138), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21072, 57, 5231, 10672, 0, 700000), -- Adena
(21072, 5292, 1, 1, 1, 139.5768), -- Sealed Dark Crystal Shield
(21072, 5494, 1, 1, 1, 13702.98655), -- Sealed Dark Crystal Shield Fragment
(21072, 5289, 1, 1, 1, 97.66955), -- Sealed Dark Crystal Helmet
(21072, 5525, 1, 1, 1, 10086.06588), -- Sealed Dark Crystal Helmet Design
(21072, 5294, 1, 1, 1, 97.66955), -- Sealed Tallum Helmet
(21072, 5526, 1, 1, 1, 10086.03167), -- Sealed Tallum Helm Design
(21072, 1868, 3, 9, 2, 118641.414714), -- Thread
(21072, 1873, 1, 1, 2, 142369.63003), -- Silver Nugget
(21072, 5549, 1, 1, 2, 35592.322974), -- Metallic Thread
(21072, 1889, 1, 1, 2, 23728.215316), -- Compound Braid
(21072, 4044, 1, 1, 2, 11864.107658), -- Thons
(21072, 4984, 1, 1, 2, 1008.315588), -- Recipe: Blue Wolf Leather Armor (60%)
(21072, 4403, 1, 1, 2, 711.77207), -- Red Dimensional Stone
(21072, 8731, 1, 1, 2, 3295.453964), -- Life Stone - Level 70
(21072, 8741, 1, 1, 2, 824.032558), -- Mid-Grade Life Stone - Level 70
(21072, 8751, 1, 1, 2, 82.504696), -- High-Grade Life Stone - Level 70
(21072, 8761, 1, 1, 2, 16.230432), -- Top-Grade Life Stone - Level 70
-- Elmoreden's Guardian Warrior
(21073, 5230, 1, 1, -1, 7723), -- Recipe: Mithril Arrow (100%)
(21073, 4052, 1, 1, -1, 205074), -- Earring of Black Ore Piece
(21073, 57, 2300, 4651, 0, 700000), -- Adena
(21073, 287, 1, 1, 1, 16.95579), -- Bow of Peril
(21073, 4121, 1, 1, 1, 3726.04421), -- Bow of Peril Shaft
(21073, 1869, 1, 1, 2, 155542.380381), -- Iron Ore
(21073, 1864, 1, 3, 2, 155542.380381), -- Stem
(21073, 1880, 1, 1, 2, 15554.118345), -- Steel
(21073, 5550, 1, 1, 2, 2073.882446), -- Durable Metal Plate
(21073, 4043, 1, 1, 2, 5184.706115), -- Asofe
(21073, 1830, 1, 1, 2, 62216.872357), -- Scroll of Escape: Castle
(21073, 5276, 1, 1, 2, 207.46804), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21073, 8729, 1, 1, 2, 2073.882446), -- Life Stone - Level 64
(21073, 8739, 1, 1, 2, 518.6701), -- Mid-Grade Life Stone - Level 64
(21073, 8749, 1, 1, 2, 51.86701), -- High-Grade Life Stone - Level 64
(21073, 8759, 1, 1, 2, 10.772379), -- Top-Grade Life Stone - Level 64
-- Bound Shaman
(21074, 5478, 1, 1, -1, 50828), -- Sealed Dark Crystal Leather Armor Pattern
(21074, 1874, 1, 1, -1, 402961), -- Oriharukon Ore
(21074, 5482, 1, 1, -1, 79779), -- Sealed Dark Crystal Leggings Design
(21074, 57, 2981, 6086, 0, 700000), -- Adena
(21074, 5291, 1, 1, 1, 62.689914), -- Sealed Dark Crystal Boots
(21074, 5496, 1, 1, 1, 6541.810086), -- Sealed Dark Crystal Boots Lining
(21074, 5296, 1, 1, 1, 62.689914), -- Sealed Tallum Boots
(21074, 5497, 1, 1, 1, 6541.810086), -- Sealed Tallum Boots Lining
(21074, 5290, 1, 1, 1, 62.689914), -- Sealed Dark Crystal Gloves
(21074, 5508, 1, 1, 1, 6541.810086), -- Sealed Dark Crystal Gloves Design
(21074, 5295, 1, 1, 1, 62.689914), -- Sealed Tallum Gloves
(21074, 5509, 1, 1, 1, 6541.810086), -- Sealed Tallum Gloves Design
(21074, 1870, 1, 1, 2, 202889.768632), -- Coal
(21074, 1865, 1, 1, 2, 202889.768632), -- Varnish
(21074, 1874, 1, 1, 2, 13526.100884), -- Oriharukon Ore
(21074, 4043, 1, 1, 2, 6763.050442), -- Asofe
(21074, 4039, 1, 1, 2, 6763.050442), -- Mold Glue
(21074, 5166, 1, 1, 2, 270.41734), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21074, 730, 1, 1, 2, 169.228916), -- Scroll: Enchant Armor (A-Grade)
(21074, 8730, 1, 1, 2, 2254.495533), -- Life Stone - Level 67
(21074, 8740, 1, 1, 2, 563.514844), -- Mid-Grade Life Stone - Level 67
(21074, 8750, 1, 1, 2, 56.264253), -- High-Grade Life Stone - Level 67
(21074, 8760, 1, 1, 2, 11.340082), -- Top-Grade Life Stone - Level 67
-- Slaughter Bathin
(21075, 4616, 1, 1, -1, 7536), -- Greater Dye of CON (Con+4 Dex-4)
(21075, 4052, 1, 1, -1, 193443), -- Earring of Black Ore Piece
(21075, 4041, 1, 1, -1, 47511), -- Mold Hardener
(21075, 57, 2167, 4388, 0, 700000), -- Adena
(21075, 601, 1, 1, 1, 65.204056), -- Sealed Doom Boots
(21075, 4099, 1, 1, 1, 9056.795944), -- Sealed Doom Boots Part
(21075, 2439, 1, 1, 1, 65.204056), -- Sealed Blue Wolf Boots
(21075, 4090, 1, 1, 1, 9056.795944), -- Sealed Blue Wolf Boots Design
(21075, 2475, 1, 1, 1, 65.204056), -- Sealed Doom Gloves
(21075, 4091, 1, 1, 1, 9056.795944), -- Sealed Doom Gloves Part
(21075, 2487, 1, 1, 1, 65.204056), -- Sealed Blue Wolf Gloves
(21075, 4096, 1, 1, 1, 9056.795944), -- Sealed Blue Wolf Gloves Fabric
(21075, 1871, 1, 1, 2, 134493.480225), -- Charcoal
(21075, 1866, 1, 1, 2, 89662.32015), -- Suede
(21075, 1877, 1, 1, 2, 5379.739209), -- Adamantite Nugget
(21075, 4041, 1, 1, 2, 1169.518792), -- Mold Hardener
(21075, 4040, 1, 1, 2, 2689.98769), -- Mold Lubricant
(21075, 5005, 1, 1, 2, 102.734385), -- Recipe: Demon's Dagger (60%)
(21075, 5276, 1, 1, 2, 179.253789), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21075, 5418, 1, 1, 2, 198.619811), -- Recipe: Sealed Tallum Plate Armor(60%)
(21075, 8729, 1, 1, 2, 1793.246403), -- Life Stone - Level 64
(21075, 8739, 1, 1, 2, 448.252558), -- Mid-Grade Life Stone - Level 64
(21075, 8749, 1, 1, 2, 44.87249), -- High-Grade Life Stone - Level 64
(21075, 8759, 1, 1, 2, 8.974498), -- Top-Grade Life Stone - Level 64
-- Bathin's Knight
(21076, 4052, 1, 1, -1, 189765), -- Earring of Black Ore Piece
(21076, 5230, 1, 1, -1, 7147), -- Recipe: Mithril Arrow (100%)
(21076, 4053, 1, 1, -1, 229743), -- Ring of Black Ore Gemstone
(21076, 57, 2126, 4306, 0, 700000), -- Adena
(21076, 2398, 1, 1, 1, 21.314447), -- Blue Wolf Tunic
(21076, 4084, 1, 1, 1, 3440.532768), -- Blue Wolf Tunic Fabric
(21076, 2399, 1, 1, 1, 21.314447), -- Tunic of Doom
(21076, 4085, 1, 1, 1, 3440.532768), -- Tunic of Doom Pattern
(21076, 2403, 1, 1, 1, 34.129168), -- Blue Wolf Stockings
(21076, 4086, 1, 1, 1, 4645.507334), -- Blue Wolf Stockings Pattern
(21076, 2404, 1, 1, 1, 34.129168), -- Stockings of Doom
(21076, 4087, 1, 1, 1, 4645.5399), -- Stockings of Doom Pattern
(21076, 1871, 1, 1, 2, 158323.32098), -- Charcoal
(21076, 1866, 1, 1, 2, 105549.10784), -- Suede
(21076, 1877, 1, 1, 2, 6333.05552), -- Adamantite Nugget
(21076, 4041, 1, 1, 2, 1376.7512), -- Mold Hardener
(21076, 4040, 1, 1, 2, 3166.52776), -- Mold Lubricant
(21076, 1830, 1, 1, 2, 63329.53286), -- Scroll of Escape: Castle
(21076, 8729, 1, 1, 2, 2111.1321), -- Life Stone - Level 64
(21076, 8739, 1, 1, 2, 527.86822), -- Mid-Grade Life Stone - Level 64
(21076, 8749, 1, 1, 2, 52.8209), -- High-Grade Life Stone - Level 64
(21076, 8759, 1, 1, 2, 9.88262), -- Top-Grade Life Stone - Level 64
-- Bathin's Wizard
(21077, 5230, 1, 1, -1, 6798), -- Recipe: Mithril Arrow (100%)
(21077, 4054, 1, 1, -1, 100424), -- Necklace of Black Ore Beads
(21077, 4041, 1, 1, -1, 44335), -- Mold Hardener
(21077, 57, 2022, 4096, 0, 700000), -- Adena
(21077, 864, 1, 1, 1, 70.60721), -- Earring of Black Ore
(21077, 4052, 1, 1, 1, 8886.33308), -- Earring of Black Ore Piece
(21077, 926, 1, 1, 1, 52.961612), -- Necklace of Black Ore
(21077, 4054, 1, 1, 1, 4943.7456), -- Necklace of Black Ore Beads
(21077, 895, 1, 1, 1, 105.898406), -- Ring of Black Ore
(21077, 4053, 1, 1, 1, 10758.454092), -- Ring of Black Ore Gemstone
(21077, 1872, 1, 1, 2, 167336.28288), -- Animal Bone
(21077, 1867, 1, 1, 2, 167336.28288), -- Animal Skin
(21077, 1881, 1, 1, 2, 16733.718885), -- Coarse Bone Powder
(21077, 1875, 1, 1, 2, 8366.63295), -- Stone of Purity
(21077, 4041, 1, 1, 2, 1091.240865), -- Mold Hardener
(21077, 5230, 1, 1, 2, 167.151465), -- Recipe: Mithril Arrow (100%)
(21077, 5276, 1, 1, 2, 167.151465), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21077, 8729, 1, 1, 2, 1673.32659), -- Life Stone - Level 64
(21077, 8739, 1, 1, 2, 418.55814), -- Mid-Grade Life Stone - Level 64
(21077, 8749, 1, 1, 2, 41.67462), -- High-Grade Life Stone - Level 64
(21077, 8759, 1, 1, 2, 8.15373), -- Top-Grade Life Stone - Level 64
(21077, 1343, 20, 60, 2, 89644.82553), -- Silver Arrow
-- Magus Valac
(21078, 4040, 1, 1, -1, 135112), -- Mold Lubricant
(21078, 5485, 1, 1, -1, 56808), -- Sealed Tallum Tunic Texture
(21078, 3956, 1, 1, -1, 9007), -- Recipe: Blessed Spiritshot A
(21078, 57, 2672, 5436, 0, 700000), -- Adena
(21078, 5292, 1, 1, 1, 71.13888), -- Sealed Dark Crystal Shield
(21078, 5494, 1, 1, 1, 6984.07698), -- Sealed Dark Crystal Shield Fragment
(21078, 5289, 1, 1, 1, 49.77978), -- Sealed Dark Crystal Helmet
(21078, 5525, 1, 1, 1, 5140.621008), -- Sealed Dark Crystal Helmet Design
(21078, 5294, 1, 1, 1, 49.77978), -- Sealed Tallum Helmet
(21078, 5526, 1, 1, 1, 5140.603572), -- Sealed Tallum Helm Design
(21078, 1873, 1, 1, 2, 79819.857375), -- Silver Nugget
(21078, 1868, 1, 3, 2, 199549.836589), -- Thread
(21078, 1876, 1, 1, 2, 39910.121839), -- Mithril Ore
(21078, 1895, 1, 1, 2, 57014.45977), -- Metallic Fiber
(21078, 4042, 1, 1, 2, 3325.682527), -- Enria
(21078, 4175, 1, 1, 2, 3844.873759), -- Recipe: Sealed Avadon Boots (100%)
(21078, 8730, 1, 1, 2, 2217.37922), -- Life Stone - Level 67
(21078, 8740, 1, 1, 2, 554.344805), -- Mid-Grade Life Stone - Level 67
(21078, 8750, 1, 1, 2, 55.241329), -- High-Grade Life Stone - Level 67
(21078, 8760, 1, 1, 2, 11.202787), -- Top-Grade Life Stone - Level 67
-- Valac's Creature
(21079, 1895, 1, 3, -1, 918483), -- Metallic Fiber
(21079, 4042, 1, 1, -1, 107156), -- Enria
(21079, 5478, 1, 1, -1, 54065), -- Sealed Dark Crystal Leather Armor Pattern
(21079, 57, 2545, 5167, 0, 700000), -- Adena
(21079, 5304, 1, 1, 1, 23.701236), -- Sealed Tallum Tunic
(21079, 5485, 1, 1, 1, 2661.507316), -- Sealed Tallum Tunic Texture
(21079, 5308, 1, 1, 1, 14.579292), -- Sealed Dark Crystal Robe
(21079, 5486, 1, 1, 1, 1872.819468), -- Sealed Dark Crystal Robe Fabric
(21079, 5305, 1, 1, 1, 37.902644), -- Sealed Tallum Stockings
(21079, 5489, 1, 1, 1, 4177.490044), -- Sealed Tallum Stockings Fabric
(21079, 1873, 1, 1, 2, 69059.696958), -- Silver Nugget
(21079, 1868, 1, 3, 2, 172649.076758), -- Thread
(21079, 1876, 1, 1, 2, 34529.682842), -- Mithril Ore
(21079, 1895, 1, 1, 2, 49328.35497), -- Metallic Fiber
(21079, 4042, 1, 1, 2, 2877.445964), -- Enria
(21079, 5161, 1, 1, 2, 230.23543), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21079, 730, 1, 1, 2, 143.772916), -- Scroll: Enchant Armor (A-Grade)
(21079, 8730, 1, 1, 2, 1918.407734), -- Life Stone - Level 67
(21079, 8740, 1, 1, 2, 479.684752), -- Mid-Grade Life Stone - Level 67
(21079, 8750, 1, 1, 2, 48.03473), -- High-Grade Life Stone - Level 67
(21079, 8760, 1, 1, 2, 9.606946), -- Top-Grade Life Stone - Level 67
-- Valac's Guardian Spirit
(21080, 1807, 1, 1, -1, 7923), -- Recipe: Soulshot (A-Grade)
(21080, 5479, 1, 1, -1, 35162), -- Sealed Tallum Leather Armor Pattern
(21080, 3035, 1, 1, -1, 7923), -- Recipe: Spiritshot A
(21080, 57, 2352, 4776, 0, 700000), -- Adena
(21080, 6324, 1, 1, 1, 58.217938), -- Sealed Phoenix Earring
(21080, 6341, 1, 1, 1, 8091.08426), -- Sealed Phoenix Earring Gemstone
(21080, 6323, 1, 1, 1, 43.657022), -- Sealed Phoenix Necklace
(21080, 6343, 1, 1, 1, 6254.710928), -- Sealed Phoenix Necklace Beads
(21080, 6325, 1, 1, 1, 87.314044), -- Sealed Phoenix Ring
(21080, 6345, 1, 1, 1, 11191.015808), -- Sealed Phoenix Ring Gemstone
(21080, 1864, 1, 3, 2, 146273.299821), -- Stem
(21080, 1869, 1, 1, 2, 146273.299821), -- Iron Ore
(21080, 1878, 1, 1, 2, 58509.229293), -- Braided Hemp
(21080, 1884, 1, 1, 2, 90014.094333), -- Cord
(21080, 4039, 1, 1, 2, 4875.731343), -- Mold Glue
(21080, 5166, 1, 1, 2, 194.86611), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21080, 8314, 1, 1, 2, 79.759152), -- Recipe: Spiritual Eye (60%)
(21080, 8730, 1, 1, 2, 1625.092722), -- Life Stone - Level 67
(21080, 8740, 1, 1, 2, 406.499769), -- Mid-Grade Life Stone - Level 67
(21080, 8750, 1, 1, 2, 40.78593), -- High-Grade Life Stone - Level 67
(21080, 8760, 1, 1, 2, 8.157186), -- Top-Grade Life Stone - Level 67
(21080, 6036, 1, 1, 2, 4876.18452), -- Greater Magic Haste Potion
-- Power Angel Amon
(21081, 5230, 1, 1, -1, 8037), -- Recipe: Mithril Arrow (100%)
(21081, 4119, 1, 1, -1, 26385), -- Demon's Dagger Edge
(21081, 5478, 1, 1, -1, 50689), -- Sealed Dark Crystal Leather Armor Pattern
(21081, 57, 2973, 6067, 0, 700000), -- Adena
(21081, 5297, 1, 1, 1, 27.776403), -- Sealed Dark Crystal Leather Armor
(21081, 5478, 1, 1, 1, 3119.124243), -- Sealed Dark Crystal Leather Armor Pattern
(21081, 5301, 1, 1, 1, 17.086041), -- Sealed Tallum Leather Armor
(21081, 5479, 1, 1, 1, 2194.830189), -- Sealed Tallum Leather Armor Pattern
(21081, 5298, 1, 1, 1, 44.419587), -- Sealed Dark Crystal Leggings
(21081, 5482, 1, 1, 1, 4895.763537), -- Sealed Dark Crystal Leggings Design
(21081, 1872, 1, 3, 2, 148380.202152), -- Animal Bone
(21081, 1867, 1, 1, 2, 296759.909446), -- Animal Skin
(21081, 1881, 1, 1, 2, 29676.139402), -- Coarse Bone Powder
(21081, 1875, 1, 1, 2, 14837.822272), -- Stone of Purity
(21081, 4041, 1, 1, 2, 1935.389638), -- Mold Hardener
(21081, 4985, 1, 1, 2, 630.449092), -- Recipe: Leather Armor of Doom (60%)
(21081, 8731, 1, 1, 2, 2060.588712), -- Life Stone - Level 70
(21081, 8741, 1, 1, 2, 515.147178), -- Mid-Grade Life Stone - Level 70
(21081, 8751, 1, 1, 2, 51.465232), -- High-Grade Life Stone - Level 70
(21081, 8761, 1, 1, 2, 10.886876), -- Top-Grade Life Stone - Level 70
-- Amon's Captain of the Guards
(21082, 5482, 1, 1, -1, 76302), -- Sealed Dark Crystal Leggings Design
(21082, 5486, 1, 1, -1, 34207), -- Sealed Dark Crystal Robe Fabric
(21082, 5156, 1, 1, -1, 7708), -- Recipe: Soulshot (A) Compressed Package (100%)
(21082, 57, 2853, 5815, 0, 700000), -- Adena
(21082, 5304, 1, 1, 1, 26.638269), -- Sealed Tallum Tunic
(21082, 5485, 1, 1, 1, 2991.318589), -- Sealed Tallum Tunic Texture
(21082, 5308, 1, 1, 1, 16.385943), -- Sealed Dark Crystal Robe
(21082, 5486, 1, 1, 1, 2104.897347), -- Sealed Dark Crystal Robe Fabric
(21082, 5305, 1, 1, 1, 42.599501), -- Sealed Tallum Stockings
(21082, 5489, 1, 1, 1, 4695.160351), -- Sealed Tallum Stockings Fabric
(21082, 1865, 1, 1, 2, 213451.890565), -- Varnish
(21082, 1870, 1, 1, 2, 213451.890565), -- Coal
(21082, 1879, 1, 1, 2, 35575.234462), -- Cokes
(21082, 1875, 1, 1, 2, 14230.287302), -- Stone of Purity
(21082, 4040, 1, 1, 2, 4268.989432), -- Mold Lubricant
(21082, 5281, 1, 1, 2, 284.470284), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21082, 8731, 1, 1, 2, 1976.294405), -- Life Stone - Level 70
(21082, 8741, 1, 1, 2, 493.952653), -- Mid-Grade Life Stone - Level 70
(21082, 8751, 1, 1, 2, 49.346886), -- High-Grade Life Stone - Level 70
(21082, 8761, 1, 1, 2, 10.643446), -- Top-Grade Life Stone - Level 70
-- Amon's Spirits
(21083, 5485, 1, 1, -1, 50785), -- Sealed Tallum Tunic Texture
(21083, 5156, 1, 1, -1, 8052), -- Recipe: Soulshot (A) Compressed Package (100%)
(21083, 5486, 1, 1, -1, 35736), -- Sealed Dark Crystal Robe Fabric
(21083, 57, 2980, 6075, 0, 700000), -- Adena
(21083, 6324, 1, 1, 1, 73.959366), -- Sealed Phoenix Earring
(21083, 6341, 1, 1, 1, 10278.81582), -- Sealed Phoenix Earring Gemstone
(21083, 6323, 1, 1, 1, 55.461354), -- Sealed Phoenix Necklace
(21083, 6343, 1, 1, 1, 7945.909296), -- Sealed Phoenix Necklace Beads
(21083, 6325, 1, 1, 1, 110.922708), -- Sealed Phoenix Ring
(21083, 6345, 1, 1, 1, 14216.931456), -- Sealed Phoenix Ring Gemstone
(21083, 1866, 1, 1, 2, 135145.54431), -- Suede
(21083, 1871, 1, 1, 2, 202718.13273), -- Charcoal
(21083, 5220, 1, 1, 2, 8108.59302), -- Metal Hardener
(21083, 1885, 1, 1, 2, 16893.33084), -- High-Grade Suede
(21083, 4041, 1, 1, 2, 1762.75359), -- Mold Hardener
(21083, 1807, 1, 1, 2, 270.45792), -- Recipe: Soulshot (A-Grade)
(21083, 730, 1, 1, 2, 169.0362), -- Scroll: Enchant Armor (A-Grade)
(21083, 8731, 1, 1, 2, 1877.03676), -- Life Stone - Level 70
(21083, 8741, 1, 1, 2, 469.25919), -- Mid-Grade Life Stone - Level 70
(21083, 8751, 1, 1, 2, 47.03616), -- High-Grade Life Stone - Level 70
(21083, 8761, 1, 1, 2, 8.81928), -- Top-Grade Life Stone - Level 70
-- Bloody Lady
(21084, 4129, 1, 1, -1, 54392), -- Recipe: Earrings of Black Ore (100%)
(21084, 4056, 1, 1, -1, 90964), -- Zubei's Breastplate Part
(21084, 57, 1988, 4041, 0, 700000), -- Adena
(21084, 78, 1, 1, 1, 7.408178), -- Great Sword
(21084, 4104, 1, 1, 1, 1415.883266), -- Great Sword Blade
(21084, 142, 1, 1, 1, 7.408178), -- Keshanberk
(21084, 4107, 1, 1, 1, 1393.9461), -- Keshanberk Blade
(21084, 148, 1, 1, 1, 7.408178), -- Sword of Valhalla
(21084, 4108, 1, 1, 1, 1393.9461), -- Sword of Valhalla Blade
(21084, 1868, 1, 1, 2, 228390.933016), -- Thread
(21084, 1873, 1, 1, 2, 45678.101277), -- Silver Nugget
(21084, 5549, 1, 1, 2, 11419.631977), -- Metallic Thread
(21084, 1889, 1, 1, 2, 7613.230195), -- Compound Braid
(21084, 4044, 1, 1, 2, 3806.401782), -- Thons
(21084, 4196, 1, 1, 2, 87.032724), -- Recipe: Staff of Evil Spirits (100%)
(21084, 4402, 1, 1, 2, 228.247585), -- Blue Dimensional Stone
(21084, 5002, 1, 1, 2, 87.032724), -- Recipe: Deadman's Glory (60%)
(21084, 8728, 1, 1, 2, 1903.200891), -- Life Stone - Level 61
(21084, 8738, 1, 1, 2, 475.693565), -- Mid-Grade Life Stone - Level 61
(21084, 8748, 1, 1, 2, 47.782672), -- High-Grade Life Stone - Level 61
(21084, 8758, 1, 1, 2, 9.385882), -- Top-Grade Life Stone - Level 61
(21084, 1832, 1, 1, 2, 126884.32571), -- Greater Antidote
-- Bloody Sniper
(21085, 5479, 1, 1, -1, 55365), -- Sealed Tallum Leather Armor Pattern
(21085, 5489, 1, 1, -1, 123496), -- Sealed Tallum Stockings Fabric
(21085, 1889, 1, 1, -1, 623779), -- Compound Braid
(21085, 57, 4617, 9411, 0, 700000), -- Adena
(21085, 5297, 1, 1, 1, 43.114242), -- Sealed Dark Crystal Leather Armor
(21085, 5478, 1, 1, 1, 4841.472002), -- Sealed Dark Crystal Leather Armor Pattern
(21085, 5301, 1, 1, 1, 26.520774), -- Sealed Tallum Leather Armor
(21085, 5479, 1, 1, 1, 3406.792446), -- Sealed Tallum Leather Armor Pattern
(21085, 5298, 1, 1, 1, 68.947618), -- Sealed Dark Crystal Leggings
(21085, 5482, 1, 1, 1, 7599.152918), -- Sealed Dark Crystal Leggings Design
(21085, 1868, 3, 9, 2, 104690.175148), -- Thread
(21085, 1873, 1, 1, 2, 125628.272302), -- Silver Nugget
(21085, 5549, 1, 1, 2, 31406.99042), -- Metallic Thread
(21085, 1889, 1, 1, 2, 20938.097154), -- Compound Braid
(21085, 4044, 1, 1, 2, 10468.893266), -- Thons
(21085, 4131, 1, 1, 2, 2553.31284), -- Recipe: Necklace of Black Ore (100%)
(21085, 8730, 1, 1, 2, 3489.527548), -- Life Stone - Level 67
(21085, 8740, 1, 1, 2, 872.537198), -- Mid-Grade Life Stone - Level 67
(21085, 8750, 1, 1, 2, 87.284782), -- High-Grade Life Stone - Level 67
(21085, 8760, 1, 1, 2, 17.394832), -- Top-Grade Life Stone - Level 67
(21085, 6036, 1, 1, 2, 10469.51451), -- Greater Magic Haste Potion
-- Bloody Liviona
(21086, 1807, 1, 1, -1, 12483), -- Recipe: Soulshot (A-Grade)
(21086, 5482, 1, 1, -1, 123574), -- Sealed Dark Crystal Leggings Design
(21086, 1895, 1, 5, -1, 891673), -- Metallic Fiber
(21086, 57, 4617, 9427, 0, 700000), -- Adena
(21086, 5287, 1, 1, 1, 32.350949), -- Sealed Dark Crystal breastplate
(21086, 5520, 1, 1, 1, 3715.728913), -- Sealed Dark Crystal Breastplate Pattern
(21086, 5293, 1, 1, 1, 19.914803), -- Sealed Tallum Plate Armor
(21086, 5521, 1, 1, 1, 2621.966236), -- Sealed Tallum Plate Armor Pattern
(21086, 5288, 1, 1, 1, 51.768791), -- Sealed Dark Crystal Gaiters
(21086, 5524, 1, 1, 1, 5679.270308), -- Sealed Dark Crystal Gaiters Pattern
(21086, 1895, 1, 1, 2, 98770.285188), -- Metallic Fiber
(21086, 4040, 1, 1, 2, 6913.954136), -- Mold Lubricant
(21086, 4042, 1, 1, 2, 5761.540824), -- Enria
(21086, 4043, 1, 1, 2, 11523.213082), -- Asofe
(21086, 4166, 1, 1, 2, 2856.980858), -- Recipe: Doom Helmet (100%)
(21086, 4401, 1, 1, 2, 691.34284), -- Green Dimensional Stone
(21086, 8730, 1, 1, 2, 3841.027216), -- Life Stone - Level 67
(21086, 8740, 1, 1, 2, 960.256804), -- Mid-Grade Life Stone - Level 67
(21086, 8750, 1, 1, 2, 96.078254), -- High-Grade Life Stone - Level 67
(21086, 8760, 1, 1, 2, 19.320798), -- Top-Grade Life Stone - Level 67
-- Bloody Knight
(21087, 4082, 1, 1, -1, 146799), -- Blue Wolf Leather Armor Texture
(21087, 1894, 1, 1, -1, 455851), -- Crafted Leather
(21087, 5494, 1, 1, -1, 272850), -- Sealed Dark Crystal Shield Fragment
(21087, 57, 6416, 13062, 0, 700000), -- Adena
(21087, 5287, 1, 1, 1, 44.889911), -- Sealed Dark Crystal breastplate
(21087, 5520, 1, 1, 1, 5155.914907), -- Sealed Dark Crystal Breastplate Pattern
(21087, 5293, 1, 1, 1, 27.633617), -- Sealed Tallum Plate Armor
(21087, 5521, 1, 1, 1, 3638.218804), -- Sealed Tallum Plate Armor Pattern
(21087, 5288, 1, 1, 1, 71.833949), -- Sealed Dark Crystal Gaiters
(21087, 5524, 1, 1, 1, 7880.508812), -- Sealed Dark Crystal Gaiters Pattern
(21087, 1869, 2, 6, 2, 92249.215127), -- Iron Ore
(21087, 1864, 5, 15, 2, 73799.494938), -- Stem
(21087, 1880, 1, 1, 2, 36899.747469), -- Steel
(21087, 5550, 1, 1, 2, 4919.904911), -- Durable Metal Plate
(21087, 4043, 1, 1, 2, 12299.915823), -- Asofe
(21087, 4614, 1, 1, 2, 508.849787), -- Greater Dye of STR (Str+4 Dex-4)
(21087, 6037, 9, 27, 2, 40999.71941), -- Waking Scroll
(21087, 729, 1, 1, 2, 41.150194), -- Scroll: Enchant Weapon (A-Grade)
(21087, 6671, 1, 1, 2, 40999.71941), -- Deluxe Chest Key - Grade 7
(21087, 8731, 1, 1, 2, 3416.694466), -- Life Stone - Level 70
(21087, 8741, 1, 1, 2, 854.020071), -- Mid-Grade Life Stone - Level 70
(21087, 8751, 1, 1, 2, 85.371298), -- High-Grade Life Stone - Level 70
(21087, 8761, 1, 1, 2, 17.197096), -- Top-Grade Life Stone - Level 70
-- Bloody Banshee
(21088, 5338, 1, 1, -1, 12863), -- Recipe: Sealed Majestic Leather Armor(60%)
(21088, 4042, 1, 1, -1, 165717), -- Enria
(21088, 5485, 1, 1, -1, 83611), -- Sealed Tallum Tunic Texture
(21088, 57, 4907, 10001, 0, 700000), -- Adena
(21088, 5304, 1, 1, 1, 45.816636), -- Sealed Tallum Tunic
(21088, 5485, 1, 1, 1, 5144.934716), -- Sealed Tallum Tunic Texture
(21088, 5308, 1, 1, 1, 28.183092), -- Sealed Dark Crystal Robe
(21088, 5486, 1, 1, 1, 3620.329668), -- Sealed Dark Crystal Robe Fabric
(21088, 5305, 1, 1, 1, 73.269244), -- Sealed Tallum Stockings
(21088, 5489, 1, 1, 1, 8075.466644), -- Sealed Tallum Stockings Fabric
(21088, 1873, 1, 1, 2, 146851.06194), -- Silver Nugget
(21088, 1868, 3, 9, 2, 122375.96154), -- Thread
(21088, 1876, 1, 1, 2, 73425.76074), -- Mithril Ore
(21088, 1895, 1, 1, 2, 104893.68132), -- Metallic Fiber
(21088, 4042, 1, 1, 2, 6118.7751), -- Enria
(21088, 4986, 1, 1, 2, 1523.3751), -- Recipe: Blue Wolf Tunic (60%)
(21088, 8731, 1, 1, 2, 3399.21738), -- Life Stone - Level 70
(21088, 8741, 1, 1, 2, 849.68946), -- Mid-Grade Life Stone - Level 70
(21088, 8751, 1, 1, 2, 85.0149), -- High-Grade Life Stone - Level 70
(21088, 8761, 1, 1, 2, 17.46252), -- Top-Grade Life Stone - Level 70
-- Bloody Lord
(21089, 4116, 1, 1, -1, 50514), -- Deadman's Glory Stone
(21089, 3035, 1, 1, -1, 15413), -- Recipe: Spiritshot A
(21089, 5480, 1, 1, -1, 51871), -- Sealed Leather Armor of Nightmare Fabric
(21089, 57, 5702, 11635, 0, 700000), -- Adena
(21089, 5304, 1, 1, 1, 53.26575), -- Sealed Tallum Tunic
(21089, 5485, 1, 1, 1, 5981.42575), -- Sealed Tallum Tunic Texture
(21089, 5308, 1, 1, 1, 32.76525), -- Sealed Dark Crystal Robe
(21089, 5486, 1, 1, 1, 4208.94225), -- Sealed Dark Crystal Robe Fabric
(21089, 5305, 1, 1, 1, 85.18175), -- Sealed Tallum Stockings
(21089, 5489, 1, 1, 1, 9388.41925), -- Sealed Tallum Stockings Fabric
(21089, 1873, 2, 6, 2, 42682.333768), -- Silver Nugget
(21089, 1868, 3, 9, 2, 142275.12292), -- Thread
(21089, 1876, 1, 1, 2, 85365.073752), -- Mithril Ore
(21089, 1895, 1, 1, 2, 121950.10536), -- Metallic Fiber
(21089, 4042, 1, 1, 2, 7113.654592), -- Enria
(21089, 4986, 1, 1, 2, 1771.10176), -- Recipe: Blue Wolf Tunic (60%)
(21089, 8731, 1, 1, 2, 3952.075464), -- Life Stone - Level 70
(21089, 8741, 1, 1, 2, 987.917312), -- Mid-Grade Life Stone - Level 70
(21089, 8751, 1, 1, 2, 98.710488), -- High-Grade Life Stone - Level 70
(21089, 8761, 1, 1, 2, 19.904584), -- Top-Grade Life Stone - Level 70
-- Bloody Guardian
(21090, 5230, 1, 1, -1, 11849), -- Recipe: Mithril Arrow (100%)
(21090, 5486, 1, 1, -1, 52583), -- Sealed Dark Crystal Robe Fabric
(21090, 5156, 1, 1, -1, 11849), -- Recipe: Soulshot (A) Compressed Package (100%)
(21090, 57, 4384, 8944, 0, 700000), -- Adena
(21090, 5287, 1, 1, 1, 30.704176), -- Sealed Dark Crystal breastplate
(21090, 5520, 1, 1, 1, 3526.585712), -- Sealed Dark Crystal Breastplate Pattern
(21090, 5293, 1, 1, 1, 18.901072), -- Sealed Tallum Plate Armor
(21090, 5521, 1, 1, 1, 2488.499264), -- Sealed Tallum Plate Armor Pattern
(21090, 5288, 1, 1, 1, 49.133584), -- Sealed Dark Crystal Gaiters
(21090, 5524, 1, 1, 1, 5390.176192), -- Sealed Dark Crystal Gaiters Pattern
(21090, 1871, 1, 3, 2, 91143.638391), -- Charcoal
(21090, 1866, 1, 1, 2, 182286.809659), -- Suede
(21090, 1877, 1, 1, 2, 10937.217922), -- Adamantite Nugget
(21090, 4041, 1, 1, 2, 2377.65607), -- Mold Hardener
(21090, 4040, 1, 1, 2, 5468.608961), -- Mold Lubricant
(21090, 4401, 1, 1, 2, 547.001033), -- Green Dimensional Stone
(21090, 730, 1, 1, 2, 227.956024), -- Scroll: Enchant Armor (A-Grade)
(21090, 8731, 1, 1, 2, 2531.80666), -- Life Stone - Level 70
(21090, 8741, 1, 1, 2, 632.951665), -- Mid-Grade Life Stone - Level 70
(21090, 8751, 1, 1, 2, 63.061605), -- High-Grade Life Stone - Level 70
(21090, 8761, 1, 1, 2, 12.612321), -- Top-Grade Life Stone - Level 70
(21090, 1344, 20, 60, 2, 170893.679689), -- Mithril Arrow
-- Bloody Keeper
(21091, 5479, 1, 1, -1, 35349), -- Sealed Tallum Leather Armor Pattern
(21091, 3035, 1, 1, -1, 7965), -- Recipe: Spiritshot A
(21091, 5336, 1, 1, -1, 7728), -- Recipe: Sealed Leather Armor of Nightmare(60%)
(21091, 57, 2948, 6009, 0, 700000), -- Adena
(21091, 5297, 1, 1, 1, 27.528279), -- Sealed Dark Crystal Leather Armor
(21091, 5478, 1, 1, 1, 3091.261399), -- Sealed Dark Crystal Leather Armor Pattern
(21091, 5301, 1, 1, 1, 16.933413), -- Sealed Tallum Leather Armor
(21091, 5479, 1, 1, 1, 2175.223977), -- Sealed Tallum Leather Armor Pattern
(21091, 5298, 1, 1, 1, 44.022791), -- Sealed Dark Crystal Leggings
(21091, 5482, 1, 1, 1, 4852.030141), -- Sealed Dark Crystal Leggings Design
(21091, 1867, 1, 3, 2, 210072.547114), -- Animal Skin
(21091, 1872, 1, 3, 2, 140048.218698), -- Animal Bone
(21091, 1882, 1, 1, 2, 70024.328416), -- Leather
(21091, 1894, 1, 1, 2, 11056.31149), -- Crafted Leather
(21091, 4042, 1, 1, 2, 5251.912258), -- Enria
(21091, 3035, 1, 1, 2, 420.170506), -- Recipe: Spiritshot A
(21091, 10306, 1, 1, 2, 1260.511518), -- Transformation Sealbook: Doll Blader
-- Bloody Mystic
(21092, 5485, 1, 1, -1, 49077), -- Sealed Tallum Tunic Texture
(21092, 5161, 1, 1, -1, 7782), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21092, 5478, 1, 1, -1, 49077), -- Sealed Dark Crystal Leather Armor Pattern
(21092, 57, 2880, 5870, 0, 700000), -- Adena
(21092, 5292, 1, 1, 1, 76.82232), -- Sealed Dark Crystal Shield
(21092, 5494, 1, 1, 1, 7542.050095), -- Sealed Dark Crystal Shield Fragment
(21092, 5289, 1, 1, 1, 53.756795), -- Sealed Dark Crystal Helmet
(21092, 5525, 1, 1, 1, 5551.316412), -- Sealed Dark Crystal Helmet Design
(21092, 5294, 1, 1, 1, 53.756795), -- Sealed Tallum Helmet
(21092, 5526, 1, 1, 1, 5551.297583), -- Sealed Tallum Helm Design
(21092, 1868, 4, 12, 2, 67340.646289), -- Thread
(21092, 1873, 1, 1, 2, 107744.828485), -- Silver Nugget
(21092, 5549, 1, 1, 2, 26936.121464), -- Metallic Thread
(21092, 1889, 1, 1, 2, 17957.528519), -- Compound Braid
(21092, 4044, 1, 1, 2, 8978.592945), -- Thons
(21092, 3956, 1, 1, 2, 359.075192), -- Recipe: Blessed Spiritshot A
(21092, 10306, 1, 1, 2, 1077.568205), -- Transformation Sealbook: Doll Blader
(21092, 1344, 30, 90, 2, 112234.638901), -- Mithril Arrow
-- Ratman Sub Chieftain
(21093, 1800, 1, 1, -1, 83774), -- Recipe: Piece Bone Breastplate
(21093, 1897, 1, 1, -1, 63429), -- Necklace of Wisdom Chain
(21093, 1864, 1, 1, -1, 532802), -- Stem
(21093, 57, 125, 213, 0, 700000), -- Adena
(21093, 2, 1, 1, 1, 74.977705), -- Long Sword
(21093, 120, 1, 1, 1, 74.977705), -- Sword of Reflection
(21093, 2012, 1, 1, 1, 820.066885), -- Sword of Reflection Blade
(21093, 121, 1, 1, 1, 74.977705), -- Sword of Watershadow
(21093, 1864, 1, 1, 2, 78690.917104), -- Stem
(21093, 1869, 1, 1, 2, 39345.458552), -- Iron Ore
(21093, 1878, 1, 1, 2, 15738.21414), -- Braided Hemp
(21093, 1801, 1, 1, 2, 19821.410204), -- Recipe: Piece Bone Gaiters
-- Ratman Chieftain
(21094, 1870, 1, 1, -1, 270215), -- Coal
(21094, 734, 1, 1, -1, 45036), -- Haste Potion
(21094, 1924, 1, 1, -1, 87166), -- Leather Helmet Design
(21094, 57, 125, 217, 0, 700000), -- Adena
(21094, 176, 1, 1, 1, 152), -- Apprentice's Staff
(21094, 2501, 1, 1, 1, 152), -- Bone Club
(21094, 1865, 1, 1, 2, 39908.853285), -- Varnish
(21094, 1870, 1, 1, 2, 39908.853285), -- Coal
(21094, 1879, 1, 1, 2, 6651.522773), -- Cokes
(21094, 2141, 1, 1, 2, 7981.770657), -- Recipe: Silver Mold
-- Giant Poison Bee
(21095, 1804, 1, 1, -1, 15036), -- Recipe: Soulshot (D-Grade)
(21095, 1898, 1, 1, -1, 38613), -- Blue Diamond Necklace Gem
(21095, 2151, 1, 1, -1, 104706), -- Recipe: Necklace of Devotion
(21095, 57, 171, 306, 0, 700000), -- Adena
(21095, 257, 1, 1, 1, 236), -- Viper Fang
(21095, 1870, 1, 1, 2, 55516.67957), -- Coal
(21095, 1865, 1, 1, 2, 55516.67957), -- Varnish
(21095, 1804, 1, 1, 2, 2220.771702), -- Recipe: Soulshot (D-Grade)
(21095, 1831, 1, 1, 2, 148043.869158), -- Antidote
-- Cloudy Beast 
(21096, 1926, 1, 1, -1, 37310), -- Piece Bone Breastplate Fragment
(21096, 1866, 1, 1, -1, 246245), -- Suede
(21096, 1871, 1, 1, -1, 369368), -- Charcoal
(21096, 57, 168, 301, 0, 700000), -- Adena
(21096, 39, 1, 1, 1, 1531.287612), -- Boots
(21096, 1930, 1, 1, 1, 18650.403063), -- Boot Lining
(21096, 51, 1, 1, 1, 1531.309325), -- Bracer
(21096, 1866, 1, 1, 2, 48491.470211), -- Suede
(21096, 1871, 1, 1, 2, 72737.127301), -- Charcoal
(21096, 2179, 1, 1, 2, 34802.402488), -- Recipe: Crafted Leather Gloves
-- Young Araneid
(21097, 1927, 1, 1, -1, 33847), -- Hard Leather Shirt Pattern
(21097, 2176, 1, 1, -1, 203004), -- Recipe: Leather Boots
(21097, 1928, 1, 1, -1, 61803), -- Piece Bone Gaiters Fragment
(21097, 57, 194, 343, 0, 700000), -- Adena
(21097, 846, 1, 1, 1, 1018.870708), -- Coral Earring
(21097, 909, 1, 1, 1, 764.155468), -- Blue Diamond Necklace
(21097, 1898, 1, 1, 1, 6436.65314), -- Blue Diamond Necklace Gem
(21097, 878, 1, 1, 1, 1528.320684), -- Blue Coral Ring
(21097, 1870, 1, 1, 2, 50130.015455), -- Coal
(21097, 1865, 1, 1, 2, 50130.015455), -- Varnish
(21097, 2257, 1, 1, 2, 1225.641193), -- Recipe: Trident
(21097, 734, 1, 1, 2, 8354.961989), -- Haste Potion
(21097, 1831, 1, 1, 2, 133680.365908), -- Antidote
-- Plain Grizzly
(21098, 2177, 1, 1, -1, 127600), -- Recipe: Bone Helmet
(21098, 1929, 1, 1, -1, 51534), -- Hard Leather Gaiters Material
(21098, 1879, 1, 1, -1, 66565), -- Cokes
(21098, 57, 177, 327, 0, 700000), -- Adena
(21098, 16, 1, 1, 1, 251), -- Great Spear
(21098, 1865, 1, 1, 2, 58986.680208), -- Varnish
(21098, 1870, 1, 1, 2, 58986.680208), -- Coal
(21098, 1879, 1, 1, 2, 9831.156756), -- Cokes
(21098, 5158, 1, 1, 2, 2359.482828), -- Recipe: Spiritshot (D) Compressed Package (100%)
-- Cloudy Beast Turen
(21099, 1875, 1, 1, -1, 28539), -- Stone of Purity
(21099, 1899, 1, 1, -1, 66888), -- Necklace of Devotion Chain
(21099, 2152, 1, 1, -1, 75366), -- Recipe: Enchanted Necklace
(21099, 57, 188, 353, 0, 700000), -- Adena
(21099, 626, 1, 1, 1, 947.733136), -- Bronze Shield
(21099, 45, 1, 1, 1, 664.590628), -- Bone Helmet
(21099, 1932, 1, 1, 1, 12711.676236), -- Bone Helmet Design
(21099, 1875, 1, 1, 2, 3203.322531), -- Stone of Purity
(21099, 1879, 1, 1, 2, 8008.344804), -- Cokes
(21099, 5549, 1, 1, 2, 4804.996622), -- Metallic Thread
(21099, 2152, 1, 1, 2, 8459.520243), -- Recipe: Enchanted Necklace
(21099, 8294, 1, 1, 2, 1174.8158), -- Recipe: Steel Sword (100%)
-- Langk Lizardman Sentinel
(21100, 1897, 1, 1, -1, 63429), -- Necklace of Wisdom Chain
(21100, 1800, 1, 1, -1, 83774), -- Recipe: Piece Bone Breastplate
(21100, 1924, 1, 1, -1, 85936), -- Leather Helmet Design
(21100, 57, 125, 213, 0, 700000), -- Adena
(21100, 845, 1, 1, 1, 1150.453818), -- Cat's Eye Earring
(21100, 908, 1, 1, 1, 862.846917), -- Necklace of Wisdom
(21100, 1897, 1, 1, 1, 9368.018538), -- Necklace of Wisdom Chain
(21100, 877, 1, 1, 1, 1725.680727), -- Ring of Wisdom
(21100, 1869, 1, 1, 2, 39345.4152), -- Iron Ore
(21100, 1864, 1, 1, 2, 78690.96024), -- Stem
(21100, 1880, 1, 1, 2, 3934.54152), -- Steel
(21100, 1817, 1, 1, 2, 7869.08304), -- Recipe: Cord
-- Langk Lizardman Shaman
(21101, 1870, 1, 1, -1, 399388), -- Coal
(21101, 1865, 1, 1, -1, 399388), -- Varnish
(21101, 1898, 1, 1, -1, 41026), -- Blue Diamond Necklace Gem
(21101, 57, 177, 327, 0, 700000), -- Adena
(21101, 39, 1, 1, 1, 1655.762472), -- Boots
(21101, 1930, 1, 1, 1, 20166.451578), -- Boot Lining
(21101, 51, 1, 1, 1, 1655.78595), -- Bracer
(21101, 1870, 1, 1, 2, 47189.363348), -- Coal
(21101, 1865, 1, 1, 2, 47189.363348), -- Varnish
(21101, 5163, 1, 1, 2, 1887.598116), -- Recipe: Blessed Spiritshot (D) Compressed Package (100%)
(21101, 6666, 1, 1, 2, 47189.363348), -- Deluxe Chest Key - Grade 2
(21101, 6035, 1, 1, 2, 3932.31184), -- Magic Haste Potion
-- Watchman of the Plains
(21102, 2153, 1, 1, -1, 84230), -- Recipe: Tiger's Eye Earring
(21102, 1900, 1, 1, -1, 59256), -- Enchanted Necklace Chain
(21102, 2183, 1, 1, -1, 35631), -- Recipe: Mithril Banded Mail
(21102, 57, 228, 457, 0, 700000), -- Adena
(21102, 433, 1, 1, 1, 96.214123), -- Elven Tunic
(21102, 434, 1, 1, 1, 96.214123), -- White Tunic
(21102, 1936, 1, 1, 1, 3027.472147), -- White Tunic Pattern
(21102, 435, 1, 1, 1, 96.214123), -- Mystic's Tunic
(21102, 466, 1, 1, 1, 154.147498), -- Elven Stockings
(21102, 467, 1, 1, 1, 154.147498), -- Dark Stockings
(21102, 1933, 1, 1, 1, 4352.434859), -- Dark Stockings Fabric
(21102, 468, 1, 1, 1, 154.155629), -- Mystic's Stockings
(21102, 1874, 1, 1, 2, 3288.45484), -- Oriharukon Ore
(21102, 1878, 1, 1, 2, 19730.78932), -- Braided Hemp
(21102, 1884, 1, 1, 2, 30355.01876), -- Cord
(21102, 1889, 1, 1, 2, 3288.45484), -- Compound Braid
(21102, 5220, 1, 1, 2, 1973.08496), -- Metal Hardener
(21102, 956, 1, 1, 2, 1644.19728), -- Scroll: Enchant Armor (D-Grade)
-- Roughly Hewn Rock Golem
(21103, 1933, 1, 1, -1, 66361), -- Dark Stockings Fabric
(21103, 1879, 1, 1, -1, 94011), -- Cokes
(21103, 955, 1, 1, -1, 2256), -- Scroll: Enchant Weapon (D-Grade)
(21103, 57, 239, 476, 0, 700000), -- Adena
(21103, 348, 1, 1, 1, 150.355692), -- Scale Mail
(21103, 1935, 1, 1, 1, 4304.991144), -- Scale Mail Fragment
(21103, 377, 1, 1, 1, 240.431052), -- Scale Gaiters
(21103, 1937, 1, 1, 1, 6620.222112), -- Scale Gaiters Fragment
(21103, 1875, 1, 1, 2, 2935.62317), -- Stone of Purity
(21103, 1879, 1, 1, 2, 7338.97649), -- Cokes
(21103, 1885, 1, 1, 2, 3669.51539), -- High-Grade Suede
(21103, 5550, 1, 1, 2, 587.14635), -- Durable Metal Plate
(21103, 5549, 1, 1, 2, 4403.40761), -- Metallic Thread
(21103, 2185, 1, 1, 2, 8668.10427), -- Recipe: Iron Boots
(21103, 1061, 1, 1, 2, 26687.22672), -- Greater Healing Potion
-- Delu Lizardman Supplier
(21104, 1876, 1, 1, -1, 140715), -- Mithril Ore
(21104, 1061, 1, 1, -1, 426409), -- Greater Healing Potion
(21104, 1935, 1, 1, -1, 39306), -- Scale Mail Fragment
(21104, 57, 296, 595, 0, 700000), -- Adena
(21104, 1123, 1, 1, 1, 1502), -- Blue Buckskin Boots
(21104, 605, 1, 1, 1, 1502), -- Leather Gauntlets
(21104, 1876, 1, 1, 2, 10985.1025), -- Mithril Ore
(21104, 1880, 1, 1, 2, 5492.5147), -- Steel
(21104, 1877, 1, 1, 2, 2197.0205), -- Adamantite Nugget
(21104, 1881, 1, 1, 2, 7323.3773), -- Coarse Bone Powder
(21104, 1882, 1, 1, 2, 12205.6532), -- Leather
(21104, 2264, 1, 1, 2, 567.987), -- Recipe: Two-handed Sword
(21104, 6667, 1, 1, 2, 34328.3448), -- Deluxe Chest Key - Grade 3
-- Delu Lizardman Special Agent
(21105, 2154, 1, 1, -1, 86586), -- Recipe: Elven Earring
(21105, 1901, 1, 1, -1, 111700), -- Tiger's Eye Earring Stone
(21105, 2155, 1, 1, -1, 129809), -- Recipe: Elven Ring
(21105, 57, 342, 683, 0, 700000), -- Adena
(21105, 393, 1, 1, 1, 122.506823), -- Mithril Banded Mail
(21105, 1938, 1, 1, 1, 4817.759693), -- Mithril Banded Mail Material
(21105, 394, 1, 1, 1, 122.506823), -- Reinforced Leather Shirt
(21105, 415, 1, 1, 1, 195.808834), -- Mithril Banded Gaiters
(21105, 1939, 1, 1, 1, 6294.620742), -- Mithril Banded Gaiters Material
(21105, 416, 1, 1, 1, 195.797085), -- Reinforced Leather Gaiters
(21105, 1874, 1, 1, 2, 4777.605589), -- Oriharukon Ore
(21105, 1878, 1, 1, 2, 28665.540673), -- Braided Hemp
(21105, 1884, 1, 1, 2, 44100.896093), -- Cord
(21105, 1889, 1, 1, 2, 4777.605589), -- Compound Braid
(21105, 5220, 1, 1, 2, 2866.526209), -- Metal Hardener
(21105, 2154, 1, 1, 2, 7672.825847), -- Recipe: Elven Earring
-- Cursed Seer
(21106, 1938, 1, 1, -1, 45809), -- Mithril Banded Mail Material
(21106, 1885, 1, 1, -1, 56785), -- High-Grade Suede
(21106, 5550, 1, 1, -1, 9086), -- Durable Metal Plate
(21106, 57, 288, 574, 0, 700000), -- Adena
(21106, 628, 1, 1, 1, 883.706206), -- Hoplon
(21106, 47, 1, 1, 1, 618.293794), -- Helmet
(21106, 1875, 1, 1, 2, 3019.186494), -- Stone of Purity
(21106, 1879, 1, 1, 2, 7547.793966), -- Cokes
(21106, 1885, 1, 1, 2, 3773.896983), -- High-Grade Suede
(21106, 5550, 1, 1, 2, 603.802845), -- Durable Metal Plate
(21106, 5549, 1, 1, 2, 4528.779741), -- Metallic Thread
(21106, 2186, 1, 1, 2, 1514.589048), -- Recipe: Brigandine Tunic
(21106, 8317, 1, 1, 2, 323.521182), -- Recipe: Titan Hammer (100%)
(21106, 1341, 10, 30, 2, 150957.429741), -- Bone Arrow
-- Delu Lizardman Commander
(21107, 1939, 1, 1, -1, 126271), -- Mithril Banded Gaiters Material
(21107, 2156, 1, 1, -1, 115008), -- Recipe: Elven Necklace
(21107, 1940, 1, 1, -1, 214567), -- Iron Boots Design
(21107, 57, 607, 1211, 0, 700000), -- Adena
(21107, 260, 1, 1, 1, 206), -- Triple-Edged Jamadhr
(21107, 1876, 1, 1, 2, 25478.533496), -- Mithril Ore
(21107, 1880, 1, 1, 2, 12739.266748), -- Steel
(21107, 1877, 1, 1, 2, 5095.667616), -- Adamantite Nugget
(21107, 1881, 1, 1, 2, 16985.656428), -- Coarse Bone Powder
(21107, 1882, 1, 1, 2, 28309.42738), -- Leather
(21107, 2188, 1, 1, 2, 9099.448332), -- Recipe: Manticore Skin Gaiters
-- Glow Wisp
(21108, 5230, 1, 1, -1, 3610), -- Recipe: Mithril Arrow (100%)
(21108, 4052, 1, 1, -1, 95871), -- Earring of Black Ore Piece
(21108, 5550, 1, 1, -1, 36105), -- Durable Metal Plate
(21108, 57, 1068, 2182, 0, 700000), -- Adena
(21108, 12204, 1, 1, 1, 177.511148), -- Common Item - Blue Wolf Breastplate
(21108, 4078, 1, 1, 1, 1947.25167), -- Blue Wolf Breastplate Part
(21108, 12184, 1, 1, 1, 109.266454), -- Common Item - Doom Plate Armor
(21108, 4081, 1, 1, 1, 1313.905936), -- Doom Plate Armor Temper
(21108, 12193, 1, 1, 1, 283.937634), -- Common Item - Blue Wolf Gaiters
(21108, 4080, 1, 1, 1, 2742.127158), -- Blue Wolf Gaiters Material
(21108, 1869, 1, 1, 2, 72714.84642), -- Iron Ore
(21108, 1864, 1, 1, 2, 145429.46286), -- Stem
(21108, 1880, 1, 1, 2, 7271.50764), -- Steel
(21108, 5550, 1, 1, 2, 969.59568), -- Durable Metal Plate
(21108, 4043, 1, 1, 2, 2423.75922), -- Asofe
(21108, 5230, 1, 1, 2, 97.05156), -- Recipe: Mithril Arrow (100%)
(21108, 8487, 1, 1, 2, 39.78654), -- Recipe: Destroyer Hammer (60%)
(21108, 8730, 1, 1, 2, 807.91974), -- Life Stone - Level 67
(21108, 8740, 1, 1, 2, 201.92244), -- Mid-Grade Life Stone - Level 67
(21108, 8750, 1, 1, 2, 20.23824), -- High-Grade Life Stone - Level 67
(21108, 8760, 1, 1, 2, 3.90966), -- Top-Grade Life Stone - Level 67
-- Hames Orc Scout
(21109, 1874, 1, 1, -1, 224175), -- Oriharukon Ore
(21109, 4043, 1, 1, -1, 112087), -- Asofe
(21109, 5478, 1, 1, -1, 28276), -- Sealed Dark Crystal Leather Armor Pattern
(21109, 57, 1330, 2704, 0, 700000), -- Adena
(21109, 12345, 1, 1, 1, 639.16551), -- Common Item - Sealed Phoenix Earring
(21109, 6341, 1, 1, 1, 4578.76041), -- Sealed Phoenix Earring Gemstone
(21109, 12344, 1, 1, 1, 479.83284), -- Common Item - Sealed Phoenix Necklace
(21109, 6343, 1, 1, 1, 3539.55237), -- Sealed Phoenix Necklace Beads
(21109, 12346, 1, 1, 1, 959.68221), -- Common Item - Sealed Phoenix Ring
(21109, 6345, 1, 1, 1, 6333.00666), -- Sealed Phoenix Ring Gemstone
(21109, 1870, 1, 1, 2, 82772.23776), -- Coal
(21109, 1865, 1, 1, 2, 82772.23776), -- Varnish
(21109, 1874, 1, 1, 2, 5518.149184), -- Oriharukon Ore
(21109, 4043, 1, 1, 2, 2759.074592), -- Asofe
(21109, 4039, 1, 1, 2, 2759.074592), -- Mold Glue
(21109, 1807, 1, 1, 2, 110.377272), -- Recipe: Soulshot (A-Grade)
(21109, 6037, 1, 1, 2, 165544.47552), -- Waking Scroll
(21109, 6670, 1, 1, 2, 13795.37296), -- Deluxe Chest Key - Grade 6
(21109, 8730, 1, 1, 2, 919.8106), -- Life Stone - Level 67
(21109, 8740, 1, 1, 2, 230.041952), -- Mid-Grade Life Stone - Level 67
(21109, 8750, 1, 1, 2, 22.861312), -- High-Grade Life Stone - Level 67
(21109, 8760, 1, 1, 2, 4.286496), -- Top-Grade Life Stone - Level 67
-- Marsh Predator
(21110, 1807, 1, 1, -1, 3832), -- Recipe: Soulshot (A-Grade)
(21110, 5479, 1, 1, -1, 17005), -- Sealed Tallum Leather Armor Pattern
(21110, 3035, 1, 1, -1, 3832), -- Recipe: Spiritshot A
(21110, 57, 1137, 2310, 0, 700000), -- Adena
(21110, 12222, 1, 1, 1, 205.489715), -- Common Item - Sealed Dark Crystal Leather Armor
(21110, 5478, 1, 1, 1, 1189.69312), -- Sealed Dark Crystal Leather Armor Pattern
(21110, 12230, 1, 1, 1, 126.31926), -- Common Item - Sealed Tallum Leather Armor
(21110, 5479, 1, 1, 1, 837.149785), -- Sealed Tallum Leather Armor Pattern
(21110, 12228, 1, 1, 1, 329.021315), -- Common Item - Sealed Dark Crystal Leggings
(21110, 5482, 1, 1, 1, 1867.326805), -- Sealed Dark Crystal Leggings Design
(21110, 1871, 1, 1, 2, 77173.162866), -- Charcoal
(21110, 1866, 1, 1, 2, 51448.775244), -- Suede
(21110, 1877, 1, 1, 2, 3086.921108), -- Adamantite Nugget
(21110, 4041, 1, 1, 2, 671.09919), -- Mold Hardener
(21110, 4040, 1, 1, 2, 1543.460554), -- Mold Lubricant
(21110, 3956, 1, 1, 2, 102.861326), -- Recipe: Blessed Spiritshot A
(21110, 8487, 1, 1, 2, 42.171792), -- Recipe: Destroyer Hammer (60%)
(21110, 8730, 1, 1, 2, 857.493104), -- Life Stone - Level 67
(21110, 8740, 1, 1, 2, 214.373276), -- Mid-Grade Life Stone - Level 67
(21110, 8750, 1, 1, 2, 21.491394), -- High-Grade Life Stone - Level 67
(21110, 8760, 1, 1, 2, 4.190146), -- Top-Grade Life Stone - Level 67
-- Lava Wyrm
(21111, 5482, 1, 1, -1, 39755), -- Sealed Dark Crystal Leggings Design
(21111, 4041, 1, 1, -1, 26191), -- Mold Hardener
(21111, 5479, 1, 1, -1, 17822), -- Sealed Tallum Leather Armor Pattern
(21111, 57, 1191, 2424, 0, 700000), -- Adena
(21111, 12222, 1, 1, 1, 215.369462), -- Common Item - Sealed Dark Crystal Leather Armor
(21111, 5478, 1, 1, 1, 1246.892416), -- Sealed Dark Crystal Leather Armor Pattern
(21111, 12230, 1, 1, 1, 132.392568), -- Common Item - Sealed Tallum Leather Armor
(21111, 5479, 1, 1, 1, 877.399138), -- Sealed Tallum Leather Armor Pattern
(21111, 12228, 1, 1, 1, 344.840342), -- Common Item - Sealed Dark Crystal Leggings
(21111, 5482, 1, 1, 1, 1957.106074), -- Sealed Dark Crystal Leggings Design
(21111, 1865, 1, 1, 2, 74141.595432), -- Varnish
(21111, 1870, 1, 1, 2, 74141.595432), -- Coal
(21111, 1879, 1, 1, 2, 12356.932572), -- Cokes
(21111, 1875, 1, 1, 2, 4942.668654), -- Stone of Purity
(21111, 4040, 1, 1, 2, 1482.904971), -- Mold Lubricant
(21111, 5166, 1, 1, 2, 98.895123), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21111, 8487, 1, 1, 2, 40.445235), -- Recipe: Destroyer Hammer (60%)
(21111, 8730, 1, 1, 2, 823.778109), -- Life Stone - Level 67
(21111, 8740, 1, 1, 2, 205.879293), -- Mid-Grade Life Stone - Level 67
(21111, 8750, 1, 1, 2, 20.614023), -- High-Grade Life Stone - Level 67
(21111, 8760, 1, 1, 2, 4.174992), -- Top-Grade Life Stone - Level 67
(21111, 1344, 10, 30, 2, 92677.516164), -- Mithril Arrow
-- Hames Orc Footsoldier
(21112, 5485, 1, 1, -1, 24627), -- Sealed Tallum Tunic Texture
(21112, 3956, 1, 1, -1, 3905), -- Recipe: Blessed Spiritshot A
(21112, 5486, 1, 1, -1, 17329), -- Sealed Dark Crystal Robe Fabric
(21112, 57, 1445, 2946, 0, 700000), -- Adena
(21112, 12224, 1, 1, 1, 588.977907), -- Common Item - Sealed Dark Crystal Boots
(21112, 5496, 1, 1, 1, 3169.272093), -- Sealed Dark Crystal Boots Lining
(21112, 12231, 1, 1, 1, 588.977907), -- Common Item - Sealed Tallum Boots
(21112, 5497, 1, 1, 1, 3169.272093), -- Sealed Tallum Boots Lining
(21112, 12221, 1, 1, 1, 588.977907), -- Common Item - Sealed Dark Crystal Gloves
(21112, 5508, 1, 1, 1, 3169.272093), -- Sealed Dark Crystal Gloves Design
(21112, 12229, 1, 1, 1, 588.977907), -- Common Item - Sealed Tallum Gloves
(21112, 5509, 1, 1, 1, 3169.272093), -- Sealed Tallum Gloves Design
(21112, 1873, 1, 1, 2, 43253.661907), -- Silver Nugget
(21112, 1868, 1, 1, 2, 216268.625064), -- Thread
(21112, 1876, 1, 1, 2, 21626.988718), -- Mithril Ore
(21112, 1895, 1, 1, 2, 30895.653093), -- Metallic Fiber
(21112, 4042, 1, 1, 2, 1802.301648), -- Enria
(21112, 5281, 1, 1, 2, 144.196753), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21112, 8730, 1, 1, 2, 1201.534432), -- Life Stone - Level 67
(21112, 8740, 1, 1, 2, 300.383608), -- Mid-Grade Life Stone - Level 67
(21112, 8750, 1, 1, 2, 29.975255), -- High-Grade Life Stone - Level 67
(21112, 8760, 1, 1, 2, 5.679522), -- Top-Grade Life Stone - Level 67
-- Hames Orc Sniper
(21113, 5156, 1, 1, -1, 4361), -- Recipe: Soulshot (A) Compressed Package (100%)
(21113, 5489, 1, 1, -1, 43172), -- Sealed Tallum Stockings Fabric
(21113, 5166, 1, 1, -1, 4361), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21113, 57, 1613, 3293, 0, 700000), -- Adena
(21113, 12222, 1, 1, 1, 292.377353), -- Common Item - Sealed Dark Crystal Leather Armor
(21113, 5478, 1, 1, 1, 1692.733504), -- Sealed Dark Crystal Leather Armor Pattern
(21113, 12230, 1, 1, 1, 179.731092), -- Common Item - Sealed Tallum Leather Armor
(21113, 5479, 1, 1, 1, 1191.123547), -- Sealed Tallum Leather Armor Pattern
(21113, 12228, 1, 1, 1, 468.142073), -- Common Item - Sealed Dark Crystal Leggings
(21113, 5482, 1, 1, 1, 2656.892431), -- Sealed Dark Crystal Leggings Design
(21113, 1864, 1, 3, 2, 109793.118153), -- Stem
(21113, 1869, 1, 1, 2, 109793.118153), -- Iron Ore
(21113, 1878, 1, 1, 2, 43916.963055), -- Braided Hemp
(21113, 1884, 1, 1, 2, 67564.813603), -- Cord
(21113, 4039, 1, 1, 2, 3659.628502), -- Mold Glue
(21113, 3035, 1, 1, 2, 146.366193), -- Recipe: Spiritshot A
(21113, 8730, 1, 1, 2, 1219.718275), -- Life Stone - Level 67
(21113, 8740, 1, 1, 2, 305.047988), -- Mid-Grade Life Stone - Level 67
(21113, 8750, 1, 1, 2, 30.315328), -- High-Grade Life Stone - Level 67
(21113, 8760, 1, 1, 2, 6.157801), -- Top-Grade Life Stone - Level 67
(21113, 1344, 10, 30, 2, 137241.752949), -- Mithril Arrow
-- Cursed Guardian
(21114, 1875, 1, 1, -1, 207673), -- Stone of Purity
(21114, 5494, 1, 1, -1, 65423), -- Sealed Dark Crystal Shield Fragment
(21114, 5161, 1, 1, -1, 4153), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21114, 57, 1538, 3132, 0, 700000), -- Adena
(21114, 12227, 1, 1, 1, 208.942419), -- Common Item - Sealed Dark Crystal Breastplate
(21114, 5520, 1, 1, 1, 1236.21113), -- Sealed Dark Crystal Breastplate Pattern
(21114, 12233, 1, 1, 1, 128.658964), -- Common Item - Sealed Tallum Plate Armor
(21114, 5521, 1, 1, 1, 872.318608), -- Sealed Tallum Plate Armor Pattern
(21114, 12220, 1, 1, 1, 333.399283), -- Common Item - Sealed Dark Crystal Gaiters
(21114, 5524, 1, 1, 1, 1889.469596), -- Sealed Dark Crystal Gaiters Pattern
(21114, 1870, 1, 1, 2, 104562.90785), -- Coal
(21114, 1865, 1, 1, 2, 104562.90785), -- Varnish
(21114, 1874, 1, 1, 2, 6970.8842), -- Oriharukon Ore
(21114, 4043, 1, 1, 2, 3485.4421), -- Asofe
(21114, 4039, 1, 1, 2, 3485.4421), -- Mold Glue
(21114, 5271, 1, 1, 2, 139.57395), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21114, 8731, 1, 1, 2, 968.1389), -- Life Stone - Level 70
(21114, 8741, 1, 1, 2, 242.2123), -- Mid-Grade Life Stone - Level 70
(21114, 8751, 1, 1, 2, 24.1502), -- High-Grade Life Stone - Level 70
(21114, 8761, 1, 1, 2, 4.9721), -- Top-Grade Life Stone - Level 70
(21114, 1344, 10, 30, 2, 130703.36845), -- Mithril Arrow
-- Hames Orc Shaman
(21115, 5496, 1, 1, -1, 63784), -- Sealed Dark Crystal Boots Lining
(21115, 5166, 1, 1, -1, 3627), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21115, 5497, 1, 1, -1, 63784), -- Sealed Tallum Boots Lining
(21115, 57, 1342, 2736, 0, 700000), -- Adena
(21115, 12232, 1, 1, 1, 243.15907), -- Common Item - Sealed Tallum Tunic
(21115, 5485, 1, 1, 1, 1407.78176), -- Sealed Tallum Tunic Texture
(21115, 12223, 1, 1, 1, 149.47548), -- Common Item - Sealed Dark Crystal Robe
(21115, 5486, 1, 1, 1, 990.61193), -- Sealed Dark Crystal Robe Fabric
(21115, 12235, 1, 1, 1, 389.33587), -- Common Item - Sealed Tallum Stockings
(21115, 5489, 1, 1, 1, 2209.63589), -- Sealed Tallum Stockings Fabric
(21115, 1866, 1, 1, 2, 60875.972472), -- Suede
(21115, 1871, 1, 1, 2, 91313.958708), -- Charcoal
(21115, 5220, 1, 1, 2, 3652.572396), -- Metal Hardener
(21115, 1885, 1, 1, 2, 7609.45266), -- High-Grade Suede
(21115, 4041, 1, 1, 2, 794.045112), -- Mold Hardener
(21115, 5281, 1, 1, 2, 121.688028), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21115, 6671, 1, 1, 2, 10145.93688), -- Deluxe Chest Key - Grade 7
(21115, 8731, 1, 1, 2, 845.49474), -- Life Stone - Level 70
(21115, 8741, 1, 1, 2, 211.417584), -- Mid-Grade Life Stone - Level 70
(21115, 8751, 1, 1, 2, 21.07152), -- High-Grade Life Stone - Level 70
(21115, 8761, 1, 1, 2, 4.3899), -- Top-Grade Life Stone - Level 70
-- Hames Orc Overlord
(21116, 729, 1, 1, -1, 479), -- Scroll: Enchant Weapon (A-Grade)
(21116, 5480, 1, 1, -1, 19326), -- Sealed Leather Armor of Nightmare Fabric
(21116, 5481, 1, 1, -1, 19326), -- Sealed Majestic Leather Armor Fabric
(21116, 57, 2125, 4335, 0, 700000), -- Adena
(21116, 12345, 1, 1, 1, 1023.322155), -- Common Item - Sealed Phoenix Earring
(21116, 6341, 1, 1, 1, 7330.725605), -- Sealed Phoenix Earring Gemstone
(21116, 12344, 1, 1, 1, 768.22602), -- Common Item - Sealed Phoenix Necklace
(21116, 6343, 1, 1, 1, 5666.923985), -- Sealed Phoenix Necklace Beads
(21116, 12346, 1, 1, 1, 1536.478505), -- Common Item - Sealed Phoenix Ring
(21116, 6345, 1, 1, 1, 10139.32373), -- Sealed Phoenix Ring Gemstone
(21116, 1867, 1, 1, 2, 192758.694975), -- Animal Skin
(21116, 1872, 1, 1, 2, 192758.694975), -- Animal Bone
(21116, 1882, 1, 1, 2, 32126.235435), -- Leather
(21116, 1894, 1, 1, 2, 5072.608485), -- Crafted Leather
(21116, 4042, 1, 1, 2, 2409.563835), -- Enria
(21116, 729, 1, 1, 2, 16.24329), -- Scroll: Enchant Weapon (A-Grade)
(21116, 4987, 1, 1, 2, 599.719365), -- Recipe: Tunic of Doom (60%)
(21116, 8731, 1, 1, 2, 1338.78906), -- Life Stone - Level 70
(21116, 8741, 1, 1, 2, 334.697265), -- Mid-Grade Life Stone - Level 70
(21116, 8751, 1, 1, 2, 33.34149), -- High-Grade Life Stone - Level 70
(21116, 8761, 1, 1, 2, 6.411825), -- Top-Grade Life Stone - Level 70
-- Kasha Imp
(21117, 734, 1, 1, -1, 43530), -- Haste Potion
(21117, 1897, 1, 1, -1, 62185), -- Necklace of Wisdom Chain
(21117, 1800, 1, 1, -1, 82131), -- Recipe: Piece Bone Breastplate
(21117, 57, 122, 208, 0, 700000), -- Adena
(21117, 38, 1, 1, 1, 1974.358375), -- Low Boots
(21117, 50, 1, 1, 1, 1974.358375), -- Leather Gloves
(21117, 1925, 1, 1, 1, 33726.28325), -- Leather Gloves Lining
(21117, 1868, 1, 1, 2, 102863.877013), -- Thread
(21117, 1873, 1, 1, 2, 20572.748658), -- Silver Nugget
(21117, 2139, 1, 1, 2, 10286.374329), -- Recipe: Steel Mold
-- Baar Dre Vanul
(21118, 1924, 1, 1, -1, 88910), -- Leather Helmet Design
(21118, 1801, 1, 1, -1, 138851), -- Recipe: Piece Bone Gaiters
(21118, 1925, 1, 1, -1, 180734), -- Leather Gloves Lining
(21118, 57, 127, 221, 0, 700000), -- Adena
(21118, 945, 1, 1, 1, 3083.9274), -- Skeleton Buckler
(21118, 102, 1, 1, 1, 1488.409235), -- Round Shield
(21118, 44, 1, 1, 1, 1041.116045), -- Leather Helmet
(21118, 1924, 1, 1, 1, 13131.54732), -- Leather Helmet Design
(21118, 1869, 1, 1, 2, 32565.57206), -- Iron Ore
(21118, 1864, 1, 1, 2, 65131.03394), -- Stem
(21118, 1880, 1, 1, 2, 3256.59026), -- Steel
(21118, 2142, 1, 1, 2, 6513.07034), -- Recipe: Varnish of Purity
(21118, 6035, 1, 1, 2, 2713.7334), -- Magic Haste Potion
-- Hobgoblin
(21119, 1868, 1, 1, -1, 683443), -- Thread
(21119, 1873, 1, 1, -1, 136689), -- Silver Nugget
(21119, 1898, 1, 1, -1, 35102), -- Blue Diamond Necklace Gem
(21119, 57, 156, 278, 0, 700000), -- Adena
(21119, 27, 1, 1, 1, 355.418392), -- Hard Leather Shirt
(21119, 1927, 1, 1, 1, 4026.225584), -- Hard Leather Shirt Pattern
(21119, 33, 1, 1, 1, 570.265216), -- Hard Leather Gaiters
(21119, 1929, 1, 1, 1, 6512.090808), -- Hard Leather Gaiters Material
(21119, 1868, 1, 1, 2, 201878.252582), -- Thread
(21119, 1873, 1, 1, 2, 40375.747418), -- Silver Nugget
-- Kasha Imp Turen
(21120, 1804, 1, 1, -1, 17582), -- Recipe: Soulshot (D-Grade)
(21120, 1926, 1, 1, -1, 44399), -- Piece Bone Breastplate Fragment
(21120, 2151, 1, 1, -1, 122437), -- Recipe: Necklace of Devotion
(21120, 57, 199, 358, 0, 700000), -- Adena
(21120, 87, 1, 1, 1, 69.03532), -- Iron Hammer
(21120, 2014, 1, 1, 1, 745.894993), -- Iron Hammer Head
(21120, 155, 1, 1, 1, 69.03532), -- Flanged Mace
(21120, 177, 1, 1, 1, 69.034367), -- Mage Staff
(21120, 1867, 1, 1, 2, 86557.26612), -- Animal Skin
(21120, 1872, 1, 1, 2, 86557.26612), -- Animal Bone
(21120, 1882, 1, 1, 2, 14426.305584), -- Leather
(21120, 2255, 1, 1, 2, 1587.162176), -- Recipe: Saber
-- Kasha Dire Wolf
(21121, 1927, 1, 1, -1, 30770), -- Hard Leather Shirt Pattern
(21121, 1881, 1, 1, -1, 51428), -- Coarse Bone Powder
(21121, 1875, 1, 1, -1, 25714), -- Stone of Purity
(21121, 57, 177, 312, 0, 700000), -- Adena
(21121, 257, 1, 1, 1, 242), -- Viper Fang
(21121, 1872, 1, 1, 2, 75954.797064), -- Animal Bone
(21121, 1867, 1, 1, 2, 75954.797064), -- Animal Skin
(21121, 1881, 1, 1, 2, 7595.511886), -- Coarse Bone Powder
(21121, 2258, 1, 1, 2, 1392.893986), -- Recipe: Temptation of Abyss
-- Kasha Bugbear
(21122, 1928, 1, 1, -1, 59341), -- Piece Bone Gaiters Fragment
(21122, 2176, 1, 1, -1, 194917), -- Recipe: Leather Boots
(21122, 1929, 1, 1, -1, 52565), -- Hard Leather Gaiters Material
(21122, 57, 181, 334, 0, 700000), -- Adena
(21122, 273, 1, 1, 1, 128.001588), -- Composite Bow
(21122, 2016, 1, 1, 1, 1409.998412), -- Composite Bow Shaft
(21122, 1873, 1, 1, 2, 32088.769028), -- Silver Nugget
(21122, 1868, 1, 1, 2, 160444.236624), -- Thread
(21122, 5268, 1, 1, 2, 3208.994348), -- Recipe: Greater Soulshot (D) Compressed Package (100%)
-- Baar Dre Vanul Destroyer
(21123, 2152, 1, 1, -1, 94359), -- Recipe: Enchanted Necklace
(21123, 1899, 1, 1, -1, 83743), -- Necklace of Devotion Chain
(21123, 1874, 1, 1, -1, 35730), -- Oriharukon Ore
(21123, 57, 236, 442, 0, 700000), -- Adena
(21123, 220, 1, 1, 1, 191), -- Crafted Dagger
(21123, 1874, 1, 1, 2, 5013.3), -- Oriharukon Ore
(21123, 1878, 1, 1, 2, 30079.8), -- Braided Hemp
(21123, 5220, 1, 1, 2, 3007.98), -- Metal Hardener
(21123, 2178, 1, 1, 2, 12031.92), -- Recipe: Dark Stockings
-- Red Eye Barbed Bat
(21124, 1865, 1, 1, -1, 253256), -- Varnish
(21124, 735, 1, 1, -1, 21105), -- Alacrity Potion
(21124, 1897, 1, 1, -1, 60299), -- Necklace of Wisdom Chain
(21124, 57, 121, 200, 0, 700000), -- Adena
(21124, 309, 1, 1, 1, 142.5), -- Tears of Eva
(21124, 310, 1, 1, 1, 142.5), -- Relic of the Saints
(21124, 1865, 1, 1, 2, 37403.909768), -- Varnish
(21124, 1870, 1, 1, 2, 37403.909768), -- Coal
(21124, 1879, 1, 1, 2, 6234.015896), -- Cokes
(21124, 1800, 1, 1, 2, 11762.164568), -- Recipe: Piece Bone Breastplate
-- Northern Trimden
(21125, 1800, 1, 1, -1, 82944), -- Recipe: Piece Bone Breastplate
(21125, 1924, 1, 1, -1, 85085), -- Leather Helmet Design
(21125, 1801, 1, 1, -1, 132878), -- Recipe: Piece Bone Gaiters
(21125, 57, 124, 211, 0, 700000), -- Adena
(21125, 15, 1, 1, 1, 148.419486), -- Short Spear
(21125, 2011, 1, 1, 1, 1777.580514), -- Short Spear Edge
(21125, 1866, 1, 1, 2, 25970.50349), -- Suede
(21125, 1871, 1, 1, 2, 38955.71563), -- Charcoal
(21125, 2140, 1, 1, 2, 7791.17481), -- Recipe: High-Grade Suede
(21125, 734, 1, 1, 2, 6492.60607), -- Haste Potion
-- Kerope Werewolf
(21126, 1925, 1, 1, -1, 177190), -- Leather Gloves Lining
(21126, 1864, 1, 1, -1, 540431), -- Stem
(21126, 1865, 1, 1, -1, 270215), -- Varnish
(21126, 57, 125, 217, 0, 700000), -- Adena
(21126, 24, 1, 1, 1, 511.60535), -- Bone Breastplate
(21126, 390, 1, 1, 1, 511.60535), -- Cotton Shirt
(21126, 31, 1, 1, 1, 816.89465), -- Bone Gaiters
(21126, 412, 1, 1, 1, 816.89465), -- Cotton Pants
(21126, 1864, 1, 1, 2, 53211.71277), -- Stem
(21126, 1865, 1, 1, 2, 26605.77302), -- Varnish
(21126, 1866, 1, 1, 2, 17737.23759), -- Suede
(21126, 1873, 1, 1, 2, 10642.3759), -- Silver Nugget
(21126, 1868, 1, 1, 2, 53211.71277), -- Thread
(21126, 2143, 1, 1, 2, 5321.18795), -- Recipe: Synthetic Cokes
-- Northern Goblin
(21127, 1898, 1, 1, -1, 35102), -- Blue Diamond Necklace Gem
(21127, 1804, 1, 1, -1, 13669), -- Recipe: Soulshot (D-Grade)
(21127, 1926, 1, 1, -1, 34517), -- Piece Bone Breastplate Fragment
(21127, 57, 156, 278, 0, 700000), -- Adena
(21127, 25, 1, 1, 1, 274.899912), -- Piece Bone Breastplate
(21127, 1926, 1, 1, 1, 3398.782366), -- Piece Bone Breastplate Fragment
(21127, 26, 1, 1, 1, 177.939972), -- Bronze Breastplate
(21127, 32, 1, 1, 1, 439.845546), -- Piece Bone Gaiters
(21127, 1928, 1, 1, 1, 4901.377096), -- Piece Bone Gaiters Fragment
(21127, 34, 1, 1, 1, 285.155108), -- Bronze Gaiters
(21127, 1868, 1, 1, 2, 100939.016913), -- Thread
(21127, 1873, 1, 1, 2, 20187.859139), -- Silver Nugget
(21127, 2151, 1, 1, 2, 14058.418696), -- Recipe: Necklace of Devotion
(21127, 6035, 1, 1, 2, 4205.705252), -- Magic Haste Potion
-- Spine Golem
(21128, 2151, 1, 1, -1, 100871), -- Recipe: Necklace of Devotion
(21128, 1927, 1, 1, -1, 28889), -- Hard Leather Shirt Pattern
(21128, 1869, 1, 1, -1, 362125), -- Iron Ore
(21128, 57, 164, 295, 0, 700000), -- Adena
(21128, 1102, 1, 1, 1, 753.305976), -- Tunic of Magic
(21128, 1105, 1, 1, 1, 1208.694024), -- Stockings of Magic
(21128, 1869, 1, 1, 2, 35655.47904), -- Iron Ore
(21128, 1870, 1, 1, 2, 35655.47904), -- Coal
(21128, 1871, 1, 1, 2, 35655.47904), -- Charcoal
(21128, 1872, 1, 1, 2, 47540.70636), -- Animal Bone
(21128, 1867, 1, 1, 2, 47540.70636), -- Animal Skin
(21128, 2256, 1, 1, 2, 872.15016), -- Recipe: Assassin Knife
-- Kerope Werewolf Chief
(21129, 1870, 1, 1, -1, 385707), -- Coal
(21129, 1928, 1, 1, -1, 56185), -- Piece Bone Gaiters Fragment
(21129, 2176, 1, 1, -1, 184549), -- Recipe: Leather Boots
(21129, 57, 177, 312, 0, 700000), -- Adena
(21129, 846, 1, 1, 1, 926.265102), -- Coral Earring
(21129, 909, 1, 1, 1, 694.701042), -- Blue Diamond Necklace
(21129, 1898, 1, 1, 1, 5851.62291), -- Blue Diamond Necklace Gem
(21129, 878, 1, 1, 1, 1389.410946), -- Blue Coral Ring
(21129, 1870, 1, 1, 2, 56966.137764), -- Coal
(21129, 1865, 1, 1, 2, 56966.137764), -- Varnish
(21129, 3032, 1, 1, 2, 2278.606804), -- Recipe: Spiritshot D
(21129, 6035, 1, 1, 2, 4747.117668), -- Magic Haste Potion
-- Northern Goblin Leader
(21130, 1929, 1, 1, -1, 52565), -- Hard Leather Gaiters Material
(21130, 2177, 1, 1, -1, 130152), -- Recipe: Bone Helmet
(21130, 1930, 1, 1, -1, 104455), -- Boot Lining
(21130, 57, 181, 334, 0, 700000), -- Adena
(21130, 39, 1, 1, 1, 1688.908752), -- Boots
(21130, 1930, 1, 1, 1, 20570.158548), -- Boot Lining
(21130, 51, 1, 1, 1, 1688.9327), -- Bracer
(21130, 1871, 1, 1, 2, 60166.567296), -- Charcoal
(21130, 1866, 1, 1, 2, 40111.044864), -- Suede
(21130, 5273, 1, 1, 2, 2406.626624), -- Recipe: Greater Spiritshot (D) Compressed Package(100%)
(21130, 734, 1, 1, 2, 10027.761216), -- Haste Potion
-- Enchanted Spine Golem
(21131, 1872, 1, 1, -1, 559583), -- Animal Bone
(21131, 1867, 1, 1, -1, 559583), -- Animal Skin
(21131, 1899, 1, 1, -1, 65576), -- Necklace of Devotion Chain
(21131, 57, 185, 346, 0, 700000), -- Adena
(21131, 626, 1, 1, 1, 929.141052), -- Bronze Shield
(21131, 45, 1, 1, 1, 651.553071), -- Bone Helmet
(21131, 1932, 1, 1, 1, 12462.305877), -- Bone Helmet Design
(21131, 1872, 1, 1, 2, 62811.194194), -- Animal Bone
(21131, 1867, 1, 1, 2, 62811.194194), -- Animal Skin
(21131, 1881, 1, 1, 2, 6281.133278), -- Coarse Bone Powder
(21131, 1875, 1, 1, 2, 3140.497346), -- Stone of Purity
(21131, 2180, 1, 1, 2, 3541.980988), -- Recipe: Scale Mail
-- Underground Kobold
(21132, 2179, 1, 1, -1, 159246), -- Recipe: Crafted Leather Gloves
(21132, 1898, 1, 1, -1, 34188), -- Blue Diamond Necklace Gem
(21132, 2255, 1, 1, -1, 8137), -- Recipe: Saber
(21132, 57, 148, 273, 0, 700000), -- Adena
(21132, 68, 1, 1, 1, 104.5), -- Falchion
(21132, 5284, 1, 1, 1, 104.5), -- Zweihander
(21132, 1873, 1, 1, 2, 26216.32528), -- Silver Nugget
(21132, 1868, 1, 1, 2, 131081.94624), -- Thread
(21132, 5278, 1, 1, 2, 2621.72848), -- Recipe: Greater Blessed Spiritshot (D) Compressed Package(100%)
-- Dead Pit Skeleton Archer
(21133, 1899, 1, 1, -1, 56286), -- Necklace of Devotion Chain
(21133, 1878, 1, 1, -1, 144093), -- Braided Hemp
(21133, 1864, 1, 1, -1, 720463), -- Stem
(21133, 57, 159, 297, 0, 700000), -- Adena
(21133, 156, 1, 1, 1, 42.666624), -- Hand Axe
(21133, 167, 1, 1, 1, 42.666624), -- Scalpel
(21133, 178, 1, 1, 1, 42.666752), -- Bone Staff
(21133, 1864, 1, 1, 2, 80869.217263), -- Stem
(21133, 1869, 1, 1, 2, 40434.525616), -- Iron Ore
(21133, 1878, 1, 1, 2, 16173.909865), -- Braided Hemp
(21133, 2181, 1, 1, 2, 4047.503718), -- Recipe: White Tunic
(21133, 1061, 1, 1, 2, 24505.843538), -- Greater Healing Potion
-- Dead Pit Spartoi
(21134, 1931, 1, 1, -1, 49119), -- Leather Boots Lining
(21134, 2152, 1, 1, -1, 66155), -- Recipe: Enchanted Necklace
(21134, 1932, 1, 1, -1, 59645), -- Bone Helmet Design
(21134, 57, 163, 312, 0, 700000), -- Adena
(21134, 258, 1, 1, 1, 134), -- Bagh-Nakh
(21134, 1865, 1, 1, 2, 42177.743988), -- Varnish
(21134, 1870, 1, 1, 2, 42177.743988), -- Coal
(21134, 1879, 1, 1, 2, 7029.671424), -- Cokes
(21134, 1875, 1, 1, 2, 2811.88754), -- Stone of Purity
(21134, 2259, 1, 1, 2, 654.95306), -- Recipe: Spinebone Sword
-- Underground Kobold Warrior
(21135, 2178, 1, 1, -1, 73236), -- Recipe: Dark Stockings
(21135, 1934, 1, 1, -1, 59833), -- Crafted Leather Gloves Lining
(21135, 5220, 1, 1, -1, 18309), -- Metal Hardener
(21135, 57, 198, 381, 0, 700000), -- Adena
(21135, 274, 1, 1, 1, 163), -- Reinforced Bow
(21135, 1866, 1, 1, 2, 34251.808304), -- Suede
(21135, 1871, 1, 1, 2, 51377.80522), -- Charcoal
(21135, 5220, 1, 1, 2, 2055.093656), -- Metal Hardener
(21135, 1885, 1, 1, 2, 4281.52242), -- High-Grade Suede
(21135, 2261, 1, 1, 2, 797.7704), -- Recipe: Conjuror's Staff
-- Dead Pit Horror
(21136, 1882, 1, 1, -1, 89848), -- Leather
(21136, 2017, 1, 1, -1, 5373), -- Saber Blade
(21136, 2180, 1, 1, -1, 30400), -- Recipe: Scale Mail
(21136, 57, 173, 339, 0, 700000), -- Adena
(21136, 220, 1, 1, 1, 144), -- Crafted Dagger
(21136, 1867, 1, 1, 2, 60510.58416), -- Animal Skin
(21136, 1872, 1, 1, 2, 60510.58416), -- Animal Bone
(21136, 1882, 1, 1, 2, 10085.034186), -- Leather
(21136, 2152, 1, 1, 2, 7990.057998), -- Recipe: Enchanted Necklace
(21136, 1834, 1, 1, 2, 50425.739496), -- Emergency Dressing
-- Iron Ore Golem
(21137, 1900, 1, 1, -1, 47223), -- Enchanted Necklace Chain
(21137, 2153, 1, 1, -1, 67126), -- Recipe: Tiger's Eye Earring
(21137, 1933, 1, 1, -1, 50779), -- Dark Stockings Fabric
(21137, 57, 183, 362, 0, 700000), -- Adena
(21137, 315, 1, 1, 1, 95), -- Divine Tome
(21137, 1868, 1, 1, 2, 78621.401316), -- Thread
(21137, 1873, 1, 1, 2, 15724.258983), -- Silver Nugget
(21137, 5549, 1, 1, 2, 3931.091346), -- Metallic Thread
(21137, 1889, 1, 1, 2, 2620.763031), -- Compound Braid
(21137, 737, 1, 1, 2, 3931.091346), -- Scroll of Resurrection
(21137, 6387, 1, 1, 2, 1572.393978), -- Blessed Scroll of Resurrection for Pets
-- Greedy Geist
(21138, 1869, 1, 1, -1, 460180), -- Iron Ore
(21138, 1864, 1, 1, -1, 920360), -- Stem
(21138, 956, 1, 1, -1, 15339), -- Scroll: Enchant Armor (D-Grade)
(21138, 57, 194, 388, 0, 700000), -- Adena
(21138, 292, 1, 1, 1, 102), -- Pike
(21138, 1869, 1, 1, 2, 41911.791592), -- Iron Ore
(21138, 1864, 1, 1, 2, 83823.870141), -- Stem
(21138, 1880, 1, 1, 2, 4191.293942), -- Steel
(21138, 5550, 1, 1, 2, 558.705279), -- Durable Metal Plate
(21138, 1829, 1, 1, 2, 16764.888811), -- Scroll of Escape: Clan Hall
(21138, 1341, 10, 30, 2, 139706.450235), -- Bone Arrow
-- Catacomb Barbed Bat
(21139, 1898, 1, 1, -1, 96575), -- Blue Diamond Necklace Gem
(21139, 1804, 1, 1, -1, 37606), -- Recipe: Soulshot (D-Grade)
(21139, 1926, 1, 1, -1, 94966), -- Piece Bone Breastplate Fragment
(21139, 57, 430, 759, 0, 700000), -- Adena
(21139, 27, 1, 1, 1, 977.83462), -- Hard Leather Shirt
(21139, 1927, 1, 1, 1, 11077.03724), -- Hard Leather Shirt Pattern
(21139, 33, 1, 1, 1, 1568.92576), -- Hard Leather Gaiters
(21139, 1929, 1, 1, 1, 17916.20238), -- Hard Leather Gaiters Material
(21139, 1870, 1, 1, 2, 185139.186064), -- Coal
(21139, 1865, 1, 1, 2, 185139.186064), -- Varnish
(21139, 3953, 1, 1, 2, 7405.627872), -- Recipe: Blessed Spiritshot D
-- Catacomb Wisp
(21140, 2152, 1, 1, -1, 193505), -- Recipe: Enchanted Necklace
(21140, 1899, 1, 1, -1, 171735), -- Necklace of Devotion Chain
(21140, 1871, 1, 3, -1, 549553); -- Charcoal

INSERT INTO `droplist` VALUES
(21140, 57, 477, 911, 0, 700000), -- Adena
(21140, 347, 1, 1, 1, 960.693069), -- Ring Mail Breastplate
(21140, 376, 1, 1, 1, 1538.306931), -- Iron Plate Gaiters
(21140, 1871, 1, 1, 2, 154212.99259), -- Charcoal
(21140, 1866, 1, 1, 2, 102808.750255), -- Suede
(21140, 1877, 1, 1, 2, 6168.47721), -- Adamantite Nugget
(21140, 2260, 1, 1, 2, 2394.779945), -- Recipe: Mace of Judgment
-- Catacomb Serpent
(21141, 1881, 1, 1, -1, 169543), -- Coarse Bone Powder
(21141, 1931, 1, 1, -1, 166219), -- Leather Boots Lining
(21141, 2178, 1, 1, -1, 203452), -- Recipe: Dark Stockings
(21141, 57, 545, 1067, 0, 700000), -- Adena
(21141, 432, 1, 1, 1, 1480.781988), -- Cursed Tunic
(21141, 465, 1, 1, 1, 2371.218012), -- Cursed Stockings
(21141, 1872, 1, 1, 2, 190305.884826), -- Animal Bone
(21141, 1867, 1, 1, 2, 190305.884826), -- Animal Skin
(21141, 1881, 1, 1, 2, 19030.631682), -- Coarse Bone Powder
(21141, 1875, 1, 1, 2, 9515.099844), -- Stone of Purity
(21141, 2178, 1, 1, 2, 22836.498822), -- Recipe: Dark Stockings
-- Grave Keeper Spartoi
(21142, 1900, 1, 1, -1, 138128), -- Enchanted Necklace Chain
(21142, 2153, 1, 1, -1, 196344), -- Recipe: Tiger's Eye Earring
(21142, 1933, 1, 1, -1, 148528), -- Dark Stockings Fabric
(21142, 57, 535, 1059, 0, 700000), -- Adena
(21142, 848, 1, 1, 1, 1051.697156), -- Enchanted Earring
(21142, 911, 1, 1, 1, 789.363658), -- Enchanted Necklace
(21142, 1900, 1, 1, 1, 18870.577948), -- Enchanted Necklace Chain
(21142, 879, 1, 1, 1, 1582.361238), -- Enchanted Ring
(21142, 1873, 1, 1, 2, 68990.39847), -- Silver Nugget
(21142, 1868, 1, 1, 2, 344951.543223), -- Thread
(21142, 1876, 1, 1, 2, 34495.199235), -- Mithril Ore
(21142, 955, 1, 1, 2, 689.859072), -- Scroll: Enchant Weapon (D-Grade)
-- Catacomb Scavenger Bat
(21143, 955, 1, 1, -1, 5610), -- Scroll: Enchant Weapon (D-Grade)
(21143, 1875, 1, 1, -1, 93494), -- Stone of Purity
(21143, 1872, 1, 3, -1, 934937), -- Animal Bone
(21143, 57, 593, 1182, 0, 700000), -- Adena
(21143, 1123, 1, 1, 1, 2993.5), -- Blue Buckskin Boots
(21143, 605, 1, 1, 1, 2993.5), -- Leather Gauntlets
(21143, 1872, 1, 1, 2, 170302.636242), -- Animal Bone
(21143, 1867, 1, 1, 2, 170302.636242), -- Animal Skin
(21143, 1881, 1, 1, 2, 17030.386242), -- Coarse Bone Powder
(21143, 1875, 1, 1, 2, 8514.988758), -- Stone of Purity
(21143, 2250, 1, 1, 2, 31931.71875), -- Recipe: Bone Arrow
(21143, 6035, 1, 1, 2, 10643.633766), -- Magic Haste Potion
-- Catacomb Shadow
(21144, 1901, 1, 1, -1, 229413), -- Tiger's Eye Earring Stone
(21144, 2154, 1, 1, -1, 177832), -- Recipe: Elven Earring
(21144, 1938, 1, 1, -1, 111661), -- Mithril Banded Mail Material
(21144, 57, 702, 1399, 0, 700000), -- Adena
(21144, 628, 1, 1, 1, 2153.960333), -- Hoplon
(21144, 47, 1, 1, 1, 1507.039667), -- Helmet
(21144, 1865, 1, 1, 2, 126159.284034), -- Varnish
(21144, 1870, 1, 1, 2, 126159.284034), -- Coal
(21144, 1879, 1, 1, 2, 21026.397938), -- Cokes
(21144, 1875, 1, 1, 2, 8410.678696), -- Stone of Purity
(21144, 2187, 1, 1, 2, 5632.118898), -- Recipe: Manticore Skin Shirt
(21144, 8317, 1, 1, 2, 901.186832), -- Recipe: Titan Hammer (100%)
(21144, 6035, 1, 1, 2, 10513.049568), -- Magic Haste Potion
-- Catacomb Stakato Soldier
(21145, 1825, 1, 1, -1, 150797), -- Recipe: Oriharukon
(21145, 1902, 1, 1, -1, 213897), -- Elven Earring Beads
(21145, 1885, 1, 1, -1, 175930), -- High-Grade Suede
(21145, 57, 893, 1781, 0, 700000), -- Adena
(21145, 129, 1, 1, 1, 101.61644), -- Sword of Revolution
(21145, 2034, 1, 1, 1, 5765.38356), -- Sword of Revolution Blade
(21145, 1866, 1, 1, 2, 103934.33472), -- Suede
(21145, 1871, 1, 1, 2, 155901.97664), -- Charcoal
(21145, 5220, 1, 1, 2, 6236.19296), -- Metal Hardener
(21145, 1885, 1, 1, 2, 12992.02912), -- High-Grade Suede
(21145, 2146, 1, 1, 2, 11136.02496), -- Recipe: Artisan's frame
(21145, 5473, 1, 1, 2, 11136.02496), -- Recipe: Durable Metal Plate(100%)
(21145, 1832, 1, 1, 2, 173223.41664), -- Greater Antidote
-- Grave Keeper Dark Horror
(21146, 1894, 1, 1, -1, 79948), -- Crafted Leather
(21146, 1903, 1, 1, -1, 380070), -- Elven Ring Piece
(21146, 2145, 1, 1, -1, 162751), -- Recipe: Mithril Alloy
(21146, 57, 951, 1898, 0, 700000), -- Adena
(21146, 88, 1, 1, 1, 21.934692), -- Morning Star
(21146, 2031, 1, 1, 1, 1192.248369), -- Morning Star Head
(21146, 90, 1, 1, 1, 21.934692), -- Goat Head Staff
(21146, 2032, 1, 1, 1, 1088.350965), -- Goat Head Staff Head
(21146, 158, 1, 1, 1, 21.934692), -- Tarbar
(21146, 2035, 1, 1, 1, 1192.248369), -- Tarbar Head
(21146, 169, 1, 1, 1, 21.934692), -- Skull Breaker
(21146, 2036, 1, 1, 1, 1192.248369), -- Skull Breaker Head
(21146, 172, 1, 1, 1, 21.934692), -- Heavy Bone Club
(21146, 2037, 1, 1, 1, 1192.230468), -- Heavy Bone Club Head
(21146, 1872, 1, 1, 2, 224346.478044), -- Animal Bone
(21146, 1867, 1, 1, 2, 224346.478044), -- Animal Skin
(21146, 1881, 1, 1, 2, 22434.449076), -- Coarse Bone Powder
(21146, 1875, 1, 1, 2, 11217.224538), -- Stone of Purity
(21146, 1805, 1, 1, 2, 560.910909), -- Recipe: Soulshot (C-Grade)
(21146, 2990, 1, 1, 2, 13354.051659), -- Recipe: Chain Boots
(21146, 5164, 1, 1, 2, 561.40773), -- Recipe: Blessed Spiritshot (C) Compressed Package (100%)
-- Catacomb Gargoyle
(21147, 1905, 1, 1, -1, 273798), -- Omen Beast's Eye Earring Gemstone
(21147, 1805, 1, 1, -1, 9382), -- Recipe: Soulshot (C-Grade)
(21147, 1906, 1, 1, -1, 386892), -- Mithril Ring Wire
(21147, 57, 1113, 2260, 0, 700000), -- Adena
(21147, 262, 1, 1, 1, 101.8973), -- Scallop Jamadhr
(21147, 2053, 1, 1, 1, 5843.1027), -- Scallop Jamadhr Edge
(21147, 1868, 1, 3, 2, 235563.65775), -- Thread
(21147, 1873, 1, 1, 2, 94225.4631), -- Silver Nugget
(21147, 5549, 1, 1, 2, 23556.555784), -- Metallic Thread
(21147, 1889, 1, 1, 2, 15704.24385), -- Compound Braid
(21147, 2199, 1, 1, 2, 9939.37079), -- Recipe: Karmian Stockings
(21147, 2301, 1, 1, 2, 1028.708726), -- Recipe: Battle Axe
-- Catacomb Liviona
(21148, 1880, 1, 1, -1, 279242), -- Steel
(21148, 5550, 1, 1, -1, 37232), -- Durable Metal Plate
(21148, 1869, 1, 5, -1, 930808), -- Iron Ore
(21148, 57, 1099, 2253, 0, 700000), -- Adena
(21148, 281, 1, 1, 1, 74.867985), -- Crystallized Ice Bow
(21148, 2074, 1, 1, 1, 4674.132015), -- Crystallized Ice Bow Shaft
(21148, 1869, 1, 1, 2, 119976.49755), -- Iron Ore
(21148, 1864, 1, 3, 2, 119976.49755), -- Stem
(21148, 1880, 1, 1, 2, 11997.826204), -- Steel
(21148, 5550, 1, 1, 2, 1599.686634), -- Durable Metal Plate
(21148, 2163, 1, 1, 2, 6121.368708), -- Recipe: Earring of Protection
(21148, 6037, 1, 3, 2, 79984.3317), -- Waking Scroll
(21148, 2217, 1, 1, 2, 7099.249066), -- Recipe: Knight's Shield
(21148, 8723, 1, 1, 2, 4799.059902), -- Life Stone - Level 46
(21148, 8733, 1, 1, 2, 1199.8532), -- Mid-Grade Life Stone - Level 46
(21148, 8743, 1, 1, 2, 119.98532), -- High-Grade Life Stone - Level 46
(21148, 8753, 1, 1, 2, 23.644166), -- Top-Grade Life Stone - Level 46
-- Decayed Ancient Pikeman
(21149, 1908, 1, 1, -1, 305158), -- Moonstone Earring Wire
(21149, 2163, 1, 1, -1, 164412), -- Recipe: Earring of Protection
(21149, 1909, 1, 1, -1, 435175), -- Aquastone Ring Wire
(21149, 57, 1269, 2596, 0, 700000), -- Adena
(21149, 226, 1, 1, 1, 43.194719), -- Cursed Dagger
(21149, 2070, 1, 1, 1, 3023.305281), -- Cursed Dagger Blade
(21149, 232, 1, 1, 1, 43.194719), -- Dark Elven Dagger
(21149, 2072, 1, 1, 1, 3023.305281), -- Dark Elven Dagger Edge
(21149, 1873, 1, 1, 2, 55381.38858), -- Silver Nugget
(21149, 1868, 1, 1, 2, 276907.35736), -- Thread
(21149, 1876, 1, 1, 2, 27690.90152), -- Mithril Ore
(21149, 1895, 1, 1, 2, 39558.1347), -- Metallic Fiber
(21149, 4042, 1, 1, 2, 2307.71328), -- Enria
(21149, 2215, 1, 1, 2, 1763.94176), -- Recipe: Robe of Seal
(21149, 2228, 1, 1, 2, 3762.46788), -- Recipe: Shining Circlet
(21149, 8723, 1, 1, 2, 5538.01452), -- Life Stone - Level 46
(21149, 8733, 1, 1, 2, 1384.71086), -- Mid-Grade Life Stone - Level 46
(21149, 8743, 1, 1, 2, 138.42964), -- High-Grade Life Stone - Level 46
(21149, 8753, 1, 1, 2, 26.9399), -- Top-Grade Life Stone - Level 46
-- Decayed Ancient Soldier
(21150, 2166, 1, 1, -1, 124078), -- Recipe: Earrings of Binding (100%)
(21150, 1911, 1, 1, -1, 272241), -- Earring of Protection Gemstone
(21150, 951, 1, 1, -1, 6655), -- Scroll: Enchant Weapon (C-Grade)
(21150, 57, 1445, 2946, 0, 700000), -- Adena
(21150, 325, 1, 1, 1, 73.39184), -- Horn of Glory
(21150, 2088, 1, 1, 1, 5714.60816), -- Horn of Glory Fragment
(21150, 1871, 1, 1, 2, 124753.040586), -- Charcoal
(21150, 1866, 1, 1, 2, 83168.693724), -- Suede
(21150, 1877, 1, 1, 2, 4990.237038), -- Adamantite Nugget
(21150, 4041, 1, 1, 2, 1084.896864), -- Mold Hardener
(21150, 4040, 1, 1, 2, 2494.878072), -- Mold Lubricant
(21150, 2166, 1, 1, 2, 4228.981836), -- Recipe: Earrings of Binding (100%)
(21150, 3014, 1, 1, 2, 3484.557924), -- Recipe: Full Plate Boots
(21150, 2234, 1, 1, 2, 1859.136204), -- Recipe: Divine Stockings
(21150, 8724, 1, 1, 2, 4158.290418), -- Life Stone - Level 49
(21150, 8734, 1, 1, 2, 1039.692828), -- Mid-Grade Life Stone - Level 49
(21150, 8744, 1, 1, 2, 103.873104), -- High-Grade Life Stone - Level 49
(21150, 8754, 1, 1, 2, 20.678442), -- Top-Grade Life Stone - Level 49
(21150, 1342, 10, 30, 2, 249507.04296), -- Steel Arrow
-- Decayed Ancient Knight
(21151, 4043, 1, 1, -1, 127207), -- Asofe
(21151, 1869, 1, 9, -1, 763245), -- Iron Ore
(21151, 4601, 1, 1, -1, 8480), -- Greater Dye of STR (Str+3 Con-3)
(21151, 57, 1509, 3068, 0, 700000), -- Adena
(21151, 231, 1, 1, 1, 23.879216), -- Grace Dagger
(21151, 2106, 1, 1, 1, 2150.120784), -- Grace Dagger Edge
(21151, 233, 1, 1, 1, 23.879216), -- Dark Screamer
(21151, 2107, 1, 1, 1, 2150.120784), -- Dark Screamer Edge
(21151, 1869, 1, 1, 2, 157815.289722), -- Iron Ore
(21151, 1864, 1, 3, 2, 157815.289722), -- Stem
(21151, 1880, 1, 1, 2, 15781.459536), -- Steel
(21151, 5550, 1, 1, 2, 2104.264041), -- Durable Metal Plate
(21151, 4043, 1, 1, 2, 5260.486512), -- Asofe
(21151, 2169, 1, 1, 2, 2793.071145), -- Recipe: Necklace of Seal
(21151, 8725, 1, 1, 2, 4383.854487), -- Life Stone - Level 52
(21151, 8735, 1, 1, 2, 1096.050417), -- Mid-Grade Life Stone - Level 52
(21151, 8745, 1, 1, 2, 109.709196), -- High-Grade Life Stone - Level 52
(21151, 8755, 1, 1, 2, 21.525222), -- Top-Grade Life Stone - Level 52
-- Purgatory Wisp
(21152, 4600, 1, 1, -1, 13611), -- Greater Dye of WIT (Wit+2 Men-2)
(21152, 1806, 1, 1, -1, 8167), -- Recipe: Soulshot (B-Grade)
(21152, 1920, 1, 1, -1, 139722), -- Necklace of Seal Chain
(21152, 57, 1616, 3283, 0, 700000), -- Adena
(21152, 400, 1, 1, 1, 79.146848), -- Theca Leather Armor
(21152, 1984, 1, 1, 1, 5386.390768), -- Theca Leather Armor Pattern
(21152, 401, 1, 1, 1, 37.470576), -- Drake Leather Armor
(21152, 1987, 1, 1, 1, 3833.636928), -- Drake Leather Armor Texture
(21152, 420, 1, 1, 1, 126.678464), -- Theca Leather Gaiters
(21152, 1985, 1, 1, 1, 8664.676416), -- Theca Leather Gaiters Pattern
(21152, 1873, 1, 1, 2, 50256.959093), -- Silver Nugget
(21152, 1868, 1, 1, 2, 251284.423442), -- Thread
(21152, 1876, 1, 1, 2, 25128.293535), -- Mithril Ore
(21152, 1895, 1, 1, 2, 35897.615339), -- Metallic Fiber
(21152, 4042, 1, 1, 2, 2094.117467), -- Enria
(21152, 1806, 1, 1, 2, 251.115525), -- Recipe: Soulshot (B-Grade)
(21152, 4959, 1, 1, 2, 2420.753661), -- Recipe: Sealed Avadon Boots (60%)
(21152, 4941, 1, 1, 2, 966.515754), -- Recipe: Zubei's Gaiters (60%)
(21152, 8726, 1, 1, 2, 2908.475814), -- Life Stone - Level 55
(21152, 8736, 1, 1, 2, 726.932942), -- Mid-Grade Life Stone - Level 55
(21152, 8746, 1, 1, 2, 72.544485), -- High-Grade Life Stone - Level 55
(21152, 8756, 1, 1, 2, 15.252943), -- Top-Grade Life Stone - Level 55
-- Purgatory Serpent
(21153, 4129, 1, 1, -1, 52277), -- Recipe: Earrings of Black Ore (100%)
(21153, 4049, 1, 1, -1, 253365), -- Adamantite Earring Gemstone
(21153, 947, 1, 1, -1, 1932), -- Scroll: Enchant Weapon (B-Grade)
(21153, 57, 1906, 3892, 0, 700000), -- Adena
(21153, 357, 1, 1, 1, 22.3506), -- Zubei's Breastplate
(21153, 4056, 1, 1, 1, 3229.231244), -- Zubei's Breastplate Part
(21153, 2376, 1, 1, 1, 22.3506), -- Avadon Breastplate
(21153, 4064, 1, 1, 1, 3229.231244), -- Avadon Breastplate Part
(21153, 383, 1, 1, 1, 35.76096), -- Zubei's Gaiters
(21153, 4057, 1, 1, 1, 4990.64064), -- Zubei's Gaiter Material
(21153, 2379, 1, 1, 1, 35.76096), -- Avadon Gaiters
(21153, 4065, 1, 1, 1, 4990.673752), -- Avadon Gaiters Material
(21153, 1894, 1, 1, 2, 4551.275414), -- Crafted Leather
(21153, 4039, 1, 1, 2, 4323.714376), -- Mold Glue
(21153, 4041, 1, 1, 2, 1127.931034), -- Mold Hardener
(21153, 4044, 1, 1, 2, 4323.714376), -- Thons
(21153, 947, 1, 1, 2, 51.884864), -- Scroll: Enchant Weapon (B-Grade)
(21153, 3955, 1, 1, 2, 259.42432), -- Recipe: Blessed Spiritshot B
(21153, 5280, 1, 1, 2, 259.42432), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(21153, 8727, 1, 1, 2, 2594.224982), -- Life Stone - Level 58
(21153, 8737, 1, 1, 2, 648.5608), -- Mid-Grade Life Stone - Level 58
(21153, 8747, 1, 1, 2, 64.85608), -- High-Grade Life Stone - Level 58
(21153, 8757, 1, 1, 2, 12.989434), -- Top-Grade Life Stone - Level 58
-- Hell Keeper Medusa
(21154, 4613, 1, 1, -1, 7001), -- Greater Dye of STR (Str+4 Con-4)
(21154, 4614, 1, 1, -1, 7001), -- Greater Dye of STR (Str+4 Dex-4)
(21154, 4049, 1, 1, -1, 266232), -- Adamantite Earring Gemstone
(21154, 57, 2005, 4083, 0, 700000), -- Adena
(21154, 2397, 1, 1, 1, 41.751641), -- Tunic of Zubei
(21154, 4069, 1, 1, 1, 5892.656172), -- Tunic of Zubei Fabric
(21154, 2406, 1, 1, 1, 25.682817), -- Avadon Robe
(21154, 4071, 1, 1, 1, 4527.020643), -- Avadon Robe Fabric
(21154, 2402, 1, 1, 1, 66.810426), -- Stockings of Zubei
(21154, 4070, 1, 1, 1, 8947.078301), -- Stockings of Zubei Fabric
(21154, 1872, 1, 3, 2, 111058.181145), -- Animal Bone
(21154, 1867, 1, 3, 2, 74038.78743), -- Animal Skin
(21154, 1881, 1, 1, 2, 22211.55499), -- Coarse Bone Powder
(21154, 1875, 1, 1, 2, 11105.777495), -- Stone of Purity
(21154, 4041, 1, 1, 2, 1448.49137), -- Mold Hardener
(21154, 948, 1, 1, 2, 416.349875), -- Scroll: Enchant Armor (B-Grade)
(21154, 4162, 1, 1, 2, 691.34389), -- Recipe: Tunic of Doom (100%)
(21154, 5003, 1, 1, 2, 127.139035), -- Recipe: Art of Battle Axe (60%)
(21154, 1832, 1, 1, 2, 185097.37477), -- Greater Antidote
-- Purgatory Conjurer
(21155, 4050, 1, 1, -1, 317155), -- Adamantite Ring Wire
(21155, 4130, 1, 1, -1, 83099), -- Recipe: Ring of Black Ore (100%)
(21155, 4051, 1, 1, -1, 198522), -- Adamantite Necklace Chain
(21155, 57, 2021, 4119, 0, 700000), -- Adena
(21155, 856, 1, 1, 1, 108.180812), -- Adamantite Earring
(21155, 4049, 1, 1, 1, 13217.926624), -- Adamantite Earring Gemstone
(21155, 918, 1, 1, 1, 81.145348), -- Adamantite Necklace
(21155, 4051, 1, 1, 1, 9773.125456), -- Adamantite Necklace Chain
(21155, 887, 1, 1, 1, 162.25174), -- Adamantite Ring
(21155, 4050, 1, 1, 1, 15613.37002), -- Adamantite Ring Wire
(21155, 1895, 1, 1, 2, 43201.079614), -- Metallic Fiber
(21155, 4040, 1, 1, 2, 3024.025004), -- Mold Lubricant
(21155, 4042, 1, 1, 2, 2520.141239), -- Enria
(21155, 4043, 1, 1, 2, 5040.282478), -- Asofe
(21155, 4154, 1, 1, 2, 1789.419478), -- Recipe: Doom Shield (100%)
(21155, 6037, 1, 1, 2, 302406.834884), -- Waking Scroll
(21155, 8728, 1, 1, 2, 2520.141239), -- Life Stone - Level 61
(21155, 8738, 1, 1, 2, 629.945008), -- Mid-Grade Life Stone - Level 61
(21155, 8748, 1, 1, 2, 62.850018), -- High-Grade Life Stone - Level 61
(21155, 8758, 1, 1, 2, 12.281038), -- Top-Grade Life Stone - Level 61
-- Purgatory Shadow
(21156, 4131, 1, 1, -1, 44665), -- Recipe: Necklace of Black Ore (100%)
(21156, 4056, 1, 1, -1, 99436), -- Zubei's Breastplate Part
(21156, 948, 1, 1, -1, 13735), -- Scroll: Enchant Armor (B-Grade)
(21156, 57, 2177, 4415, 0, 700000), -- Adena
(21156, 554, 1, 1, 1, 101.65376), -- Sealed Zubei's Boots
(21156, 4097, 1, 1, 1, 10558.34624), -- Sealed Zubei's Boots Design
(21156, 600, 1, 1, 1, 101.65376), -- Sealed Avadon Boots
(21156, 4098, 1, 1, 1, 10558.34624), -- Sealed Avadon Boots Design
(21156, 612, 1, 1, 1, 101.65376), -- Sealed Zubei's Gauntlets
(21156, 4100, 1, 1, 1, 10558.34624), -- Sealed Zubei's Gauntlets Part
(21156, 2464, 1, 1, 1, 101.65376), -- Sealed Avadon Gloves
(21156, 4073, 1, 1, 1, 10558.34624), -- Sealed Avadon Gloves Part
(21156, 1865, 1, 1, 2, 147526.144134), -- Varnish
(21156, 1870, 1, 1, 2, 147526.144134), -- Coal
(21156, 1879, 1, 1, 2, 24587.617128), -- Cokes
(21156, 1875, 1, 1, 2, 9834.958578), -- Stone of Purity
(21156, 4040, 1, 1, 2, 2950.53171), -- Mold Lubricant
(21156, 4160, 1, 1, 2, 417.973602), -- Recipe: Leather Armor of Doom (100%)
(21156, 8728, 1, 1, 2, 2458.849986), -- Life Stone - Level 61
(21156, 8738, 1, 1, 2, 614.822838), -- Mid-Grade Life Stone - Level 61
(21156, 8748, 1, 1, 2, 61.349874), -- High-Grade Life Stone - Level 61
(21156, 8758, 1, 1, 2, 12.358248), -- Top-Grade Life Stone - Level 61
(21156, 1343, 20, 60, 2, 105375.249768), -- Silver Arrow
-- Purgatory Tarantula
(21157, 5549, 1, 1, -1, 626651), -- Metallic Thread
(21157, 1889, 1, 1, -1, 417768), -- Compound Braid
(21157, 4052, 1, 1, -1, 221863), -- Earring of Black Ore Piece
(21157, 57, 2488, 5032, 0, 700000), -- Adena
(21157, 110, 1, 1, 1, 94.954836), -- Doom Shield
(21157, 4077, 1, 1, 1, 13879.2381), -- Doom Shield Fragment
(21157, 2416, 1, 1, 1, 66.472128), -- Blue Wolf Helmet
(21157, 4088, 1, 1, 1, 11660.431404), -- Blue Wolf Helmet Design
(21157, 2417, 1, 1, 1, 66.472128), -- Doom Helmet
(21157, 4089, 1, 1, 1, 11660.431404), -- Doom Helmet Pattern
(21157, 1868, 1, 3, 2, 154252.604066), -- Thread
(21157, 1873, 1, 1, 2, 61701.234672), -- Silver Nugget
(21157, 5549, 1, 1, 2, 15425.308668), -- Metallic Thread
(21157, 1889, 1, 1, 2, 10283.539112), -- Compound Braid
(21157, 4044, 1, 1, 2, 5141.769556), -- Thons
(21157, 1830, 1, 1, 2, 61701.234672), -- Scroll of Escape: Castle
(21157, 8487, 1, 1, 2, 84.45745), -- Recipe: Destroyer Hammer (60%)
(21157, 8729, 1, 1, 2, 2056.900868), -- Life Stone - Level 64
(21157, 8739, 1, 1, 2, 513.98391), -- Mid-Grade Life Stone - Level 64
(21157, 8749, 1, 1, 2, 51.639698), -- High-Grade Life Stone - Level 64
(21157, 8759, 1, 1, 2, 10.134894), -- Top-Grade Life Stone - Level 64
(21157, 1832, 1, 1, 2, 171391.192434), -- Greater Antidote
-- Hell Keeper Crimson Doll
(21158, 5230, 1, 1, -1, 9462), -- Recipe: Mithril Arrow (100%)
(21158, 4053, 1, 1, -1, 304195), -- Ring of Black Ore Gemstone
(21158, 57, 2798, 5718, 0, 700000), -- Adena
(21158, 2391, 1, 1, 1, 34.741224), -- Blue Wolf Leather Armor
(21158, 4082, 1, 1, 1, 5922.258776), -- Blue Wolf Leather Armor Texture
(21158, 2392, 1, 1, 1, 34.741224), -- Leather Armor of Doom
(21158, 4083, 1, 1, 1, 5922.258776), -- Leather Armor of Doom Design
(21158, 1869, 2, 6, 2, 43672.998096), -- Iron Ore
(21158, 1864, 1, 3, 2, 174691.992384), -- Stem
(21158, 1880, 1, 1, 2, 17469.121392), -- Steel
(21158, 5550, 1, 1, 2, 2329.164288), -- Durable Metal Plate
(21158, 4043, 1, 1, 2, 5822.91072), -- Asofe
(21158, 1830, 1, 1, 2, 69876.8748), -- Scroll of Escape: Castle
(21158, 8487, 1, 1, 2, 95.36184), -- Recipe: Destroyer Hammer (60%)
(21158, 8730, 1, 1, 2, 1941.099984), -- Life Stone - Level 67
(21158, 8740, 1, 1, 2, 485.372304), -- Mid-Grade Life Stone - Level 67
(21158, 8750, 1, 1, 2, 48.654), -- High-Grade Life Stone - Level 67
(21158, 8760, 1, 1, 2, 9.7308), -- Top-Grade Life Stone - Level 67
(21158, 1344, 30, 90, 2, 72788.719392), -- Mithril Arrow
-- Purgatory Gargoyle
(21159, 5478, 1, 1, -1, 61665), -- Sealed Dark Crystal Leather Armor Pattern
(21159, 1874, 1, 1, -1, 488878), -- Oriharukon Ore
(21159, 4043, 1, 1, -1, 244439), -- Asofe
(21159, 57, 2901, 5897, 0, 700000), -- Adena
(21159, 5304, 1, 1, 1, 27.032031), -- Sealed Tallum Tunic
(21159, 5485, 1, 1, 1, 3035.535711), -- Sealed Tallum Tunic Texture
(21159, 5308, 1, 1, 1, 16.628157), -- Sealed Dark Crystal Robe
(21159, 5486, 1, 1, 1, 2136.011553), -- Sealed Dark Crystal Robe Fabric
(21159, 5305, 1, 1, 1, 43.229199), -- Sealed Tallum Stockings
(21159, 5489, 1, 1, 1, 4764.563349), -- Sealed Tallum Stockings Fabric
(21159, 1870, 1, 1, 2, 166623.321557), -- Coal
(21159, 1865, 1, 1, 2, 166623.321557), -- Varnish
(21159, 1874, 1, 1, 2, 11108.283101), -- Oriharukon Ore
(21159, 4043, 1, 1, 2, 5553.910311), -- Asofe
(21159, 4039, 1, 1, 2, 5553.910311), -- Mold Glue
(21159, 3035, 1, 1, 2, 221.98992), -- Recipe: Spiritshot A
(21159, 5281, 1, 1, 2, 221.98992), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21159, 8326, 1, 1, 2, 61.509707), -- Recipe: Doom Crusher (60%)
(21159, 8730, 1, 1, 2, 1851.303437), -- Life Stone - Level 67
(21159, 8740, 1, 1, 2, 462.941479), -- Mid-Grade Life Stone - Level 67
(21159, 8750, 1, 1, 2, 46.2479), -- High-Grade Life Stone - Level 67
(21159, 8760, 1, 1, 2, 9.24958), -- Top-Grade Life Stone - Level 67
(21159, 1344, 20, 60, 2, 104141.02122), -- Mithril Arrow
-- Purgatory Liviona
(21160, 5479, 1, 1, -1, 36206), -- Sealed Tallum Leather Armor Pattern
(21160, 1807, 1, 1, -1, 8158), -- Recipe: Soulshot (A-Grade)
(21160, 5482, 1, 1, -1, 80760), -- Sealed Dark Crystal Leggings Design
(21160, 57, 3019, 6154, 0, 700000), -- Adena
(21160, 5304, 1, 1, 1, 28.194438), -- Sealed Tallum Tunic
(21160, 5485, 1, 1, 1, 3166.067078), -- Sealed Tallum Tunic Texture
(21160, 5308, 1, 1, 1, 17.343186), -- Sealed Dark Crystal Robe
(21160, 5486, 1, 1, 1, 2227.862394), -- Sealed Dark Crystal Robe Fabric
(21160, 5305, 1, 1, 1, 45.088102), -- Sealed Tallum Stockings
(21160, 5489, 1, 1, 1, 4969.444802), -- Sealed Tallum Stockings Fabric
(21160, 1894, 1, 1, 2, 7206.497034), -- Crafted Leather
(21160, 4039, 1, 1, 2, 6846.237684), -- Mold Glue
(21160, 4041, 1, 1, 2, 1786.01302), -- Mold Hardener
(21160, 4044, 1, 1, 2, 6846.237684), -- Thons
(21160, 1807, 1, 1, 2, 273.797106), -- Recipe: Soulshot (A-Grade)
(21160, 6037, 1, 1, 2, 410775.134396), -- Waking Scroll
(21160, 729, 1, 1, 2, 22.707256), -- Scroll: Enchant Weapon (A-Grade)
(21160, 8730, 1, 1, 2, 2282.079228), -- Life Stone - Level 67
(21160, 8740, 1, 1, 2, 570.738146), -- Mid-Grade Life Stone - Level 67
(21160, 8750, 1, 1, 2, 57.204818), -- High-Grade Life Stone - Level 67
(21160, 8760, 1, 1, 2, 11.353628), -- Top-Grade Life Stone - Level 67
-- Lesser Ancient Soldier
(21161, 3035, 1, 1, -1, 8917), -- Recipe: Spiritshot A
(21161, 5485, 1, 1, -1, 56237), -- Sealed Tallum Tunic Texture
(21161, 4041, 1, 1, -1, 58154), -- Mold Hardener
(21161, 57, 3302, 6724, 0, 700000), -- Adena
(21161, 6324, 1, 1, 1, 81.900233), -- Sealed Phoenix Earring
(21161, 6341, 1, 1, 1, 11382.43141), -- Sealed Phoenix Earring Gemstone
(21161, 6323, 1, 1, 1, 61.416127), -- Sealed Phoenix Necklace
(21161, 6343, 1, 1, 1, 8799.045448), -- Sealed Phoenix Necklace Beads
(21161, 6325, 1, 1, 1, 122.832254), -- Sealed Phoenix Ring
(21161, 6345, 1, 1, 1, 15743.374528), -- Sealed Phoenix Ring Gemstone
(21161, 1871, 1, 1, 2, 224482.756764), -- Charcoal
(21161, 1866, 1, 1, 2, 149655.171176), -- Suede
(21161, 1877, 1, 1, 2, 8979.200342), -- Adamantite Nugget
(21161, 4041, 1, 1, 2, 1952.017144), -- Mold Hardener
(21161, 4040, 1, 1, 2, 4489.796472), -- Mold Lubricant
(21161, 5276, 1, 1, 2, 299.162724), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21161, 8326, 1, 1, 2, 83.231624), -- Recipe: Doom Crusher (60%)
(21161, 8731, 1, 1, 2, 2078.434988), -- Life Stone - Level 70
(21161, 8741, 1, 1, 2, 519.805048), -- Mid-Grade Life Stone - Level 70
(21161, 8751, 1, 1, 2, 51.823464), -- High-Grade Life Stone - Level 70
(21161, 8761, 1, 1, 2, 10.600254), -- Top-Grade Life Stone - Level 70
-- Lesser Ancient Scout
(21162, 5486, 1, 1, -1, 39629), -- Sealed Dark Crystal Robe Fabric
(21162, 3956, 1, 1, -1, 8930), -- Recipe: Blessed Spiritshot A
(21162, 5478, 1, 1, -1, 56317), -- Sealed Dark Crystal Leather Armor Pattern
(21162, 57, 3305, 6737, 0, 700000), -- Adena
(21162, 5297, 1, 1, 1, 30.859074), -- Sealed Dark Crystal Leather Armor
(21162, 5478, 1, 1, 1, 3465.289794), -- Sealed Dark Crystal Leather Armor Pattern
(21162, 5301, 1, 1, 1, 18.982278), -- Sealed Tallum Leather Armor
(21162, 5479, 1, 1, 1, 2438.416062), -- Sealed Tallum Leather Armor Pattern
(21162, 5298, 1, 1, 1, 49.349346), -- Sealed Dark Crystal Leggings
(21162, 5482, 1, 1, 1, 5439.103446), -- Sealed Dark Crystal Leggings Design
(21162, 1873, 1, 1, 2, 89921.50128), -- Silver Nugget
(21162, 1868, 1, 3, 2, 224803.7532), -- Thread
(21162, 1876, 1, 1, 2, 44960.75064), -- Mithril Ore
(21162, 1895, 1, 1, 2, 64229.70636), -- Metallic Fiber
(21162, 4042, 1, 1, 2, 3746.80224), -- Enria
(21162, 1807, 1, 1, 2, 299.67408), -- Recipe: Soulshot (A-Grade)
(21162, 8731, 1, 1, 2, 2081.50812), -- Life Stone - Level 70
(21162, 8741, 1, 1, 2, 520.48656), -- Mid-Grade Life Stone - Level 70
(21162, 8751, 1, 1, 2, 52.13628), -- High-Grade Life Stone - Level 70
(21162, 8761, 1, 1, 2, 10.51488), -- Top-Grade Life Stone - Level 70
(21162, 6036, 1, 1, 2, 7493.16636), -- Greater Magic Haste Potion
-- Lesser Ancient Shaman
(21163, 5480, 1, 1, -1, 31860), -- Sealed Leather Armor of Nightmare Fabric
(21163, 5481, 1, 1, -1, 31860), -- Sealed Majestic Leather Armor Fabric
(21163, 729, 1, 1, -1, 789), -- Scroll: Enchant Weapon (A-Grade)
(21163, 57, 3493, 7152, 0, 700000), -- Adena
(21163, 5291, 1, 1, 1, 73.638936), -- Sealed Dark Crystal Boots
(21163, 5496, 1, 1, 1, 7684.361064), -- Sealed Dark Crystal Boots Lining
(21163, 5296, 1, 1, 1, 73.638936), -- Sealed Tallum Boots
(21163, 5497, 1, 1, 1, 7684.361064), -- Sealed Tallum Boots Lining
(21163, 5290, 1, 1, 1, 73.638936), -- Sealed Dark Crystal Gloves
(21163, 5508, 1, 1, 1, 7684.361064), -- Sealed Dark Crystal Gloves Design
(21163, 5295, 1, 1, 1, 73.638936), -- Sealed Tallum Gloves
(21163, 5509, 1, 1, 1, 7684.361064), -- Sealed Tallum Gloves Design
(21163, 1867, 1, 3, 2, 158882.97502), -- Animal Skin
(21163, 1872, 1, 3, 2, 105921.76072), -- Animal Bone
(21163, 1882, 1, 1, 2, 52960.88036), -- Leather
(21163, 1894, 1, 1, 2, 8362.19154), -- Crafted Leather
(21163, 4042, 1, 1, 2, 3972.2163), -- Enria
(21163, 729, 1, 1, 2, 26.38126), -- Scroll: Enchant Weapon (A-Grade)
(21163, 4987, 1, 1, 2, 988.79634), -- Recipe: Tunic of Doom (60%)
(21163, 8731, 1, 1, 2, 2206.67552), -- Life Stone - Level 70
(21163, 8741, 1, 1, 2, 551.66888), -- Mid-Grade Life Stone - Level 70
(21163, 8751, 1, 1, 2, 55.1001), -- High-Grade Life Stone - Level 70
(21163, 8761, 1, 1, 2, 11.35396), -- Top-Grade Life Stone - Level 70
-- Guardian Spirit of Ancient Holy Ground
(21164, 5487, 1, 1, -1, 36693), -- Sealed Robe of Nightmare Fabric
(21164, 5480, 1, 1, -1, 36564), -- Sealed Leather Armor of Nightmare Fabric
(21164, 5481, 1, 1, -1, 36564), -- Sealed Majestic Leather Armor Fabric
(21164, 57, 4018, 8199, 0, 700000), -- Adena
(21164, 6327, 1, 1, 1, 66.949245), -- Sealed Majestic Earring
(21164, 6342, 1, 1, 1, 11359.619315), -- Sealed Majestic Earring Gemstone
(21164, 6326, 1, 1, 1, 50.20312), -- Sealed Majestic Necklace
(21164, 6344, 1, 1, 1, 7351.30209), -- Sealed Majestic Necklace Beads
(21164, 6328, 1, 1, 1, 100.40624), -- Sealed Majestic Ring
(21164, 6346, 1, 1, 1, 16326.51999), -- Sealed Majestic Ring Gemstone
(21164, 1871, 1, 3, 2, 167148.341884), -- Charcoal
(21164, 1866, 1, 1, 2, 222864.594701), -- Suede
(21164, 1877, 1, 1, 2, 13371.8007), -- Adamantite Nugget
(21164, 4041, 1, 1, 2, 2906.804526), -- Mold Hardener
(21164, 4040, 1, 1, 2, 6685.90035), -- Mold Lubricant
(21164, 729, 1, 1, 2, 37.074463), -- Scroll: Enchant Weapon (A-Grade)
(21164, 8732, 1, 1, 2, 2786.000096), -- Life Stone - Level 76
(21164, 8742, 1, 1, 2, 696.500024), -- Mid-Grade Life Stone - Level 76
(21164, 8752, 1, 1, 2, 69.983256), -- High-Grade Life Stone - Level 76
-- Lesser Ancient Warrior
(21165, 5488, 1, 1, -1, 37883), -- Sealed Majestic Robe Fabric
(21165, 5495, 1, 1, -1, 127745), -- Sealed Shield of Nightmare Fragment
(21165, 730, 1, 1, -1, 7011), -- Scroll: Enchant Armor (A-Grade)
(21165, 57, 4147, 8467, 0, 700000), -- Adena
(21165, 5320, 1, 1, 1, 23.520984), -- Sealed Leather Armor of Nightmare
(21165, 5480, 1, 1, 1, 3484.979016), -- Sealed Leather Armor of Nightmare Fabric
(21165, 5323, 1, 1, 1, 23.520984), -- Sealed Majestic Leather Armor
(21165, 5481, 1, 1, 1, 3484.979016), -- Sealed Majestic Leather Armor Fabric
(21165, 1895, 1, 1, 2, 88748.898255), -- Metallic Fiber
(21165, 4040, 1, 1, 2, 6212.613996), -- Mold Lubricant
(21165, 4042, 1, 1, 2, 5177.17833), -- Enria
(21165, 4043, 1, 1, 2, 10353.931953), -- Asofe
(21165, 730, 1, 1, 2, 258.646563), -- Scroll: Enchant Armor (A-Grade)
(21165, 6037, 1, 3, 2, 310620.931539), -- Waking Scroll
(21165, 729, 1, 1, 2, 34.401267), -- Scroll: Enchant Weapon (A-Grade)
(21165, 8732, 1, 1, 2, 2588.589165), -- Life Stone - Level 76
(21165, 8742, 1, 1, 2, 647.253468), -- Mid-Grade Life Stone - Level 76
(21165, 8752, 1, 1, 2, 64.555464), -- High-Grade Life Stone - Level 76
-- Lith Scout
(21166, 1868, 1, 3, -1, 886728), -- Thread
(21166, 1873, 1, 1, -1, 354691), -- Silver Nugget
(21166, 1898, 1, 1, -1, 91087), -- Blue Diamond Necklace Gem
(21166, 6362, 23, 42, 0, 700000), -- Red Seal Stone
(21166, 6360, 53, 109, 1, 700000), -- Blue Seal Stone
(21166, 25, 1, 1, 2, 713.295372), -- Piece Bone Breastplate
(21166, 1926, 1, 1, 2, 8818.976021), -- Piece Bone Breastplate Fragment
(21166, 26, 1, 1, 2, 461.708982), -- Bronze Breastplate
(21166, 32, 1, 1, 2, 1141.287351), -- Piece Bone Gaiters
(21166, 1928, 1, 1, 2, 12717.827276), -- Piece Bone Gaiters Fragment
(21166, 34, 1, 1, 2, 739.904998), -- Bronze Gaiters
(21166, 1868, 1, 3, 3, 130962.642108), -- Thread
(21166, 1873, 1, 1, 3, 52385.256834), -- Silver Nugget
(21166, 2176, 1, 1, 3, 62661.450774), -- Recipe: Leather Boots
(21166, 6037, 1, 3, 3, 87308.650284), -- Waking Scroll
-- Lith Witch
(21167, 1804, 1, 1, -1, 39326), -- Recipe: Soulshot (D-Grade)
(21167, 1926, 1, 1, -1, 99308), -- Piece Bone Breastplate Fragment
(21167, 2151, 1, 1, -1, 273857), -- Recipe: Necklace of Devotion
(21167, 6362, 21, 39, 0, 700000), -- Red Seal Stone
(21167, 6360, 72, 143, 1, 700000), -- Blue Seal Stone
(21167, 1102, 1, 1, 2, 2045.290996), -- Tunic of Magic
(21167, 1105, 1, 1, 2, 3281.709004), -- Stockings of Magic
(21167, 1867, 1, 1, 3, 193604.579046), -- Animal Skin
(21167, 1872, 1, 1, 3, 193604.579046), -- Animal Bone
(21167, 1882, 1, 1, 3, 32267.285982), -- Leather
(21167, 735, 1, 1, 3, 12100.555926), -- Alacrity Potion
-- Lith Warrior
(21168, 1899, 1, 1, -1, 184636), -- Necklace of Devotion Chain
(21168, 5549, 1, 1, -1, 118167), -- Metallic Thread
(21168, 1889, 1, 1, -1, 78778), -- Compound Braid
(21168, 6362, 22, 41, 0, 700000), -- Red Seal Stone
(21168, 6360, 97, 190, 1, 700000), -- Blue Seal Stone
(21168, 847, 1, 1, 2, 1601.894656), -- Red Crescent Earring
(21168, 910, 1, 1, 2, 1201.420992), -- Necklace of Devotion
(21168, 1899, 1, 1, 2, 25905.811256), -- Necklace of Devotion Chain
(21168, 890, 1, 1, 2, 2402.873096), -- Ring of Devotion
(21168, 1868, 1, 3, 3, 110531.493468), -- Thread
(21168, 1873, 1, 1, 3, 44212.518198), -- Silver Nugget
(21168, 5549, 1, 1, 3, 11053.228536), -- Metallic Thread
(21168, 1889, 1, 1, 3, 7368.951006), -- Compound Braid
(21168, 2262, 1, 1, 3, 1716.42591), -- Recipe: Elven Bow
(21168, 6037, 1, 1, 3, 221063.382882), -- Waking Scroll
-- Lith Guard
(21169, 1061, 1, 1, -1, 881783), -- Greater Healing Potion
(21169, 1900, 1, 1, -1, 159184), -- Enchanted Necklace Chain
(21169, 2153, 1, 1, -1, 226274), -- Recipe: Tiger's Eye Earring
(21169, 6362, 24, 44, 0, 700000), -- Red Seal Stone
(21169, 6360, 128, 259, 1, 700000), -- Blue Seal Stone
(21169, 1123, 1, 1, 2, 3105.5), -- Blue Buckskin Boots
(21169, 605, 1, 1, 2, 3105.5), -- Leather Gauntlets
(21169, 1869, 1, 1, 3, 159014.14578), -- Iron Ore
(21169, 1864, 1, 3, 3, 159014.14578), -- Stem
(21169, 1880, 1, 1, 3, 15901.3785), -- Steel
(21169, 5550, 1, 1, 3, 2120.30406), -- Durable Metal Plate
(21169, 2153, 1, 1, 3, 24730.02588), -- Recipe: Tiger's Eye Earring
-- Lith Medium
(21170, 1901, 1, 1, -1, 222980), -- Tiger's Eye Earring Stone
(21170, 2154, 1, 1, -1, 172845), -- Recipe: Elven Earring
(21170, 1938, 1, 1, -1, 108529), -- Mithril Banded Mail Material
(21170, 6362, 22, 41, 0, 700000), -- Red Seal Stone
(21170, 6361, 33, 63, 1, 700000), -- Green Seal Stone
(21170, 6360, 108, 211, 2, 700000), -- Blue Seal Stone
(21170, 628, 1, 1, 3, 2093.359974), -- Hoplon
(21170, 47, 1, 1, 3, 1464.640026), -- Helmet
(21170, 1869, 1, 1, 4, 143058.140368), -- Iron Ore
(21170, 1864, 1, 1, 4, 286116.280736), -- Stem
(21170, 1880, 1, 1, 4, 14305.862064), -- Steel
(21170, 5550, 1, 1, 4, 1907.640384), -- Durable Metal Plate
(21170, 2155, 1, 1, 4, 22962.764864), -- Recipe: Elven Ring
(21170, 6035, 1, 1, 4, 11921.311584), -- Magic Haste Potion
-- Lith Overlord
(21171, 1870, 1, 5, -1, 684631), -- Coal
(21171, 1865, 1, 5, -1, 684631), -- Varnish
(21171, 1939, 1, 1, -1, 180403), -- Mithril Banded Gaiters Material
(21171, 6362, 24, 44, 0, 700000), -- Red Seal Stone
(21171, 6361, 68, 136, 1, 700000), -- Green Seal Stone
(21171, 6360, 96, 192, 2, 700000), -- Blue Seal Stone
(21171, 83, 1, 1, 3, 66.0972), -- Sword of Magic
(21171, 144, 1, 1, 3, 66.0972), -- Sword of Occult
(21171, 124, 1, 1, 3, 48.96528), -- Two-Handed Sword
(21171, 2026, 1, 1, 3, 2190.90729), -- Two-Handed Sword Edge
(21171, 127, 1, 1, 3, 48.96528), -- Crimson Sword
(21171, 130, 1, 1, 3, 48.96775), -- Elven Sword
(21171, 1870, 1, 3, 4, 136504.928575), -- Coal
(21171, 1865, 1, 1, 4, 273009.85715), -- Varnish
(21171, 1874, 1, 1, 4, 18200.502389), -- Oriharukon Ore
(21171, 2191, 1, 1, 4, 36547.711886), -- Recipe: RIP Gauntlets
-- Lith Patrolman
(21172, 1825, 1, 1, -1, 172903), -- Recipe: Oriharukon
(21172, 1902, 1, 1, -1, 245252), -- Elven Earring Beads
(21172, 2145, 1, 1, -1, 172903), -- Recipe: Mithril Alloy
(21172, 6362, 24, 45, 0, 700000), -- Red Seal Stone
(21172, 6361, 105, 206, 1, 700000), -- Green Seal Stone
(21172, 6360, 89, 178, 2, 700000), -- Blue Seal Stone
(21172, 88, 1, 1, 3, 23.302164), -- Morning Star
(21172, 2031, 1, 1, 3, 1266.576573), -- Morning Star Head
(21172, 90, 1, 1, 3, 23.302164), -- Goat Head Staff
(21172, 2032, 1, 1, 3, 1156.201905), -- Goat Head Staff Head
(21172, 158, 1, 1, 3, 23.302164), -- Tarbar
(21172, 2035, 1, 1, 3, 1266.576573), -- Tarbar Head
(21172, 169, 1, 1, 3, 23.302164), -- Skull Breaker
(21172, 2036, 1, 1, 3, 1266.576573), -- Skull Breaker Head
(21172, 172, 1, 1, 3, 23.302164), -- Heavy Bone Club
(21172, 2037, 1, 1, 3, 1266.557556), -- Heavy Bone Club Head
(21172, 1871, 2, 6, 4, 62564.106297), -- Charcoal
(21172, 1866, 1, 1, 4, 166837.616792), -- Suede
(21172, 1877, 1, 1, 4, 10010.225302), -- Adamantite Nugget
(21172, 2147, 1, 1, 4, 17875.572176), -- Recipe: Blacksmith's frame
(21172, 1341, 60, 180, 4, 139031.479433), -- Bone Arrow
-- Lith Shaman
(21173, 1905, 1, 1, -1, 252534), -- Omen Beast's Eye Earring Gemstone
(21173, 1881, 1, 1, -1, 346140), -- Coarse Bone Powder
(21173, 1875, 1, 1, -1, 173070), -- Stone of Purity
(21173, 6362, 22, 41, 0, 700000), -- Red Seal Stone
(21173, 6361, 137, 274, 1, 700000), -- Green Seal Stone
(21173, 6360, 56, 111, 2, 700000), -- Blue Seal Stone
(21173, 262, 1, 1, 3, 93.99576), -- Scallop Jamadhr
(21173, 2053, 1, 1, 3, 5390.00424), -- Scallop Jamadhr Edge
(21173, 1872, 1, 1, 4, 217269.16134), -- Animal Bone
(21173, 1867, 1, 1, 4, 217269.16134), -- Animal Skin
(21173, 1881, 1, 1, 4, 21726.77016), -- Coarse Bone Powder
(21173, 1875, 1, 1, 4, 10863.38508), -- Stone of Purity
(21173, 1805, 1, 1, 4, 543.02328), -- Recipe: Soulshot (C-Grade)
(21173, 2990, 1, 1, 4, 12932.80982), -- Recipe: Chain Boots
(21173, 5164, 1, 1, 4, 543.02328), -- Recipe: Blessed Spiritshot (C) Compressed Package (100%)
(21173, 6036, 1, 1, 4, 5432.6657), -- Greater Magic Haste Potion
-- Lith Commander
(21174, 1908, 1, 1, -1, 316239), -- Moonstone Earring Wire
(21174, 2163, 1, 1, -1, 170382), -- Recipe: Earring of Protection
(21174, 1873, 1, 3, -1, 667898), -- Silver Nugget
(21174, 6362, 25, 45, 0, 700000), -- Red Seal Stone
(21174, 6361, 211, 425, 1, 700000), -- Green Seal Stone
(21174, 6360, 33, 62, 2, 700000), -- Blue Seal Stone
(21174, 281, 1, 1, 3, 89.529435), -- Crystallized Ice Bow
(21174, 2074, 1, 1, 3, 5589.470565), -- Crystallized Ice Bow Shaft
(21174, 1873, 1, 1, 4, 90188.18376), -- Silver Nugget
(21174, 1868, 1, 3, 4, 225470.91968), -- Thread
(21174, 1876, 1, 1, 4, 45094.09188), -- Mithril Ore
(21174, 1895, 1, 1, 4, 64420.32852), -- Metallic Fiber
(21174, 4042, 1, 1, 4, 3757.72592), -- Enria
(21174, 2164, 1, 1, 4, 17343.81068), -- Recipe: Ring of Protection
(21174, 3002, 1, 1, 4, 14004.93956), -- Recipe: Dwarven Chain Gloves
-- Lilim Butcher
(21175, 440, 1, 1, -1, 1258), -- Robe of Seal
(21175, 1912, 1, 1, -1, 409204), -- Ring of Protection Gemstone
(21175, 4590, 1, 1, -1, 12658), -- Greater Dye of STR (Str+2 Dex-2)
(21175, 6362, 25, 45, 0, 700000), -- Red Seal Stone
(21175, 6361, 268, 532, 1, 700000), -- Green Seal Stone
(21175, 227, 1, 1, 2, 38.069854), -- Stiletto
(21175, 2083, 1, 1, 2, 2794.930146), -- Stiletto Edge
(21175, 242, 1, 1, 2, 38.069854), -- Soulfire Dirk
(21175, 2084, 1, 1, 2, 2794.930146), -- Soulfire Dirk Blade
(21175, 1871, 1, 3, 3, 80121.356916), -- Charcoal
(21175, 1866, 1, 1, 3, 160242.216156), -- Suede
(21175, 1877, 1, 1, 3, 9614.602644), -- Adamantite Nugget
(21175, 4041, 1, 1, 3, 2090.2392), -- Mold Hardener
(21175, 4040, 1, 1, 3, 4807.052484), -- Mold Lubricant
(21175, 951, 1, 1, 3, 436.959528), -- Scroll: Enchant Weapon (C-Grade)
(21175, 6037, 1, 3, 3, 240363.573072), -- Waking Scroll
-- Lilim Magus
(21176, 4041, 1, 1, -1, 33616), -- Mold Hardener
(21176, 1872, 1, 11, -1, 859080), -- Animal Bone
(21176, 4601, 1, 1, -1, 8591), -- Greater Dye of STR (Str+3 Con-3)
(21176, 6362, 11, 22, 0, 700000), -- Red Seal Stone
(21176, 6361, 219, 437, 1, 700000), -- Green Seal Stone
(21176, 6360, 133, 267, 2, 700000), -- Blue Seal Stone
(21176, 326, 1, 1, 3, 48.377142), -- Heathen's Book
(21176, 2110, 1, 1, 3, 4505.622858), -- Heathen's Book Page
(21176, 1864, 4, 12, 4, 57095.68895), -- Stem
(21176, 1865, 2, 6, 4, 45676.55116), -- Varnish
(21176, 1866, 3, 9, 4, 25375.81983), -- Suede
(21176, 1873, 1, 1, 4, 91353.10232), -- Silver Nugget
(21176, 1868, 1, 3, 4, 152255.29631), -- Thread
(21176, 2232, 1, 1, 4, 1312.73107), -- Recipe: Drake Leather Armor
(21176, 3012, 1, 1, 4, 4260.81036), -- Recipe: Full Plate Helmet
-- Lilim Knight-Errant
(21177, 4594, 1, 1, -1, 17584), -- Greater Dye of DEX (Dex+2 Con-2)
(21177, 1806, 1, 1, -1, 10550), -- Recipe: Soulshot (B-Grade)
(21177, 1920, 1, 1, -1, 180500), -- Necklace of Seal Chain
(21177, 6362, 13, 27, 0, 700000), -- Red Seal Stone
(21177, 6361, 314, 633, 1, 700000), -- Green Seal Stone
(21177, 6360, 148, 301, 2, 700000), -- Blue Seal Stone
(21177, 301, 1, 1, 3, 17.6528), -- Scorpion
(21177, 2113, 1, 1, 3, 1572.085625), -- Scorpion Blade
(21177, 303, 1, 1, 3, 17.6528), -- Widow Maker
(21177, 2114, 1, 1, 3, 1572.085625), -- Widowmaker Head
(21177, 299, 1, 1, 3, 13.77255), -- Orcish Poleaxe
(21177, 2122, 1, 1, 3, 1481.7506), -- Orcish Poleaxe Blade
(21177, 1873, 1, 1, 4, 97386.731248), -- Silver Nugget
(21177, 1868, 1, 3, 4, 243466.595568), -- Thread
(21177, 1876, 1, 1, 4, 48693.133072), -- Mithril Ore
(21177, 1895, 1, 1, 4, 69561.884448), -- Metallic Fiber
(21177, 4042, 1, 1, 4, 4057.567296), -- Enria
(21177, 3034, 1, 1, 4, 486.963888), -- Recipe: Spiritshot B
(21177, 4944, 1, 1, 4, 1170.666768), -- Recipe: Avadon Breastplate (60%)
(21177, 4968, 1, 1, 4, 280.457712), -- Recipe: Kris (60%)
-- Lilim Marauder
(21178, 4129, 1, 1, -1, 61196), -- Recipe: Earrings of Black Ore (100%)
(21178, 4610, 1, 1, -1, 12566), -- Greater Dye of MEN (Men+3 Wit-3)
(21178, 947, 1, 1, -1, 2262), -- Scroll: Enchant Weapon (B-Grade)
(21178, 6362, 13, 26, 0, 700000), -- Red Seal Stone
(21178, 6361, 391, 782, 1, 700000), -- Green Seal Stone
(21178, 6360, 73, 146, 2, 700000), -- Blue Seal Stone
(21178, 2384, 1, 1, 3, 46.513225), -- Zubei's Leather Shirt
(21178, 4066, 1, 1, 3, 6564.6867), -- Zubei's Leather Shirt Fabric
(21178, 2390, 1, 1, 3, 28.611825), -- Avadon Leather Armor
(21178, 4068, 1, 1, 3, 5043.306675), -- Avadon Leather Armor Lining
(21178, 2388, 1, 1, 3, 74.42985), -- Zubei's Leather Gaiters
(21178, 4067, 1, 1, 3, 9967.451725), -- Zubei's Leather Gaiter Texture
(21178, 1872, 1, 3, 4, 139188.904008), -- Animal Bone
(21178, 1867, 1, 1, 4, 278377.34533), -- Animal Skin
(21178, 1881, 1, 1, 4, 27837.965876), -- Coarse Bone Powder
(21178, 1875, 1, 1, 4, 13918.982938), -- Stone of Purity
(21178, 4041, 1, 1, 4, 1815.579864), -- Mold Hardener
(21178, 948, 1, 1, 4, 521.909808), -- Scroll: Enchant Armor (B-Grade)
(21178, 4162, 1, 1, 4, 866.148192), -- Recipe: Tunic of Doom (100%)
(21178, 5003, 1, 1, 4, 159.163984), -- Recipe: Art of Battle Axe (60%)
-- Lilim Priest
(21179, 4613, 1, 1, -1, 7498), -- Greater Dye of STR (Str+4 Con-4)
(21179, 947, 1, 1, -1, 2174), -- Scroll: Enchant Weapon (B-Grade)
(21179, 1872, 1, 15, -1, 906001), -- Animal Bone
(21179, 6362, 11, 22, 0, 700000), -- Red Seal Stone
(21179, 6361, 415, 830, 1, 700000), -- Green Seal Stone
(21179, 6360, 7, 15, 2, 700000), -- Blue Seal Stone
(21179, 357, 1, 1, 3, 25.15185), -- Zubei's Breastplate
(21179, 4056, 1, 1, 3, 3633.957919), -- Zubei's Breastplate Part
(21179, 2376, 1, 1, 3, 25.15185), -- Avadon Breastplate
(21179, 4064, 1, 1, 3, 3633.957919), -- Avadon Breastplate Part
(21179, 383, 1, 1, 3, 40.24296), -- Zubei's Gaiters
(21179, 4057, 1, 1, 3, 5616.12864), -- Zubei's Gaiter Material
(21179, 2379, 1, 1, 3, 40.24296), -- Avadon Gaiters
(21179, 4065, 1, 1, 3, 5616.165902), -- Avadon Gaiters Material
(21179, 1872, 1, 3, 4, 101949.964025), -- Animal Bone
(21179, 1867, 2, 6, 4, 76462.57073), -- Animal Skin
(21179, 1881, 1, 1, 4, 30584.793785), -- Coarse Bone Powder
(21179, 1875, 1, 1, 4, 15292.592315), -- Stone of Purity
(21179, 4041, 1, 1, 4, 1994.482035), -- Mold Hardener
(21179, 4155, 1, 1, 4, 712.510435), -- Recipe: Blue Wolf Breastplate (100%)
(21179, 1343, 20, 60, 4, 163848.086675), -- Silver Arrow
-- Lilim Knight
(21180, 4052, 1, 1, -1, 271551), -- Earring of Black Ore Piece
(21180, 5230, 1, 1, -1, 10227), -- Recipe: Mithril Arrow (100%)
(21180, 4053, 1, 1, -1, 328759), -- Ring of Black Ore Gemstone
(21180, 6362, 14, 28, 0, 700000), -- Red Seal Stone
(21180, 6361, 574, 1144, 1, 700000), -- Green Seal Stone
(21180, 2398, 1, 1, 2, 30.501009), -- Blue Wolf Tunic
(21180, 4084, 1, 1, 2, 4923.408096), -- Blue Wolf Tunic Fabric
(21180, 2399, 1, 1, 2, 30.501009), -- Tunic of Doom
(21180, 4085, 1, 1, 2, 4923.408096), -- Tunic of Doom Pattern
(21180, 2403, 1, 1, 2, 48.838896), -- Blue Wolf Stockings
(21180, 4086, 1, 1, 2, 6647.728698), -- Blue Wolf Stockings Pattern
(21180, 2404, 1, 1, 2, 48.838896), -- Stockings of Doom
(21180, 4087, 1, 1, 2, 6647.7753), -- Stockings of Doom Pattern
(21180, 1871, 1, 3, 3, 188798.808672), -- Charcoal
(21180, 1866, 1, 3, 3, 83910.431736), -- Suede
(21180, 1877, 1, 1, 3, 15104.120544), -- Adamantite Nugget
(21180, 4041, 1, 1, 3, 3283.621776), -- Mold Hardener
(21180, 4040, 1, 1, 3, 7552.060272), -- Mold Lubricant
(21180, 1830, 1, 1, 3, 151038.957), -- Scroll of Escape: Castle
-- Lilim Assassin
(21181, 5230, 1, 1, -1, 10851), -- Recipe: Mithril Arrow (100%)
(21181, 4054, 1, 1, -1, 160289), -- Necklace of Black Ore Beads
(21181, 4041, 1, 1, -1, 70764), -- Mold Hardener
(21181, 6362, 14, 27, 0, 700000), -- Red Seal Stone
(21181, 6361, 578, 1160, 1, 700000), -- Green Seal Stone
(21181, 864, 1, 1, 2, 112.69614), -- Earring of Black Ore
(21181, 4052, 1, 1, 2, 14183.47272), -- Earring of Black Ore Piece
(21181, 926, 1, 1, 2, 84.532008), -- Necklace of Black Ore
(21181, 4054, 1, 1, 2, 7890.7104), -- Necklace of Black Ore Beads
(21181, 895, 1, 1, 2, 169.024404), -- Ring of Black Ore
(21181, 4053, 1, 1, 2, 17171.564328), -- Ring of Black Ore Gemstone
(21181, 1872, 1, 3, 3, 228933.690628), -- Animal Bone
(21181, 1867, 1, 3, 3, 152622.611798), -- Animal Skin
(21181, 1881, 1, 1, 3, 45786.647298), -- Coarse Bone Powder
(21181, 1875, 1, 1, 3, 22893.550718), -- Stone of Purity
(21181, 4041, 1, 1, 3, 2985.95735), -- Mold Hardener
(21181, 5230, 1, 1, 3, 457.771104), -- Recipe: Mithril Arrow (100%)
(21181, 5276, 1, 1, 3, 457.771104), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
-- Lilim Soldier
(21182, 1876, 1, 3, -1, 736136), -- Mithril Ore
(21182, 5478, 1, 1, -1, 61902), -- Sealed Dark Crystal Leather Armor Pattern
(21182, 6362, 11, 22, 0, 700000), -- Red Seal Stone
(21182, 6361, 512, 1023, 1, 700000), -- Green Seal Stone
(21182, 5291, 1, 1, 2, 61.078647), -- Sealed Dark Crystal Boots
(21182, 5496, 1, 1, 2, 6373.671353), -- Sealed Dark Crystal Boots Lining
(21182, 5296, 1, 1, 2, 61.078647), -- Sealed Tallum Boots
(21182, 5497, 1, 1, 2, 6373.671353), -- Sealed Tallum Boots Lining
(21182, 5290, 1, 1, 2, 61.078647), -- Sealed Dark Crystal Gloves
(21182, 5508, 1, 1, 2, 6373.671353), -- Sealed Dark Crystal Gloves Design
(21182, 5295, 1, 1, 2, 61.078647), -- Sealed Tallum Gloves
(21182, 5509, 1, 1, 2, 6373.671353), -- Sealed Tallum Gloves Design
(21182, 1873, 1, 1, 3, 124253.288295), -- Silver Nugget
(21182, 1868, 4, 12, 3, 77658.366161), -- Thread
(21182, 1876, 1, 1, 3, 62126.888054), -- Mithril Ore
(21182, 1895, 1, 1, 3, 88752.209407), -- Metallic Fiber
(21182, 4042, 1, 1, 3, 5177.159369), -- Enria
(21182, 5156, 1, 1, 3, 414.153237), -- Recipe: Soulshot (A) Compressed Package (100%)
(21182, 1344, 30, 90, 3, 129430.935477), -- Mithril Arrow
-- Lilim Knight Commander
(21183, 1807, 1, 1, -1, 10950), -- Recipe: Soulshot (A-Grade)
(21183, 5479, 1, 1, -1, 48593), -- Sealed Tallum Leather Armor Pattern
(21183, 3035, 1, 1, -1, 10950), -- Recipe: Spiritshot A
(21183, 6362, 14, 28, 0, 700000), -- Red Seal Stone
(21183, 6361, 687, 1380, 1, 700000), -- Green Seal Stone
(21183, 5292, 1, 1, 2, 108.0996), -- Sealed Dark Crystal Shield
(21183, 5494, 1, 1, 2, 10612.704725), -- Sealed Dark Crystal Shield Fragment
(21183, 5289, 1, 1, 2, 75.643225), -- Sealed Dark Crystal Helmet
(21183, 5525, 1, 1, 2, 7811.46786), -- Sealed Dark Crystal Helmet Design
(21183, 5294, 1, 1, 2, 75.643225), -- Sealed Tallum Helmet
(21183, 5526, 1, 1, 2, 7811.441365), -- Sealed Tallum Helm Design
(21183, 1894, 1, 1, 3, 21278.91699), -- Crafted Leather
(21183, 4039, 1, 1, 3, 20215.005036), -- Mold Glue
(21183, 4041, 1, 1, 3, 5273.46189), -- Mold Hardener
(21183, 4044, 1, 1, 3, 20215.005036), -- Thons
(21183, 5156, 1, 1, 3, 808.611048), -- Recipe: Soulshot (A) Compressed Package (100%)
-- Lilim Slayer
(21184, 5480, 1, 1, -1, 38649), -- Sealed Leather Armor of Nightmare Fabric
(21184, 729, 1, 1, -1, 957), -- Scroll: Enchant Weapon (A-Grade)
(21184, 1895, 1, 5, -1, 820300), -- Metallic Fiber
(21184, 6362, 14, 27, 0, 700000), -- Red Seal Stone
(21184, 6361, 700, 1400, 1, 700000), -- Green Seal Stone
(21184, 5304, 1, 1, 2, 39.689052), -- Sealed Tallum Tunic
(21184, 5485, 1, 1, 2, 4456.843612), -- Sealed Tallum Tunic Texture
(21184, 5308, 1, 1, 2, 24.413844), -- Sealed Dark Crystal Robe
(21184, 5486, 1, 1, 2, 3136.141476), -- Sealed Dark Crystal Robe Fabric
(21184, 5305, 1, 1, 2, 63.470108), -- Sealed Tallum Stockings
(21184, 5489, 1, 1, 2, 6995.441908), -- Sealed Tallum Stockings Fabric
(21184, 1867, 1, 3, 3, 192741.596432), -- Animal Skin
(21184, 1872, 1, 3, 3, 128494.127552), -- Animal Bone
(21184, 1882, 1, 1, 3, 64247.063776), -- Leather
(21184, 1894, 1, 1, 3, 10144.209264), -- Crafted Leather
(21184, 4042, 1, 1, 3, 4818.71208), -- Enria
(21184, 729, 1, 1, 3, 32.003216), -- Scroll: Enchant Weapon (A-Grade)
(21184, 4987, 1, 1, 3, 1199.512944), -- Recipe: Tunic of Doom (60%)
(21184, 8731, 1, 1, 3, 2676.927232), -- Life Stone - Level 70
(21184, 8741, 1, 1, 3, 669.231808), -- Mid-Grade Life Stone - Level 70
(21184, 8751, 1, 1, 3, 66.84216), -- High-Grade Life Stone - Level 70
(21184, 8761, 1, 1, 3, 13.773536), -- Top-Grade Life Stone - Level 70
-- Lilim Great Magus
(21185, 1875, 1, 1, -1, 513582), -- Stone of Purity
(21185, 5481, 1, 1, -1, 34568), -- Sealed Majestic Leather Armor Fabric
(21185, 5487, 1, 1, -1, 34691), -- Sealed Robe of Nightmare Fabric
(21185, 6362, 11, 22, 0, 700000), -- Red Seal Stone
(21185, 6361, 612, 1227, 1, 700000), -- Green Seal Stone
(21185, 5304, 1, 1, 2, 35.497914), -- Sealed Tallum Tunic
(21185, 5485, 1, 1, 2, 3986.203834), -- Sealed Tallum Tunic Texture
(21185, 5308, 1, 1, 2, 21.835758), -- Sealed Dark Crystal Robe
(21185, 5486, 1, 1, 2, 2804.966982), -- Sealed Dark Crystal Robe Fabric
(21185, 5305, 1, 1, 2, 56.767706), -- Sealed Tallum Stockings
(21185, 5489, 1, 1, 2, 6256.727806), -- Sealed Tallum Stockings Fabric
(21185, 1873, 1, 1, 3, 113778.029204), -- Silver Nugget
(21185, 1868, 3, 9, 3, 94814.895588), -- Thread
(21185, 1876, 1, 1, 3, 56889.014602), -- Mithril Ore
(21185, 1895, 1, 1, 3, 81270.02086), -- Metallic Fiber
(21185, 4042, 1, 1, 3, 4740.783404), -- Enria
(21185, 5282, 1, 1, 3, 126.302442), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21185, 6671, 1, 1, 3, 31604.965196), -- Deluxe Chest Key - Grade 7
(21185, 8732, 1, 1, 3, 2370.391702), -- Life Stone - Level 76
(21185, 8742, 1, 1, 3, 592.501364), -- Mid-Grade Life Stone - Level 76
(21185, 8752, 1, 1, 3, 59.095638), -- High-Grade Life Stone - Level 76
-- Lilim Guard Knight
(21186, 5488, 1, 1, -1, 46584), -- Sealed Majestic Robe Fabric
(21186, 730, 1, 1, -1, 8621), -- Scroll: Enchant Armor (A-Grade)
(21186, 5480, 1, 1, -1, 46420), -- Sealed Leather Armor of Nightmare Fabric
(21186, 6362, 14, 28, 0, 700000), -- Red Seal Stone
(21186, 6361, 805, 1610, 1, 700000), -- Green Seal Stone
(21186, 5315, 1, 1, 2, 89.538834), -- Sealed Shield of Nightmare
(21186, 5495, 1, 1, 2, 9665.951834), -- Sealed Shield of Nightmare Fragment
(21186, 5312, 1, 1, 2, 62.654592), -- Sealed Helm of Nightmare
(21186, 5527, 1, 1, 2, 7610.600074), -- Sealed Helm of Nightmare Design
(21186, 5317, 1, 1, 2, 62.654592), -- Sealed Majestic Circlet
(21186, 5528, 1, 1, 2, 7610.600074), -- Sealed Majestic Circlet Design
(21186, 1871, 4, 12, 3, 79576.53054), -- Charcoal
(21186, 1866, 1, 3, 3, 141469.358199), -- Suede
(21186, 1877, 1, 1, 3, 25464.436803), -- Adamantite Nugget
(21186, 4041, 1, 1, 3, 5535.873798), -- Mold Hardener
(21186, 4040, 1, 1, 3, 12732.350826), -- Mold Lubricant
(21186, 729, 1, 1, 3, 70.449834), -- Scroll: Enchant Weapon (A-Grade)
-- Gigant Slave
(21187, 1868, 1, 3, -1, 886728), -- Thread
(21187, 1873, 1, 1, -1, 354691), -- Silver Nugget
(21187, 1898, 1, 1, -1, 91087), -- Blue Diamond Necklace Gem
(21187, 6362, 23, 42, 0, 700000), -- Red Seal Stone
(21187, 6360, 53, 109, 1, 700000), -- Blue Seal Stone
(21187, 25, 1, 1, 2, 713.295372), -- Piece Bone Breastplate
(21187, 1926, 1, 1, 2, 8818.976021), -- Piece Bone Breastplate Fragment
(21187, 26, 1, 1, 2, 461.708982), -- Bronze Breastplate
(21187, 32, 1, 1, 2, 1141.287351), -- Piece Bone Gaiters
(21187, 1928, 1, 1, 2, 12717.827276), -- Piece Bone Gaiters Fragment
(21187, 34, 1, 1, 2, 739.904998), -- Bronze Gaiters
(21187, 1868, 1, 1, 3, 261925.83979), -- Thread
(21187, 1873, 1, 1, 3, 52385.167958), -- Silver Nugget
(21187, 2176, 1, 1, 3, 62661.819642), -- Recipe: Leather Boots
(21187, 6035, 1, 1, 3, 10913.17261), -- Magic Haste Potion
-- Gigant Acolyte
(21188, 1804, 1, 1, -1, 39326), -- Recipe: Soulshot (D-Grade)
(21188, 1926, 1, 1, -1, 99308), -- Piece Bone Breastplate Fragment
(21188, 2151, 1, 1, -1, 273857), -- Recipe: Necklace of Devotion
(21188, 6362, 21, 39, 0, 700000), -- Red Seal Stone
(21188, 6360, 72, 143, 1, 700000), -- Blue Seal Stone
(21188, 1102, 1, 1, 2, 2045.290996), -- Tunic of Magic
(21188, 1105, 1, 1, 2, 3281.709004), -- Stockings of Magic
(21188, 1867, 1, 1, 3, 193604.579046), -- Animal Skin
(21188, 1872, 1, 1, 3, 193604.579046), -- Animal Bone
(21188, 1882, 1, 1, 3, 32267.285982), -- Leather
(21188, 735, 1, 1, 3, 12100.555926), -- Alacrity Potion
-- Gigant Overseer
(21189, 1899, 1, 1, -1, 184636), -- Necklace of Devotion Chain
(21189, 5549, 1, 1, -1, 118167), -- Metallic Thread
(21189, 1889, 1, 1, -1, 78778), -- Compound Braid
(21189, 6362, 22, 41, 0, 700000), -- Red Seal Stone
(21189, 6360, 97, 190, 1, 700000), -- Blue Seal Stone
(21189, 847, 1, 1, 2, 1601.894656), -- Red Crescent Earring
(21189, 910, 1, 1, 2, 1201.420992), -- Necklace of Devotion
(21189, 1899, 1, 1, 2, 25905.811256), -- Necklace of Devotion Chain
(21189, 890, 1, 1, 2, 2402.873096), -- Ring of Devotion
(21189, 1868, 1, 1, 3, 265275.913895), -- Thread
(21189, 1873, 1, 1, 3, 53055.182779), -- Silver Nugget
(21189, 5549, 1, 1, 3, 13263.881319), -- Metallic Thread
(21189, 1889, 1, 1, 3, 8842.587546), -- Compound Braid
(21189, 2262, 1, 1, 3, 2059.434461), -- Recipe: Elven Bow
-- Gigant Footman
(21190, 1061, 1, 1, -1, 881783), -- Greater Healing Potion
(21190, 1900, 1, 1, -1, 159184), -- Enchanted Necklace Chain
(21190, 2153, 1, 1, -1, 226274), -- Recipe: Tiger's Eye Earring
(21190, 6362, 24, 44, 0, 700000), -- Red Seal Stone
(21190, 6360, 128, 259, 1, 700000), -- Blue Seal Stone
(21190, 1123, 1, 1, 2, 3105.5), -- Blue Buckskin Boots
(21190, 605, 1, 1, 2, 3105.5), -- Leather Gauntlets
(21190, 1869, 1, 1, 3, 132511.529539), -- Iron Ore
(21190, 1864, 1, 1, 3, 265022.614875), -- Stem
(21190, 1880, 1, 1, 3, 13251.019693), -- Steel
(21190, 5550, 1, 1, 3, 1767.039534), -- Durable Metal Plate
(21190, 2153, 1, 1, 3, 20608.353982), -- Recipe: Tiger's Eye Earring
(21190, 6035, 1, 1, 3, 11042.442377), -- Magic Haste Potion
-- Gigant Cleric
(21191, 1901, 1, 1, -1, 222980), -- Tiger's Eye Earring Stone
(21191, 2154, 1, 1, -1, 172845), -- Recipe: Elven Earring
(21191, 1938, 1, 1, -1, 108529), -- Mithril Banded Mail Material
(21191, 6362, 22, 41, 0, 700000), -- Red Seal Stone
(21191, 6361, 33, 63, 1, 700000), -- Green Seal Stone
(21191, 6360, 108, 211, 2, 700000), -- Blue Seal Stone
(21191, 628, 1, 1, 3, 2093.359974), -- Hoplon
(21191, 47, 1, 1, 3, 1464.640026), -- Helmet
(21191, 1869, 1, 1, 4, 171669.733833), -- Iron Ore
(21191, 1864, 1, 3, 4, 171669.733833), -- Stem
(21191, 1880, 1, 1, 4, 17166.856278), -- Steel
(21191, 5550, 1, 1, 4, 2289.018264), -- Durable Metal Plate
(21191, 2155, 1, 1, 4, 27555.657792), -- Recipe: Elven Ring
-- Gigant Officer
(21192, 1870, 1, 5, -1, 684631), -- Coal
(21192, 1865, 1, 5, -1, 684631), -- Varnish
(21192, 1939, 1, 1, -1, 180403), -- Mithril Banded Gaiters Material
(21192, 6362, 24, 44, 0, 700000), -- Red Seal Stone
(21192, 6361, 68, 136, 1, 700000), -- Green Seal Stone
(21192, 6360, 96, 192, 2, 700000), -- Blue Seal Stone
(21192, 83, 1, 1, 3, 66.0972), -- Sword of Magic
(21192, 144, 1, 1, 3, 66.0972), -- Sword of Occult
(21192, 124, 1, 1, 3, 48.96528), -- Two-Handed Sword
(21192, 2026, 1, 1, 3, 2190.90729), -- Two-Handed Sword Edge
(21192, 127, 1, 1, 3, 48.96528), -- Crimson Sword
(21192, 130, 1, 1, 3, 48.96775), -- Elven Sword
(21192, 1870, 1, 1, 4, 218407.94591), -- Coal
(21192, 1865, 1, 1, 4, 218407.94591), -- Varnish
(21192, 1874, 1, 1, 4, 14560.690452), -- Oriharukon Ore
(21192, 2191, 1, 1, 4, 29238.067012), -- Recipe: RIP Gauntlets
(21192, 8317, 1, 1, 4, 1559.350716), -- Recipe: Titan Hammer (100%)
-- Gigant Raider
(21193, 1825, 1, 1, -1, 172903), -- Recipe: Oriharukon
(21193, 1902, 1, 1, -1, 245252), -- Elven Earring Beads
(21193, 2145, 1, 1, -1, 172903), -- Recipe: Mithril Alloy
(21193, 6362, 24, 45, 0, 700000), -- Red Seal Stone
(21193, 6361, 105, 206, 1, 700000), -- Green Seal Stone
(21193, 6360, 89, 178, 2, 700000), -- Blue Seal Stone
(21193, 88, 1, 1, 3, 23.302164), -- Morning Star
(21193, 2031, 1, 1, 3, 1266.576573), -- Morning Star Head
(21193, 90, 1, 1, 3, 23.302164), -- Goat Head Staff
(21193, 2032, 1, 1, 3, 1156.201905), -- Goat Head Staff Head
(21193, 158, 1, 1, 3, 23.302164), -- Tarbar
(21193, 2035, 1, 1, 3, 1266.576573), -- Tarbar Head
(21193, 169, 1, 1, 3, 23.302164), -- Skull Breaker
(21193, 2036, 1, 1, 3, 1266.576573), -- Skull Breaker Head
(21193, 172, 1, 1, 3, 23.302164), -- Heavy Bone Club
(21193, 2037, 1, 1, 3, 1266.557556), -- Heavy Bone Club Head
(21193, 1871, 1, 3, 4, 156410.426705), -- Charcoal
(21193, 1866, 1, 1, 4, 208547.50215), -- Suede
(21193, 1877, 1, 1, 4, 12513.010055), -- Adamantite Nugget
(21193, 2147, 1, 1, 4, 22344.06109), -- Recipe: Blacksmith's frame
-- Gigant Confessor
(21194, 1905, 1, 1, -1, 252534), -- Omen Beast's Eye Earring Gemstone
(21194, 1881, 1, 1, -1, 346140), -- Coarse Bone Powder
(21194, 1875, 1, 1, -1, 173070), -- Stone of Purity
(21194, 6362, 22, 41, 0, 700000), -- Red Seal Stone
(21194, 6361, 137, 274, 1, 700000), -- Green Seal Stone
(21194, 6360, 56, 111, 2, 700000), -- Blue Seal Stone
(21194, 262, 1, 1, 3, 93.99576), -- Scallop Jamadhr
(21194, 2053, 1, 1, 3, 5390.00424), -- Scallop Jamadhr Edge
(21194, 1872, 1, 3, 4, 82769.2668), -- Animal Bone
(21194, 1867, 2, 6, 4, 62076.9501), -- Animal Skin
(21194, 1881, 1, 1, 4, 24830.78004), -- Coarse Bone Powder
(21194, 1875, 1, 1, 4, 12415.39002), -- Stone of Purity
(21194, 1805, 1, 1, 4, 620.865432), -- Recipe: Soulshot (C-Grade)
(21194, 6037, 1, 3, 4, 186230.8503), -- Waking Scroll
(21194, 2994, 1, 1, 4, 14779.897308), -- Recipe: Boots of Seal
-- Gigant Commander
(21195, 1908, 1, 1, -1, 316239), -- Moonstone Earring Wire
(21195, 440, 1, 1, -1, 1106), -- Robe of Seal
(21195, 6362, 25, 45, 0, 700000), -- Red Seal Stone
(21195, 6361, 211, 425, 1, 700000), -- Green Seal Stone
(21195, 6360, 33, 62, 2, 700000), -- Blue Seal Stone
(21195, 281, 1, 1, 3, 89.529435), -- Crystallized Ice Bow
(21195, 2074, 1, 1, 3, 5589.470565), -- Crystallized Ice Bow Shaft
(21195, 1873, 1, 1, 4, 78914.727419), -- Silver Nugget
(21195, 1868, 1, 3, 4, 197286.214907), -- Thread
(21195, 1876, 1, 1, 4, 39457.162496), -- Mithril Ore
(21195, 1895, 1, 1, 4, 56367.547463), -- Metallic Fiber
(21195, 4042, 1, 1, 4, 3288.231017), -- Enria
(21195, 2164, 1, 1, 4, 15175.924597), -- Recipe: Ring of Protection
(21195, 2228, 1, 1, 4, 5361.132494), -- Recipe: Shining Circlet
(21195, 6036, 1, 1, 4, 6576.059607), -- Greater Magic Haste Potion
-- Nephilim Sentinel
(21196, 1911, 1, 1, -1, 282441), -- Earring of Protection Gemstone
(21196, 2166, 1, 1, -1, 128726), -- Recipe: Earrings of Binding (100%)
(21196, 2167, 1, 1, -1, 193746), -- Recipe: Ring of Ages
(21196, 6362, 25, 45, 0, 700000), -- Red Seal Stone
(21196, 6361, 268, 532, 1, 700000), -- Green Seal Stone
(21196, 227, 1, 1, 2, 38.069854), -- Stiletto
(21196, 2083, 1, 1, 2, 2794.930146), -- Stiletto Edge
(21196, 242, 1, 1, 2, 38.069854), -- Soulfire Dirk
(21196, 2084, 1, 1, 2, 2794.930146), -- Soulfire Dirk Blade
(21196, 1871, 1, 1, 3, 280424.31046), -- Charcoal
(21196, 1866, 1, 1, 3, 186949.865072), -- Suede
(21196, 1877, 1, 1, 3, 11217.069848), -- Adamantite Nugget
(21196, 4041, 1, 1, 3, 2438.662888), -- Mold Hardener
(21196, 4040, 1, 1, 3, 5608.534924), -- Mold Lubricant
(21196, 951, 1, 1, 3, 509.556808), -- Scroll: Enchant Weapon (C-Grade)
-- Nephilim Priest
(21197, 4041, 1, 1, -1, 36601), -- Mold Hardener
(21197, 1872, 1, 11, -1, 935364), -- Animal Bone
(21197, 4603, 1, 1, -1, 9354), -- Greater Dye of CON (Con+3 Str-3)
(21197, 6362, 12, 24, 0, 700000), -- Red Seal Stone
(21197, 6361, 238, 476, 1, 700000), -- Green Seal Stone
(21197, 6360, 145, 291, 2, 700000), -- Blue Seal Stone
(21197, 326, 1, 1, 3, 52.679457), -- Heathen's Book
(21197, 2110, 1, 1, 3, 4906.320543), -- Heathen's Book Page
(21197, 1869, 2, 6, 4, 72526.748024), -- Iron Ore
(21197, 1870, 2, 6, 4, 58021.600699), -- Coal
(21197, 1871, 3, 9, 4, 48351.277727), -- Charcoal
(21197, 1872, 7, 21, 4, 27629.397882), -- Animal Bone
(21197, 1867, 1, 3, 4, 128936.852983), -- Animal Skin
(21197, 2232, 1, 1, 4, 1667.122685), -- Recipe: Drake Leather Armor
-- Nephilim Swordsman
(21198, 4593, 1, 1, -1, 17584), -- Greater Dye of DEX (Dex+2 Str-2)
(21198, 1806, 1, 1, -1, 10550), -- Recipe: Soulshot (B-Grade)
(21198, 1920, 1, 1, -1, 180500), -- Necklace of Seal Chain
(21198, 6362, 13, 27, 0, 700000), -- Red Seal Stone
(21198, 6361, 314, 633, 1, 700000), -- Green Seal Stone
(21198, 6360, 148, 301, 2, 700000), -- Blue Seal Stone
(21198, 301, 1, 1, 3, 17.6528), -- Scorpion
(21198, 2113, 1, 1, 3, 1572.085625), -- Scorpion Blade
(21198, 303, 1, 1, 3, 17.6528), -- Widow Maker
(21198, 2114, 1, 1, 3, 1572.085625), -- Widowmaker Head
(21198, 299, 1, 1, 3, 13.77255), -- Orcish Poleaxe
(21198, 2122, 1, 1, 3, 1481.7506), -- Orcish Poleaxe Blade
(21198, 1873, 1, 1, 4, 97386.731248), -- Silver Nugget
(21198, 1868, 1, 3, 4, 243466.595568), -- Thread
(21198, 1876, 1, 1, 4, 48693.133072), -- Mithril Ore
(21198, 1895, 1, 1, 4, 69561.884448), -- Metallic Fiber
(21198, 4042, 1, 1, 4, 4057.567296), -- Enria
(21198, 3034, 1, 1, 4, 486.963888), -- Recipe: Spiritshot B
(21198, 4944, 1, 1, 4, 1170.666768), -- Recipe: Avadon Breastplate (60%)
(21198, 4968, 1, 1, 4, 280.457712), -- Recipe: Kris (60%)
-- Nephilim Guard
(21199, 4129, 1, 1, -1, 61196), -- Recipe: Earrings of Black Ore (100%)
(21199, 4611, 1, 1, -1, 12566), -- Greater Dye of WIT (Wit+3 Int-3)
(21199, 947, 1, 1, -1, 2262), -- Scroll: Enchant Weapon (B-Grade)
(21199, 6362, 13, 26, 0, 700000), -- Red Seal Stone
(21199, 6361, 391, 782, 1, 700000), -- Green Seal Stone
(21199, 6360, 73, 146, 2, 700000), -- Blue Seal Stone
(21199, 2384, 1, 1, 3, 46.513225), -- Zubei's Leather Shirt
(21199, 4066, 1, 1, 3, 6564.6867), -- Zubei's Leather Shirt Fabric
(21199, 2390, 1, 1, 3, 28.611825), -- Avadon Leather Armor
(21199, 4068, 1, 1, 3, 5043.306675), -- Avadon Leather Armor Lining
(21199, 2388, 1, 1, 3, 74.42985), -- Zubei's Leather Gaiters
(21199, 4067, 1, 1, 3, 9967.451725), -- Zubei's Leather Gaiter Texture
(21199, 1872, 1, 3, 4, 139189.096368), -- Animal Bone
(21199, 1867, 1, 1, 4, 278378.65594), -- Animal Skin
(21199, 1881, 1, 1, 4, 27837.633992), -- Coarse Bone Powder
(21199, 1875, 1, 1, 4, 13918.816996), -- Stone of Purity
(21199, 4041, 1, 1, 4, 1815.296476), -- Mold Hardener
(21199, 948, 1, 1, 4, 522.030908), -- Scroll: Enchant Armor (B-Grade)
(21199, 4163, 1, 1, 4, 1382.66394), -- Recipe: Blue Wolf Stockings (100%)
(21199, 8311, 1, 1, 4, 159.80538), -- Recipe: Kaim Vanul's Bones (100%)
-- Nephilim Bishop
(21200, 4613, 1, 1, -1, 8164), -- Greater Dye of STR (Str+4 Con-4)
(21200, 4129, 1, 1, -1, 64055), -- Recipe: Earrings of Black Ore (100%)
(21200, 4049, 1, 1, -1, 310449), -- Adamantite Earring Gemstone
(21200, 6362, 12, 24, 0, 700000), -- Red Seal Stone
(21200, 6361, 452, 904, 1, 700000), -- Green Seal Stone
(21200, 6360, 8, 16, 2, 700000), -- Blue Seal Stone
(21200, 357, 1, 1, 3, 27.3861), -- Zubei's Breastplate
(21200, 4056, 1, 1, 3, 3956.764014), -- Zubei's Breastplate Part
(21200, 2376, 1, 1, 3, 27.3861), -- Avadon Breastplate
(21200, 4064, 1, 1, 3, 3956.764014), -- Avadon Breastplate Part
(21200, 383, 1, 1, 3, 43.81776), -- Zubei's Gaiters
(21200, 4057, 1, 1, 3, 6115.01184), -- Zubei's Gaiter Material
(21200, 2379, 1, 1, 3, 43.81776), -- Avadon Gaiters
(21200, 4065, 1, 1, 3, 6115.052412), -- Avadon Gaiters Material
(21200, 1872, 1, 3, 4, 111002.850595), -- Animal Bone
(21200, 1867, 2, 6, 4, 83252.244334), -- Animal Skin
(21200, 1881, 1, 1, 4, 33300.642403), -- Coarse Bone Powder
(21200, 1875, 1, 1, 4, 16650.533977), -- Stone of Purity
(21200, 4041, 1, 1, 4, 2171.586753), -- Mold Hardener
(21200, 4155, 1, 1, 4, 775.779473), -- Recipe: Blue Wolf Breastplate (100%)
(21200, 1343, 20, 60, 4, 178397.362465), -- Silver Arrow
-- Nephilim Centurion
(21201, 4052, 1, 1, -1, 271551), -- Earring of Black Ore Piece
(21201, 5230, 1, 1, -1, 10227), -- Recipe: Mithril Arrow (100%)
(21201, 4053, 1, 1, -1, 328759), -- Ring of Black Ore Gemstone
(21201, 6362, 14, 28, 0, 700000), -- Red Seal Stone
(21201, 6361, 574, 1144, 1, 700000), -- Green Seal Stone
(21201, 2398, 1, 1, 2, 30.501009), -- Blue Wolf Tunic
(21201, 4084, 1, 1, 2, 4923.408096), -- Blue Wolf Tunic Fabric
(21201, 2399, 1, 1, 2, 30.501009), -- Tunic of Doom
(21201, 4085, 1, 1, 2, 4923.408096), -- Tunic of Doom Pattern
(21201, 2403, 1, 1, 2, 48.838896), -- Blue Wolf Stockings
(21201, 4086, 1, 1, 2, 6647.728698), -- Blue Wolf Stockings Pattern
(21201, 2404, 1, 1, 2, 48.838896), -- Stockings of Doom
(21201, 4087, 1, 1, 2, 6647.7753), -- Stockings of Doom Pattern
(21201, 1871, 1, 3, 3, 161827.525055), -- Charcoal
(21201, 1866, 1, 3, 3, 71923.388495), -- Suede
(21201, 1877, 1, 1, 3, 12946.186155), -- Adamantite Nugget
(21201, 4041, 1, 1, 3, 2814.457205), -- Mold Hardener
(21201, 4040, 1, 1, 3, 6473.291195), -- Mold Lubricant
(21201, 1830, 1, 1, 3, 129461.86155), -- Scroll of Escape: Castle
(21201, 6036, 1, 1, 3, 10788.290345), -- Greater Magic Haste Potion
-- Nephilim Scout
(21202, 5230, 1, 1, -1, 10851), -- Recipe: Mithril Arrow (100%)
(21202, 4054, 1, 1, -1, 160289), -- Necklace of Black Ore Beads
(21202, 4041, 1, 1, -1, 70764), -- Mold Hardener
(21202, 6362, 14, 27, 0, 700000), -- Red Seal Stone
(21202, 6361, 578, 1160, 1, 700000), -- Green Seal Stone
(21202, 864, 1, 1, 2, 112.69614), -- Earring of Black Ore
(21202, 4052, 1, 1, 2, 14183.47272), -- Earring of Black Ore Piece
(21202, 926, 1, 1, 2, 84.532008), -- Necklace of Black Ore
(21202, 4054, 1, 1, 2, 7890.7104), -- Necklace of Black Ore Beads
(21202, 895, 1, 1, 2, 169.024404), -- Ring of Black Ore
(21202, 4053, 1, 1, 2, 17171.564328), -- Ring of Black Ore Gemstone
(21202, 1872, 4, 12, 3, 66772.25872), -- Animal Bone
(21202, 1867, 1, 3, 3, 178059.246928), -- Animal Skin
(21202, 1881, 1, 1, 3, 53417.806976), -- Coarse Bone Powder
(21202, 1875, 1, 1, 3, 26708.903488), -- Stone of Purity
(21202, 4041, 1, 1, 3, 3483.85584), -- Mold Hardener
(21202, 5230, 1, 1, 3, 533.928048), -- Recipe: Mithril Arrow (100%)
-- Nephilim Archbishop
(21203, 1876, 1, 3, -1, 801503), -- Mithril Ore
(21203, 5478, 1, 1, -1, 67398), -- Sealed Dark Crystal Leather Armor Pattern
(21203, 4042, 1, 1, -1, 133584), -- Enria
(21203, 6362, 12, 24, 0, 700000), -- Red Seal Stone
(21203, 6361, 557, 1114, 1, 700000), -- Green Seal Stone
(21203, 5291, 1, 1, 2, 66.503325), -- Sealed Dark Crystal Boots
(21203, 5496, 1, 1, 2, 6939.746675), -- Sealed Dark Crystal Boots Lining
(21203, 5296, 1, 1, 2, 66.503325), -- Sealed Tallum Boots
(21203, 5497, 1, 1, 2, 6939.746675), -- Sealed Tallum Boots Lining
(21203, 5290, 1, 1, 2, 66.503325), -- Sealed Dark Crystal Gloves
(21203, 5508, 1, 1, 2, 6939.746675), -- Sealed Dark Crystal Gloves Design
(21203, 5295, 1, 1, 2, 66.503325), -- Sealed Tallum Gloves
(21203, 5509, 1, 1, 2, 6939.746675), -- Sealed Tallum Gloves Design
(21203, 1873, 1, 1, 3, 135286.501539), -- Silver Nugget
(21203, 1868, 4, 12, 3, 84553.906566), -- Thread
(21203, 1876, 1, 1, 3, 67643.041575), -- Mithril Ore
(21203, 1895, 1, 1, 3, 96633.215385), -- Metallic Fiber
(21203, 4042, 1, 1, 3, 5636.954997), -- Enria
(21203, 5156, 1, 1, 3, 451.023342), -- Recipe: Soulshot (A) Compressed Package (100%)
(21203, 1344, 150, 450, 3, 28184.356596), -- Mithril Arrow
-- Nephilim Praetorian
(21204, 1807, 1, 1, -1, 10950), -- Recipe: Soulshot (A-Grade)
(21204, 5479, 1, 1, -1, 48593), -- Sealed Tallum Leather Armor Pattern
(21204, 3035, 1, 1, -1, 10950), -- Recipe: Spiritshot A
(21204, 6362, 14, 28, 0, 700000), -- Red Seal Stone
(21204, 6361, 687, 1380, 1, 700000), -- Green Seal Stone
(21204, 5292, 1, 1, 2, 108.0996), -- Sealed Dark Crystal Shield
(21204, 5494, 1, 1, 2, 10612.704725), -- Sealed Dark Crystal Shield Fragment
(21204, 5289, 1, 1, 2, 75.643225), -- Sealed Dark Crystal Helmet
(21204, 5525, 1, 1, 2, 7811.46786), -- Sealed Dark Crystal Helmet Design
(21204, 5294, 1, 1, 2, 75.643225), -- Sealed Tallum Helmet
(21204, 5526, 1, 1, 2, 7811.441365), -- Sealed Tallum Helm Design
(21204, 1894, 1, 1, 3, 21278.91699), -- Crafted Leather
(21204, 4039, 1, 1, 3, 20215.005036), -- Mold Glue
(21204, 4041, 1, 1, 3, 5273.46189), -- Mold Hardener
(21204, 4044, 1, 1, 3, 20215.005036), -- Thons
(21204, 3956, 1, 1, 3, 808.611048), -- Recipe: Blessed Spiritshot A
-- Nephilim Royal Guard
(21205, 5480, 1, 1, -1, 38649), -- Sealed Leather Armor of Nightmare Fabric
(21205, 729, 1, 1, -1, 957), -- Scroll: Enchant Weapon (A-Grade)
(21205, 1895, 1, 5, -1, 820300), -- Metallic Fiber
(21205, 6362, 14, 27, 0, 700000), -- Red Seal Stone
(21205, 6361, 700, 1400, 1, 700000), -- Green Seal Stone
(21205, 5297, 1, 1, 2, 39.689052), -- Sealed Dark Crystal Leather Armor
(21205, 5478, 1, 1, 2, 4456.843612), -- Sealed Dark Crystal Leather Armor Pattern
(21205, 5301, 1, 1, 2, 24.413844), -- Sealed Tallum Leather Armor
(21205, 5479, 1, 1, 2, 3136.141476), -- Sealed Tallum Leather Armor Pattern
(21205, 5298, 1, 1, 2, 63.470108), -- Sealed Dark Crystal Leggings
(21205, 5482, 1, 1, 2, 6995.441908), -- Sealed Dark Crystal Leggings Design
(21205, 1895, 1, 1, 3, 181727.779416), -- Metallic Fiber
(21205, 4040, 1, 1, 3, 12720.826633), -- Mold Lubricant
(21205, 4042, 1, 1, 3, 10600.877845), -- Enria
(21205, 4043, 1, 1, 3, 21201.528909), -- Asofe
(21205, 730, 1, 1, 3, 529.987197), -- Scroll: Enchant Armor (A-Grade)
-- Nephilim Cardinal
(21206, 1875, 1, 1, -1, 559187), -- Stone of Purity
(21206, 5481, 1, 1, -1, 37638), -- Sealed Majestic Leather Armor Fabric
(21206, 5487, 1, 1, -1, 37771), -- Sealed Robe of Nightmare Fabric
(21206, 6362, 12, 24, 0, 700000), -- Red Seal Stone
(21206, 6361, 666, 1336, 1, 700000), -- Green Seal Stone
(21206, 5287, 1, 1, 2, 28.982671), -- Sealed Dark Crystal breastplate
(21206, 5520, 1, 1, 2, 3328.859027), -- Sealed Dark Crystal Breastplate Pattern
(21206, 5293, 1, 1, 2, 17.841337), -- Sealed Tallum Plate Armor
(21206, 5521, 1, 1, 2, 2348.975444), -- Sealed Tallum Plate Armor Pattern
(21206, 5288, 1, 1, 2, 46.378789), -- Sealed Dark Crystal Gaiters
(21206, 5524, 1, 1, 2, 5087.962732), -- Sealed Dark Crystal Gaiters Pattern
(21206, 1873, 1, 1, 3, 123881.328256), -- Silver Nugget
(21206, 1868, 3, 9, 3, 103234.300032), -- Thread
(21206, 1876, 1, 1, 3, 61940.664128), -- Mithril Ore
(21206, 1895, 1, 1, 3, 88486.66304), -- Metallic Fiber
(21206, 4042, 1, 1, 3, 5161.757056), -- Enria
(21206, 5282, 1, 1, 3, 137.517888), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21206, 6671, 1, 1, 3, 34411.433344), -- Deluxe Chest Key - Grade 7
(21206, 8732, 1, 1, 3, 2580.878528), -- Life Stone - Level 76
(21206, 8742, 1, 1, 3, 645.114496), -- Mid-Grade Life Stone - Level 76
(21206, 8752, 1, 1, 3, 64.343232), -- High-Grade Life Stone - Level 76
-- Nephilim Commander
(21207, 5488, 1, 1, -1, 46584), -- Sealed Majestic Robe Fabric
(21207, 730, 1, 1, -1, 8621), -- Scroll: Enchant Armor (A-Grade)
(21207, 5480, 1, 1, -1, 46420), -- Sealed Leather Armor of Nightmare Fabric
(21207, 6362, 14, 28, 0, 700000), -- Red Seal Stone
(21207, 6361, 805, 1610, 1, 700000), -- Green Seal Stone
(21207, 5315, 1, 1, 2, 89.538834), -- Sealed Shield of Nightmare
(21207, 5495, 1, 1, 2, 9665.951834), -- Sealed Shield of Nightmare Fragment
(21207, 5312, 1, 1, 2, 62.654592), -- Sealed Helm of Nightmare
(21207, 5527, 1, 1, 2, 7610.600074), -- Sealed Helm of Nightmare Design
(21207, 5317, 1, 1, 2, 62.654592), -- Sealed Majestic Circlet
(21207, 5528, 1, 1, 2, 7610.600074), -- Sealed Majestic Circlet Design
(21207, 1871, 4, 12, 3, 79576.53054), -- Charcoal
(21207, 1866, 1, 3, 3, 141469.358199), -- Suede
(21207, 1877, 1, 1, 3, 25464.436803), -- Adamantite Nugget
(21207, 4041, 1, 1, 3, 5535.873798), -- Mold Hardener
(21207, 4040, 1, 1, 3, 12732.350826), -- Mold Lubricant
(21207, 729, 1, 1, 3, 70.449834), -- Scroll: Enchant Weapon (A-Grade)
-- Hallowed Watchman
(21208, 1871, 1, 1, -1, 790380), -- Charcoal
(21208, 734, 1, 1, -1, 131730), -- Haste Potion
(21208, 1897, 1, 1, -1, 188186), -- Necklace of Wisdom Chain
(21208, 57, 365, 635, 0, 700000), -- Adena
(21208, 38, 1, 1, 1, 5974.79886), -- Low Boots
(21208, 50, 1, 1, 1, 5974.79886), -- Leather Gloves
(21208, 1925, 1, 1, 1, 102062.40228), -- Leather Gloves Lining
(21208, 1871, 1, 1, 2, 155643.947885), -- Charcoal
(21208, 1866, 1, 1, 2, 103762.441692), -- Suede
(21208, 734, 1, 1, 2, 25940.610423), -- Haste Potion
-- Hallowed Seer
(21209, 1804, 1, 1, -1, 36013), -- Recipe: Soulshot (D-Grade)
(21209, 1898, 1, 1, -1, 92484), -- Blue Diamond Necklace Gem
(21209, 2151, 1, 1, -1, 250789), -- Recipe: Necklace of Devotion
(21209, 57, 409, 734, 0, 700000), -- Adena
(21209, 625, 1, 1, 1, 5372.435016), -- Bone Shield
(21209, 1148, 1, 1, 1, 3745.564984), -- Hard Leather Helmet
(21209, 1870, 1, 1, 2, 177296.591934), -- Coal
(21209, 1865, 1, 1, 2, 177296.591934), -- Varnish
(21209, 734, 1, 1, 2, 29549.816132), -- Haste Potion
-- Vault Guardian
(21210, 1899, 1, 1, -1, 171864), -- Necklace of Devotion Chain
(21210, 1866, 1, 1, -1, 733287), -- Suede
(21210, 1877, 1, 1, -1, 43997), -- Adamantite Nugget
(21210, 57, 484, 907, 0, 700000), -- Adena
(21210, 123, 1, 1, 1, 97.988852), -- Saber
(21210, 2017, 1, 1, 1, 2050.881418), -- Saber Blade
(21210, 5285, 1, 1, 1, 97.988852), -- Heavy Sword
(21210, 5531, 1, 1, 1, 2591.140878), -- Heavy Sword Edge
(21210, 1871, 1, 1, 2, 154328.462934), -- Charcoal
(21210, 1866, 1, 1, 2, 102885.641956), -- Suede
(21210, 1877, 1, 1, 2, 6173.070858), -- Adamantite Nugget
(21210, 2182, 1, 1, 2, 18526.824252), -- Recipe: Scale Gaiters
-- Vault Seer
(21211, 1931, 1, 1, -1, 150011), -- Leather Boots Lining
(21211, 2152, 1, 1, -1, 202039), -- Recipe: Enchanted Necklace
(21211, 1932, 1, 1, -1, 182156), -- Bone Helmet Design
(21211, 57, 495, 955, 0, 700000), -- Adena
(21211, 156, 1, 1, 1, 136.333197), -- Hand Axe
(21211, 167, 1, 1, 1, 136.333197), -- Scalpel
(21211, 178, 1, 1, 1, 136.333606), -- Bone Staff
(21211, 1872, 1, 1, 2, 171749.16103), -- Animal Bone
(21211, 1867, 1, 1, 2, 171749.16103), -- Animal Skin
(21211, 1881, 1, 1, 2, 17174.80438), -- Coarse Bone Powder
(21211, 1875, 1, 1, 2, 8587.40219), -- Stone of Purity
(21211, 5437, 1, 1, 2, 3149.47137), -- Recipe: Heavy Sword(100%)
-- Hallowed Monk
(21213, 2153, 1, 1, -1, 230897), -- Recipe: Tiger's Eye Earring
(21213, 1900, 1, 1, -1, 162437), -- Enchanted Necklace Chain
(21213, 57, 626, 1255, 0, 700000), -- Adena
(21213, 275, 1, 1, 1, 109.163865), -- Long Bow
(21213, 276, 1, 1, 1, 109.163865), -- Elven Bow
(21213, 2024, 1, 1, 1, 3852.67227), -- Elven Bow Shaft
(21213, 1864, 3, 9, 2, 54087.7134), -- Stem
(21213, 1869, 1, 1, 2, 162262.66075), -- Iron Ore
(21213, 1878, 1, 1, 2, 64905.0643), -- Braided Hemp
(21213, 1884, 1, 1, 2, 99854.0926), -- Cord
(21213, 1061, 1, 1, 2, 98340.46895), -- Greater Healing Potion
-- Vault Sentinel
(21214, 1875, 1, 1, -1, 123331), -- Stone of Purity
(21214, 1865, 1, 3, -1, 924982), -- Varnish
(21214, 1901, 1, 1, -1, 255520), -- Tiger's Eye Earring Stone
(21214, 57, 781, 1559, 0, 700000), -- Adena
(21214, 223, 1, 1, 1, 52.91724), -- Kukuri
(21214, 238, 1, 1, 1, 52.91724), -- Dagger of Mana
(21214, 239, 1, 1, 1, 52.91724), -- Mystic Knife
(21214, 241, 1, 1, 1, 52.91724), -- Shilen Knife
(21214, 2028, 1, 1, 1, 2337.33104), -- Shilen Knife Edge
(21214, 1865, 1, 1, 2, 196722.357194), -- Varnish
(21214, 1870, 1, 1, 2, 196722.357194), -- Coal
(21214, 1879, 1, 1, 2, 32786.910156), -- Cokes
(21214, 1875, 1, 1, 2, 13114.943314), -- Stone of Purity
(21214, 2189, 1, 1, 2, 8782.432142), -- Recipe: Mithril Tunic
-- Vault Monk
(21215, 1825, 1, 1, -1, 139345), -- Recipe: Oriharukon
(21215, 1902, 1, 1, -1, 197653), -- Elven Earring Beads
(21215, 2145, 1, 1, -1, 139345), -- Recipe: Mithril Alloy
(21215, 57, 824, 1645, 0, 700000), -- Adena
(21215, 318, 1, 1, 1, 93.890762), -- Crucifix of Blood
(21215, 2042, 1, 1, 1, 4659.109238), -- Crucifix of Blood Piece
(21215, 1866, 1, 1, 2, 112047.747354), -- Suede
(21215, 1871, 1, 1, 2, 168071.458602), -- Charcoal
(21215, 5220, 1, 1, 2, 6722.93631), -- Metal Hardener
(21215, 1885, 1, 1, 2, 14005.927812), -- High-Grade Suede
(21215, 1825, 1, 1, 2, 12005.12739), -- Recipe: Oriharukon
(21215, 5473, 1, 1, 2, 12004.802532), -- Recipe: Durable Metal Plate(100%)
-- Hallowed Priest
(21217, 1905, 1, 1, -1, 246339), -- Omen Beast's Eye Earring Gemstone
(21217, 1889, 1, 1, -1, 168824), -- Compound Braid
(21217, 1868, 1, 11, -1, 844121), -- Thread
(21217, 57, 1020, 2061, 0, 700000), -- Adena
(21217, 396, 1, 1, 1, 346.880611), -- Salamander Skin Mail
(21217, 1952, 1, 1, 1, 20366.119389), -- Salamander Skin Mail Texture
(21217, 1868, 1, 3, 2, 211938.94854), -- Thread
(21217, 1873, 1, 1, 2, 84775.72719), -- Silver Nugget
(21217, 5549, 1, 1, 2, 21193.74708), -- Metallic Thread
(21217, 1889, 1, 1, 2, 14129.41101), -- Compound Braid
(21217, 2161, 1, 1, 2, 20576.79063), -- Recipe: Aquastone Ring
(21217, 2993, 1, 1, 2, 16820.37555), -- Recipe: Dwarven Chain Boots
-- Vault Overlord
(21218, 1908, 1, 1, -1, 292039), -- Moonstone Earring Wire
(21218, 2163, 1, 1, -1, 157343), -- Recipe: Earring of Protection
(21218, 1909, 1, 1, -1, 416466), -- Aquastone Ring Wire
(21218, 57, 1220, 2478, 0, 700000), -- Adena
(21218, 354, 1, 1, 1, 187.534332), -- Chain Mail Shirt
(21218, 1959, 1, 1, 1, 9814.437954), -- Chain Mail Shirt Material
(21218, 381, 1, 1, 1, 300.006504), -- Chain Gaiters
(21218, 1960, 1, 1, 1, 19965.02121), -- Chain Gaiters Part
(21218, 1869, 1, 1, 2, 145751.293329), -- Iron Ore
(21218, 1864, 1, 1, 2, 291503.055015), -- Stem
(21218, 1880, 1, 1, 2, 14575.26984), -- Steel
(21218, 5550, 1, 1, 2, 1943.213193), -- Durable Metal Plate
(21218, 4043, 1, 1, 2, 4858.267161), -- Asofe
(21218, 2213, 1, 1, 2, 2263.101024), -- Recipe: Dwarven Chain Mail Shirt
(21218, 8723, 1, 1, 2, 5830.107936), -- Life Stone - Level 46
(21218, 8733, 1, 1, 2, 1457.526984), -- Mid-Grade Life Stone - Level 46
(21218, 8743, 1, 1, 2, 145.659027), -- High-Grade Life Stone - Level 46
(21218, 8753, 1, 1, 2, 29.506491), -- Top-Grade Life Stone - Level 46
-- Vault Priest
(21219, 1911, 1, 1, -1, 237145), -- Earring of Protection Gemstone
(21219, 2166, 1, 1, -1, 108082), -- Recipe: Earrings of Binding (100%)
(21219, 1912, 1, 1, -1, 343579), -- Ring of Protection Gemstone
(21219, 57, 1258, 2567, 0, 700000), -- Adena
(21219, 440, 1, 1, 1, 233.926298), -- Robe of Seal
(21219, 1970, 1, 1, 1, 15773.073702), -- Robe of Seal Fabric
(21219, 1871, 1, 1, 2, 235452.62048), -- Charcoal
(21219, 1866, 1, 1, 2, 156968.686336), -- Suede
(21219, 1877, 1, 1, 2, 9418.186624), -- Adamantite Nugget
(21219, 4041, 1, 1, 2, 2047.574144), -- Mold Hardener
(21219, 4040, 1, 1, 2, 4709.093312), -- Mold Lubricant
(21219, 951, 1, 1, 2, 427.839104), -- Scroll: Enchant Weapon (C-Grade)
-- Sepulcher Inquisitor
(21221, 1872, 1, 11, -1, 871890), -- Animal Bone
(21221, 1867, 1, 11, -1, 871890), -- Animal Skin
(21221, 4605, 1, 1, -1, 8719), -- Greater Dye of DEX (Dex+3 Str-3)
(21221, 57, 1558, 3150, 0, 700000), -- Adena
(21221, 64, 1, 1, 1, 429.6901), -- Composite Boots
(21221, 2956, 1, 1, 1, 23860.3099), -- Composite Boots Part
(21221, 608, 1, 1, 1, 429.6901), -- Mithril Gauntlets
(21221, 1981, 1, 1, 1, 23860.3099), -- Mithril Gauntlets Design
(21221, 1872, 2, 6, 2, 38631.479279), -- Animal Bone
(21221, 1867, 1, 1, 2, 154525.917116), -- Animal Skin
(21221, 1881, 1, 1, 2, 15452.508349), -- Coarse Bone Powder
(21221, 1875, 1, 1, 2, 7726.462581), -- Stone of Purity
(21221, 4041, 1, 1, 2, 1007.853834), -- Mold Hardener
(21221, 2234, 1, 1, 2, 1727.273072), -- Recipe: Divine Stockings
(21221, 6037, 1, 3, 2, 115894.437837), -- Waking Scroll
(21221, 3955, 1, 1, 2, 231.748028), -- Recipe: Blessed Spiritshot B
(21221, 5280, 1, 1, 2, 231.748028), -- Recipe: Greater Blessed Spiritshot (B) Compressed Package(100%)
(21221, 8725, 1, 1, 2, 3219.463612), -- Life Stone - Level 52
(21221, 8735, 1, 1, 2, 804.865903), -- Mid-Grade Life Stone - Level 52
(21221, 8745, 1, 1, 2, 80.444909), -- High-Grade Life Stone - Level 52
(21221, 8755, 1, 1, 2, 16.255707), -- Top-Grade Life Stone - Level 52
(21221, 1342, 30, 90, 2, 77262.541745), -- Steel Arrow
-- Sepulcher Archon
(21222, 1806, 1, 1, -1, 9299), -- Recipe: Soulshot (B-Grade)
(21222, 1920, 1, 1, -1, 159086), -- Necklace of Seal Chain
(21222, 4126, 1, 1, -1, 76721), -- Recipe: Adamantite Earrings (100%)
(21222, 57, 1837, 3743, 0, 700000), -- Adena
(21222, 2497, 1, 1, 1, 297.204255), -- Full Plate Shield
(21222, 2966, 1, 1, 1, 23484.417705), -- Full Plate Shield Fragment
(21222, 2414, 1, 1, 1, 208.039095), -- Full Plate Helmet
(21222, 2959, 1, 1, 1, 14845.338945), -- Full Plate Helmet Design
(21222, 1873, 1, 1, 2, 57221.847612), -- Silver Nugget
(21222, 1868, 1, 1, 2, 286108.815933), -- Thread
(21222, 1876, 1, 1, 2, 28610.923806), -- Mithril Ore
(21222, 1895, 1, 1, 2, 40872.868902), -- Metallic Fiber
(21222, 4042, 1, 1, 2, 2384.173296), -- Enria
(21222, 4126, 1, 1, 2, 2360.534184), -- Recipe: Adamantite Earrings (100%)
(21222, 4965, 1, 1, 2, 164.62953), -- Recipe: Sprite's Staff (60%)
(21222, 4183, 1, 1, 2, 164.62953), -- Recipe: Heavy War Axe (100%)
(21222, 8726, 1, 1, 2, 3311.586315), -- Life Stone - Level 55
(21222, 8736, 1, 1, 2, 827.791047), -- Mid-Grade Life Stone - Level 55
(21222, 8746, 1, 1, 2, 82.736892), -- High-Grade Life Stone - Level 55
(21222, 8756, 1, 1, 2, 16.462953), -- Top-Grade Life Stone - Level 55
-- Sepulcher Inquisitor
(21223, 4129, 1, 1, -1, 51501), -- Recipe: Earrings of Black Ore (100%)
(21223, 4049, 1, 1, -1, 249606), -- Adamantite Earring Gemstone
(21223, 4603, 1, 1, -1, 10575), -- Greater Dye of CON (Con+3 Str-3)
(21223, 57, 1877, 3833, 0, 700000), -- Adena
(21223, 78, 1, 1, 1, 7.013753), -- Great Sword
(21223, 4104, 1, 1, 1, 1340.499041), -- Great Sword Blade
(21223, 142, 1, 1, 1, 7.013753), -- Keshanberk
(21223, 4107, 1, 1, 1, 1319.72985), -- Keshanberk Blade
(21223, 148, 1, 1, 1, 7.013753), -- Sword of Valhalla
(21223, 4108, 1, 1, 1, 1319.72985), -- Sword of Valhalla Blade
(21223, 1873, 1, 1, 2, 51114.767046), -- Silver Nugget
(21223, 1868, 1, 1, 2, 255573.082474), -- Thread
(21223, 1876, 1, 1, 2, 25557.195334), -- Mithril Ore
(21223, 1895, 1, 1, 2, 36510.54789), -- Metallic Fiber
(21223, 4042, 1, 1, 2, 2129.923102), -- Enria
(21223, 4130, 1, 1, 2, 2074.595536), -- Recipe: Ring of Black Ore (100%)
(21223, 4182, 1, 1, 2, 147.163798), -- Recipe: Great Sword (100%)
(21223, 8727, 1, 1, 2, 2555.60662), -- Life Stone - Level 58
(21223, 8737, 1, 1, 2, 639.089844), -- Mid-Grade Life Stone - Level 58
(21223, 8747, 1, 1, 2, 63.98426), -- High-Grade Life Stone - Level 58
(21223, 8757, 1, 1, 2, 12.044096), -- Top-Grade Life Stone - Level 58
-- Sepulcher Guardian
(21224, 1894, 1, 1, -1, 182410), -- Crafted Leather
(21224, 4039, 1, 1, -1, 173289), -- Mold Glue
(21224, 4613, 1, 1, -1, 7171), -- Greater Dye of STR (Str+4 Con-4)
(21224, 57, 2056, 4180, 0, 700000), -- Adena
(21224, 91, 1, 1, 1, 11.49312), -- Heavy War Axe
(21224, 4105, 1, 1, 1, 2196.5262), -- Heavy War Axe Head
(21224, 92, 1, 1, 1, 11.49312), -- Sprite's Staff
(21224, 4106, 1, 1, 1, 2160.48756), -- Sprite's Staff Head
(21224, 1894, 1, 1, 2, 5388.115096), -- Crafted Leather
(21224, 4039, 1, 1, 2, 5118.901294), -- Mold Glue
(21224, 4041, 1, 1, 2, 1335.271665), -- Mold Hardener
(21224, 4044, 1, 1, 2, 5118.901294), -- Thons
(21224, 4158, 1, 1, 2, 326.079819), -- Recipe: Doom Plate Armor (100%)
(21224, 8728, 1, 1, 2, 2559.450647), -- Life Stone - Level 61
(21224, 8738, 1, 1, 2, 639.922647), -- Mid-Grade Life Stone - Level 61
(21224, 8748, 1, 1, 2, 64.064247), -- High-Grade Life Stone - Level 61
(21224, 8758, 1, 1, 2, 12.716873), -- Top-Grade Life Stone - Level 61
(21224, 1343, 10, 30, 2, 219377.576418), -- Silver Arrow
-- Sepulcher Sage
(21225, 4052, 1, 1, -1, 201435), -- Earring of Black Ore Piece
(21225, 5230, 1, 1, -1, 7586), -- Recipe: Mithril Arrow (100%)
(21225, 4053, 1, 1, -1, 243872), -- Ring of Black Ore Gemstone
(21225, 57, 2256, 4571, 0, 700000), -- Adena
(21225, 2391, 1, 1, 1, 27.853632), -- Blue Wolf Leather Armor
(21225, 4082, 1, 1, 1, 4748.146368), -- Blue Wolf Leather Armor Texture
(21225, 2392, 1, 1, 1, 27.853632), -- Leather Armor of Doom
(21225, 4083, 1, 1, 1, 4748.146368), -- Leather Armor of Doom Design
(21225, 1871, 1, 3, 2, 140050.167295), -- Charcoal
(21225, 1866, 1, 1, 2, 186733.403705), -- Suede
(21225, 1877, 1, 1, 2, 11203.811835), -- Adamantite Nugget
(21225, 4041, 1, 1, 2, 2435.531605), -- Mold Hardener
(21225, 4040, 1, 1, 2, 5602.13495), -- Mold Lubricant
(21225, 1830, 1, 1, 2, 112039.95061), -- Scroll of Escape: Castle
-- Sepulcher Guardian
(21226, 5230, 1, 1, -1, 8862), -- Recipe: Mithril Arrow (100%)
(21226, 4054, 1, 1, -1, 130913), -- Necklace of Black Ore Beads
(21226, 4052, 1, 1, -1, 235314), -- Earring of Black Ore Piece
(21226, 57, 2634, 5340, 0, 700000), -- Adena
(21226, 79, 1, 1, 1, 6.485445), -- Sword of Damascus
(21226, 4114, 1, 1, 1, 1432.64904), -- Sword of Damascus Blade
(21226, 7883, 1, 1, 1, 6.485445), -- Guardian Sword
(21226, 8330, 1, 1, 1, 1430.24127), -- Guardian Sword Blade
(21226, 7889, 1, 1, 1, 6.485445), -- Wizard's Tear
(21226, 8336, 1, 1, 1, 1432.653355), -- Blade of the Wizard's Tear
(21226, 1867, 1, 3, 2, 118985.367), -- Animal Skin
(21226, 1872, 1, 1, 2, 237970.324764), -- Animal Bone
(21226, 1882, 1, 1, 2, 39661.925412), -- Leather
(21226, 1894, 1, 1, 2, 6262.538508), -- Crafted Leather
(21226, 4042, 1, 1, 2, 2974.736484), -- Enria
(21226, 5230, 1, 1, 2, 237.766116), -- Recipe: Mithril Arrow (100%)
(21226, 8314, 1, 1, 2, 97.398168), -- Recipe: Spiritual Eye (60%)
(21226, 8729, 1, 1, 2, 2379.70734), -- Life Stone - Level 64
(21226, 8739, 1, 1, 2, 595.029144), -- Mid-Grade Life Stone - Level 64
(21226, 8749, 1, 1, 2, 59.33922), -- High-Grade Life Stone - Level 64
(21226, 8759, 1, 1, 2, 11.867844), -- Top-Grade Life Stone - Level 64
-- Sepulcher Sage
(21227, 5549, 1, 1, -1, 712964), -- Metallic Thread
(21227, 4077, 1, 1, -1, 320722), -- Doom Shield Fragment
(21227, 5230, 1, 1, -1, 9506), -- Recipe: Mithril Arrow (100%)
(21227, 57, 2811, 5744, 0, 700000), -- Adena
(21227, 287, 1, 1, 1, 20.86971), -- Bow of Peril
(21227, 4121, 1, 1, 1, 4586.13029), -- Bow of Peril Shaft
(21227, 1868, 1, 3, 2, 191453.316384), -- Thread
(21227, 1873, 1, 1, 2, 76581.264672), -- Silver Nugget
(21227, 5549, 1, 1, 2, 19145.238816), -- Metallic Thread
(21227, 1889, 1, 1, 2, 12763.698816), -- Compound Braid
(21227, 4044, 1, 1, 2, 6381.849408), -- Thons
(21227, 5230, 1, 1, 2, 255.2616), -- Recipe: Mithril Arrow (100%)
(21227, 8314, 1, 1, 2, 104.579904), -- Recipe: Spiritual Eye (60%)
(21227, 8730, 1, 1, 2, 2127.18), -- Life Stone - Level 67
(21227, 8740, 1, 1, 2, 531.872352), -- Mid-Grade Life Stone - Level 67
(21227, 8750, 1, 1, 2, 53.218176), -- High-Grade Life Stone - Level 67
(21227, 8760, 1, 1, 2, 10.519872), -- Top-Grade Life Stone - Level 67
-- Sepulcher Guard 
(21228, 1807, 1, 1, -1, 9693), -- Recipe: Soulshot (A-Grade)
(21228, 5478, 1, 1, -1, 61132), -- Sealed Dark Crystal Leather Armor Pattern
(21228, 3035, 1, 1, -1, 9693), -- Recipe: Spiritshot A
(21228, 57, 2875, 5849, 0, 700000), -- Adena
(21228, 5287, 1, 1, 1, 20.094901), -- Sealed Dark Crystal breastplate
(21228, 5520, 1, 1, 1, 2308.037537), -- Sealed Dark Crystal Breastplate Pattern
(21228, 5293, 1, 1, 1, 12.370147), -- Sealed Tallum Plate Armor
(21228, 5521, 1, 1, 1, 1628.643164), -- Sealed Tallum Plate Armor Pattern
(21228, 5288, 1, 1, 1, 32.156359), -- Sealed Dark Crystal Gaiters
(21228, 5524, 1, 1, 1, 3527.697892), -- Sealed Dark Crystal Gaiters Pattern
(21228, 1866, 1, 1, 2, 143158.763529), -- Suede
(21228, 1871, 1, 1, 2, 214738.340088), -- Charcoal
(21228, 5220, 1, 1, 2, 8589.658272), -- Metal Hardener
(21228, 1885, 1, 1, 2, 17894.991537), -- High-Grade Suede
(21228, 4041, 1, 1, 2, 1867.300077), -- Mold Hardener
(21228, 5271, 1, 1, 2, 286.347915), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21228, 8730, 1, 1, 2, 2385.843036), -- Life Stone - Level 67
(21228, 8740, 1, 1, 2, 596.460759), -- Mid-Grade Life Stone - Level 67
(21228, 8750, 1, 1, 2, 59.607117), -- High-Grade Life Stone - Level 67
(21228, 8760, 1, 1, 2, 11.68767), -- Top-Grade Life Stone - Level 67
-- Sepulcher Preacher
(21229, 5479, 1, 1, -1, 37315), -- Sealed Tallum Leather Armor Pattern
(21229, 4041, 1, 1, -1, 54837), -- Mold Hardener
(21229, 4044, 1, 1, -1, 210209), -- Thons
(21229, 57, 3110, 6350, 0, 700000), -- Adena
(21229, 6324, 1, 1, 1, 77.229401), -- Sealed Phoenix Earring
(21229, 6341, 1, 1, 1, 10733.28277), -- Sealed Phoenix Earring Gemstone
(21229, 6323, 1, 1, 1, 57.913519), -- Sealed Phoenix Necklace
(21229, 6343, 1, 1, 1, 8297.229256), -- Sealed Phoenix Necklace Beads
(21229, 6325, 1, 1, 1, 115.827038), -- Sealed Phoenix Ring
(21229, 6345, 1, 1, 1, 14845.518016), -- Sealed Phoenix Ring Gemstone
(21229, 1894, 1, 1, 2, 9077.747721), -- Crafted Leather
(21229, 4039, 1, 1, 2, 8623.849185), -- Mold Glue
(21229, 4041, 1, 1, 2, 2249.709483), -- Mold Hardener
(21229, 4044, 1, 1, 2, 8623.849185), -- Thons
(21229, 730, 1, 1, 2, 215.608176), -- Scroll: Enchant Armor (A-Grade)
(21229, 8731, 1, 1, 2, 2395.518972), -- Life Stone - Level 70
(21229, 8741, 1, 1, 2, 598.879743), -- Mid-Grade Life Stone - Level 70
(21229, 8751, 1, 1, 2, 59.89116), -- High-Grade Life Stone - Level 70
(21229, 8761, 1, 1, 2, 11.946375), -- Top-Grade Life Stone - Level 70
-- Sepulcher Guard
(21230, 5480, 1, 1, -1, 32628), -- Sealed Leather Armor of Nightmare Fabric
(21230, 5481, 1, 1, -1, 32628), -- Sealed Majestic Leather Armor Fabric
(21230, 5487, 1, 1, -1, 32744), -- Sealed Robe of Nightmare Fabric
(21230, 57, 3587, 7319, 0, 700000), -- Adena
(21230, 5292, 1, 1, 1, 95.7168), -- Sealed Dark Crystal Shield
(21230, 5494, 1, 1, 1, 9397.0203), -- Sealed Dark Crystal Shield Fragment
(21230, 5289, 1, 1, 1, 66.9783), -- Sealed Dark Crystal Helmet
(21230, 5525, 1, 1, 1, 6916.66488), -- Sealed Dark Crystal Helmet Design
(21230, 5294, 1, 1, 1, 66.9783), -- Sealed Tallum Helmet
(21230, 5526, 1, 1, 1, 6916.64142), -- Sealed Tallum Helm Design
(21230, 1895, 1, 1, 2, 85232.828844), -- Metallic Fiber
(21230, 4040, 1, 1, 2, 5966.306811), -- Mold Lubricant
(21230, 4042, 1, 1, 2, 4971.940659), -- Enria
(21230, 4043, 1, 1, 2, 9943.771419), -- Asofe
(21230, 730, 1, 1, 2, 248.591538), -- Scroll: Enchant Armor (A-Grade)
(21230, 8731, 1, 1, 2, 2762.201466), -- Life Stone - Level 70
(21230, 8741, 1, 1, 2, 690.495417), -- Mid-Grade Life Stone - Level 70
(21230, 8751, 1, 1, 2, 69.016572), -- High-Grade Life Stone - Level 70
(21230, 8761, 1, 1, 2, 13.847274), -- Top-Grade Life Stone - Level 70
-- Sepulcher Preacher
(21231, 729, 1, 1, -1, 812), -- Scroll: Enchant Weapon (A-Grade)
(21231, 1875, 1, 1, -1, 487115), -- Stone of Purity
(21231, 5480, 1, 1, -1, 32787), -- Sealed Leather Armor of Nightmare Fabric
(21231, 57, 3602, 7359, 0, 700000), -- Adena
(21231, 5292, 1, 1, 1, 96.18192), -- Sealed Dark Crystal Shield
(21231, 5494, 1, 1, 1, 9442.68357), -- Sealed Dark Crystal Shield Fragment
(21231, 5289, 1, 1, 1, 67.30377), -- Sealed Dark Crystal Helmet
(21231, 5525, 1, 1, 1, 6950.275272), -- Sealed Dark Crystal Helmet Design
(21231, 5294, 1, 1, 1, 67.30377), -- Sealed Tallum Helmet
(21231, 5526, 1, 1, 1, 6950.251698), -- Sealed Tallum Helm Design
(21231, 1872, 1, 3, 2, 199842.391552), -- Animal Bone
(21231, 1867, 1, 3, 2, 133227.995136), -- Animal Skin
(21231, 1881, 1, 1, 2, 39968.55808), -- Coarse Bone Powder
(21231, 1875, 1, 1, 2, 19984.27904), -- Stone of Purity
(21231, 4041, 1, 1, 2, 2606.47168), -- Mold Hardener
(21231, 729, 1, 1, 2, 33.503232), -- Scroll: Enchant Weapon (A-Grade)
(21231, 8732, 1, 1, 2, 2497.985024), -- Life Stone - Level 76
(21231, 8742, 1, 1, 2, 624.595968), -- Mid-Grade Life Stone - Level 76
(21231, 8752, 1, 1, 2, 62.220288), -- High-Grade Life Stone - Level 76
-- Barrow Sentinel
(21236, 1061, 1, 1, -1, 784398), -- Greater Healing Potion
(21236, 1900, 1, 1, -1, 141604), -- Enchanted Necklace Chain
(21236, 2153, 1, 1, -1, 201284), -- Recipe: Tiger's Eye Earring
(21236, 57, 546, 1092, 0, 700000), -- Adena
(21236, 69, 1, 1, 1, 57.082802), -- Bastard Sword
(21236, 125, 1, 1, 1, 57.082802), -- Spinebone Sword
(21236, 2021, 1, 1, 1, 1785.664764), -- Spinebone Sword Blade
(21236, 126, 1, 1, 1, 57.082802), -- Artisan's Sword
(21236, 128, 1, 1, 1, 57.08683), -- Knight's Sword
(21236, 1867, 1, 3, 2, 117877.019123), -- Animal Skin
(21236, 1872, 1, 1, 2, 235754.449743), -- Animal Bone
(21236, 1882, 1, 1, 2, 39292.202542), -- Leather
(21236, 2184, 1, 1, 2, 18573.328592), -- Recipe: Mithril Banded Gaiters
-- Barrow Monk
(21237, 1933, 1, 1, -1, 174667), -- Dark Stockings Fabric
(21237, 2183, 1, 1, -1, 97676), -- Recipe: Mithril Banded Mail
(21237, 1935, 1, 1, -1, 82942), -- Scale Mail Fragment
(21237, 57, 626, 1255, 0, 700000), -- Adena
(21237, 86, 1, 1, 1, 32.746078), -- Tomahawk
(21237, 179, 1, 1, 1, 32.746078), -- Mace of Prayer
(21237, 180, 1, 1, 1, 32.746078), -- Mace of Judgment
(21237, 2022, 1, 1, 1, 1263.70299), -- Mace of Judgment Head
(21237, 181, 1, 1, 1, 32.746078), -- Mace of Miracle
(21237, 182, 1, 1, 1, 32.746078), -- Doom Hammer
(21237, 183, 1, 1, 1, 32.746078), -- Mystic Staff
(21237, 184, 1, 1, 1, 32.746078), -- Conjuror's Staff
(21237, 2023, 1, 1, 1, 1005.325855), -- Conjuror's Staff Head
(21237, 185, 1, 1, 1, 32.748609), -- Staff of Mana
(21237, 1868, 1, 3, 2, 135219.311403), -- Thread
(21237, 1873, 1, 1, 2, 54087.627825), -- Silver Nugget
(21237, 5549, 1, 1, 2, 13521.786036), -- Metallic Thread
(21237, 1889, 1, 1, 2, 9014.846478), -- Compound Braid
(21237, 2265, 1, 1, 2, 1398.321771), -- Recipe: Spiked Club
(21237, 6037, 1, 1, 2, 270439.106487), -- Waking Scroll
-- Grave Sentinel
(21238, 1878, 1, 1, -1, 739986), -- Braided Hemp
(21238, 1884, 1, 3, -1, 569220), -- Cord
(21238, 1901, 1, 1, -1, 255520), -- Tiger's Eye Earring Stone
(21238, 57, 781, 1559, 0, 700000), -- Adena
(21238, 260, 1, 1, 1, 265), -- Triple-Edged Jamadhr
(21238, 1874, 1, 1, 2, 9367.725836), -- Oriharukon Ore
(21238, 1878, 1, 1, 2, 56205.943754), -- Braided Hemp
(21238, 1884, 1, 1, 2, 86471.125596), -- Cord
(21238, 1889, 1, 1, 2, 9367.725836), -- Compound Braid
(21238, 5220, 1, 1, 2, 5620.717754), -- Metal Hardener
(21238, 2190, 1, 1, 2, 10036.84911), -- Recipe: Mithril Stockings
(21238, 1341, 20, 60, 2, 234191.912114), -- Bone Arrow
-- Grave Monk
(21239, 1825, 1, 1, -1, 139345), -- Recipe: Oriharukon
(21239, 1902, 1, 1, -1, 197653), -- Elven Earring Beads
(21239, 2145, 1, 1, -1, 139345), -- Recipe: Mithril Alloy
(21239, 57, 824, 1645, 0, 700000), -- Adena
(21239, 279, 1, 1, 1, 93.89952), -- Reinforced Long Bow
(21239, 2040, 1, 1, 1, 5834.10048), -- Reinforced Long Bow Shaft
(21239, 1870, 1, 1, 2, 168071.726056), -- Coal
(21239, 1865, 1, 1, 2, 168071.726056), -- Varnish
(21239, 1874, 1, 1, 2, 11204.756261), -- Oriharukon Ore
(21239, 2145, 1, 1, 2, 12004.959515), -- Recipe: Mithril Alloy
(21239, 2208, 1, 1, 2, 17185.262911), -- Recipe: Ogre Power Gauntlets
(21239, 6036, 1, 1, 2, 5602.569201), -- Greater Magic Haste Potion
-- Barrow Overlord
(21240, 1903, 1, 1, -1, 372617), -- Elven Ring Piece
(21240, 1871, 1, 5, -1, 744614), -- Charcoal
(21240, 1866, 1, 3, -1, 744614), -- Suede
(21240, 57, 932, 1861, 0, 700000), -- Adena
(21240, 224, 1, 1, 1, 53.76128), -- Maingauche
(21240, 2038, 1, 1, 1, 3050.23872), -- Maingauche Edge
(21240, 1660, 1, 1, 1, 53.76128), -- Cursed Maingauche
(21240, 2044, 1, 1, 1, 3050.23872), -- Cursed Maingauche Edge
(21240, 1871, 2, 6, 2, 72170.28068), -- Charcoal
(21240, 1866, 1, 1, 2, 192453.499748), -- Suede
(21240, 1877, 1, 1, 2, 11547.157599), -- Adamantite Nugget
(21240, 1341, 60, 180, 2, 160378.061973), -- Bone Arrow
-- Barrow Priest
(21241, 4469, 1, 1, -1, 14471), -- Dye of STR (Str+1 Con-1)
(21241, 1905, 1, 1, -1, 246339), -- Omen Beast's Eye Earring Gemstone
(21241, 1805, 1, 1, -1, 8441), -- Recipe: Soulshot (C-Grade)
(21241, 57, 1020, 2061, 0, 700000), -- Adena
(21241, 396, 1, 1, 1, 346.880611), -- Salamander Skin Mail
(21241, 1952, 1, 1, 1, 20366.119389), -- Salamander Skin Mail Texture
(21241, 1872, 1, 3, 2, 121108.069957), -- Animal Bone
(21241, 1867, 1, 1, 2, 242215.712271), -- Animal Skin
(21241, 1881, 1, 1, 2, 24221.69952), -- Coarse Bone Powder
(21241, 1875, 1, 1, 2, 12110.84976), -- Stone of Purity
(21241, 2162, 1, 1, 2, 8776.089646), -- Recipe: Aquastone Necklace
(21241, 2990, 1, 1, 2, 14417.556102), -- Recipe: Chain Boots
(21241, 2206, 1, 1, 2, 4793.022744), -- Recipe: Mithril Shirt
-- Grave Overlord
(21242, 1908, 1, 1, -1, 292039), -- Moonstone Earring Wire
(21242, 2163, 1, 1, -1, 157343), -- Recipe: Earring of Protection
(21242, 1909, 1, 1, -1, 416466), -- Aquastone Ring Wire
(21242, 57, 1220, 2478, 0, 700000), -- Adena
(21242, 96, 1, 1, 1, 27.557894), -- Scythe
(21242, 2062, 1, 1, 1, 1905.10684), -- Scythe Edge
(21242, 298, 1, 1, 1, 27.557894), -- Orcish Glaive
(21242, 2075, 1, 1, 1, 1905.10684), -- Orcish Glaive Blade
(21242, 302, 1, 1, 1, 27.557894), -- Body Slasher
(21242, 2076, 1, 1, 1, 1905.112638), -- Body Slasher Blade
(21242, 1873, 1, 1, 2, 58300.467003), -- Silver Nugget
(21242, 1868, 1, 1, 2, 291501.466809), -- Thread
(21242, 1876, 1, 1, 2, 29150.01645), -- Mithril Ore
(21242, 1895, 1, 1, 2, 41643.066687), -- Metallic Fiber
(21242, 4042, 1, 1, 2, 2429.240388), -- Enria
(21242, 2214, 1, 1, 2, 3616.512093), -- Recipe: Dwarven Chain Gaiters
(21242, 8723, 1, 1, 2, 5830.00329), -- Life Stone - Level 46
(21242, 8733, 1, 1, 2, 1457.717874), -- Mid-Grade Life Stone - Level 46
(21242, 8743, 1, 1, 2, 145.858608), -- High-Grade Life Stone - Level 46
(21242, 8753, 1, 1, 2, 28.650798), -- Top-Grade Life Stone - Level 46
-- Grave Priest
(21243, 951, 1, 1, -1, 5797), -- Scroll: Enchant Weapon (C-Grade)
(21243, 2166, 1, 1, -1, 108082), -- Recipe: Earrings of Binding (100%)
(21243, 1911, 1, 1, -1, 237145), -- Earring of Protection Gemstone
(21243, 57, 1258, 2567, 0, 700000), -- Adena
(21243, 398, 1, 1, 1, 102.96804), -- Plated Leather
(21243, 1966, 1, 1, 1, 6446.93235), -- Plated Leather Fragment
(21243, 399, 1, 1, 1, 94.95058), -- Rind Leather Armor
(21243, 1975, 1, 1, 1, 5800.00284), -- Rind Leather Armor Design
(21243, 418, 1, 1, 1, 164.6561), -- Plated Leather Gaiters
(21243, 1967, 1, 1, 1, 9630.82474), -- Plated Leather Gaiters Material
(21243, 419, 1, 1, 1, 152.03357), -- Rind Leather Gaiters
(21243, 1976, 1, 1, 1, 10737.63178), -- Rind Leather Gaiters Material
(21243, 1873, 1, 1, 2, 56508.534733), -- Silver Nugget
(21243, 1868, 1, 1, 2, 282543.506283), -- Thread
(21243, 1876, 1, 1, 2, 28254.475521), -- Mithril Ore
(21243, 1895, 1, 1, 2, 40363.239095), -- Metallic Fiber
(21243, 4042, 1, 1, 2, 2354.643704), -- Enria
(21243, 951, 1, 1, 2, 256.862653), -- Scroll: Enchant Weapon (C-Grade)
(21243, 8724, 1, 1, 2, 4708.871099), -- Life Stone - Level 49
(21243, 8734, 1, 1, 2, 1177.321852), -- Mid-Grade Life Stone - Level 49
(21243, 8744, 1, 1, 2, 117.815447), -- High-Grade Life Stone - Level 49
(21243, 8754, 1, 1, 2, 23.729613), -- Top-Grade Life Stone - Level 49
-- Crypt Archon
(21244, 4601, 1, 1, -1, 7887), -- Greater Dye of STR (Str+3 Con-3)
(21244, 1539, 1, 1, -1, 788726), -- Greater Healing Potion
(21244, 1914, 1, 1, -1, 199397), -- Earring of Seal Gemstone
(21244, 57, 1404, 2854, 0, 700000), -- Adena
(21244, 60, 1, 1, 1, 119.616525), -- Composite Armor
(21244, 1977, 1, 1, 1, 10855.383475), -- Composite Armor Temper
(21244, 1865, 1, 1, 2, 133432.516646), -- Varnish
(21244, 1870, 1, 1, 2, 133432.516646), -- Coal
(21244, 1879, 1, 1, 2, 22238.648344), -- Cokes
(21244, 1875, 1, 1, 2, 8895.584654), -- Stone of Purity
(21244, 4040, 1, 1, 2, 2668.612738), -- Mold Lubricant
(21244, 2170, 1, 1, 2, 3147.008095), -- Recipe: Nassen's Earring
(21244, 2970, 1, 1, 2, 4731.633973), -- Recipe: Ring of Seal
(21244, 8725, 1, 1, 2, 3706.545821), -- Life Stone - Level 52
(21244, 8735, 1, 1, 2, 926.714778), -- Mid-Grade Life Stone - Level 52
(21244, 8745, 1, 1, 2, 92.734136), -- High-Grade Life Stone - Level 52
(21244, 8755, 1, 1, 2, 18.484169), -- Top-Grade Life Stone - Level 52
-- Crypt Inquisitor
(21245, 2169, 1, 1, -1, 69443), -- Recipe: Necklace of Seal
(21245, 1915, 1, 1, -1, 345683), -- Ring of Ages Gemstone
(21245, 2170, 1, 1, -1, 92536), -- Recipe: Nassen's Earring
(21245, 57, 1558, 3150, 0, 700000), -- Adena
(21245, 60, 1, 1, 1, 132.237567), -- Composite Armor
(21245, 1977, 1, 1, 1, 12000.762433), -- Composite Armor Temper
(21245, 1871, 1, 1, 2, 135209.754141), -- Charcoal
(21245, 1866, 1, 1, 2, 90139.836094), -- Suede
(21245, 1877, 1, 1, 2, 5408.282), -- Adamantite Nugget
(21245, 4041, 1, 1, 2, 1175.809673), -- Mold Hardener
(21245, 4040, 1, 1, 2, 2704.141), -- Mold Lubricant
(21245, 2353, 1, 1, 2, 220.510407), -- Recipe: Samurai Longsword
(21245, 4122, 1, 1, 2, 6009.338795), -- Recipe: Maestro Holder (100%)
(21245, 8309, 1, 1, 2, 155.856854), -- Recipe: Spell Breaker (100%)
(21245, 8725, 1, 1, 2, 3755.806018), -- Life Stone - Level 52
(21245, 8735, 1, 1, 2, 939.07442), -- Mid-Grade Life Stone - Level 52
(21245, 8745, 1, 1, 2, 93.907442), -- High-Grade Life Stone - Level 52
(21245, 8755, 1, 1, 2, 18.683156), -- Top-Grade Life Stone - Level 52
-- Tomb Archon
(21246, 1918, 1, 1, -1, 201354), -- Nassen's Earring Gemstone
(21246, 4042, 1, 1, -1, 77488), -- Enria
(21246, 1867, 1, 13, -1, 885576), -- Animal Skin
(21246, 57, 1837, 3743, 0, 700000), -- Adena
(21246, 855, 1, 1, 1, 175.636134), -- Nassen's Earring
(21246, 1918, 1, 1, 1, 12391.556392), -- Nassen's Earring Gemstone
(21246, 119, 1, 1, 1, 131.746694), -- Necklace of Seal
(21246, 1920, 1, 1, 1, 9790.284145), -- Necklace of Seal Chain
(21246, 886, 1, 1, 1, 263.454201), -- Ring of Seal
(21246, 2917, 1, 1, 1, 16434.322434), -- Ring of Seal Gemstone
(21246, 1867, 1, 1, 2, 190739.38488), -- Animal Skin
(21246, 1872, 1, 1, 2, 190739.38488), -- Animal Bone
(21246, 1882, 1, 1, 2, 31789.89748), -- Leather
(21246, 1894, 1, 1, 2, 5019.322092), -- Crafted Leather
(21246, 4042, 1, 1, 2, 2384.456702), -- Enria
(21246, 4127, 1, 1, 2, 3540.881756), -- Recipe: Adamantite Ring (100%)
(21246, 4965, 1, 1, 2, 164.652288), -- Recipe: Sprite's Staff (60%)
(21246, 4183, 1, 1, 2, 164.652288), -- Recipe: Heavy War Axe (100%)
(21246, 8726, 1, 1, 2, 3311.483386), -- Life Stone - Level 55
(21246, 8736, 1, 1, 2, 827.978042), -- Mid-Grade Life Stone - Level 55
(21246, 8746, 1, 1, 2, 82.754926), -- High-Grade Life Stone - Level 55
(21246, 8756, 1, 1, 2, 17.15128), -- Top-Grade Life Stone - Level 55
-- Tomb Inquisitor
(21247, 4613, 1, 1, -1, 6564), -- Greater Dye of STR (Str+4 Con-4)
(21247, 4049, 1, 1, -1, 249606), -- Adamantite Earring Gemstone
(21247, 4129, 1, 1, -1, 51501), -- Recipe: Earrings of Black Ore (100%)
(21247, 57, 1877, 3833, 0, 700000), -- Adena
(21247, 554, 1, 1, 1, 88.050656), -- Sealed Zubei's Boots
(21247, 4097, 1, 1, 1, 9145.449344), -- Sealed Zubei's Boots Design
(21247, 600, 1, 1, 1, 88.050656), -- Sealed Avadon Boots
(21247, 4098, 1, 1, 1, 9145.449344), -- Sealed Avadon Boots Design
(21247, 612, 1, 1, 1, 88.050656), -- Sealed Zubei's Gauntlets
(21247, 4100, 1, 1, 1, 9145.449344), -- Sealed Zubei's Gauntlets Part
(21247, 2464, 1, 1, 1, 88.050656), -- Sealed Avadon Gloves
(21247, 4073, 1, 1, 1, 9145.449344), -- Sealed Avadon Gloves Part
(21247, 1872, 1, 1, 2, 170382.461206), -- Animal Bone
(21247, 1867, 1, 1, 2, 170382.461206), -- Animal Skin
(21247, 1881, 1, 1, 2, 17038.171454), -- Coarse Bone Powder
(21247, 1875, 1, 1, 2, 8519.085727), -- Stone of Purity
(21247, 4041, 1, 1, 2, 1111.039008), -- Mold Hardener
(21247, 4131, 1, 1, 2, 1038.985739), -- Recipe: Necklace of Black Ore (100%)
(21247, 4173, 1, 1, 2, 1589.278581), -- Recipe: Sealed Blue Wolf Gloves (100%)
(21247, 8727, 1, 1, 2, 2555.837718), -- Life Stone - Level 58
(21247, 8737, 1, 1, 2, 638.772763), -- Mid-Grade Life Stone - Level 58
(21247, 8747, 1, 1, 2, 63.839943), -- High-Grade Life Stone - Level 58
(21247, 8757, 1, 1, 2, 13.066655), -- Top-Grade Life Stone - Level 58
-- Crypt Guardian
(21248, 4050, 1, 1, -1, 322099), -- Adamantite Ring Wire
(21248, 4130, 1, 1, -1, 84394), -- Recipe: Ring of Black Ore (100%)
(21248, 4051, 1, 1, -1, 201616), -- Adamantite Necklace Chain
(21248, 57, 2056, 4180, 0, 700000), -- Adena
(21248, 633, 1, 1, 1, 91.624004), -- Zubei's Shield
(21248, 4101, 1, 1, 1, 11126.113214), -- Zubei's Shield Fragment
(21248, 673, 1, 1, 1, 91.624004), -- Avadon Shield
(21248, 4439, 1, 1, 1, 13236.273544), -- Avadon Shield Fragment
(21248, 503, 1, 1, 1, 64.12842), -- Zubei's Helmet
(21248, 4102, 1, 1, 1, 8620.075154), -- Zubei's Helmet Design
(21248, 2415, 1, 1, 1, 64.12842), -- Avadon Circlet
(21248, 4072, 1, 1, 1, 8620.03324), -- Avadon Circlet Pattern
(21248, 1869, 1, 1, 2, 139600.894576), -- Iron Ore
(21248, 1864, 1, 1, 2, 279201.341848), -- Stem
(21248, 1880, 1, 1, 2, 13959.910536), -- Steel
(21248, 5550, 1, 1, 2, 1861.231944), -- Durable Metal Plate
(21248, 4043, 1, 1, 2, 4653.303512), -- Asofe
(21248, 4159, 1, 1, 2, 395.416736), -- Recipe: Blue Wolf Leather Armor (100%)
(21248, 8728, 1, 1, 2, 2326.875408), -- Life Stone - Level 61
(21248, 8738, 1, 1, 2, 581.4952), -- Mid-Grade Life Stone - Level 61
(21248, 8748, 1, 1, 2, 58.14952), -- High-Grade Life Stone - Level 61
(21248, 8758, 1, 1, 2, 11.629904), -- Top-Grade Life Stone - Level 61
(21248, 6036, 1, 1, 2, 4653.750816), -- Greater Magic Haste Potion
-- Crypt Sage
(21249, 5230, 1, 1, -1, 7586), -- Recipe: Mithril Arrow (100%)
(21249, 4052, 1, 1, -1, 201435), -- Earring of Black Ore Piece
(21249, 4053, 1, 1, -1, 243872), -- Ring of Black Ore Gemstone
(21249, 57, 2256, 4571, 0, 700000), -- Adena
(21249, 358, 1, 1, 1, 22.633608), -- Blue Wolf Breastplate
(21249, 4078, 1, 1, 1, 4091.595561), -- Blue Wolf Breastplate Part
(21249, 2381, 1, 1, 1, 13.930326), -- Doom Plate Armor
(21249, 4081, 1, 1, 1, 2760.805383), -- Doom Plate Armor Temper
(21249, 2380, 1, 1, 1, 36.208698), -- Blue Wolf Gaiters
(21249, 4080, 1, 1, 1, 5761.826424), -- Blue Wolf Gaiters Material
(21249, 1871, 1, 1, 2, 168059.921611), -- Charcoal
(21249, 1866, 1, 1, 2, 112039.849495), -- Suede
(21249, 1877, 1, 1, 2, 6722.361496), -- Adamantite Nugget
(21249, 4041, 1, 1, 2, 1461.306046), -- Mold Hardener
(21249, 4040, 1, 1, 2, 3361.180748), -- Mold Lubricant
(21249, 5166, 1, 1, 2, 224.00012), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21249, 8729, 1, 1, 2, 2240.885411), -- Life Stone - Level 64
(21249, 8739, 1, 1, 2, 560.295037), -- Mid-Grade Life Stone - Level 64
(21249, 8749, 1, 1, 2, 56.00003), -- High-Grade Life Stone - Level 64
(21249, 8759, 1, 1, 2, 11.200006), -- Top-Grade Life Stone - Level 64
-- Tomb Guardian
(21250, 4052, 1, 1, -1, 235314), -- Earring of Black Ore Piece
(21250, 5230, 1, 1, -1, 8862), -- Recipe: Mithril Arrow (100%)
(21250, 4053, 1, 1, -1, 284889), -- Ring of Black Ore Gemstone
(21250, 57, 2634, 5340, 0, 700000), -- Adena
(21250, 171, 1, 1, 1, 6.484956), -- Deadman's Glory
(21250, 4116, 1, 1, 1, 1429.560294), -- Deadman's Glory Stone
(21250, 175, 1, 1, 1, 6.484956), -- Art of Battle Axe
(21250, 4117, 1, 1, 1, 1429.560294), -- Art of Battle Axe Blade
(21250, 210, 1, 1, 1, 6.484956), -- Staff of Evil Spirits
(21250, 4118, 1, 1, 1, 1354.424544), -- Evil Spirit Head
(21250, 1871, 1, 1, 2, 178478.266995), -- Charcoal
(21250, 1866, 1, 1, 2, 118985.51133), -- Suede
(21250, 1877, 1, 1, 2, 7139.229822), -- Adamantite Nugget
(21250, 4041, 1, 1, 2, 1552.071141), -- Mold Hardener
(21250, 4040, 1, 1, 2, 3569.614911), -- Mold Lubricant
(21250, 1830, 1, 1, 2, 71391.306798), -- Scroll of Escape: Castle
(21250, 8729, 1, 1, 2, 2379.908511), -- Life Stone - Level 64
(21250, 8739, 1, 1, 2, 594.8532), -- Mid-Grade Life Stone - Level 64
(21250, 8749, 1, 1, 2, 59.48532), -- High-Grade Life Stone - Level 64
(21250, 8759, 1, 1, 2, 11.897064), -- Top-Grade Life Stone - Level 64
(21250, 1344, 20, 60, 2, 111548.854908), -- Mithril Arrow
-- Tomb Sage
(21251, 5230, 1, 1, -1, 9506), -- Recipe: Mithril Arrow (100%)
(21251, 4054, 1, 1, -1, 140430), -- Necklace of Black Ore Beads
(21251, 4053, 1, 1, -1, 305600), -- Ring of Black Ore Gemstone
(21251, 57, 2811, 5744, 0, 700000), -- Adena
(21251, 2398, 1, 1, 1, 28.351631), -- Blue Wolf Tunic
(21251, 4084, 1, 1, 1, 4576.460064), -- Blue Wolf Tunic Fabric
(21251, 2399, 1, 1, 1, 28.351631), -- Tunic of Doom
(21251, 4085, 1, 1, 1, 4576.460064), -- Tunic of Doom Pattern
(21251, 2403, 1, 1, 1, 45.397264), -- Blue Wolf Stockings
(21251, 4086, 1, 1, 1, 6179.269382), -- Blue Wolf Stockings Pattern
(21251, 2404, 1, 1, 1, 45.397264), -- Stockings of Doom
(21251, 4087, 1, 1, 1, 6179.3127), -- Stockings of Doom Pattern
(21251, 1866, 1, 1, 2, 127635.625799), -- Suede
(21251, 1871, 1, 3, 2, 63817.605053), -- Charcoal
(21251, 5220, 1, 1, 2, 7658.312139), -- Metal Hardener
(21251, 1885, 1, 1, 2, 15954.29734), -- High-Grade Suede
(21251, 4041, 1, 1, 2, 1664.850465), -- Mold Hardener
(21251, 1830, 1, 1, 2, 76581.458618), -- Scroll of Escape: Castle
(21251, 8730, 1, 1, 2, 2127.101081), -- Life Stone - Level 67
(21251, 8740, 1, 1, 2, 531.671347), -- Mid-Grade Life Stone - Level 67
(21251, 8750, 1, 1, 2, 53.208704), -- High-Grade Life Stone - Level 67
(21251, 8760, 1, 1, 2, 10.808018), -- Top-Grade Life Stone - Level 67
(21251, 1344, 20, 60, 2, 119658.061436), -- Mithril Arrow
-- Crypt Guard 
(21252, 5478, 1, 1, -1, 61132), -- Sealed Dark Crystal Leather Armor Pattern
(21252, 4053, 1, 1, -1, 311606), -- Ring of Black Ore Gemstone
(21252, 5230, 1, 1, -1, 9693), -- Recipe: Mithril Arrow (100%)
(21252, 57, 2875, 5849, 0, 700000), -- Adena
(21252, 5297, 1, 1, 1, 26.797392), -- Sealed Dark Crystal Leather Armor
(21252, 5478, 1, 1, 1, 3009.187152), -- Sealed Dark Crystal Leather Armor Pattern
(21252, 5301, 1, 1, 1, 16.483824), -- Sealed Tallum Leather Armor
(21252, 5479, 1, 1, 1, 2117.470896), -- Sealed Tallum Leather Armor Pattern
(21252, 5298, 1, 1, 1, 42.853968), -- Sealed Dark Crystal Leggings
(21252, 5482, 1, 1, 1, 4723.206768), -- Sealed Dark Crystal Leggings Design
(21252, 10579, 1, 1, 2, 11545), -- Forgotten Scroll - Improve Combat
(21252, 10583, 1, 1, 2, 11545), -- Forgotten Scroll - Improve Shield Defense
(21252, 10608, 1, 1, 2, 11545), -- Forgotten Scroll - Chant of Combat
(21252, 14214, 1, 1, 2, 11545), -- Forgotten Scroll - Chant of Movement
-- Crypt Preacher
(21253, 1807, 1, 1, -1, 8408), -- Recipe: Soulshot (A-Grade)
(21253, 5479, 1, 1, -1, 37315), -- Sealed Tallum Leather Armor Pattern
(21253, 3035, 1, 1, -1, 8408), -- Recipe: Spiritshot A
(21253, 57, 3110, 6350, 0, 700000), -- Adena
(21253, 5304, 1, 1, 1, 29.057478), -- Sealed Tallum Tunic
(21253, 5485, 1, 1, 1, 3262.981318), -- Sealed Tallum Tunic Texture
(21253, 5308, 1, 1, 1, 17.874066), -- Sealed Dark Crystal Robe
(21253, 5486, 1, 1, 1, 2296.057914), -- Sealed Dark Crystal Robe Fabric
(21253, 5305, 1, 1, 1, 46.468262), -- Sealed Tallum Stockings
(21253, 5489, 1, 1, 1, 5121.560962), -- Sealed Tallum Stockings Fabric
(21253, 10580, 1, 1, 2, 11642.455968), -- Forgotten Scroll - Improve Magic
(21253, 10582, 1, 1, 2, 11642.455968), -- Forgotten Scroll - Improve Critical Attack
(21253, 10610, 1, 1, 2, 11642.455968), -- Forgotten Scroll - Chant of Blood Awakening
(21253, 14215, 1, 1, 2, 12064.632096), -- Forgotten Scroll - Combat of Pa'agrio
-- Tomb Guard
(21254, 5480, 1, 1, -1, 32628), -- Sealed Leather Armor of Nightmare Fabric
(21254, 729, 1, 1, -1, 808), -- Scroll: Enchant Weapon (A-Grade)
(21254, 1877, 1, 1, -1, 290856), -- Adamantite Nugget
(21254, 57, 3587, 7319, 0, 700000), -- Adena
(21254, 6324, 1, 1, 1, 89.04905), -- Sealed Phoenix Earring
(21254, 6341, 1, 1, 1, 12375.9685), -- Sealed Phoenix Earring Gemstone
(21254, 6323, 1, 1, 1, 66.77695), -- Sealed Phoenix Necklace
(21254, 6343, 1, 1, 1, 9567.0868), -- Sealed Phoenix Necklace Beads
(21254, 6325, 1, 1, 1, 133.5539), -- Sealed Phoenix Ring
(21254, 6345, 1, 1, 1, 17117.5648), -- Sealed Phoenix Ring Gemstone
(21254, 14216, 1, 1, 2, 53696), -- Forgotten Scroll - Critical of Pa'agrio
-- Tomb Preacher
(21255, 4041, 1, 1, -1, 67285), -- Mold Hardener
(21255, 5481, 1, 1, -1, 34721), -- Sealed Majestic Leather Armor Fabric
(21255, 5487, 1, 1, -1, 34844), -- Sealed Robe of Nightmare Fabric
(21255, 57, 3814, 7793, 0, 700000), -- Adena
(21255, 5297, 1, 1, 1, 35.65434), -- Sealed Dark Crystal Leather Armor
(21255, 5478, 1, 1, 1, 4003.76954), -- Sealed Dark Crystal Leather Armor Pattern
(21255, 5301, 1, 1, 1, 21.93198), -- Sealed Tallum Leather Armor
(21255, 5479, 1, 1, 1, 2817.32742), -- Sealed Tallum Leather Armor Pattern
(21255, 5298, 1, 1, 1, 57.01786), -- Sealed Dark Crystal Leggings
(21255, 5482, 1, 1, 1, 6284.29886), -- Sealed Dark Crystal Leggings Design
(21255, 1873, 1, 1, 2, 114281.750744), -- Silver Nugget
(21255, 1868, 3, 9, 2, 95234.662968), -- Thread
(21255, 1876, 1, 1, 2, 57140.875372), -- Mithril Ore
(21255, 1895, 1, 1, 2, 81629.82196), -- Metallic Fiber
(21255, 4042, 1, 1, 2, 4761.771944), -- Enria
(21255, 5282, 1, 1, 2, 126.861612), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21255, 6671, 1, 1, 2, 31744.887656), -- Deluxe Chest Key - Grade 7
(21255, 8732, 1, 1, 2, 2380.885972), -- Life Stone - Level 76
(21255, 8742, 1, 1, 2, 595.124504), -- Mid-Grade Life Stone - Level 76
(21255, 8752, 1, 1, 2, 59.357268), -- High-Grade Life Stone - Level 76
-- Underground Werewolf
(21256, 1804, 1, 1, -1, 12984), -- Recipe: Soulshot (D-Grade)
(21256, 1898, 1, 1, -1, 33344), -- Blue Diamond Necklace Gem
(21256, 1872, 1, 1, -1, 432806), -- Animal Bone
(21256, 57, 149, 262, 0, 700000), -- Adena
(21256, 27, 1, 1, 1, 337.62267), -- Hard Leather Shirt
(21256, 1927, 1, 1, 1, 3824.63334), -- Hard Leather Shirt Pattern
(21256, 33, 1, 1, 1, 541.71216), -- Hard Leather Gaiters
(21256, 1929, 1, 1, 1, 6186.03183), -- Hard Leather Gaiters Material
(21256, 1867, 1, 1, 2, 42614.618235), -- Animal Skin
(21256, 1872, 1, 1, 2, 42614.618235), -- Animal Bone
(21256, 1882, 1, 1, 2, 7102.4849), -- Leather
(21256, 5153, 1, 1, 2, 1278.40846), -- Recipe: Soulshot (D) Compressed Package (100%)
(21256, 8294, 1, 1, 2, 781.48686), -- Recipe: Steel Sword (100%)
(21256, 735, 1, 1, 2, 2663.38331), -- Alacrity Potion
-- Evil Eye Seer
(21257, 1868, 1, 1, -1, 511527), -- Thread
(21257, 734, 1, 1, -1, 42627), -- Haste Potion
(21257, 1897, 1, 1, -1, 60896), -- Necklace of Wisdom Chain
(21257, 57, 122, 202, 0, 700000), -- Adena
(21257, 217, 1, 1, 1, 144), -- Shining Knife
(21257, 218, 1, 1, 1, 144), -- Throwing Knife
(21257, 1868, 1, 1, 2, 100731.527675), -- Thread
(21257, 1873, 1, 1, 2, 20146.33055), -- Silver Nugget
(21257, 735, 1, 1, 2, 4197.141775), -- Alacrity Potion
-- Fallen Orc Shaman
(21259, 4613, 1, 1, -1, 7283), -- Greater Dye of STR (Str+4 Con-4)
(21259, 4049, 1, 1, -1, 276943), -- Adamantite Earring Gemstone
(21259, 4129, 1, 1, -1, 57142), -- Recipe: Earrings of Black Ore (100%)
(21259, 57, 2085, 4248, 0, 700000), -- Adena
(21259, 229, 1, 1, 1, 11.674131), -- Kris
(21259, 4109, 1, 1, 1, 2196.825869), -- Kris Edge
(21259, 243, 1, 1, 1, 11.674131), -- Hell Knife
(21259, 4110, 1, 1, 1, 2196.825869), -- Hell Knife Edge
(21259, 1873, 1, 1, 2, 62384.21973), -- Silver Nugget
(21259, 1868, 1, 1, 2, 311920.18656), -- Thread
(21259, 1876, 1, 1, 2, 31192.109865), -- Mithril Ore
(21259, 1895, 1, 1, 2, 44560.15695), -- Metallic Fiber
(21259, 4042, 1, 1, 2, 2599.4565), -- Enria
(21259, 947, 1, 1, 2, 62.478165), -- Scroll: Enchant Weapon (B-Grade)
(21259, 8728, 1, 1, 2, 2599.4565), -- Life Stone - Level 61
(21259, 8738, 1, 1, 2, 649.864125), -- Mid-Grade Life Stone - Level 61
(21259, 8748, 1, 1, 2, 64.75839), -- High-Grade Life Stone - Level 61
(21259, 8758, 1, 1, 2, 12.313215), -- Top-Grade Life Stone - Level 61
-- Ol Mahum Transcender
(21261, 2169, 1, 1, -1, 29259), -- Recipe: Necklace of Seal
(21261, 1914, 1, 1, -1, 92873), -- Earring of Seal Gemstone
(21261, 2170, 1, 1, -1, 38989), -- Recipe: Nassen's Earring
(21261, 57, 654, 1329, 0, 700000), -- Adena
(21261, 231, 1, 1, 1, 10.346928), -- Grace Dagger
(21261, 2106, 1, 1, 1, 931.653072), -- Grace Dagger Edge
(21261, 233, 1, 1, 1, 10.346928), -- Dark Screamer
(21261, 2107, 1, 1, 1, 931.653072), -- Dark Screamer Edge
(21261, 1869, 1, 1, 2, 62148.7397), -- Iron Ore
(21261, 1864, 1, 1, 2, 124297.69125), -- Stem
(21261, 1880, 1, 1, 2, 6214.8316), -- Steel
(21261, 5550, 1, 1, 2, 828.54535), -- Durable Metal Plate
(21261, 4043, 1, 1, 2, 2071.68115), -- Asofe
(21261, 2231, 1, 1, 2, 267.7784), -- Recipe: Full Plate Armor
(21261, 8725, 1, 1, 2, 1726.36565), -- Life Stone - Level 52
(21261, 8735, 1, 1, 2, 431.53845), -- Mid-Grade Life Stone - Level 52
(21261, 8745, 1, 1, 2, 43.2174), -- High-Grade Life Stone - Level 52
(21261, 8755, 1, 1, 2, 8.68585), -- Top-Grade Life Stone - Level 52
(21261, 1539, 1, 1, 2, 13810.9252), -- Greater Healing Potion
-- Ol Mahum Transcender
(21262, 2169, 1, 1, -1, 39317), -- Recipe: Necklace of Seal
(21262, 1914, 1, 1, -1, 124797), -- Earring of Seal Gemstone
(21262, 2170, 1, 1, -1, 52391), -- Recipe: Nassen's Earring
(21262, 57, 879, 1786, 0, 700000), -- Adena
(21262, 228, 1, 1, 1, 17.400236), -- Crystal Dagger
(21262, 2119, 1, 1, 1, 1868.599764), -- Crystal Dagger Blade
(21262, 1869, 1, 1, 2, 74564.102417), -- Iron Ore
(21262, 1864, 1, 1, 2, 149128.204834), -- Stem
(21262, 1880, 1, 1, 2, 7456.334123), -- Steel
(21262, 5550, 1, 1, 2, 994.110222), -- Durable Metal Plate
(21262, 4043, 1, 1, 2, 2485.529284), -- Asofe
(21262, 2231, 1, 1, 2, 321.474643), -- Recipe: Full Plate Armor
(21262, 8726, 1, 1, 2, 1726.118387), -- Life Stone - Level 55
(21262, 8736, 1, 1, 2, 431.593029), -- Mid-Grade Life Stone - Level 55
(21262, 8746, 1, 1, 2, 43.13393), -- High-Grade Life Stone - Level 55
(21262, 8756, 1, 1, 2, 8.626786), -- Top-Grade Life Stone - Level 55
(21262, 1539, 1, 1, 2, 16569.772345), -- Greater Healing Potion
-- Ol Mahum Transcender
(21263, 2169, 1, 1, -1, 55228), -- Recipe: Necklace of Seal
(21263, 1914, 1, 1, -1, 175302), -- Earring of Seal Gemstone
(21263, 2170, 1, 1, -1, 73594), -- Recipe: Nassen's Earring
(21263, 57, 1233, 2512, 0, 700000), -- Adena
(21263, 228, 1, 1, 1, 24.439674), -- Crystal Dagger
(21263, 2119, 1, 1, 1, 2624.560326), -- Crystal Dagger Blade
(21263, 1869, 1, 1, 2, 104739.863676), -- Iron Ore
(21263, 1864, 1, 1, 2, 209479.727352), -- Stem
(21263, 1880, 1, 1, 2, 10473.879444), -- Steel
(21263, 5550, 1, 1, 2, 1396.422216), -- Durable Metal Plate
(21263, 4043, 1, 1, 2, 3491.411952), -- Asofe
(21263, 2231, 1, 1, 2, 451.574004), -- Recipe: Full Plate Armor
(21263, 8726, 1, 1, 2, 2424.670836), -- Life Stone - Level 55
(21263, 8736, 1, 1, 2, 606.256812), -- Mid-Grade Life Stone - Level 55
(21263, 8746, 1, 1, 2, 60.59004), -- High-Grade Life Stone - Level 55
(21263, 8756, 1, 1, 2, 12.118008), -- Top-Grade Life Stone - Level 55
(21263, 1539, 1, 1, 2, 23275.48566), -- Greater Healing Potion
-- Ol Mahum Transcender
(21264, 2169, 1, 1, -1, 76366), -- Recipe: Necklace of Seal
(21264, 1914, 1, 1, -1, 242396), -- Earring of Seal Gemstone
(21264, 2170, 1, 1, -1, 101761), -- Recipe: Nassen's Earring
(21264, 57, 1704, 3471, 0, 700000), -- Adena
(21264, 229, 1, 1, 1, 9.538587), -- Kris
(21264, 4109, 1, 1, 1, 1794.961413), -- Kris Edge
(21264, 243, 1, 1, 1, 9.538587), -- Hell Knife
(21264, 4110, 1, 1, 1, 1794.961413), -- Hell Knife Edge
(21264, 1869, 1, 1, 2, 115861.975602), -- Iron Ore
(21264, 1864, 1, 1, 2, 231723.557413), -- Stem
(21264, 1880, 1, 1, 2, 11586.118802), -- Steel
(21264, 5550, 1, 1, 2, 1544.842093), -- Durable Metal Plate
(21264, 4043, 1, 1, 2, 3861.908337), -- Asofe
(21264, 2231, 1, 1, 2, 499.326988), -- Recipe: Full Plate Armor
(21264, 8727, 1, 1, 2, 2317.066244), -- Life Stone - Level 58
(21264, 8737, 1, 1, 2, 579.266561), -- Mid-Grade Life Stone - Level 58
(21264, 8747, 1, 1, 2, 57.887277), -- High-Grade Life Stone - Level 58
(21264, 8757, 1, 1, 2, 11.419939), -- Top-Grade Life Stone - Level 58
(21264, 1539, 1, 1, 2, 25747.630744), -- Greater Healing Potion
-- Cave Ant Larva
(21265, 1864, 1, 3, -1, 627198), -- Stem
(21265, 1869, 1, 1, -1, 627198), -- Iron Ore
(21265, 1901, 1, 1, -1, 86630), -- Tiger's Eye Earring Stone
(21265, 57, 264, 530, 0, 700000), -- Adena
(21265, 83, 1, 1, 1, 20.17704), -- Sword of Magic
(21265, 144, 1, 1, 1, 20.17704), -- Sword of Occult
(21265, 124, 1, 1, 1, 14.947296), -- Two-Handed Sword
(21265, 2026, 1, 1, 1, 668.803278), -- Two-Handed Sword Edge
(21265, 127, 1, 1, 1, 14.947296), -- Crimson Sword
(21265, 130, 1, 1, 1, 14.94805), -- Elven Sword
(21265, 1864, 1, 1, 2, 133390.472304), -- Stem
(21265, 1869, 1, 1, 2, 66695.236152), -- Iron Ore
(21265, 1878, 1, 1, 2, 26678.20444), -- Braided Hemp
(21265, 1884, 1, 1, 2, 41043.137648), -- Cord
(21265, 2154, 1, 1, 2, 7140.949456), -- Recipe: Elven Earring
-- Cave Ant Larva
(21268, 1940, 1, 1, -1, 174118), -- Iron Boots Design
(21268, 2156, 1, 1, -1, 93327), -- Recipe: Elven Necklace
(21268, 2026, 1, 1, -1, 14041), -- Two-Handed Sword Edge
(21268, 57, 492, 986, 0, 700000), -- Adena
(21268, 278, 1, 1, 1, 83.430282), -- Gastraphetes
(21268, 2029, 1, 1, 1, 3699.569718), -- Gastraphetes Shaft
(21268, 1867, 1, 1, 2, 118145.997732), -- Animal Skin
(21268, 1872, 1, 1, 2, 118145.997732), -- Animal Bone
(21268, 1882, 1, 1, 2, 19690.999622), -- Leather
(21268, 1894, 1, 1, 2, 3109.154552), -- Crafted Leather
(21268, 2186, 1, 1, 2, 2963.354331), -- Recipe: Brigandine Tunic
(21268, 6037, 1, 3, 2, 59072.998866), -- Waking Scroll
(21268, 1341, 20, 60, 2, 147682.497165), -- Bone Arrow
-- Cave Ant
(21269, 1825, 1, 1, -1, 94807), -- Recipe: Oriharukon
(21269, 1902, 1, 1, -1, 134478); -- Elven Earring Beads

INSERT INTO `droplist` VALUES
(21269, 2145, 1, 1, -1, 94807), -- Recipe: Mithril Alloy
(21269, 57, 561, 1119, 0, 700000), -- Adena
(21269, 129, 1, 1, 1, 63.87616), -- Sword of Revolution
(21269, 2034, 1, 1, 1, 3624.12384), -- Sword of Revolution Blade
(21269, 1872, 1, 1, 2, 182963.082148), -- Animal Bone
(21269, 1867, 1, 1, 2, 182963.082148), -- Animal Skin
(21269, 1881, 1, 1, 2, 18296.348532), -- Coarse Bone Powder
(21269, 1875, 1, 1, 2, 9147.97268), -- Stone of Purity
(21269, 1825, 1, 1, 2, 9801.514492), -- Recipe: Oriharukon
-- Cave Ant Soldier
(21270, 1903, 1, 1, -1, 255201), -- Elven Ring Piece
(21270, 6036, 1, 1, -1, 50998), -- Greater Magic Haste Potion
(21270, 1902, 1, 1, -1, 155008), -- Elven Earring Beads
(21270, 57, 647, 1291, 0, 700000), -- Adena
(21270, 88, 1, 1, 1, 14.726056), -- Morning Star
(21270, 2031, 1, 1, 1, 800.426842), -- Morning Star Head
(21270, 90, 1, 1, 1, 14.726056), -- Goat Head Staff
(21270, 2032, 1, 1, 1, 730.67437), -- Goat Head Staff Head
(21270, 158, 1, 1, 1, 14.726056), -- Tarbar
(21270, 2035, 1, 1, 1, 800.426842), -- Tarbar Head
(21270, 169, 1, 1, 1, 14.726056), -- Skull Breaker
(21270, 2036, 1, 1, 1, 800.426842), -- Skull Breaker Head
(21270, 172, 1, 1, 1, 14.726056), -- Heavy Bone Club
(21270, 2037, 1, 1, 1, 800.414824), -- Heavy Bone Club Head
(21270, 1868, 1, 1, 2, 316342.742333), -- Thread
(21270, 1873, 1, 1, 2, 63268.715375), -- Silver Nugget
(21270, 5549, 1, 1, 2, 15817.074526), -- Metallic Thread
(21270, 1889, 1, 1, 2, 10544.855441), -- Compound Braid
(21270, 2145, 1, 1, 2, 11297.612325), -- Recipe: Mithril Alloy
-- Cave Ant
(21271, 1864, 1, 3, -1, 905720), -- Stem
(21271, 1869, 1, 1, -1, 905720), -- Iron Ore
(21271, 1901, 1, 1, -1, 125099), -- Tiger's Eye Earring Stone
(21271, 57, 383, 764, 0, 700000), -- Adena
(21271, 129, 1, 1, 1, 43.59444), -- Sword of Revolution
(21271, 2034, 1, 1, 1, 2473.40556), -- Sword of Revolution Blade
(21271, 1864, 1, 1, 2, 187274.890368), -- Stem
(21271, 1869, 1, 1, 2, 93637.445184), -- Iron Ore
(21271, 1878, 1, 1, 2, 37455.13248), -- Braided Hemp
(21271, 1884, 1, 1, 2, 57622.924416), -- Cord
(21271, 2154, 1, 1, 2, 10025.607552), -- Recipe: Elven Earring
-- Cave Ant Soldier
(21272, 1864, 1, 7, -1, 802957), -- Stem
(21272, 1869, 1, 3, -1, 802957), -- Iron Ore
(21272, 1901, 1, 1, -1, 221811), -- Tiger's Eye Earring Stone
(21272, 57, 679, 1355, 0, 700000), -- Adena
(21272, 129, 1, 1, 1, 77.29916), -- Sword of Revolution
(21272, 2034, 1, 1, 1, 4385.70084), -- Sword of Revolution Blade
(21272, 1864, 3, 9, 2, 55342.280884), -- Stem
(21272, 1869, 1, 1, 2, 166026.842652), -- Iron Ore
(21272, 1878, 1, 1, 2, 66410.818606), -- Braided Hemp
(21272, 1884, 1, 1, 2, 102170.427436), -- Cord
(21272, 2154, 1, 1, 2, 17775.630422), -- Recipe: Elven Earring
-- Cave Noble Ant
(21273, 1864, 1, 19, -1, 930725), -- Stem
(21273, 1869, 1, 9, -1, 930725), -- Iron Ore
(21273, 1901, 1, 1, -1, 642766), -- Tiger's Eye Earring Stone
(21273, 57, 1969, 3922, 0, 700000), -- Adena
(21273, 129, 1, 1, 1, 223.98224), -- Sword of Revolution
(21273, 2034, 1, 1, 1, 12708.01776), -- Sword of Revolution Blade
(21273, 1864, 3, 9, 2, 160371.145974), -- Stem
(21273, 1869, 2, 6, 2, 120278.571205), -- Iron Ore
(21273, 1878, 3, 9, 2, 32074.144505), -- Braided Hemp
(21273, 1884, 2, 6, 2, 59213.837813), -- Cord
(21273, 2154, 1, 1, 2, 51511.300503), -- Recipe: Elven Earring
-- Kookaburra
(21274, 4087, 1, 1, -1, 72770), -- Stockings of Doom Pattern
(21274, 6333, 1, 1, -1, 35604), -- Recipe: Sealed Phoenix Ring(70%)
(21274, 4088, 1, 1, -1, 117199), -- Blue Wolf Helmet Design
(21274, 57, 1223, 2498, 0, 700000), -- Adena
(21274, 12341, 1, 1, 1, 708.44508), -- Common Item - Earring of Black Ore
(21274, 4052, 1, 1, 1, 5405.234928), -- Earring of Black Ore Piece
(21274, 12342, 1, 1, 1, 531.036144), -- Common Item - Necklace of Black Ore
(21274, 4054, 1, 1, 1, 3007.099584), -- Necklace of Black Ore Beads
(21274, 12343, 1, 1, 1, 1060.20864), -- Common Item - Ring of Black Ore
(21274, 4053, 1, 1, 1, 6543.975624), -- Ring of Black Ore Gemstone
(21274, 1864, 1, 1, 2, 166548.059594), -- Stem
(21274, 1869, 1, 1, 2, 83274.029797), -- Iron Ore
(21274, 1878, 1, 1, 2, 33309.703385), -- Braided Hemp
(21274, 1884, 1, 1, 2, 51245.767874), -- Cord
(21274, 4039, 1, 1, 2, 2775.99917), -- Mold Glue
(21274, 5456, 1, 1, 2, 30.641177), -- Recipe: Tallum Glaive(60%)
(21274, 8730, 1, 1, 2, 925.180613), -- Life Stone - Level 67
(21274, 8740, 1, 1, 2, 231.409486), -- Mid-Grade Life Stone - Level 67
(21274, 8750, 1, 1, 2, 23.323881), -- High-Grade Life Stone - Level 67
(21274, 8760, 1, 1, 2, 4.57331), -- Top-Grade Life Stone - Level 67
(21274, 1343, 10, 30, 2, 118962.311713), -- Silver Arrow
-- Kookaburra
(21275, 4087, 1, 1, -1, 73242), -- Stockings of Doom Pattern
(21275, 6333, 1, 1, -1, 35835), -- Recipe: Sealed Phoenix Ring(70%)
(21275, 4088, 1, 1, -1, 117959), -- Blue Wolf Helmet Design
(21275, 57, 1230, 2515, 0, 700000), -- Adena
(21275, 12341, 1, 1, 1, 713.04324), -- Common Item - Earring of Black Ore
(21275, 4052, 1, 1, 1, 5440.317584), -- Earring of Black Ore Piece
(21275, 12342, 1, 1, 1, 534.482832), -- Common Item - Necklace of Black Ore
(21275, 4054, 1, 1, 1, 3026.617152), -- Necklace of Black Ore Beads
(21275, 12343, 1, 1, 1, 1067.08992), -- Common Item - Ring of Black Ore
(21275, 4053, 1, 1, 1, 6586.449272), -- Ring of Black Ore Gemstone
(21275, 1864, 1, 1, 2, 167627.835504), -- Stem
(21275, 1869, 1, 1, 2, 83813.917752), -- Iron Ore
(21275, 1878, 1, 1, 2, 33525.65916), -- Braided Hemp
(21275, 1884, 1, 1, 2, 51578.007984), -- Cord
(21275, 4039, 1, 1, 2, 2793.99672), -- Mold Glue
(21275, 5456, 1, 1, 2, 30.839832), -- Recipe: Tallum Glaive(60%)
(21275, 8730, 1, 1, 2, 931.178808), -- Life Stone - Level 67
(21275, 8740, 1, 1, 2, 232.909776), -- Mid-Grade Life Stone - Level 67
(21275, 8750, 1, 1, 2, 23.475096), -- High-Grade Life Stone - Level 67
(21275, 8760, 1, 1, 2, 4.60296), -- Top-Grade Life Stone - Level 67
(21275, 1343, 10, 30, 2, 119733.576408), -- Silver Arrow
-- Kookaburra
(21276, 4087, 1, 1, -1, 72350), -- Stockings of Doom Pattern
(21276, 6333, 1, 1, -1, 35399), -- Recipe: Sealed Phoenix Ring(70%)
(21276, 4088, 1, 1, -1, 116524), -- Blue Wolf Helmet Design
(21276, 57, 1216, 2484, 0, 700000), -- Adena
(21276, 12341, 1, 1, 1, 704.33958), -- Common Item - Earring of Black Ore
(21276, 4052, 1, 1, 1, 5373.911128), -- Earring of Black Ore Piece
(21276, 12342, 1, 1, 1, 527.958744), -- Common Item - Necklace of Black Ore
(21276, 4054, 1, 1, 1, 2989.673184), -- Necklace of Black Ore Beads
(21276, 12343, 1, 1, 1, 1054.06464), -- Common Item - Ring of Black Ore
(21276, 4053, 1, 1, 1, 6506.052724), -- Ring of Black Ore Gemstone
(21276, 1864, 1, 1, 2, 165588.09693), -- Stem
(21276, 1869, 1, 1, 2, 82794.048465), -- Iron Ore
(21276, 1878, 1, 1, 2, 33117.710325), -- Braided Hemp
(21276, 1884, 1, 1, 2, 50950.39353), -- Cord
(21276, 4039, 1, 1, 2, 2759.99865), -- Mold Glue
(21276, 5456, 1, 1, 2, 30.464565), -- Recipe: Tallum Glaive(60%)
(21276, 8730, 1, 1, 2, 919.847985), -- Life Stone - Level 67
(21276, 8740, 1, 1, 2, 230.07567), -- Mid-Grade Life Stone - Level 67
(21276, 8750, 1, 1, 2, 23.189445), -- High-Grade Life Stone - Level 67
(21276, 8760, 1, 1, 2, 4.54695), -- Top-Grade Life Stone - Level 67
(21276, 1343, 10, 30, 2, 118276.627485), -- Silver Arrow
-- Antelope
(21278, 5478, 1, 1, -1, 26945), -- Sealed Dark Crystal Leather Armor Pattern
(21278, 729, 1, 1, -1, 356), -- Scroll: Enchant Weapon (A-Grade)
(21278, 4040, 1, 1, -1, 64087), -- Mold Lubricant
(21278, 57, 1268, 2577, 0, 700000), -- Adena
(21278, 11957, 1, 1, 1, 43.42806), -- Common Item - Tallum Blade
(21278, 5548, 1, 1, 1, 536.71891), -- Tallum Blade Edge
(21278, 11952, 1, 1, 1, 43.42806), -- Common Item - Elemental Sword
(21278, 5547, 1, 1, 1, 536.71891), -- Elemental Sword Edge
(21278, 11954, 1, 1, 1, 43.42806), -- Common Item - Inferno Master
(21278, 8331, 1, 1, 1, 538.278), -- Infernal Master Blade
(21278, 1865, 1, 1, 2, 94651.322115), -- Varnish
(21278, 1870, 1, 1, 2, 94651.322115), -- Coal
(21278, 1879, 1, 1, 2, 15775.18446), -- Cokes
(21278, 1875, 1, 1, 2, 6310.116855), -- Stone of Purity
(21278, 4040, 1, 1, 2, 1892.97045), -- Mold Lubricant
(21278, 6339, 1, 1, 2, 728.115255), -- Recipe: Sealed Majestic Ring(70%)
(21278, 8730, 1, 1, 2, 1051.578465), -- Life Stone - Level 67
(21278, 8740, 1, 1, 2, 262.948455), -- Mid-Grade Life Stone - Level 67
(21278, 8750, 1, 1, 2, 26.27331), -- High-Grade Life Stone - Level 67
(21278, 8760, 1, 1, 2, 5.16852), -- Top-Grade Life Stone - Level 67
-- Antelope
(21279, 5478, 1, 1, -1, 26790), -- Sealed Dark Crystal Leather Armor Pattern
(21279, 729, 1, 1, -1, 354), -- Scroll: Enchant Weapon (A-Grade)
(21279, 4040, 1, 1, -1, 63717), -- Mold Lubricant
(21279, 57, 1260, 2562, 0, 700000), -- Adena
(21279, 11957, 1, 1, 1, 43.17876), -- Common Item - Tallum Blade
(21279, 5548, 1, 1, 1, 533.63786), -- Tallum Blade Edge
(21279, 11952, 1, 1, 1, 43.17876), -- Common Item - Elemental Sword
(21279, 5547, 1, 1, 1, 533.63786), -- Elemental Sword Edge
(21279, 11954, 1, 1, 1, 43.17876), -- Common Item - Inferno Master
(21279, 8331, 1, 1, 1, 535.188), -- Infernal Master Blade
(21279, 1865, 1, 1, 2, 94105.886482), -- Varnish
(21279, 1870, 1, 1, 2, 94105.886482), -- Coal
(21279, 1879, 1, 1, 2, 15684.278728), -- Cokes
(21279, 1875, 1, 1, 2, 6273.754314), -- Stone of Purity
(21279, 4040, 1, 1, 2, 1882.06206), -- Mold Lubricant
(21279, 6339, 1, 1, 2, 723.919434), -- Recipe: Sealed Majestic Ring(70%)
(21279, 8730, 1, 1, 2, 1045.518662), -- Life Stone - Level 67
(21279, 8740, 1, 1, 2, 261.433194), -- Mid-Grade Life Stone - Level 67
(21279, 8750, 1, 1, 2, 26.121908), -- High-Grade Life Stone - Level 67
(21279, 8760, 1, 1, 2, 5.138736), -- Top-Grade Life Stone - Level 67
-- Antelope
(21280, 5478, 1, 1, -1, 27120), -- Sealed Dark Crystal Leather Armor Pattern
(21280, 729, 1, 1, -1, 358), -- Scroll: Enchant Weapon (A-Grade)
(21280, 4040, 1, 1, -1, 64502), -- Mold Lubricant
(21280, 57, 1276, 2593, 0, 700000), -- Adena
(21280, 11957, 1, 1, 1, 43.70229), -- Common Item - Tallum Blade
(21280, 5548, 1, 1, 1, 540.108065), -- Tallum Blade Edge
(21280, 11952, 1, 1, 1, 43.70229), -- Common Item - Elemental Sword
(21280, 5547, 1, 1, 1, 540.108065), -- Elemental Sword Edge
(21280, 11954, 1, 1, 1, 43.70229), -- Common Item - Inferno Master
(21280, 8331, 1, 1, 1, 541.677), -- Infernal Master Blade
(21280, 1865, 1, 1, 2, 95265.321776), -- Varnish
(21280, 1870, 1, 1, 2, 95265.321776), -- Coal
(21280, 1879, 1, 1, 2, 15877.517504), -- Cokes
(21280, 1875, 1, 1, 2, 6351.050352), -- Stone of Purity
(21280, 4040, 1, 1, 2, 1905.25008), -- Mold Lubricant
(21280, 6339, 1, 1, 2, 732.838512), -- Recipe: Sealed Majestic Ring(70%)
(21280, 8730, 1, 1, 2, 1058.400016), -- Life Stone - Level 67
(21280, 8740, 1, 1, 2, 264.654192), -- Mid-Grade Life Stone - Level 67
(21280, 8750, 1, 1, 2, 26.443744), -- High-Grade Life Stone - Level 67
(21280, 8760, 1, 1, 2, 5.202048), -- Top-Grade Life Stone - Level 67
-- Bandersnatch
(21282, 5536, 1, 1, -1, 11253), -- Bloody Orchid Head
(21282, 729, 1, 1, -1, 368), -- Scroll: Enchant Weapon (A-Grade)
(21282, 4040, 1, 1, -1, 66152), -- Mold Lubricant
(21282, 57, 1309, 2658, 0, 700000), -- Adena
(21282, 11957, 1, 1, 1, 44.82414), -- Common Item - Tallum Blade
(21282, 5548, 1, 1, 1, 553.97279), -- Tallum Blade Edge
(21282, 11952, 1, 1, 1, 44.82414), -- Common Item - Elemental Sword
(21282, 5547, 1, 1, 1, 553.97279), -- Elemental Sword Edge
(21282, 11954, 1, 1, 1, 44.82414), -- Common Item - Inferno Master
(21282, 8331, 1, 1, 1, 555.582), -- Infernal Master Blade
(21282, 1865, 1, 1, 2, 97701.271628), -- Varnish
(21282, 1870, 1, 1, 2, 97701.271628), -- Coal
(21282, 1879, 1, 1, 2, 16283.619131), -- Cokes
(21282, 1875, 1, 1, 2, 6513.314705), -- Stone of Purity
(21282, 4040, 1, 1, 2, 1954.105201), -- Mold Lubricant
(21282, 5456, 1, 1, 2, 36.117377), -- Recipe: Tallum Glaive(60%)
(21282, 8730, 1, 1, 2, 1085.515521), -- Life Stone - Level 67
(21282, 8740, 1, 1, 2, 271.434275), -- Mid-Grade Life Stone - Level 67
(21282, 8750, 1, 1, 2, 27.032638), -- High-Grade Life Stone - Level 67
(21282, 8760, 1, 1, 2, 5.317896), -- Top-Grade Life Stone - Level 67
-- Bandersnatch
(21283, 5536, 1, 1, -1, 11326), -- Bloody Orchid Head
(21283, 729, 1, 1, -1, 370), -- Scroll: Enchant Weapon (A-Grade)
(21283, 4040, 1, 1, -1, 66581), -- Mold Lubricant
(21283, 57, 1318, 2676, 0, 700000), -- Adena
(21283, 11957, 1, 1, 1, 45.1233), -- Common Item - Tallum Blade
(21283, 5548, 1, 1, 1, 557.67005), -- Tallum Blade Edge
(21283, 11952, 1, 1, 1, 45.1233), -- Common Item - Elemental Sword
(21283, 5547, 1, 1, 1, 557.67005), -- Elemental Sword Edge
(21283, 11954, 1, 1, 1, 45.1233), -- Common Item - Inferno Master
(21283, 8331, 1, 1, 1, 559.29), -- Infernal Master Blade
(21283, 1865, 1, 1, 2, 98334.890912), -- Varnish
(21283, 1870, 1, 1, 2, 98334.890912), -- Coal
(21283, 1879, 1, 1, 2, 16389.222824), -- Cokes
(21283, 1875, 1, 1, 2, 6555.55532), -- Stone of Purity
(21283, 4040, 1, 1, 2, 1966.778104), -- Mold Lubricant
(21283, 5456, 1, 1, 2, 36.351608), -- Recipe: Tallum Glaive(60%)
(21283, 8730, 1, 1, 2, 1092.555384), -- Life Stone - Level 67
(21283, 8740, 1, 1, 2, 273.1946), -- Mid-Grade Life Stone - Level 67
(21283, 8750, 1, 1, 2, 27.207952), -- High-Grade Life Stone - Level 67
(21283, 8760, 1, 1, 2, 5.352384), -- Top-Grade Life Stone - Level 67
-- Bandersnatch
(21284, 5536, 1, 1, -1, 11188), -- Bloody Orchid Head
(21284, 729, 1, 1, -1, 365), -- Scroll: Enchant Weapon (A-Grade)
(21284, 4040, 1, 1, -1, 65771), -- Mold Lubricant
(21284, 57, 1302, 2643, 0, 700000), -- Adena
(21284, 11957, 1, 1, 1, 44.57484), -- Common Item - Tallum Blade
(21284, 5548, 1, 1, 1, 550.89174), -- Tallum Blade Edge
(21284, 11952, 1, 1, 1, 44.57484), -- Common Item - Elemental Sword
(21284, 5547, 1, 1, 1, 550.89174), -- Elemental Sword Edge
(21284, 11954, 1, 1, 1, 44.57484), -- Common Item - Inferno Master
(21284, 8331, 1, 1, 1, 552.492), -- Infernal Master Blade
(21284, 1865, 1, 1, 2, 97138.201464), -- Varnish
(21284, 1870, 1, 1, 2, 97138.201464), -- Coal
(21284, 1879, 1, 1, 2, 16189.773678), -- Cokes
(21284, 1875, 1, 1, 2, 6475.77729), -- Stone of Purity
(21284, 4040, 1, 1, 2, 1942.843338), -- Mold Lubricant
(21284, 5456, 1, 1, 2, 35.909226), -- Recipe: Tallum Glaive(60%)
(21284, 8730, 1, 1, 2, 1079.259498), -- Life Stone - Level 67
(21284, 8740, 1, 1, 2, 269.86995), -- Mid-Grade Life Stone - Level 67
(21284, 8750, 1, 1, 2, 26.876844), -- High-Grade Life Stone - Level 67
(21284, 8760, 1, 1, 2, 5.287248), -- Top-Grade Life Stone - Level 67
-- Buffalo
(21286, 5549, 1, 1, -1, 341557), -- Metallic Thread
(21286, 1889, 1, 1, -1, 227705), -- Compound Braid
(21286, 6343, 1, 1, -1, 73029), -- Sealed Phoenix Necklace Beads
(21286, 57, 1351, 2748, 0, 700000), -- Adena
(21286, 12224, 1, 1, 1, 549.524654), -- Common Item - Sealed Dark Crystal Boots
(21286, 5496, 1, 1, 1, 2956.975346), -- Sealed Dark Crystal Boots Lining
(21286, 12231, 1, 1, 1, 549.524654), -- Common Item - Sealed Tallum Boots
(21286, 5497, 1, 1, 1, 2956.975346), -- Sealed Tallum Boots Lining
(21286, 12221, 1, 1, 1, 549.524654), -- Common Item - Sealed Dark Crystal Gloves
(21286, 5508, 1, 1, 1, 2956.975346), -- Sealed Dark Crystal Gloves Design
(21286, 12229, 1, 1, 1, 549.524654), -- Common Item - Sealed Tallum Gloves
(21286, 5509, 1, 1, 1, 2956.975346), -- Sealed Tallum Gloves Design
(21286, 1868, 1, 1, 2, 201781.465144), -- Thread
(21286, 1873, 1, 1, 2, 40356.398544), -- Silver Nugget
(21286, 5549, 1, 1, 2, 10089.099636), -- Metallic Thread
(21286, 1889, 1, 1, 2, 6726.066424), -- Compound Braid
(21286, 4044, 1, 1, 2, 3363.033212), -- Thons
(21286, 5440, 1, 1, 2, 37.457896), -- Recipe: Elysian(60%)
(21286, 8730, 1, 1, 2, 1121.099), -- Life Stone - Level 67
(21286, 8740, 1, 1, 2, 280.142856), -- Mid-Grade Life Stone - Level 67
(21286, 8750, 1, 1, 2, 27.961528), -- High-Grade Life Stone - Level 67
(21286, 8760, 1, 1, 2, 5.27576), -- Top-Grade Life Stone - Level 67
-- Buffalo
(21287, 5549, 1, 1, -1, 339589), -- Metallic Thread
(21287, 1889, 1, 1, -1, 226392), -- Compound Braid
(21287, 6343, 1, 1, -1, 72608), -- Sealed Phoenix Necklace Beads
(21287, 57, 1343, 2732, 0, 700000), -- Adena
(21287, 12224, 1, 1, 1, 546.351155), -- Common Item - Sealed Dark Crystal Boots
(21287, 5496, 1, 1, 1, 2939.898845), -- Sealed Dark Crystal Boots Lining
(21287, 12231, 1, 1, 1, 546.351155), -- Common Item - Sealed Tallum Boots
(21287, 5497, 1, 1, 1, 2939.898845), -- Sealed Tallum Boots Lining
(21287, 12221, 1, 1, 1, 546.351155), -- Common Item - Sealed Dark Crystal Gloves
(21287, 5508, 1, 1, 1, 2939.898845), -- Sealed Dark Crystal Gloves Design
(21287, 12229, 1, 1, 1, 546.351155), -- Common Item - Sealed Tallum Gloves
(21287, 5509, 1, 1, 1, 2939.898845), -- Sealed Tallum Gloves Design
(21287, 1868, 1, 1, 2, 200618.759384), -- Thread
(21287, 1873, 1, 1, 2, 40123.856784), -- Silver Nugget
(21287, 5549, 1, 1, 2, 10030.964196), -- Metallic Thread
(21287, 1889, 1, 1, 2, 6687.309464), -- Compound Braid
(21287, 4044, 1, 1, 2, 3343.654732), -- Thons
(21287, 5440, 1, 1, 2, 37.242056), -- Recipe: Elysian(60%)
(21287, 8730, 1, 1, 2, 1114.639), -- Life Stone - Level 67
(21287, 8740, 1, 1, 2, 278.528616), -- Mid-Grade Life Stone - Level 67
(21287, 8750, 1, 1, 2, 27.800408), -- High-Grade Life Stone - Level 67
(21287, 8760, 1, 1, 2, 5.24536), -- Top-Grade Life Stone - Level 67
-- Buffalo
(21288, 5549, 1, 1, -1, 343772), -- Metallic Thread
(21288, 1889, 1, 1, -1, 229181), -- Compound Braid
(21288, 6343, 1, 1, -1, 73503), -- Sealed Phoenix Necklace Beads
(21288, 57, 1360, 2766, 0, 700000), -- Adena
(21288, 12224, 1, 1, 1, 553.089943), -- Common Item - Sealed Dark Crystal Boots
(21288, 5496, 1, 1, 1, 2976.160057), -- Sealed Dark Crystal Boots Lining
(21288, 12231, 1, 1, 1, 553.089943), -- Common Item - Sealed Tallum Boots
(21288, 5497, 1, 1, 1, 2976.160057), -- Sealed Tallum Boots Lining
(21288, 12221, 1, 1, 1, 553.089943), -- Common Item - Sealed Dark Crystal Gloves
(21288, 5508, 1, 1, 1, 2976.160057), -- Sealed Dark Crystal Gloves Design
(21288, 12229, 1, 1, 1, 553.089943), -- Common Item - Sealed Tallum Gloves
(21288, 5509, 1, 1, 1, 2976.160057), -- Sealed Tallum Gloves Design
(21288, 1868, 1, 1, 2, 203089.509124), -- Thread
(21288, 1873, 1, 1, 2, 40618.008024), -- Silver Nugget
(21288, 5549, 1, 1, 2, 10154.502006), -- Metallic Thread
(21288, 1889, 1, 1, 2, 6769.668004), -- Compound Braid
(21288, 4044, 1, 1, 2, 3384.834002), -- Thons
(21288, 5440, 1, 1, 2, 37.700716), -- Recipe: Elysian(60%)
(21288, 8730, 1, 1, 2, 1128.3665), -- Life Stone - Level 67
(21288, 8740, 1, 1, 2, 281.958876), -- Mid-Grade Life Stone - Level 67
(21288, 8750, 1, 1, 2, 28.142788), -- High-Grade Life Stone - Level 67
(21288, 8760, 1, 1, 2, 5.30996), -- Top-Grade Life Stone - Level 67
-- Grendel
(21290, 730, 1, 1, -1, 2349), -- Scroll: Enchant Armor (A-Grade)
(21290, 4041, 1, 1, -1, 24508), -- Mold Hardener
(21290, 1875, 1, 1, -1, 187895), -- Stone of Purity
(21290, 57, 1391, 2835, 0, 700000), -- Adena
(21290, 11957, 1, 1, 1, 47.74095), -- Common Item - Tallum Blade
(21290, 5548, 1, 1, 1, 590.021075), -- Tallum Blade Edge
(21290, 11952, 1, 1, 1, 47.74095), -- Common Item - Elemental Sword
(21290, 5547, 1, 1, 1, 590.021075), -- Elemental Sword Edge
(21290, 11954, 1, 1, 1, 47.74095), -- Common Item - Inferno Master
(21290, 8331, 1, 1, 1, 591.735), -- Infernal Master Blade
(21290, 1872, 1, 1, 2, 138752.735056), -- Animal Bone
(21290, 1867, 1, 1, 2, 138752.735056), -- Animal Skin
(21290, 1881, 1, 1, 2, 13875.333654), -- Coarse Bone Powder
(21290, 1875, 1, 1, 2, 6937.516456), -- Stone of Purity
(21290, 4041, 1, 1, 2, 904.932678), -- Mold Hardener
(21290, 5456, 1, 1, 2, 38.494976), -- Recipe: Tallum Glaive(60%)
(21290, 8730, 1, 1, 2, 1156.35299), -- Life Stone - Level 67
(21290, 8740, 1, 1, 2, 289.013062), -- Mid-Grade Life Stone - Level 67
(21290, 8750, 1, 1, 2, 28.871232), -- High-Grade Life Stone - Level 67
(21290, 8760, 1, 1, 2, 6.01484), -- Top-Grade Life Stone - Level 67
-- Grendel
(21291, 730, 1, 1, -1, 2335), -- Scroll: Enchant Armor (A-Grade)
(21291, 4041, 1, 1, -1, 24367), -- Mold Hardener
(21291, 1875, 1, 1, -1, 186812), -- Stone of Purity
(21291, 57, 1383, 2819, 0, 700000), -- Adena
(21291, 11957, 1, 1, 1, 47.46672), -- Common Item - Tallum Blade
(21291, 5548, 1, 1, 1, 586.63192), -- Tallum Blade Edge
(21291, 11952, 1, 1, 1, 47.46672), -- Common Item - Elemental Sword
(21291, 5547, 1, 1, 1, 586.63192), -- Elemental Sword Edge
(21291, 11954, 1, 1, 1, 47.46672), -- Common Item - Inferno Master
(21291, 8331, 1, 1, 1, 588.336), -- Infernal Master Blade
(21291, 1872, 1, 1, 2, 137953.184312), -- Animal Bone
(21291, 1867, 1, 1, 2, 137953.184312), -- Animal Skin
(21291, 1881, 1, 1, 2, 13795.378233), -- Coarse Bone Powder
(21291, 1875, 1, 1, 2, 6897.539612), -- Stone of Purity
(21291, 4041, 1, 1, 2, 899.718081), -- Mold Hardener
(21291, 5456, 1, 1, 2, 38.273152), -- Recipe: Tallum Glaive(60%)
(21291, 8730, 1, 1, 2, 1149.689605), -- Life Stone - Level 67
(21291, 8740, 1, 1, 2, 287.347649), -- Mid-Grade Life Stone - Level 67
(21291, 8750, 1, 1, 2, 28.704864), -- High-Grade Life Stone - Level 67
(21291, 8760, 1, 1, 2, 5.98018), -- Top-Grade Life Stone - Level 67
-- Grendel
(21292, 730, 1, 1, -1, 2364), -- Scroll: Enchant Armor (A-Grade)
(21292, 4041, 1, 1, -1, 24667), -- Mold Hardener
(21292, 1875, 1, 1, -1, 189113), -- Stone of Purity
(21292, 57, 1400, 2853, 0, 700000), -- Adena
(21292, 11957, 1, 1, 1, 48.06504), -- Common Item - Tallum Blade
(21292, 5548, 1, 1, 1, 594.02644), -- Tallum Blade Edge
(21292, 11952, 1, 1, 1, 48.06504), -- Common Item - Elemental Sword
(21292, 5547, 1, 1, 1, 594.02644), -- Elemental Sword Edge
(21292, 11954, 1, 1, 1, 48.06504), -- Common Item - Inferno Master
(21292, 8331, 1, 1, 1, 595.752), -- Infernal Master Blade
(21292, 1872, 1, 1, 2, 139652.402656), -- Animal Bone
(21292, 1867, 1, 1, 2, 139652.402656), -- Animal Skin
(21292, 1881, 1, 1, 2, 13965.300804), -- Coarse Bone Powder
(21292, 1875, 1, 1, 2, 6982.499056), -- Stone of Purity
(21292, 4041, 1, 1, 2, 910.800228), -- Mold Hardener
(21292, 5456, 1, 1, 2, 38.744576), -- Recipe: Tallum Glaive(60%)
(21292, 8730, 1, 1, 2, 1163.85074), -- Life Stone - Level 67
(21292, 8740, 1, 1, 2, 290.887012), -- Mid-Grade Life Stone - Level 67
(21292, 8750, 1, 1, 2, 29.058432), -- High-Grade Life Stone - Level 67
(21292, 8760, 1, 1, 2, 6.05384), -- Top-Grade Life Stone - Level 67
-- Canyon Antelope
(21294, 5486, 1, 1, -1, 33941), -- Sealed Dark Crystal Robe Fabric
(21294, 5442, 1, 1, -1, 2124), -- Recipe: Soul Bow(60%)
(21294, 5489, 1, 1, -1, 75707), -- Sealed Tallum Stockings Fabric
(21294, 57, 2269, 4612, 0, 700000), -- Adena
(21294, 11957, 1, 1, 1, 77.73174), -- Common Item - Tallum Blade
(21294, 5548, 1, 1, 1, 960.67139), -- Tallum Blade Edge
(21294, 11952, 1, 1, 1, 77.73174), -- Common Item - Elemental Sword
(21294, 5547, 1, 1, 1, 960.67139), -- Elemental Sword Edge
(21294, 11954, 1, 1, 1, 77.73174), -- Common Item - Inferno Master
(21294, 8331, 1, 1, 1, 963.462), -- Infernal Master Blade
(21294, 1869, 1, 1, 2, 169431.236205), -- Iron Ore
(21294, 1864, 1, 3, 2, 169431.236205), -- Stem
(21294, 1880, 1, 1, 2, 16943.013765), -- Steel
(21294, 5550, 1, 1, 2, 2258.995265), -- Durable Metal Plate
(21294, 4043, 1, 1, 2, 5647.671255), -- Asofe
(21294, 5440, 1, 1, 2, 62.617635), -- Recipe: Elysian(60%)
(21294, 8730, 1, 1, 2, 1882.557085), -- Life Stone - Level 67
(21294, 8740, 1, 1, 2, 470.547725), -- Mid-Grade Life Stone - Level 67
(21294, 8750, 1, 1, 2, 47.237865), -- High-Grade Life Stone - Level 67
(21294, 8760, 1, 1, 2, 9.886995), -- Top-Grade Life Stone - Level 67
-- Canyon Antelope Slave
(21295, 5547, 1, 1, -1, 20750), -- Elemental Sword Edge
(21295, 5442, 1, 1, -1, 2259), -- Recipe: Soul Bow(60%)
(21295, 5548, 1, 1, -1, 20750), -- Tallum Blade Edge
(21295, 57, 2414, 4902, 0, 700000), -- Adena
(21295, 11957, 1, 1, 1, 82.66788), -- Common Item - Tallum Blade
(21295, 5548, 1, 1, 1, 1021.67618), -- Tallum Blade Edge
(21295, 11952, 1, 1, 1, 82.66788), -- Common Item - Elemental Sword
(21295, 5547, 1, 1, 1, 1021.67618), -- Elemental Sword Edge
(21295, 11954, 1, 1, 1, 82.66788), -- Common Item - Inferno Master
(21295, 8331, 1, 1, 1, 1024.644), -- Infernal Master Blade
(21295, 1869, 1, 3, 2, 100086.186912), -- Iron Ore
(21295, 1864, 1, 3, 2, 300258.560736), -- Stem
(21295, 1880, 1, 1, 2, 30025.67784), -- Steel
(21295, 5550, 1, 1, 2, 4003.57224), -- Durable Metal Plate
(21295, 4043, 1, 1, 2, 10008.707808), -- Asofe
(21295, 10304, 1, 1, 2, 1201.294464), -- Transformation Sealbook: Saber Tooth Tiger
-- Canyon Bandersnatch 
(21296, 5482, 1, 1, -1, 120055), -- Sealed Dark Crystal Leggings Design
(21296, 5440, 1, 1, -1, 3369), -- Recipe: Elysian(60%)
(21296, 5485, 1, 1, -1, 76488), -- Sealed Tallum Tunic Texture
(21296, 57, 3597, 7319, 0, 700000), -- Adena
(21296, 11955, 1, 1, 1, 369.855732), -- Common Item - Carnage Bow
(21296, 5535, 1, 1, 1, 4584.144268), -- Carnage Bow Stave
(21296, 1872, 4, 12, 2, 74633.468013), -- Animal Bone
(21296, 1867, 1, 3, 2, 199022.458401), -- Animal Skin
(21296, 1881, 1, 1, 2, 59706.62685), -- Coarse Bone Powder
(21296, 1875, 1, 1, 2, 29853.313425), -- Stone of Purity
(21296, 4041, 1, 1, 2, 3893.750055), -- Mold Hardener
(21296, 10304, 1, 1, 2, 1791.383256), -- Transformation Sealbook: Saber Tooth Tiger
-- Canyon Bandersnatch Slave
(21297, 5450, 1, 1, -1, 2714), -- Recipe: Dragon Grinder(60%)
(21297, 6345, 1, 1, -1, 280279), -- Sealed Phoenix Ring Gemstone
(21297, 5456, 1, 1, -1, 2714), -- Recipe: Tallum Glaive(60%)
(21297, 57, 3615, 7369, 0, 700000), -- Adena
(21297, 11951, 1, 1, 1, 372.343692), -- Common Item - Bloody Orchid
(21297, 5536, 1, 1, 1, 4601.656308), -- Bloody Orchid Head
(21297, 1873, 2, 6, 2, 45086.013615), -- Silver Nugget
(21297, 1868, 3, 9, 2, 150287.276958), -- Thread
(21297, 1876, 1, 1, 2, 90172.450911), -- Mithril Ore
(21297, 1895, 1, 1, 2, 128817.665964), -- Metallic Fiber
(21297, 4042, 1, 1, 2, 7514.406216), -- Enria
(21297, 10304, 1, 1, 2, 1803.186336), -- Transformation Sealbook: Saber Tooth Tiger
-- Eye of Restrainer 
(21298, 5478, 1, 1, -1, 39651), -- Sealed Dark Crystal Leather Armor Pattern
(21298, 730, 1, 1, -1, 3929), -- Scroll: Enchant Armor (A-Grade)
(21298, 1895, 1, 3, -1, 673616), -- Metallic Fiber
(21298, 57, 2327, 4743, 0, 700000), -- Adena
(21298, 12224, 1, 1, 1, 948.288516), -- Common Item - Sealed Dark Crystal Boots
(21298, 5496, 1, 1, 1, 5102.711484), -- Sealed Dark Crystal Boots Lining
(21298, 12231, 1, 1, 1, 948.288516), -- Common Item - Sealed Tallum Boots
(21298, 5497, 1, 1, 1, 5102.711484), -- Sealed Tallum Boots Lining
(21298, 12221, 1, 1, 1, 948.288516), -- Common Item - Sealed Dark Crystal Gloves
(21298, 5508, 1, 1, 1, 5102.711484), -- Sealed Dark Crystal Gloves Design
(21298, 12229, 1, 1, 1, 948.288516), -- Common Item - Sealed Tallum Gloves
(21298, 5509, 1, 1, 1, 5102.711484), -- Sealed Tallum Gloves Design
(21298, 1873, 1, 1, 2, 58034.635828), -- Silver Nugget
(21298, 1868, 1, 3, 2, 145087.049892), -- Thread
(21298, 1876, 1, 1, 2, 29017.317914), -- Mithril Ore
(21298, 1895, 1, 1, 2, 41453.377066), -- Metallic Fiber
(21298, 4042, 1, 1, 2, 2418.071466), -- Enria
(21298, 5167, 1, 1, 2, 64.44508), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21298, 5380, 1, 1, 2, 824.436702), -- Recipe: Sealed Boots of Nightmare(60%)
(21298, 8730, 1, 1, 2, 1612.047644), -- Life Stone - Level 67
(21298, 8740, 1, 1, 2, 403.242072), -- Mid-Grade Life Stone - Level 67
(21298, 8750, 1, 1, 2, 40.508336), -- High-Grade Life Stone - Level 67
(21298, 8760, 1, 1, 2, 8.285796), -- Top-Grade Life Stone - Level 67
(21298, 1344, 10, 30, 2, 181358.582204), -- Mithril Arrow
-- Buffalo Slave
(21299, 5508, 1, 1, -1, 177046), -- Sealed Dark Crystal Gloves Design
(21299, 729, 1, 1, -1, 839), -- Scroll: Enchant Weapon (A-Grade)
(21299, 4041, 1, 1, -1, 65661), -- Mold Hardener
(21299, 57, 3724, 7603, 0, 700000), -- Adena
(21299, 11957, 1, 1, 1, 127.91583), -- Common Item - Tallum Blade
(21299, 5548, 1, 1, 1, 1580.886755), -- Tallum Blade Edge
(21299, 11952, 1, 1, 1, 127.91583), -- Common Item - Elemental Sword
(21299, 5547, 1, 1, 1, 1580.886755), -- Elemental Sword Edge
(21299, 11954, 1, 1, 1, 127.91583), -- Common Item - Inferno Master
(21299, 8331, 1, 1, 1, 1585.479), -- Infernal Master Blade
(21299, 1872, 1, 3, 2, 154892.866007), -- Animal Bone
(21299, 1867, 1, 3, 2, 103262.166656), -- Animal Skin
(21299, 1881, 1, 1, 2, 30978.496406), -- Coarse Bone Powder
(21299, 1875, 1, 1, 2, 15489.248203), -- Stone of Purity
(21299, 4041, 1, 1, 2, 2020.486974), -- Mold Hardener
(21299, 5157, 1, 1, 2, 103.289813), -- Recipe: Soulshot (S) Compressed Package (100%)
(21299, 5382, 1, 1, 2, 1320.112926), -- Recipe: Sealed Majestic Boots(60%)
(21299, 8730, 1, 1, 2, 2581.477371), -- Life Stone - Level 67
(21299, 8740, 1, 1, 2, 645.465337), -- Mid-Grade Life Stone - Level 67
(21299, 8750, 1, 1, 2, 64.508136), -- High-Grade Life Stone - Level 67
(21299, 8760, 1, 1, 2, 13.055218), -- Top-Grade Life Stone - Level 67
(21299, 1344, 40, 120, 2, 72605.826953), -- Mithril Arrow
-- Eye of Guide
(21300, 1895, 1, 5, -1, 707483), -- Metallic Fiber
(21300, 5509, 1, 1, -1, 174175), -- Sealed Tallum Gloves Design
(21300, 5434, 1, 1, -1, 2751), -- Recipe: Dragon Slayer(60%)
(21300, 57, 3663, 7480, 0, 700000), -- Adena
(21300, 11946, 1, 1, 1, 94.390996), -- Common Item - Dasparion's Staff
(21300, 5543, 1, 1, 1, 1167.154464), -- Dasparion's Staff Head
(21300, 11949, 1, 1, 1, 94.390996), -- Common Item - Meteor Shower
(21300, 5532, 1, 1, 1, 1156.253364), -- Meteor Shower Head
(21300, 11953, 1, 1, 1, 94.390996), -- Common Item - Spiritual Eye
(21300, 8341, 1, 1, 1, 1154.774824), -- Spiritual Eye Piece
(21300, 11958, 1, 1, 1, 94.390996), -- Common Item - Destroyer Hammer
(21300, 8346, 1, 1, 1, 1156.253364), -- Hammer Piece of Destroyer
(21300, 1895, 1, 1, 2, 87074.879346), -- Metallic Fiber
(21300, 4040, 1, 1, 2, 6095.186244), -- Mold Lubricant
(21300, 4042, 1, 1, 2, 5079.397122), -- Enria
(21300, 4043, 1, 1, 2, 10158.681366), -- Asofe
(21300, 5162, 1, 1, 2, 135.4536), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21300, 8730, 1, 1, 2, 3386.227122), -- Life Stone - Level 67
(21300, 8740, 1, 1, 2, 846.585), -- Mid-Grade Life Stone - Level 67
(21300, 8750, 1, 1, 2, 84.6585), -- High-Grade Life Stone - Level 67
(21300, 8760, 1, 1, 2, 16.9317), -- Top-Grade Life Stone - Level 67
-- Gaze of Nightmare
(21301, 5520, 1, 1, -1, 57484), -- Sealed Dark Crystal Breastplate Pattern
(21301, 5440, 1, 1, -1, 3302), -- Recipe: Elysian(60%)
(21301, 5521, 1, 1, -1, 40563), -- Sealed Tallum Plate Armor Pattern
(21301, 57, 4396, 8976, 0, 700000), -- Adena
(21301, 11950, 1, 1, 1, 453.070422), -- Common Item - Blood Tornado
(21301, 5539, 1, 1, 1, 5549.929578), -- Blood Tornado Edge
(21301, 1868, 4, 12, 2, 68571.48648), -- Thread
(21301, 1873, 1, 1, 2, 109714.44897), -- Silver Nugget
(21301, 5549, 1, 1, 2, 27428.52399), -- Metallic Thread
(21301, 1889, 1, 1, 2, 18285.56499), -- Compound Braid
(21301, 4044, 1, 1, 2, 9142.959), -- Thons
(21301, 5167, 1, 1, 2, 121.78845), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21301, 5404, 1, 1, 2, 1558.53915), -- Recipe: Sealed Gauntlets of Nightmare(60%)
(21301, 8730, 1, 1, 2, 3047.53533), -- Life Stone - Level 67
(21301, 8740, 1, 1, 2, 761.79558), -- Mid-Grade Life Stone - Level 67
(21301, 8750, 1, 1, 2, 76.25016), -- High-Grade Life Stone - Level 67
(21301, 8760, 1, 1, 2, 15.17943), -- Top-Grade Life Stone - Level 67
(21301, 1344, 30, 90, 2, 114285.92847), -- Mithril Arrow
-- Eye of Watchman
(21302, 729, 1, 1, -1, 799), -- Scroll: Enchant Weapon (A-Grade)
(21302, 1875, 1, 1, -1, 479548), -- Stone of Purity
(21302, 4041, 1, 1, -1, 62550), -- Mold Hardener
(21302, 57, 3552, 7232, 0, 700000), -- Adena
(21302, 11957, 1, 1, 1, 121.85784), -- Common Item - Tallum Blade
(21302, 5548, 1, 1, 1, 1506.01724), -- Tallum Blade Edge
(21302, 11952, 1, 1, 1, 121.85784), -- Common Item - Elemental Sword
(21302, 5547, 1, 1, 1, 1506.01724), -- Elemental Sword Edge
(21302, 11954, 1, 1, 1, 121.85784), -- Common Item - Inferno Master
(21302, 8331, 1, 1, 1, 1510.392), -- Infernal Master Blade
(21302, 1872, 1, 3, 2, 160967.013024), -- Animal Bone
(21302, 1867, 1, 3, 2, 107311.342016), -- Animal Skin
(21302, 1881, 1, 1, 2, 32193.338003), -- Coarse Bone Powder
(21302, 1875, 1, 1, 2, 16096.830506), -- Stone of Purity
(21302, 4041, 1, 1, 2, 2099.5585), -- Mold Hardener
(21302, 5162, 1, 1, 2, 107.238988), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21302, 5382, 1, 1, 2, 1371.819223), -- Recipe: Sealed Majestic Boots(60%)
(21302, 8731, 1, 1, 2, 2235.545289), -- Life Stone - Level 70
(21302, 8741, 1, 1, 2, 558.80557), -- Mid-Grade Life Stone - Level 70
(21302, 8751, 1, 1, 2, 55.880557), -- High-Grade Life Stone - Level 70
(21302, 8761, 1, 1, 2, 11.628324), -- Top-Grade Life Stone - Level 70
-- Homunculus
(21303, 5547, 1, 1, -1, 24748), -- Elemental Sword Edge
(21303, 5466, 1, 1, -1, 2694), -- Recipe: Sword of Miracles(60%)
(21303, 5548, 1, 1, -1, 24748), -- Tallum Blade Edge
(21303, 57, 3592, 7313, 0, 700000), -- Adena
(21303, 11946, 1, 1, 1, 92.413531), -- Common Item - Dasparion's Staff
(21303, 5543, 1, 1, 1, 1142.702904), -- Dasparion's Staff Head
(21303, 11949, 1, 1, 1, 92.413531), -- Common Item - Meteor Shower
(21303, 5532, 1, 1, 1, 1132.030179), -- Meteor Shower Head
(21303, 11953, 1, 1, 1, 92.413531), -- Common Item - Spiritual Eye
(21303, 8341, 1, 1, 1, 1130.582614), -- Spiritual Eye Piece
(21303, 11958, 1, 1, 1, 92.413531), -- Common Item - Destroyer Hammer
(21303, 8346, 1, 1, 1, 1132.030179), -- Hammer Piece of Destroyer
(21303, 1872, 1, 3, 2, 149211.132531), -- Animal Bone
(21303, 1867, 1, 3, 2, 99474.088354), -- Animal Skin
(21303, 1881, 1, 1, 2, 29842.152634), -- Coarse Bone Powder
(21303, 1875, 1, 1, 2, 14921.076317), -- Stone of Purity
(21303, 4041, 1, 1, 2, 1946.163109), -- Mold Hardener
(21303, 5167, 1, 1, 2, 99.358109), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21303, 5406, 1, 1, 2, 1271.709923), -- Recipe: Sealed Majestic Gauntlets(60%)
(21303, 8731, 1, 1, 2, 2072.484571), -- Life Stone - Level 70
(21303, 8741, 1, 1, 2, 518.213483), -- Mid-Grade Life Stone - Level 70
(21303, 8751, 1, 1, 2, 51.71054), -- High-Grade Life Stone - Level 70
(21303, 8761, 1, 1, 2, 10.342108), -- Top-Grade Life Stone - Level 70
(21303, 1344, 40, 120, 2, 69942.568321), -- Mithril Arrow
-- Grendel Slave
(21304, 5542, 1, 1, -1, 36128), -- Halberd Edge
(21304, 5440, 1, 1, -1, 3968), -- Recipe: Elysian(60%)
(21304, 5543, 1, 1, -1, 36469), -- Dasparion's Staff Head
(21304, 57, 5287, 10776, 0, 700000), -- Adena
(21304, 11946, 1, 1, 1, 136.124924), -- Common Item - Dasparion's Staff
(21304, 5543, 1, 1, 1, 1683.198816), -- Dasparion's Staff Head
(21304, 11949, 1, 1, 1, 136.124924), -- Common Item - Meteor Shower
(21304, 5532, 1, 1, 1, 1667.477916), -- Meteor Shower Head
(21304, 11953, 1, 1, 1, 136.124924), -- Common Item - Spiritual Eye
(21304, 8341, 1, 1, 1, 1665.345656), -- Spiritual Eye Piece
(21304, 11958, 1, 1, 1, 136.124924), -- Common Item - Destroyer Hammer
(21304, 8346, 1, 1, 1, 1667.477916), -- Hammer Piece of Destroyer
(21304, 1894, 1, 1, 2, 13879.8519), -- Crafted Leather
(21304, 4039, 1, 1, 2, 13185.637464), -- Mold Glue
(21304, 4041, 1, 1, 2, 3439.718652), -- Mold Hardener
(21304, 4044, 1, 1, 2, 13185.637464), -- Thons
(21304, 5277, 1, 1, 2, 175.698072), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21304, 8731, 1, 1, 2, 3662.742804), -- Life Stone - Level 70
(21304, 8741, 1, 1, 2, 915.759648), -- Mid-Grade Life Stone - Level 70
(21304, 8751, 1, 1, 2, 91.69428), -- High-Grade Life Stone - Level 70
(21304, 8761, 1, 1, 2, 18.338856), -- Top-Grade Life Stone - Level 70
(21304, 1344, 20, 60, 2, 247232.92086), -- Mithril Arrow
-- Eye of Pilgrim
(21305, 730, 1, 1, -1, 6574), -- Scroll: Enchant Armor (A-Grade)
(21305, 4040, 1, 1, -1, 157783), -- Mold Lubricant
(21305, 1877, 1, 1, -1, 315566), -- Adamantite Nugget
(21305, 57, 3893, 7935, 0, 700000), -- Adena
(21305, 11946, 1, 1, 1, 100.229226), -- Common Item - Dasparion's Staff
(21305, 5543, 1, 1, 1, 1239.344784), -- Dasparion's Staff Head
(21305, 11949, 1, 1, 1, 100.229226), -- Common Item - Meteor Shower
(21305, 5532, 1, 1, 1, 1227.769434), -- Meteor Shower Head
(21305, 11953, 1, 1, 1, 100.229226), -- Common Item - Spiritual Eye
(21305, 8341, 1, 1, 1, 1226.199444), -- Spiritual Eye Piece
(21305, 11958, 1, 1, 1, 100.229226), -- Common Item - Destroyer Hammer
(21305, 8346, 1, 1, 1, 1227.769434), -- Hammer Piece of Destroyer
(21305, 1871, 1, 3, 2, 145645.737432), -- Charcoal
(21305, 1866, 1, 1, 2, 194194.074288), -- Suede
(21305, 1877, 1, 1, 2, 11651.62992), -- Adamantite Nugget
(21305, 4041, 1, 1, 2, 2533.12104), -- Mold Hardener
(21305, 4040, 1, 1, 2, 5825.81496), -- Mold Lubricant
(21305, 5282, 1, 1, 2, 129.381792), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21305, 8731, 1, 1, 2, 2697.028872), -- Life Stone - Level 70
(21305, 8741, 1, 1, 2, 674.16636), -- Mid-Grade Life Stone - Level 70
(21305, 8751, 1, 1, 2, 67.598352), -- High-Grade Life Stone - Level 70
(21305, 8761, 1, 1, 2, 13.446984), -- Top-Grade Life Stone - Level 70
-- Disciples of Protection
(21306, 5547, 1, 1, -1, 48569), -- Elemental Sword Edge
(21306, 5442, 1, 1, -1, 5287), -- Recipe: Soul Bow(60%)
(21306, 5548, 1, 1, -1, 48569), -- Tallum Blade Edge
(21306, 57, 7045, 14360, 0, 700000), -- Adena
(21306, 11950, 1, 1, 1, 725.531562), -- Common Item - Blood Tornado
(21306, 5539, 1, 1, 1, 8887.468438), -- Blood Tornado Edge
(21306, 1865, 1, 3, 2, 159728.673824), -- Varnish
(21306, 1870, 2, 6, 2, 119796.622112), -- Coal
(21306, 1879, 1, 1, 2, 79864.5704), -- Cokes
(21306, 1875, 1, 1, 2, 31945.82816), -- Stone of Purity
(21306, 4040, 1, 1, 2, 9583.748448), -- Mold Lubricant
(21306, 6901, 1, 1, 2, 479.117376), -- Recipe: Shining Arrow (100%)
(21306, 8731, 1, 1, 2, 4436.738976), -- Life Stone - Level 70
(21306, 8741, 1, 1, 2, 1109.068), -- Mid-Grade Life Stone - Level 70
(21306, 8751, 1, 1, 2, 111.140288), -- High-Grade Life Stone - Level 70
(21306, 8761, 1, 1, 2, 22.414848), -- Top-Grade Life Stone - Level 70
(21306, 1344, 100, 300, 2, 59898.077568), -- Mithril Arrow
-- Elder Homunculus
(21307, 5480, 1, 1, -1, 45013), -- Sealed Leather Armor of Nightmare Fabric
(21307, 1808, 1, 1, -1, 4458), -- Recipe: Soulshot (S-Grade)
(21307, 5481, 1, 1, -1, 45013), -- Sealed Majestic Leather Armor Fabric
(21307, 57, 4948, 10097, 0, 700000), -- Adena
(21307, 11957, 1, 1, 1, 169.94781), -- Common Item - Tallum Blade
(21307, 5548, 1, 1, 1, 2100.351785), -- Tallum Blade Edge
(21307, 11952, 1, 1, 1, 169.94781), -- Common Item - Elemental Sword
(21307, 5547, 1, 1, 1, 2100.351785), -- Elemental Sword Edge
(21307, 11954, 1, 1, 1, 169.94781), -- Common Item - Inferno Master
(21307, 8331, 1, 1, 1, 2106.453), -- Infernal Master Blade
(21307, 1868, 3, 9, 2, 123464.184746), -- Thread
(21307, 1873, 1, 1, 2, 148157.091746), -- Silver Nugget
(21307, 5549, 1, 1, 2, 37039.3605), -- Metallic Thread
(21307, 1889, 1, 1, 2, 24692.907), -- Compound Braid
(21307, 4044, 1, 1, 2, 12346.4535), -- Thons
(21307, 5277, 1, 1, 2, 164.61938), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21307, 8731, 1, 1, 2, 3429.687168), -- Life Stone - Level 70
(21307, 8741, 1, 1, 2, 857.421792), -- Mid-Grade Life Stone - Level 70
(21307, 8751, 1, 1, 2, 85.81223), -- High-Grade Life Stone - Level 70
(21307, 8761, 1, 1, 2, 16.461938), -- Top-Grade Life Stone - Level 70
-- Disciples of Punishment
(21308, 3036, 1, 1, -1, 5924), -- Recipe: Spiritshot S
(21308, 5487, 1, 1, -1, 60021), -- Sealed Robe of Nightmare Fabric
(21308, 1875, 1, 1, -1, 888584), -- Stone of Purity
(21308, 57, 6575, 13415, 0, 700000), -- Adena
(21308, 11946, 1, 1, 1, 169.346336), -- Common Item - Dasparion's Staff
(21308, 5543, 1, 1, 1, 2093.985024), -- Dasparion's Staff Head
(21308, 11949, 1, 1, 1, 169.346336), -- Common Item - Meteor Shower
(21308, 5532, 1, 1, 1, 2074.427424), -- Meteor Shower Head
(21308, 11953, 1, 1, 1, 169.346336), -- Common Item - Spiritual Eye
(21308, 8341, 1, 1, 1, 2071.774784), -- Spiritual Eye Piece
(21308, 11958, 1, 1, 1, 169.346336), -- Common Item - Destroyer Hammer
(21308, 8346, 1, 1, 1, 2074.427424), -- Hammer Piece of Destroyer
(21308, 1872, 5, 15, 2, 59653.14794), -- Animal Bone
(21308, 1867, 1, 3, 2, 198843.66074), -- Animal Skin
(21308, 1881, 1, 1, 2, 59653.14794), -- Coarse Bone Powder
(21308, 1875, 1, 1, 2, 29826.32538), -- Stone of Purity
(21308, 4041, 1, 1, 2, 3890.4335), -- Mold Hardener
(21308, 5282, 1, 1, 2, 198.872), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21308, 8731, 1, 1, 2, 4142.50376), -- Life Stone - Level 70
(21308, 8741, 1, 1, 2, 1035.62594), -- Mid-Grade Life Stone - Level 70
(21308, 8751, 1, 1, 2, 103.41344), -- High-Grade Life Stone - Level 70
(21308, 8761, 1, 1, 2, 20.88156), -- Top-Grade Life Stone - Level 70
(21308, 1344, 40, 120, 2, 139811.9878), -- Mithril Arrow
-- Disciples of Punishment
(21309, 3036, 1, 1, -1, 6174), -- Recipe: Spiritshot S
(21309, 5487, 1, 1, -1, 62556), -- Sealed Robe of Nightmare Fabric
(21309, 1875, 1, 1, -1, 926118), -- Stone of Purity
(21309, 57, 6853, 13982, 0, 700000), -- Adena
(21309, 11946, 1, 1, 1, 176.502876), -- Common Item - Dasparion's Staff
(21309, 5543, 1, 1, 1, 2182.476384), -- Dasparion's Staff Head
(21309, 11949, 1, 1, 1, 176.502876), -- Common Item - Meteor Shower
(21309, 5532, 1, 1, 1, 2162.092284), -- Meteor Shower Head
(21309, 11953, 1, 1, 1, 176.502876), -- Common Item - Spiritual Eye
(21309, 8341, 1, 1, 1, 2159.327544), -- Spiritual Eye Piece
(21309, 11958, 1, 1, 1, 176.502876), -- Common Item - Destroyer Hammer
(21309, 8346, 1, 1, 1, 2162.092284), -- Hammer Piece of Destroyer
(21309, 1872, 5, 15, 2, 62172.92628), -- Animal Bone
(21309, 1867, 9, 27, 2, 34540.74492), -- Animal Skin
(21309, 1881, 1, 1, 2, 62172.92628), -- Coarse Bone Powder
(21309, 1875, 1, 1, 2, 31086.63588), -- Stone of Purity
(21309, 4041, 1, 1, 2, 4054.89876), -- Mold Hardener
(21309, 5282, 1, 1, 2, 207.288), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21309, 8731, 1, 1, 2, 4317.46356), -- Life Stone - Level 70
(21309, 8741, 1, 1, 2, 1079.27952), -- Mid-Grade Life Stone - Level 70
(21309, 8751, 1, 1, 2, 107.78976), -- High-Grade Life Stone - Level 70
(21309, 8761, 1, 1, 2, 21.41976), -- Top-Grade Life Stone - Level 70
(21309, 1344, 40, 120, 2, 145718.62728), -- Mithril Arrow
-- Disciples of Authority
(21310, 5549, 1, 3, -1, 571636), -- Metallic Thread
(21310, 5546, 1, 1, -1, 34452), -- Sword of Miracles Edge
(21310, 5162, 1, 1, -1, 5081), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21310, 57, 5625, 11517, 0, 700000), -- Adena
(21310, 11957, 1, 1, 1, 193.68117), -- Common Item - Tallum Blade
(21310, 5548, 1, 1, 1, 2393.667745), -- Tallum Blade Edge
(21310, 11952, 1, 1, 1, 193.68117), -- Common Item - Elemental Sword
(21310, 5547, 1, 1, 1, 2393.667745), -- Elemental Sword Edge
(21310, 11954, 1, 1, 1, 193.68117), -- Common Item - Inferno Master
(21310, 8331, 1, 1, 1, 2400.621), -- Infernal Master Blade
(21310, 1868, 3, 9, 2, 156344.773849), -- Thread
(21310, 1873, 1, 1, 2, 187613.551436), -- Silver Nugget
(21310, 5549, 1, 1, 2, 46903.387859), -- Metallic Thread
(21310, 1889, 1, 1, 2, 31268.777587), -- Compound Braid
(21310, 4044, 1, 1, 2, 15634.610272), -- Thons
(21310, 5157, 1, 1, 2, 208.632747), -- Recipe: Soulshot (S) Compressed Package (100%)
(21310, 8732, 1, 1, 2, 3908.652568), -- Life Stone - Level 76
(21310, 8742, 1, 1, 2, 977.163142), -- Mid-Grade Life Stone - Level 76
(21310, 8752, 1, 1, 2, 97.45054), -- High-Grade Life Stone - Level 76
-- Disciples of Authority
(21311, 5549, 1, 3, -1, 527054), -- Metallic Thread
(21311, 5546, 1, 1, -1, 31765), -- Sword of Miracles Edge
(21311, 5162, 1, 1, -1, 4685), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21311, 57, 5186, 10619, 0, 700000), -- Adena
(21311, 11957, 1, 1, 1, 178.57359), -- Common Item - Tallum Blade
(21311, 5548, 1, 1, 1, 2206.956115), -- Tallum Blade Edge
(21311, 11952, 1, 1, 1, 178.57359), -- Common Item - Elemental Sword
(21311, 5547, 1, 1, 1, 2206.956115), -- Elemental Sword Edge
(21311, 11954, 1, 1, 1, 178.57359), -- Common Item - Inferno Master
(21311, 8331, 1, 1, 1, 2213.367), -- Infernal Master Blade
(21311, 1868, 3, 9, 2, 144151.521327), -- Thread
(21311, 1873, 1, 1, 2, 172981.662228), -- Silver Nugget
(21311, 5549, 1, 1, 2, 43245.415557), -- Metallic Thread
(21311, 1889, 1, 1, 2, 28830.140901), -- Compound Braid
(21311, 4044, 1, 1, 2, 14415.274656), -- Thons
(21311, 5157, 1, 1, 2, 192.361581), -- Recipe: Soulshot (S) Compressed Package (100%)
(21311, 8732, 1, 1, 2, 3603.818664), -- Life Stone - Level 76
(21311, 8742, 1, 1, 2, 900.954666), -- Mid-Grade Life Stone - Level 76
(21311, 8752, 1, 1, 2, 89.85042), -- High-Grade Life Stone - Level 76
-- Eye of Ruler
(21312, 5448, 1, 1, -1, 4041), -- Recipe: Soul Separator(60%)
(21312, 6341, 1, 1, -1, 301763), -- Sealed Phoenix Earring Gemstone
(21312, 729, 1, 1, -1, 1212), -- Scroll: Enchant Weapon (A-Grade)
(21312, 57, 5384, 10974, 0, 700000), -- Adena
(21312, 11955, 1, 1, 1, 554.484966), -- Common Item - Carnage Bow
(21312, 5535, 1, 1, 1, 6872.515034), -- Carnage Bow Stave
(21312, 1866, 1, 3, 2, 89519.913234), -- Suede
(21312, 1871, 1, 3, 2, 201419.281158), -- Charcoal
(21312, 5220, 1, 1, 2, 16113.48664), -- Metal Hardener
(21312, 1885, 1, 1, 2, 33569.880193), -- High-Grade Suede
(21312, 4041, 1, 1, 2, 3503.007765), -- Mold Hardener
(21312, 1808, 1, 1, 2, 179.077527), -- Recipe: Soulshot (S-Grade)
(21312, 8731, 1, 1, 2, 3729.909115), -- Life Stone - Level 70
(21312, 8741, 1, 1, 2, 932.390009), -- Mid-Grade Life Stone - Level 70
(21312, 8751, 1, 1, 2, 93.204093), -- High-Grade Life Stone - Level 70
(21312, 8761, 1, 1, 2, 18.850266), -- Top-Grade Life Stone - Level 70
-- Sly Hound Dog
(21313, 730, 1, 1, -1, 8658), -- Scroll: Enchant Armor (A-Grade)
(21313, 1895, 1, 7, -1, 742151), -- Metallic Fiber
(21313, 4042, 1, 1, -1, 173169), -- Enria
(21313, 57, 5124, 10462, 0, 700000), -- Adena
(21313, 11955, 1, 1, 1, 528.056034), -- Common Item - Carnage Bow
(21313, 5535, 1, 1, 1, 6544.943966), -- Carnage Bow Stave
(21313, 1873, 1, 1, 2, 139503.67112), -- Silver Nugget
(21313, 1868, 3, 9, 2, 116253.42432), -- Thread
(21313, 1876, 1, 1, 2, 69752.054592), -- Mithril Ore
(21313, 1895, 1, 1, 2, 99645.541952), -- Metallic Fiber
(21313, 4042, 1, 1, 2, 5812.671216), -- Enria
(21313, 5272, 1, 1, 2, 155.074656), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21313, 5380, 1, 1, 2, 1981.801536), -- Recipe: Sealed Boots of Nightmare(60%)
(21313, 8730, 1, 1, 2, 3875.114144), -- Life Stone - Level 67
(21313, 8740, 1, 1, 2, 968.559504), -- Mid-Grade Life Stone - Level 67
(21313, 8750, 1, 1, 2, 96.812144), -- High-Grade Life Stone - Level 67
(21313, 8760, 1, 1, 2, 19.274816), -- Top-Grade Life Stone - Level 67
-- Hot Springs Bandersnatchling
(21314, 6335, 1, 1, -1, 22347), -- Recipe: Sealed Majestic Necklace(70%)
(21314, 6341, 1, 1, -1, 160703), -- Sealed Phoenix Earring Gemstone
(21314, 730, 1, 1, -1, 4842), -- Scroll: Enchant Armor (A-Grade)
(21314, 57, 2869, 5842, 0, 700000), -- Adena
(21314, 11950, 1, 1, 1, 295.329762), -- Common Item - Blood Tornado
(21314, 5539, 1, 1, 1, 3617.670238), -- Blood Tornado Edge
(21314, 1895, 1, 1, 2, 68105.16775), -- Metallic Fiber
(21314, 4040, 1, 1, 2, 4767.339812), -- Mold Lubricant
(21314, 4042, 1, 1, 2, 3972.841658), -- Enria
(21314, 4043, 1, 1, 2, 7945.595594), -- Asofe
(21314, 5272, 1, 1, 2, 105.968176), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21314, 8731, 1, 1, 2, 2207.08552), -- Life Stone - Level 70
(21314, 8741, 1, 1, 2, 551.77138), -- Mid-Grade Life Stone - Level 70
(21314, 8751, 1, 1, 2, 55.177138), -- High-Grade Life Stone - Level 70
(21314, 8761, 1, 1, 2, 11.052972), -- Top-Grade Life Stone - Level 70
-- Hot Springs Buffalo
(21315, 5549, 1, 1, -1, 605496), -- Metallic Thread
(21315, 1889, 1, 1, -1, 403664), -- Compound Braid
(21315, 6343, 1, 1, -1, 129462), -- Sealed Phoenix Necklace Beads
(21315, 57, 2990, 6088, 0, 700000), -- Adena
(21315, 11955, 1, 1, 1, 307.740276), -- Common Item - Carnage Bow
(21315, 5535, 1, 1, 1, 3814.259724), -- Carnage Bow Stave
(21315, 1868, 1, 3, 2, 203243.393899), -- Thread
(21315, 1873, 1, 1, 2, 81297.275085), -- Silver Nugget
(21315, 5549, 1, 1, 2, 20324.215678), -- Metallic Thread
(21315, 1889, 1, 1, 2, 13549.752034), -- Compound Braid
(21315, 4044, 1, 1, 2, 6774.876017), -- Thons
(21315, 5277, 1, 1, 2, 90.309687), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21315, 8731, 1, 1, 2, 1882.070372), -- Life Stone - Level 70
(21315, 8741, 1, 1, 2, 470.517593), -- Mid-Grade Life Stone - Level 70
(21315, 8751, 1, 1, 2, 47.010522), -- High-Grade Life Stone - Level 70
(21315, 8761, 1, 1, 2, 9.484579), -- Top-Grade Life Stone - Level 70
(21315, 1344, 30, 90, 2, 84684.094534), -- Mithril Arrow
-- Hot Springs Flava
(21316, 5550, 1, 1, -1, 84418), -- Durable Metal Plate
(21316, 4043, 1, 1, -1, 211044), -- Asofe
(21316, 6343, 1, 1, -1, 135372), -- Sealed Phoenix Necklace Beads
(21316, 57, 3124, 6369, 0, 700000), -- Adena
(21316, 11951, 1, 1, 1, 321.814542), -- Common Item - Bloody Orchid
(21316, 5536, 1, 1, 1, 3977.185458), -- Bloody Orchid Head
(21316, 1869, 2, 6, 2, 53130.004037), -- Iron Ore
(21316, 1864, 1, 3, 2, 212520.016148), -- Stem
(21316, 1880, 1, 1, 2, 21252.156808), -- Steel
(21316, 5550, 1, 1, 2, 2833.439849), -- Durable Metal Plate
(21316, 4043, 1, 1, 2, 7084.181597), -- Asofe
(21316, 3036, 1, 1, 2, 94.279869), -- Recipe: Spiritshot S
(21316, 8731, 1, 1, 2, 1967.849776), -- Life Stone - Level 70
(21316, 8741, 1, 1, 2, 491.962444), -- Mid-Grade Life Stone - Level 70
(21316, 8751, 1, 1, 2, 49.273841), -- High-Grade Life Stone - Level 70
(21316, 8761, 1, 1, 2, 9.699575), -- Top-Grade Life Stone - Level 70
(21316, 1344, 30, 90, 2, 88550.136056), -- Mithril Arrow
-- Hot Springs Atroxspawn
(21317, 5450, 1, 1, -1, 2216), -- Recipe: Dragon Grinder(60%)
(21317, 6345, 1, 1, -1, 228933), -- Sealed Phoenix Ring Gemstone
(21317, 5456, 1, 1, -1, 2216), -- Recipe: Tallum Glaive(60%)
(21317, 57, 2953, 6019, 0, 700000), -- Adena
(21317, 11950, 1, 1, 1, 304.16022), -- Common Item - Blood Tornado
(21317, 5539, 1, 1, 1, 3725.83978), -- Blood Tornado Edge
(21317, 1867, 1, 3, 2, 147305.746648), -- Animal Skin
(21317, 1872, 1, 3, 2, 98203.93402), -- Animal Bone
(21317, 1882, 1, 1, 2, 49101.812628), -- Leather
(21317, 1894, 1, 1, 2, 7753.06404), -- Crafted Leather
(21317, 4042, 1, 1, 2, 3682.628228), -- Enria
(21317, 3957, 1, 1, 2, 98.186952), -- Recipe: Blessed Spiritshot S
(21317, 8731, 1, 1, 2, 2045.870264), -- Life Stone - Level 70
(21317, 8741, 1, 1, 2, 511.621948), -- Mid-Grade Life Stone - Level 70
(21317, 8751, 1, 1, 2, 51.254824), -- High-Grade Life Stone - Level 70
(21317, 8761, 1, 1, 2, 9.880448), -- Top-Grade Life Stone - Level 70
-- Hot Springs Antelope
(21318, 5478, 1, 1, -1, 52600), -- Sealed Dark Crystal Leather Armor Pattern
(21318, 730, 1, 1, -1, 5213), -- Scroll: Enchant Armor (A-Grade)
(21318, 5549, 1, 1, -1, 625522), -- Metallic Thread
(21318, 57, 3087, 6292, 0, 700000), -- Adena
(21318, 12224, 1, 1, 1, 1257.959332), -- Common Item - Sealed Dark Crystal Boots
(21318, 5496, 1, 1, 1, 6769.040668), -- Sealed Dark Crystal Boots Lining
(21318, 12231, 1, 1, 1, 1257.959332), -- Common Item - Sealed Tallum Boots
(21318, 5497, 1, 1, 1, 6769.040668), -- Sealed Tallum Boots Lining
(21318, 12221, 1, 1, 1, 1257.959332), -- Common Item - Sealed Dark Crystal Gloves
(21318, 5508, 1, 1, 1, 6769.040668), -- Sealed Dark Crystal Gloves Design
(21318, 12229, 1, 1, 1, 1257.959332), -- Common Item - Sealed Tallum Gloves
(21318, 5509, 1, 1, 1, 6769.040668), -- Sealed Tallum Gloves Design
(21318, 1868, 1, 3, 2, 209965.552356), -- Thread
(21318, 1873, 1, 1, 2, 83986.13574), -- Silver Nugget
(21318, 5549, 1, 1, 2, 20996.427432), -- Metallic Thread
(21318, 1889, 1, 1, 2, 13997.902296), -- Compound Braid
(21318, 4044, 1, 1, 2, 6998.951148), -- Thons
(21318, 5157, 1, 1, 2, 93.296628), -- Recipe: Soulshot (S) Compressed Package (100%)
(21318, 8731, 1, 1, 2, 1944.318768), -- Life Stone - Level 70
(21318, 8741, 1, 1, 2, 486.079692), -- Mid-Grade Life Stone - Level 70
(21318, 8751, 1, 1, 2, 48.565368), -- High-Grade Life Stone - Level 70
(21318, 8761, 1, 1, 2, 9.798276), -- Top-Grade Life Stone - Level 70
(21318, 1344, 30, 90, 2, 87484.972296), -- Mithril Arrow
-- Hot Springs Nepenthes
(21319, 5495, 1, 1, -1, 107187), -- Sealed Shield of Nightmare Fragment
(21319, 5157, 1, 1, -1, 3137), -- Recipe: Soulshot (S) Compressed Package (100%)
(21319, 5502, 1, 1, -1, 119216), -- Sealed Boots of Nightmare Lining
(21319, 57, 3482, 7105, 0, 700000), -- Adena
(21319, 288, 1, 1, 1, 18.4851), -- Carnage Bow
(21319, 5535, 1, 1, 1, 4446.5149), -- Carnage Bow Stave
(21319, 1869, 2, 6, 2, 59234.470779), -- Iron Ore
(21319, 1864, 1, 3, 2, 236937.883116), -- Stem
(21319, 1880, 1, 1, 2, 23693.961336), -- Steel
(21319, 5550, 1, 1, 2, 3158.992983), -- Durable Metal Plate
(21319, 4043, 1, 1, 2, 7898.131299), -- Asofe
(21319, 3036, 1, 1, 2, 105.112323), -- Recipe: Spiritshot S
(21319, 8731, 1, 1, 2, 2193.949392), -- Life Stone - Level 70
(21319, 8741, 1, 1, 2, 548.487348), -- Mid-Grade Life Stone - Level 70
(21319, 8751, 1, 1, 2, 54.935247), -- High-Grade Life Stone - Level 70
(21319, 8761, 1, 1, 2, 10.814025), -- Top-Grade Life Stone - Level 70
(21319, 1344, 30, 90, 2, 98724.262152), -- Mithril Arrow
-- Hot Springs Yeti
(21320, 4042, 1, 1, -1, 107055), -- Enria
(21320, 1894, 1, 1, -1, 225378), -- Crafted Leather
(21320, 5503, 1, 1, -1, 108483), -- Sealed Majestic Boots Lining
(21320, 57, 3168, 6465, 0, 700000), -- Adena
(21320, 11951, 1, 1, 1, 326.455738), -- Common Item - Bloody Orchid
(21320, 5536, 1, 1, 1, 4034.544262), -- Bloody Orchid Head
(21320, 1867, 1, 3, 2, 158111.176866), -- Animal Skin
(21320, 1872, 1, 3, 2, 105407.561715), -- Animal Bone
(21320, 1882, 1, 1, 2, 52703.615151), -- Leather
(21320, 1894, 1, 1, 2, 8321.78043), -- Crafted Leather
(21320, 4042, 1, 1, 2, 3952.762851), -- Enria
(21320, 3036, 1, 1, 2, 105.389334), -- Recipe: Spiritshot S
(21320, 8731, 1, 1, 2, 2195.942538), -- Life Stone - Level 70
(21320, 8741, 1, 1, 2, 549.151341), -- Mid-Grade Life Stone - Level 70
(21320, 8751, 1, 1, 2, 55.014558), -- High-Grade Life Stone - Level 70
(21320, 8761, 1, 1, 2, 10.605216), -- Top-Grade Life Stone - Level 70
-- Hot Springs Atrox
(21321, 1876, 1, 3, -1, 559345), -- Mithril Ore
(21321, 1895, 1, 3, -1, 799064), -- Metallic Fiber
(21321, 6346, 1, 1, -1, 182108), -- Sealed Majestic Ring Gemstone
(21321, 57, 2752, 5635, 0, 700000), -- Adena
(21321, 11950, 1, 1, 1, 284.310558), -- Common Item - Blood Tornado
(21321, 5539, 1, 1, 1, 3482.689442), -- Blood Tornado Edge
(21321, 1873, 1, 1, 2, 91790.00814), -- Silver Nugget
(21321, 1868, 1, 3, 2, 229475.45944), -- Thread
(21321, 1876, 1, 1, 2, 45895.00407), -- Mithril Ore
(21321, 1895, 1, 1, 2, 65564.47971), -- Metallic Fiber
(21321, 4042, 1, 1, 2, 3824.4739), -- Enria
(21321, 5167, 1, 1, 2, 101.86888), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21321, 8732, 1, 1, 2, 1912.23695), -- Life Stone - Level 76
(21321, 8742, 1, 1, 2, 478.16901), -- Mid-Grade Life Stone - Level 76
(21321, 8752, 1, 1, 2, 48.2999), -- High-Grade Life Stone - Level 76
-- Hot Springs Bandersnatch
(21322, 5272, 1, 1, -1, 2486), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21322, 5480, 1, 1, -1, 25099), -- Sealed Leather Armor of Nightmare Fabric
(21322, 5277, 1, 1, -1, 2486), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21322, 57, 2752, 5635, 0, 700000), -- Adena
(21322, 11955, 1, 1, 1, 284.297664), -- Common Item - Carnage Bow
(21322, 5535, 1, 1, 1, 3523.702336), -- Carnage Bow Stave
(21322, 1871, 1, 1, 2, 206527.465476), -- Charcoal
(21322, 1866, 1, 1, 2, 137684.976984), -- Suede
(21322, 1877, 1, 1, 2, 8260.883122), -- Adamantite Nugget
(21322, 4041, 1, 1, 2, 1795.971922), -- Mold Hardener
(21322, 4040, 1, 1, 2, 4130.686444), -- Mold Lubricant
(21322, 5272, 1, 1, 2, 91.586242), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21322, 8732, 1, 1, 2, 1721.037724), -- Life Stone - Level 76
(21322, 8742, 1, 1, 2, 430.504314), -- Mid-Grade Life Stone - Level 76
(21322, 8752, 1, 1, 2, 43.099408), -- High-Grade Life Stone - Level 76
(21322, 1344, 20, 60, 2, 129079.788364), -- Mithril Arrow
-- Hot Springs Grendel
(21323, 5481, 1, 1, -1, 24797), -- Sealed Majestic Leather Armor Fabric
(21323, 4042, 1, 1, -1, 92103), -- Enria
(21323, 1894, 1, 1, -1, 193902), -- Crafted Leather
(21323, 57, 2719, 5567, 0, 700000), -- Adena
(21323, 11951, 1, 1, 1, 280.867216), -- Common Item - Bloody Orchid
(21323, 5536, 1, 1, 1, 3471.132784), -- Bloody Orchid Head
(21323, 1867, 1, 3, 2, 151144.346532), -- Animal Skin
(21323, 1872, 1, 3, 2, 100762.897688), -- Animal Bone
(21323, 1882, 1, 1, 2, 50381.448844), -- Leather
(21323, 1894, 1, 1, 2, 7955.082224), -- Crafted Leather
(21323, 4042, 1, 1, 2, 3778.759016), -- Enria
(21323, 5277, 1, 1, 2, 100.657176), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21323, 8732, 1, 1, 2, 1889.379508), -- Life Stone - Level 76
(21323, 8742, 1, 1, 2, 472.265744), -- Mid-Grade Life Stone - Level 76
(21323, 8752, 1, 1, 2, 47.163268), -- High-Grade Life Stone - Level 76
-- Ketra Orc Footman
(21324, 4042, 1, 1, -1, 88264), -- Enria
(21324, 5502, 1, 1, -1, 89441), -- Sealed Boots of Nightmare Lining
(21324, 1808, 1, 1, -1, 2354), -- Recipe: Soulshot (S-Grade)
(21324, 57, 2610, 5333, 0, 700000), -- Adena
(21324, 11957, 1, 1, 1, 89.72307), -- Common Item - Tallum Blade
(21324, 5548, 1, 1, 1, 1108.869895), -- Tallum Blade Edge
(21324, 11952, 1, 1, 1, 89.72307), -- Common Item - Elemental Sword
(21324, 5547, 1, 1, 1, 1108.869895), -- Elemental Sword Edge
(21324, 11954, 1, 1, 1, 89.72307), -- Common Item - Inferno Master
(21324, 8331, 1, 1, 1, 1112.091), -- Infernal Master Blade
(21324, 1873, 1, 1, 2, 78215.208955), -- Silver Nugget
(21324, 1868, 1, 3, 2, 195538.250201), -- Thread
(21324, 1876, 1, 1, 2, 39107.832291), -- Mithril Ore
(21324, 1895, 1, 1, 2, 55868.071486), -- Metallic Fiber
(21324, 4042, 1, 1, 2, 3259.099931), -- Enria
(21324, 1808, 1, 1, 2, 87.024757), -- Recipe: Soulshot (S-Grade)
(21324, 8732, 1, 1, 2, 1629.322152), -- Life Stone - Level 76
(21324, 8742, 1, 1, 2, 407.330538), -- Mid-Grade Life Stone - Level 76
(21324, 8752, 1, 1, 2, 40.550803), -- High-Grade Life Stone - Level 76
(21324, 1344, 30, 90, 2, 81474.308886), -- Mithril Arrow
-- Ketra's War Hound
(21325, 5503, 1, 1, -1, 86488), -- Sealed Majestic Boots Lining
(21325, 3036, 1, 1, -1, 2276), -- Recipe: Spiritshot S
(21325, 5514, 1, 1, -1, 86488), -- Sealed Gauntlets of Nightmare Design
(21325, 57, 2524, 5157, 0, 700000), -- Adena
(21325, 11946, 1, 1, 1, 65.068015), -- Common Item - Dasparion's Staff
(21325, 5543, 1, 1, 1, 804.57276), -- Dasparion's Staff Head
(21325, 11949, 1, 1, 1, 65.068015), -- Common Item - Meteor Shower
(21325, 5532, 1, 1, 1, 797.058135), -- Meteor Shower Head
(21325, 11953, 1, 1, 1, 65.068015), -- Common Item - Spiritual Eye
(21325, 8341, 1, 1, 1, 796.03891), -- Spiritual Eye Piece
(21325, 11958, 1, 1, 1, 65.068015), -- Common Item - Destroyer Hammer
(21325, 8346, 1, 1, 1, 797.058135), -- Hammer Piece of Destroyer
(21325, 1894, 1, 1, 2, 8292.958982), -- Crafted Leather
(21325, 4039, 1, 1, 2, 7878.285184), -- Mold Glue
(21325, 4041, 1, 1, 2, 2055.217318), -- Mold Hardener
(21325, 4044, 1, 1, 2, 7878.285184), -- Thons
(21325, 3036, 1, 1, 2, 105.032697), -- Recipe: Spiritshot S
(21325, 8732, 1, 1, 2, 1969.571296), -- Life Stone - Level 76
(21325, 8742, 1, 1, 2, 492.392824), -- Mid-Grade Life Stone - Level 76
(21325, 8752, 1, 1, 2, 49.256515), -- High-Grade Life Stone - Level 76
-- Grazing Kookaburra
(21326, 1877, 1, 1, -1, 204838), -- Adamantite Nugget
(21326, 4041, 1, 1, -1, 44530), -- Mold Hardener
(21326, 5515, 1, 1, -1, 86488), -- Sealed Majestic Gauntlets Design
(21326, 57, 2524, 5157, 0, 700000), -- Adena
(21326, 11950, 1, 1, 1, 260.234352), -- Common Item - Blood Tornado
(21326, 5539, 1, 1, 1, 3187.765648), -- Blood Tornado Edge
(21326, 1871, 1, 1, 2, 189081.472284), -- Charcoal
(21326, 1866, 1, 1, 2, 126054.314856), -- Suede
(21326, 1877, 1, 1, 2, 7563.061598), -- Adamantite Nugget
(21326, 4041, 1, 1, 2, 1644.260798), -- Mold Hardener
(21326, 4040, 1, 1, 2, 3781.754996), -- Mold Lubricant
(21326, 3957, 1, 1, 2, 83.849678), -- Recipe: Blessed Spiritshot S
(21326, 8732, 1, 1, 2, 1575.656516), -- Life Stone - Level 76
(21326, 8742, 1, 1, 2, 394.138326), -- Mid-Grade Life Stone - Level 76
(21326, 8752, 1, 1, 2, 39.458672), -- High-Grade Life Stone - Level 76
(21326, 1344, 20, 60, 2, 118176.032276), -- Mithril Arrow
-- Ketra Orc Raider
(21327, 4039, 1, 1, -1, 194325), -- Mold Glue
(21327, 5533, 1, 1, -1, 15991), -- Elysian Head
(21327, 5272, 1, 1, -1, 2591), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21327, 57, 2875, 5868, 0, 700000), -- Adena
(21327, 11957, 1, 1, 1, 98.77266), -- Common Item - Tallum Blade
(21327, 5548, 1, 1, 1, 1220.71201), -- Tallum Blade Edge
(21327, 11952, 1, 1, 1, 98.77266), -- Common Item - Elemental Sword
(21327, 5547, 1, 1, 1, 1220.71201), -- Elemental Sword Edge
(21327, 11954, 1, 1, 1, 98.77266), -- Common Item - Inferno Master
(21327, 8331, 1, 1, 1, 1224.258), -- Infernal Master Blade
(21327, 1894, 1, 1, 2, 9440.997174), -- Crafted Leather
(21327, 4039, 1, 1, 2, 8968.917888), -- Mold Glue
(21327, 4041, 1, 1, 2, 2339.731926), -- Mold Hardener
(21327, 4044, 1, 1, 2, 8968.917888), -- Thons
(21327, 5277, 1, 1, 2, 119.572929), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21327, 8732, 1, 1, 2, 2242.229472), -- Life Stone - Level 76
(21327, 8742, 1, 1, 2, 560.557368), -- Mid-Grade Life Stone - Level 76
(21327, 8752, 1, 1, 2, 56.075355), -- High-Grade Life Stone - Level 76
-- Ketra Orc Scout
(21328, 5534, 1, 1, -1, 15343), -- Soul Bow Stave
(21328, 5277, 1, 1, -1, 2484), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21328, 5537, 1, 1, -1, 15333), -- Soul Separator Head
(21328, 57, 2756, 5626, 0, 700000), -- Adena
(21328, 11946, 1, 1, 1, 71.019243), -- Common Item - Dasparion's Staff
(21328, 5543, 1, 1, 1, 878.160312), -- Dasparion's Staff Head
(21328, 11949, 1, 1, 1, 71.019243), -- Common Item - Meteor Shower
(21328, 5532, 1, 1, 1, 869.958387), -- Meteor Shower Head
(21328, 11953, 1, 1, 1, 71.019243), -- Common Item - Spiritual Eye
(21328, 8341, 1, 1, 1, 868.845942), -- Spiritual Eye Piece
(21328, 11958, 1, 1, 1, 71.019243), -- Common Item - Destroyer Hammer
(21328, 8346, 1, 1, 1, 869.958387), -- Hammer Piece of Destroyer
(21328, 1873, 1, 1, 2, 75038.645032), -- Silver Nugget
(21328, 1868, 1, 3, 2, 187596.61258), -- Thread
(21328, 1876, 1, 1, 2, 37519.322516), -- Mithril Ore
(21328, 1895, 1, 1, 2, 53598.966742), -- Metallic Fiber
(21328, 4042, 1, 1, 2, 3126.533882), -- Enria
(21328, 5282, 1, 1, 2, 83.349812), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21328, 6671, 1, 1, 2, 20843.864524), -- Deluxe Chest Key - Grade 7
(21328, 8732, 1, 1, 2, 1563.495924), -- Life Stone - Level 76
(21328, 8742, 1, 1, 2, 390.644998), -- Mid-Grade Life Stone - Level 76
(21328, 8752, 1, 1, 2, 38.92711), -- High-Grade Life Stone - Level 76
(21328, 1344, 30, 90, 2, 78165.63688), -- Mithril Arrow
-- Ketra Orc Shaman
(21329, 5162, 1, 1, -1, 2526), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21329, 5487, 1, 1, -1, 25594), -- Sealed Robe of Nightmare Fabric
(21329, 5167, 1, 1, -1, 2526), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21329, 57, 2802, 5719, 0, 700000), -- Adena
(21329, 81, 1, 1, 1, 3.372642), -- Dragon Slayer
(21329, 5529, 1, 1, 1, 959.166264), -- Dragon Slayer Edge
(21329, 151, 1, 1, 1, 3.372642), -- Sword of Miracles
(21329, 5546, 1, 1, 1, 1053.552528), -- Sword of Miracles Edge
(21329, 2500, 1, 1, 1, 3.372642), -- Dark Legion's Edge
(21329, 5545, 1, 1, 1, 959.163282), -- Dark Legion's Edge Blade
(21329, 1866, 1, 1, 2, 155449.41438), -- Suede
(21329, 1871, 1, 1, 2, 233173.91058), -- Charcoal
(21329, 5220, 1, 1, 2, 9327.02394), -- Metal Hardener
(21329, 1885, 1, 1, 2, 19431.33504), -- High-Grade Suede
(21329, 4041, 1, 1, 2, 2027.6139), -- Mold Hardener
(21329, 960, 1, 1, 2, 93.25758), -- Scroll: Enchant Armor (S-Grade)
(21329, 8732, 1, 1, 2, 1943.2179), -- Life Stone - Level 76
(21329, 8742, 1, 1, 2, 485.69898), -- Mid-Grade Life Stone - Level 76
(21329, 8752, 1, 1, 2, 48.5277), -- High-Grade Life Stone - Level 76
-- Grazing Buffalo
(21330, 5488, 1, 1, -1, 24396), -- Sealed Majestic Robe Fabric
(21330, 1885, 1, 1, -1, 451470), -- High-Grade Suede
(21330, 4041, 1, 1, -1, 47110), -- Mold Hardener
(21330, 57, 2671, 5451, 0, 700000), -- Adena
(21330, 11974, 1, 1, 1, 44.44532), -- Common Item - Elysian
(21330, 5533, 1, 1, 1, 685.75908), -- Elysian Head
(21330, 11970, 1, 1, 1, 44.44532), -- Common Item - Branch of the Mother Tree
(21330, 5544, 1, 1, 1, 685.08164), -- Branch of the Mother Tree Head
(21330, 11969, 1, 1, 1, 44.44532), -- Common Item - Flaming Dragon Skull
(21330, 8342, 1, 1, 1, 685.75908), -- Flaming Dragon Skull Piece
(21330, 11966, 1, 1, 1, 44.44532), -- Common Item - Doom Crusher
(21330, 8349, 1, 1, 1, 685.61892), -- Doom Crusher Head
(21330, 1866, 1, 1, 2, 133357.154112), -- Suede
(21330, 1871, 1, 1, 2, 200036.2182), -- Charcoal
(21330, 5220, 1, 1, 2, 8001.448728), -- Metal Hardener
(21330, 1885, 1, 1, 2, 16669.644264), -- High-Grade Suede
(21330, 4041, 1, 1, 2, 1739.678304), -- Mold Hardener
(21330, 960, 1, 1, 2, 79.873248), -- Scroll: Enchant Armor (S-Grade)
(21330, 8732, 1, 1, 2, 1667.110536), -- Life Stone - Level 76
(21330, 8742, 1, 1, 2, 416.899392), -- Mid-Grade Life Stone - Level 76
(21330, 8752, 1, 1, 2, 41.884752), -- High-Grade Life Stone - Level 76
(21330, 1344, 20, 60, 2, 125022.088464), -- Mithril Arrow
-- Ketra Orc Warrior
(21331, 5546, 1, 1, -1, 16041), -- Sword of Miracles Edge
(21331, 1895, 1, 3, -1, 760448), -- Metallic Fiber
(21331, 4042, 1, 1, -1, 88719), -- Enria
(21331, 57, 2624, 5357, 0, 700000), -- Adena
(21331, 11968, 1, 1, 1, 58.230161), -- Common Item - Dragon Slayer
(21331, 5529, 1, 1, 1, 898.627587), -- Dragon Slayer Edge
(21331, 11971, 1, 1, 1, 58.230161), -- Common Item - Sword of Miracles
(21331, 5546, 1, 1, 1, 987.054343), -- Sword of Miracles Edge
(21331, 11964, 1, 1, 1, 58.230161), -- Common Item - Dark Legion's Edge
(21331, 5545, 1, 1, 1, 898.627587), -- Dark Legion's Edge Blade
(21331, 1873, 1, 1, 2, 78618.622292), -- Silver Nugget
(21331, 1868, 1, 3, 2, 196547.013699), -- Thread
(21331, 1876, 1, 1, 2, 39309.311146), -- Mithril Ore
(21331, 1895, 1, 1, 2, 56156.15878), -- Metallic Fiber
(21331, 4042, 1, 1, 2, 3275.852257), -- Enria
(21331, 960, 1, 1, 2, 78.770668), -- Scroll: Enchant Armor (S-Grade)
(21331, 8732, 1, 1, 2, 1637.697144), -- Life Stone - Level 76
(21331, 8742, 1, 1, 2, 409.424286), -- Mid-Grade Life Stone - Level 76
(21331, 8752, 1, 1, 2, 40.759241), -- High-Grade Life Stone - Level 76
(21331, 1344, 30, 90, 2, 81895.390487), -- Mithril Arrow
-- Ketra Orc Lieutenant
(21332, 6342, 1, 1, -1, 135049), -- Sealed Majestic Earring Gemstone
(21332, 5282, 1, 1, -1, 2650), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21332, 6344, 1, 1, -1, 87397), -- Sealed Majestic Necklace Beads
(21332, 57, 2939, 6000, 0, 700000), -- Adena
(21332, 11974, 1, 1, 1, 48.920294), -- Common Item - Elysian
(21332, 5533, 1, 1, 1, 754.804686), -- Elysian Head
(21332, 11970, 1, 1, 1, 48.920294), -- Common Item - Branch of the Mother Tree
(21332, 5544, 1, 1, 1, 754.059038), -- Branch of the Mother Tree Head
(21332, 11969, 1, 1, 1, 48.920294), -- Common Item - Flaming Dragon Skull
(21332, 8342, 1, 1, 1, 754.804686), -- Flaming Dragon Skull Piece
(21332, 11966, 1, 1, 1, 48.920294), -- Common Item - Doom Crusher
(21332, 8349, 1, 1, 1, 754.650414), -- Doom Crusher Head
(21332, 1894, 1, 1, 2, 9654.742156), -- Crafted Leather
(21332, 4039, 1, 1, 2, 9171.98172), -- Mold Glue
(21332, 4041, 1, 1, 2, 2392.706822), -- Mold Hardener
(21332, 4044, 1, 1, 2, 9171.98172), -- Thons
(21332, 959, 1, 1, 2, 10.99758), -- Scroll: Enchant Weapon (S-Grade)
(21332, 8732, 1, 1, 2, 2292.99543), -- Life Stone - Level 76
(21332, 8742, 1, 1, 2, 573.240526), -- Mid-Grade Life Stone - Level 76
(21332, 8752, 1, 1, 2, 57.354046), -- High-Grade Life Stone - Level 76
-- Grazing Windsus
(21333, 1808, 1, 1, -1, 2541), -- Recipe: Soulshot (S-Grade)
(21333, 5503, 1, 1, -1, 96563), -- Sealed Majestic Boots Lining
(21333, 3036, 1, 1, -1, 2541), -- Recipe: Spiritshot S
(21333, 57, 2813, 5760, 0, 700000), -- Adena
(21333, 11974, 1, 1, 1, 46.911122), -- Common Item - Elysian
(21333, 5533, 1, 1, 1, 723.804618), -- Elysian Head
(21333, 11970, 1, 1, 1, 46.911122), -- Common Item - Branch of the Mother Tree
(21333, 5544, 1, 1, 1, 723.089594), -- Branch of the Mother Tree Head
(21333, 11969, 1, 1, 1, 46.911122), -- Common Item - Flaming Dragon Skull
(21333, 8342, 1, 1, 1, 723.804618), -- Flaming Dragon Skull Piece
(21333, 11966, 1, 1, 1, 46.911122), -- Common Item - Doom Crusher
(21333, 8349, 1, 1, 1, 723.656682), -- Doom Crusher Head
(21333, 1864, 4, 12, 2, 58640.930296), -- Stem
(21333, 1865, 2, 6, 2, 46912.667373), -- Varnish
(21333, 1866, 3, 9, 2, 26062.592985), -- Suede
(21333, 1873, 1, 1, 2, 93825.334746), -- Silver Nugget
(21333, 1868, 1, 3, 2, 156375.55791), -- Thread
(21333, 959, 1, 1, 2, 9.223656), -- Scroll: Enchant Weapon (S-Grade)
(21333, 8732, 1, 1, 2, 1954.646434), -- Life Stone - Level 76
(21333, 8742, 1, 1, 2, 488.853768), -- Mid-Grade Life Stone - Level 76
(21333, 8752, 1, 1, 2, 49.192832), -- High-Grade Life Stone - Level 76
-- Ketra Orc Medium
(21334, 5514, 1, 1, -1, 130657), -- Sealed Gauntlets of Nightmare Design
(21334, 5480, 1, 1, -1, 34714), -- Sealed Leather Armor of Nightmare Fabric
(21334, 57, 3806, 7794, 0, 700000), -- Adena
(21334, 11967, 1, 1, 1, 253.876257), -- Common Item - Dragon Grinder
(21334, 5538, 1, 1, 1, 3917.123743), -- Dragon Grinder Edge
(21334, 1869, 2, 6, 2, 51935.313846), -- Iron Ore
(21334, 1870, 3, 9, 2, 43279.240698), -- Coal
(21334, 1871, 3, 9, 2, 37096.759894), -- Charcoal
(21334, 1872, 8, 24, 2, 21639.807856), -- Animal Bone
(21334, 1867, 1, 3, 2, 115411.683542), -- Animal Skin
(21334, 960, 1, 1, 2, 103.878878), -- Scroll: Enchant Armor (S-Grade)
(21334, 6672, 1, 1, 2, 21639.807856), -- Deluxe Chest Key - Grade 8
(21334, 8732, 1, 1, 2, 2163.83078), -- Life Stone - Level 76
(21334, 8742, 1, 1, 2, 541.145202), -- Mid-Grade Life Stone - Level 76
(21334, 8752, 1, 1, 2, 54.002016), -- High-Grade Life Stone - Level 76
(21334, 1344, 40, 120, 2, 81148.529432), -- Mithril Arrow
-- Ketra Orc Elite Soldier
(21335, 1889, 1, 1, -1, 368264), -- Compound Braid
(21335, 5495, 1, 1, -1, 83881), -- Sealed Shield of Nightmare Fragment
(21335, 5272, 1, 1, -1, 2455), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21335, 57, 2718, 5566, 0, 700000), -- Adena
(21335, 11976, 1, 1, 1, 181.297662), -- Common Item - Tallum Glaive
(21335, 5541, 1, 1, 1, 2796.702338), -- Tallum Glaive Edge
(21335, 1868, 1, 3, 2, 226624.563792), -- Thread
(21335, 1873, 1, 1, 2, 90649.89852), -- Silver Nugget
(21335, 5549, 1, 1, 2, 22662.383376), -- Metallic Thread
(21335, 1889, 1, 1, 2, 15108.377256), -- Compound Braid
(21335, 4044, 1, 1, 2, 7554.00612), -- Thons
(21335, 959, 1, 1, 2, 9.1254), -- Scroll: Enchant Weapon (S-Grade)
(21335, 8732, 1, 1, 2, 1888.592784), -- Life Stone - Level 76
(21335, 8742, 1, 1, 2, 471.965688), -- Mid-Grade Life Stone - Level 76
(21335, 8752, 1, 1, 2, 47.087064), -- High-Grade Life Stone - Level 76
-- Ketra Orc White Captain
(21336, 5502, 1, 1, -1, 109688), -- Sealed Boots of Nightmare Lining
(21336, 5277, 1, 1, -1, 2887), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21336, 5503, 1, 1, -1, 109688), -- Sealed Majestic Boots Lining
(21336, 57, 3195, 6545, 0, 700000), -- Adena
(21336, 12265, 1, 1, 1, 334.9159), -- Common Item - Sealed Leather Armor of Nightmare
(21336, 5480, 1, 1, 1, 2690.0841), -- Sealed Leather Armor of Nightmare Fabric
(21336, 12258, 1, 1, 1, 334.9159), -- Common Item - Sealed Majestic Leather Armor
(21336, 5481, 1, 1, 1, 2690.0841), -- Sealed Majestic Leather Armor Fabric
(21336, 1864, 5, 15, 2, 47960.470096), -- Stem
(21336, 1865, 3, 9, 2, 39966.910368), -- Varnish
(21336, 1866, 3, 9, 2, 22838.361392), -- Suede
(21336, 1873, 1, 1, 2, 95920.496056), -- Silver Nugget
(21336, 1868, 1, 3, 2, 159867.641472), -- Thread
(21336, 960, 1, 1, 2, 95.933376), -- Scroll: Enchant Armor (S-Grade)
(21336, 8732, 1, 1, 2, 1998.167864), -- Life Stone - Level 76
(21336, 8742, 1, 1, 2, 499.653), -- Mid-Grade Life Stone - Level 76
(21336, 8752, 1, 1, 2, 49.743232), -- High-Grade Life Stone - Level 76
(21336, 1344, 40, 120, 2, 74938.623144), -- Mithril Arrow
-- Grazing Elder Buffalo
(21337, 959, 1, 1, -1, 241), -- Scroll: Enchant Weapon (S-Grade)
(21337, 5220, 1, 1, -1, 240694), -- Metal Hardener
(21337, 1885, 1, 1, -1, 501446), -- High-Grade Suede
(21337, 57, 2968, 6057, 0, 700000), -- Adena
(21337, 12266, 1, 1, 1, 310.299632), -- Common Item - Sealed Robe of Nightmare
(21337, 5487, 1, 1, 1, 2501.200368), -- Sealed Robe of Nightmare Fabric
(21337, 12259, 1, 1, 1, 310.299632), -- Common Item - Sealed Majestic Robe
(21337, 5488, 1, 1, 1, 2501.200368), -- Sealed Majestic Robe Fabric
(21337, 1866, 1, 1, 2, 164577.34818), -- Suede
(21337, 1871, 1, 1, 2, 246866.02227), -- Charcoal
(21337, 5220, 1, 1, 2, 9874.53369), -- Metal Hardener
(21337, 1885, 1, 1, 2, 20572.28019), -- High-Grade Suede
(21337, 4041, 1, 1, 2, 2146.69602), -- Mold Hardener
(21337, 959, 1, 1, 2, 9.82674), -- Scroll: Enchant Weapon (S-Grade)
(21337, 8732, 1, 1, 2, 2057.36202), -- Life Stone - Level 76
(21337, 8742, 1, 1, 2, 514.11717), -- Mid-Grade Life Stone - Level 76
(21337, 8752, 1, 1, 2, 51.81372), -- High-Grade Life Stone - Level 76
-- Ketra Orc Priest
(21338, 6688, 1, 1, -1, 17114), -- Forgotten Blade Edge
(21338, 6689, 1, 1, -1, 16792), -- Basalt Battlehammer Head
(21338, 6690, 1, 1, -1, 17147), -- Imperial Staff Head
(21338, 57, 3905, 7970, 0, 700000), -- Adena
(21338, 12352, 1, 1, 1, 1198.670013), -- Common Item - Sealed Majestic Earring
(21338, 6342, 1, 1, 1, 11037.681897), -- Sealed Majestic Earring Gemstone
(21338, 12350, 1, 1, 1, 899.846697), -- Common Item - Sealed Majestic Necklace
(21338, 6344, 1, 1, 1, 7142.962365), -- Sealed Majestic Necklace Beads
(21338, 12351, 1, 1, 1, 1797.986049), -- Common Item - Sealed Majestic Ring
(21338, 6346, 1, 1, 1, 15863.852979), -- Sealed Majestic Ring Gemstone
(21338, 1869, 2, 6, 2, 73088.61518), -- Iron Ore
(21338, 1864, 5, 15, 2, 58470.892144), -- Stem
(21338, 1880, 1, 1, 2, 29235.446072), -- Steel
(21338, 5550, 1, 1, 2, 3897.979616), -- Durable Metal Plate
(21338, 4043, 1, 1, 2, 9745.248516), -- Asofe
(21338, 960, 1, 1, 2, 116.79564), -- Scroll: Enchant Armor (S-Grade)
(21338, 8732, 1, 1, 2, 2436.23726), -- Life Stone - Level 76
(21338, 8742, 1, 1, 2, 609.134184), -- Mid-Grade Life Stone - Level 76
(21338, 8752, 1, 1, 2, 60.793628), -- High-Grade Life Stone - Level 76
(21338, 1344, 30, 90, 2, 121814.85776), -- Mithril Arrow
-- Ketra Orc General
(21339, 6691, 1, 1, -1, 13041), -- Angel Slayer Blade
(21339, 6693, 1, 1, -1, 13277), -- Dragon Hunter Axe Blade
(21339, 6694, 1, 1, -1, 13277), -- Saint Spear Blade
(21339, 57, 2975, 6071, 0, 700000), -- Adena
(21339, 11973, 1, 1, 1, 198.025424), -- Common Item - Soul Separator
(21339, 5537, 1, 1, 1, 3055.974576), -- Soul Separator Head
(21339, 1867, 1, 3, 2, 148511.48214), -- Animal Skin
(21339, 1872, 1, 3, 2, 99007.65476), -- Animal Bone
(21339, 1882, 1, 1, 2, 49503.82738), -- Leather
(21339, 1894, 1, 1, 2, 7816.473928), -- Crafted Leather
(21339, 4042, 1, 1, 2, 3712.977365), -- Enria
(21339, 960, 1, 1, 2, 89.065782), -- Scroll: Enchant Armor (S-Grade)
(21339, 8732, 1, 1, 2, 1856.298371), -- Life Stone - Level 76
(21339, 8742, 1, 1, 2, 463.979437), -- Mid-Grade Life Stone - Level 76
(21339, 8752, 1, 1, 2, 46.436006), -- High-Grade Life Stone - Level 76
(21339, 1344, 40, 120, 2, 69614.804831), -- Mithril Arrow
-- Ketra Orc Battalion Commander
(21340, 960, 1, 1, -1, 2413), -- Scroll: Enchant Armor (S-Grade)
(21340, 5549, 1, 1, -1, 603328), -- Metallic Thread
(21340, 1889, 1, 1, -1, 402219), -- Compound Braid
(21340, 57, 2975, 6071, 0, 700000), -- Adena
(21340, 12268, 1, 1, 1, 963.126999), -- Common Item - Sealed Shield of Nightmare
(21340, 5495, 1, 1, 1, 5637.953658), -- Sealed Shield of Nightmare Fragment
(21340, 12269, 1, 1, 1, 673.837215), -- Common Item - Sealed Helm of Nightmare
(21340, 5527, 1, 1, 1, 4439.114043), -- Sealed Helm of Nightmare Design
(21340, 12261, 1, 1, 1, 673.837215), -- Common Item - Sealed Majestic Circlet
(21340, 5528, 1, 1, 1, 4439.13087), -- Sealed Majestic Circlet Design
(21340, 1868, 1, 3, 2, 222767.500392), -- Thread
(21340, 1873, 1, 1, 2, 89107.151104), -- Silver Nugget
(21340, 5549, 1, 1, 2, 22276.787776), -- Metallic Thread
(21340, 1889, 1, 1, 2, 14851.31764), -- Compound Braid
(21340, 4044, 1, 1, 2, 7425.470136), -- Thons
(21340, 959, 1, 1, 2, 9.056832), -- Scroll: Enchant Weapon (S-Grade)
(21340, 6672, 1, 1, 2, 18563.864024), -- Deluxe Chest Key - Grade 8
(21340, 8732, 1, 1, 2, 1856.273192), -- Life Stone - Level 76
(21340, 8742, 1, 1, 2, 464.16264), -- Mid-Grade Life Stone - Level 76
(21340, 8752, 1, 1, 2, 46.416264), -- High-Grade Life Stone - Level 76
-- Grazing Elder Kookaburra
(21341, 960, 1, 1, -1, 2527), -- Scroll: Enchant Armor (S-Grade)
(21341, 4042, 1, 1, -1, 105303), -- Enria
(21341, 1876, 1, 3, -1, 631818), -- Mithril Ore
(21341, 57, 3115, 6359, 0, 700000), -- Adena
(21341, 11968, 1, 1, 1, 69.112648), -- Common Item - Dragon Slayer
(21341, 5529, 1, 1, 1, 1066.569816), -- Dragon Slayer Edge
(21341, 11971, 1, 1, 1, 69.112648), -- Common Item - Sword of Miracles
(21341, 5546, 1, 1, 1, 1171.522424), -- Sword of Miracles Edge
(21341, 11964, 1, 1, 1, 69.112648), -- Common Item - Dark Legion's Edge
(21341, 5545, 1, 1, 1, 1066.569816), -- Dark Legion's Edge Blade
(21341, 1873, 1, 1, 2, 103682.999625), -- Silver Nugget
(21341, 1868, 1, 3, 2, 259207.251125), -- Thread
(21341, 1876, 1, 1, 2, 51841.251875), -- Mithril Ore
(21341, 1895, 1, 1, 2, 74058.93125), -- Metallic Fiber
(21341, 4042, 1, 1, 2, 4320.063), -- Enria
(21341, 959, 1, 1, 2, 10.413375), -- Scroll: Enchant Weapon (S-Grade)
(21341, 8732, 1, 1, 2, 2160.0315), -- Life Stone - Level 76
(21341, 8742, 1, 1, 2, 540.007875), -- Mid-Grade Life Stone - Level 76
(21341, 8752, 1, 1, 2, 54.050375), -- High-Grade Life Stone - Level 76
-- Ketra Orc Grand Priest
(21342, 6707, 1, 1, -1, 41193), -- Sealed Draconic Leather Armor Part
(21342, 6708, 1, 1, -1, 118371), -- Sealed Draconic Leather Gloves Fabric
(21342, 6709, 1, 1, -1, 118371), -- Sealed Draconic Leather Boots Design
(21342, 57, 4098, 8367, 0, 700000), -- Adena
(21342, 11974, 1, 1, 1, 68.220522), -- Common Item - Elysian
(21342, 5533, 1, 1, 1, 1052.593218), -- Elysian Head
(21342, 11970, 1, 1, 1, 68.220522), -- Common Item - Branch of the Mother Tree
(21342, 5544, 1, 1, 1, 1051.553394), -- Branch of the Mother Tree Head
(21342, 11969, 1, 1, 1, 68.220522), -- Common Item - Flaming Dragon Skull
(21342, 8342, 1, 1, 1, 1052.593218), -- Flaming Dragon Skull Piece
(21342, 11966, 1, 1, 1, 68.220522), -- Common Item - Doom Crusher
(21342, 8349, 1, 1, 1, 1052.378082), -- Doom Crusher Head
(21342, 1871, 1, 3, 2, 102323.189157), -- Charcoal
(21342, 1866, 2, 6, 2, 51161.779485), -- Suede
(21342, 1877, 1, 1, 2, 12278.901039), -- Adamantite Nugget
(21342, 4041, 1, 1, 2, 2669.310234), -- Mold Hardener
(21342, 4040, 1, 1, 2, 6139.265613), -- Mold Lubricant
(21342, 960, 1, 1, 2, 122.777916), -- Scroll: Enchant Armor (S-Grade)
(21342, 8732, 1, 1, 2, 2557.996521), -- Life Stone - Level 76
(21342, 8742, 1, 1, 2, 639.406677), -- Mid-Grade Life Stone - Level 76
(21342, 8752, 1, 1, 2, 63.977649), -- High-Grade Life Stone - Level 76
(21342, 1344, 20, 60, 2, 191856.395709), -- Mithril Arrow
-- Ketra Commander
(21343, 5515, 1, 1, -1, 158740), -- Sealed Majestic Gauntlets Design
(21343, 3957, 1, 1, -1, 4177), -- Recipe: Blessed Spiritshot S
(21343, 5522, 1, 1, -1, 32009), -- Sealed Armor of Nightmare Pattern
(21343, 57, 4624, 9470, 0, 700000), -- Adena
(21343, 11975, 1, 1, 1, 308.463824), -- Common Item - Soul Bow
(21343, 5534, 1, 1, 1, 4763.536176), -- Soul Bow Stave
(21343, 1894, 1, 1, 2, 15221.15324), -- Crafted Leather
(21343, 4039, 1, 1, 2, 14460.0588), -- Mold Glue
(21343, 4041, 1, 1, 2, 3772.21438), -- Mold Hardener
(21343, 4044, 1, 1, 2, 14460.0588), -- Thons
(21343, 959, 1, 1, 2, 17.3382), -- Scroll: Enchant Weapon (S-Grade)
(21343, 8732, 1, 1, 2, 3615.0147), -- Life Stone - Level 76
(21343, 8742, 1, 1, 2, 903.74054), -- Mid-Grade Life Stone - Level 76
(21343, 8752, 1, 1, 2, 90.42134), -- High-Grade Life Stone - Level 76
-- Ketra Elite Guard
(21344, 6901, 1, 1, -1, 6372), -- Recipe: Shining Arrow (100%)
(21344, 6346, 1, 1, -1, 207463), -- Sealed Majestic Ring Gemstone
(21344, 4040, 1, 1, -1, 127444), -- Mold Lubricant
(21344, 57, 3141, 6413, 0, 700000), -- Adena
(21344, 11967, 1, 1, 1, 209.139012), -- Common Item - Dragon Grinder
(21344, 5538, 1, 1, 1, 3226.860988), -- Dragon Grinder Edge
(21344, 1871, 1, 3, 2, 78427.328685), -- Charcoal
(21344, 1866, 1, 1, 2, 156855.058461), -- Suede
(21344, 1877, 1, 1, 2, 9411.199224), -- Adamantite Nugget
(21344, 4041, 1, 1, 2, 2045.965191), -- Mold Hardener
(21344, 4040, 1, 1, 2, 4705.599612), -- Mold Lubricant
(21344, 960, 1, 1, 2, 94.256385), -- Scroll: Enchant Armor (S-Grade)
(21344, 8732, 1, 1, 2, 1960.532808), -- Life Stone - Level 76
(21344, 8742, 1, 1, 2, 490.133202), -- Mid-Grade Life Stone - Level 76
(21344, 8752, 1, 1, 2, 48.933102), -- High-Grade Life Stone - Level 76
(21344, 1344, 20, 60, 2, 147051.99333), -- Mithril Arrow
-- Ketra's Head Shaman
(21345, 959, 1, 1, -1, 284), -- Scroll: Enchant Weapon (S-Grade)
(21345, 1894, 1, 1, -1, 249418), -- Crafted Leather
(21345, 4042, 1, 1, -1, 118474), -- Enria
(21345, 57, 3504, 7154, 0, 700000), -- Adena
(21345, 11967, 1, 1, 1, 233.303211), -- Common Item - Dragon Grinder
(21345, 5538, 1, 1, 1, 3599.696789), -- Dragon Grinder Edge
(21345, 1867, 1, 3, 2, 194418.10796), -- Animal Skin
(21345, 1872, 1, 3, 2, 129611.800614), -- Animal Bone
(21345, 1882, 1, 1, 2, 64805.900307), -- Leather
(21345, 1894, 1, 1, 2, 10232.553421), -- Crafted Leather
(21345, 4042, 1, 1, 2, 4860.452699), -- Enria
(21345, 959, 1, 1, 2, 11.804131), -- Scroll: Enchant Weapon (S-Grade)
(21345, 8732, 1, 1, 2, 2430.02283), -- Life Stone - Level 76
(21345, 8742, 1, 1, 2, 607.709227), -- Mid-Grade Life Stone - Level 76
(21345, 8752, 1, 1, 2, 60.648811), -- High-Grade Life Stone - Level 76
-- Ketra's Head Guard
(21346, 6695, 1, 1, -1, 14972), -- Demon Splinter Blade
(21346, 6696, 1, 1, -1, 15502), -- Heavens Divider Edge
(21346, 6697, 1, 1, -1, 14972), -- Arcana Mace Head
(21346, 57, 3481, 7103, 0, 700000), -- Adena
(21346, 11976, 1, 1, 1, 231.705474), -- Common Item - Tallum Glaive
(21346, 5541, 1, 1, 1, 3574.294526), -- Tallum Glaive Edge
(21346, 1864, 5, 15, 2, 52133.265108), -- Stem
(21346, 1865, 3, 9, 2, 43444.226664), -- Varnish
(21346, 1866, 3, 9, 2, 24825.410316), -- Suede
(21346, 1873, 1, 1, 2, 104266.047438), -- Silver Nugget
(21346, 1868, 1, 3, 2, 173776.906656), -- Thread
(21346, 960, 1, 1, 2, 104.280048), -- Scroll: Enchant Armor (S-Grade)
(21346, 8732, 1, 1, 2, 2172.018222), -- Life Stone - Level 76
(21346, 8742, 1, 1, 2, 543.12525), -- Mid-Grade Life Stone - Level 76
(21346, 8752, 1, 1, 2, 54.071136), -- High-Grade Life Stone - Level 76
(21346, 1344, 40, 120, 2, 81458.649162), -- Mithril Arrow
-- Ketra Prophet
(21347, 6710, 1, 1, -1, 175170), -- Sealed Draconic Leather Helmet Pattern
(21347, 6711, 1, 1, -1, 53504), -- Sealed Major Arcana Robe Part
(21347, 6712, 1, 1, -1, 153746), -- Sealed Major Arcana Gloves fabric
(21347, 57, 5309, 10884, 0, 700000), -- Adena
(21347, 12263, 1, 1, 1, 417.933875), -- Common Item - Sealed Armor of Nightmare
(21347, 5522, 1, 1, 1, 3394.566125), -- Sealed Armor of Nightmare Pattern
(21347, 12262, 1, 1, 1, 417.933875), -- Common Item - Sealed Majestic Plate Armor
(21347, 5523, 1, 1, 1, 3394.566125), -- Sealed Majestic Plate Armor Pattern
(21347, 1867, 4, 12, 2, 73834.843165), -- Animal Skin
(21347, 1872, 1, 3, 2, 196892.253465), -- Animal Bone
(21347, 1882, 1, 1, 2, 98446.325225), -- Leather
(21347, 1894, 1, 1, 2, 15543.947675), -- Crafted Leather
(21347, 4042, 1, 1, 2, 7383.524015), -- Enria
(21347, 960, 1, 1, 2, 177.05531), -- Scroll: Enchant Armor (S-Grade)
(21347, 8732, 1, 1, 2, 3691.563515), -- Life Stone - Level 76
(21347, 8742, 1, 1, 2, 922.990125), -- Mid-Grade Life Stone - Level 76
(21347, 8752, 1, 1, 2, 92.497505), -- High-Grade Life Stone - Level 76
-- Prophet's Guard
(21348, 6704, 1, 1, -1, 105402), -- Sealed Imperial Crusader Boots Design
(21348, 6705, 1, 1, -1, 103241), -- Sealed Imperial Crusader Shield Part
(21348, 6706, 1, 1, -1, 120089), -- Sealed Imperial Crusader Helmet Pattern
(21348, 57, 3643, 7457, 0, 700000), -- Adena
(21348, 11973, 1, 1, 1, 242.937152), -- Common Item - Soul Separator
(21348, 5537, 1, 1, 1, 3749.062848), -- Soul Separator Head
(21348, 1868, 1, 3, 2, 303709.211609), -- Thread
(21348, 1873, 1, 1, 2, 121483.586787), -- Silver Nugget
(21348, 5549, 1, 1, 2, 30370.774376), -- Metallic Thread
(21348, 1889, 1, 1, 2, 20247.509106), -- Compound Braid
(21348, 4044, 1, 1, 2, 10123.754553), -- Thons
(21348, 960, 1, 1, 2, 121.342184), -- Scroll: Enchant Armor (S-Grade)
(21348, 8732, 1, 1, 2, 2531.060959), -- Life Stone - Level 76
(21348, 8742, 1, 1, 2, 632.642919), -- Mid-Grade Life Stone - Level 76
(21348, 8752, 1, 1, 2, 63.117507), -- High-Grade Life Stone - Level 76
-- Prophet's Aide
(21349, 959, 1, 1, -1, 301), -- Scroll: Enchant Weapon (S-Grade)
(21349, 1875, 1, 1, -1, 501199), -- Stone of Purity
(21349, 4041, 1, 1, -1, 65374), -- Mold Hardener
(21349, 57, 3700, 7573, 0, 700000), -- Adena
(21349, 11967, 1, 1, 1, 246.754818), -- Common Item - Dragon Grinder
(21349, 5538, 1, 1, 1, 3807.245182), -- Dragon Grinder Edge
(21349, 1872, 1, 3, 2, 205620.13485), -- Animal Bone
(21349, 1867, 1, 3, 2, 137080.0899), -- Animal Skin
(21349, 1881, 1, 1, 2, 41124.02697), -- Coarse Bone Powder
(21349, 1875, 1, 1, 2, 20562.218664), -- Stone of Purity
(21349, 4041, 1, 1, 2, 2682.099888), -- Mold Hardener
(21349, 959, 1, 1, 2, 12.31074), -- Scroll: Enchant Weapon (S-Grade)
(21349, 8732, 1, 1, 2, 2570.072154), -- Life Stone - Level 76
(21349, 8742, 1, 1, 2, 642.620628), -- Mid-Grade Life Stone - Level 76
(21349, 8752, 1, 1, 2, 64.426206), -- High-Grade Life Stone - Level 76
-- Varka Silenos Recruit
(21350, 3957, 1, 1, -1, 2627), -- Recipe: Blessed Spiritshot S
(21350, 5522, 1, 1, -1, 20132), -- Sealed Armor of Nightmare Pattern
(21350, 5157, 1, 1, -1, 2627), -- Recipe: Soulshot (S) Compressed Package (100%)
(21350, 57, 2914, 5954, 0, 700000), -- Adena
(21350, 11955, 1, 1, 1, 300.423792), -- Common Item - Carnage Bow
(21350, 5535, 1, 1, 1, 3723.576208), -- Carnage Bow Stave
(21350, 1865, 1, 3, 2, 121264.82544), -- Varnish
(21350, 1870, 1, 1, 2, 242529.65088), -- Coal
(21350, 1879, 1, 1, 2, 40421.75112), -- Cokes
(21350, 1875, 1, 1, 2, 16168.52928), -- Stone of Purity
(21350, 4040, 1, 1, 2, 4850.4732), -- Mold Lubricant
(21350, 5157, 1, 1, 2, 107.83584), -- Recipe: Soulshot (S) Compressed Package (100%)
(21350, 8732, 1, 1, 2, 2021.06616), -- Life Stone - Level 76
(21350, 8742, 1, 1, 2, 505.37352), -- Mid-Grade Life Stone - Level 76
(21350, 8752, 1, 1, 2, 50.49456), -- High-Grade Life Stone - Level 76
-- Varka Silenos Footman
(21351, 5523, 1, 1, -1, 17614), -- Sealed Majestic Plate Armor Pattern
(21351, 4041, 1, 1, -1, 44975), -- Mold Hardener
(21351, 5220, 1, 1, -1, 206884), -- Metal Hardener
(21351, 57, 2549, 5209, 0, 700000), -- Adena
(21351, 11951, 1, 1, 1, 262.826438), -- Common Item - Bloody Orchid
(21351, 5536, 1, 1, 1, 3248.173562), -- Bloody Orchid Head
(21351, 1866, 1, 1, 2, 127313.079237), -- Suede
(21351, 1871, 1, 1, 2, 190969.851339), -- Charcoal
(21351, 5220, 1, 1, 2, 7638.942843), -- Metal Hardener
(21351, 1885, 1, 1, 2, 15913.960542), -- High-Grade Suede
(21351, 4041, 1, 1, 2, 1660.397157), -- Mold Hardener
(21351, 5162, 1, 1, 2, 85.088961), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21351, 8732, 1, 1, 2, 1591.582041), -- Life Stone - Level 76
(21351, 8742, 1, 1, 2, 398.011752), -- Mid-Grade Life Stone - Level 76
(21351, 8752, 1, 1, 2, 39.987162), -- High-Grade Life Stone - Level 76
(21351, 1344, 20, 60, 2, 119356.098966), -- Mithril Arrow
-- Grazing Antelope
(21352, 5527, 1, 1, -1, 37659), -- Sealed Helm of Nightmare Design
(21352, 5162, 1, 1, -1, 1400), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21352, 5528, 1, 1, -1, 37659), -- Sealed Majestic Circlet Design
(21352, 57, 1553, 3172, 0, 700000), -- Adena
(21352, 12222, 1, 1, 1, 281.550233), -- Common Item - Sealed Dark Crystal Leather Armor
(21352, 5478, 1, 1, 1, 1630.049344), -- Sealed Dark Crystal Leather Armor Pattern
(21352, 12230, 1, 1, 1, 173.075412), -- Common Item - Sealed Tallum Leather Armor
(21352, 5479, 1, 1, 1, 1147.014667), -- Sealed Tallum Leather Armor Pattern
(21352, 12228, 1, 1, 1, 450.806153), -- Common Item - Sealed Dark Crystal Leggings
(21352, 5482, 1, 1, 1, 2558.504191), -- Sealed Dark Crystal Leggings Design
(21352, 1869, 1, 1, 2, 129223.131516), -- Iron Ore
(21352, 1864, 1, 1, 2, 258445.85498), -- Stem
(21352, 1880, 1, 1, 2, 12922.190736), -- Steel
(21352, 5550, 1, 1, 2, 1722.795544), -- Durable Metal Plate
(21352, 4043, 1, 1, 2, 4307.396912), -- Asofe
(21352, 5167, 1, 1, 2, 57.535332), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21352, 8732, 1, 1, 2, 1076.849228), -- Life Stone - Level 76
(21352, 8742, 1, 1, 2, 269.31432), -- Mid-Grade Life Stone - Level 76
(21352, 8752, 1, 1, 2, 26.931432), -- High-Grade Life Stone - Level 76
-- Varka Silenos Scout
(21353, 4041, 1, 1, -1, 61305), -- Mold Hardener
(21353, 1875, 1, 1, -1, 470004), -- Stone of Purity
(21353, 5538, 1, 1, -1, 19338), -- Dragon Grinder Edge
(21353, 57, 3477, 7097, 0, 700000), -- Adena
(21353, 11950, 1, 1, 1, 358.275078), -- Common Item - Blood Tornado
(21353, 5539, 1, 1, 1, 4388.724922), -- Blood Tornado Edge
(21353, 1872, 1, 3, 2, 192821.957116), -- Animal Bone
(21353, 1867, 1, 3, 2, 128547.843046), -- Animal Skin
(21353, 1881, 1, 1, 2, 38564.468442), -- Coarse Bone Powder
(21353, 1875, 1, 1, 2, 19282.041674), -- Stone of Purity
(21353, 4041, 1, 1, 2, 2515.048914), -- Mold Hardener
(21353, 6901, 1, 1, 2, 289.205594), -- Recipe: Shining Arrow (100%)
(21353, 8732, 1, 1, 2, 2410.303346), -- Life Stone - Level 76
(21353, 8742, 1, 1, 2, 602.67211), -- Mid-Grade Life Stone - Level 76
(21353, 8752, 1, 1, 2, 60.459758), -- High-Grade Life Stone - Level 76
-- Varka Silenos Hunter
(21354, 5282, 1, 1, -1, 3106), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21354, 5541, 1, 1, -1, 19163), -- Tallum Glaive Edge
(21354, 6901, 1, 1, -1, 6988), -- Recipe: Shining Arrow (100%)
(21354, 57, 3446, 7034, 0, 700000), -- Adena
(21354, 11955, 1, 1, 1, 355.148106), -- Common Item - Carnage Bow
(21354, 5535, 1, 1, 1, 4401.851894), -- Carnage Bow Stave
(21354, 1868, 4, 12, 2, 58638.06879), -- Thread
(21354, 1873, 1, 1, 2, 93821.235822), -- Silver Nugget
(21354, 5549, 1, 1, 2, 23455.227516), -- Metallic Thread
(21354, 1889, 1, 1, 2, 15636.709758), -- Compound Braid
(21354, 4044, 1, 1, 2, 7818.517758), -- Thons
(21354, 1808, 1, 1, 2, 104.24256), -- Recipe: Soulshot (S-Grade)
(21354, 6671, 1, 1, 2, 26061.291516), -- Deluxe Chest Key - Grade 7
(21354, 8732, 1, 1, 2, 1954.548), -- Life Stone - Level 76
(21354, 8742, 1, 1, 2, 488.637), -- Mid-Grade Life Stone - Level 76
(21354, 8752, 1, 1, 2, 48.8637), -- High-Grade Life Stone - Level 76
(21354, 1344, 30, 90, 2, 97730.65758), -- Mithril Arrow
-- Varka Silenos Shaman
(21355, 5495, 1, 1, -1, 107862), -- Sealed Shield of Nightmare Fragment
(21355, 5272, 1, 1, -1, 3157), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21355, 5502, 1, 1, -1, 119967), -- Sealed Boots of Nightmare Lining
(21355, 57, 3502, 7147, 0, 700000), -- Adena
(21355, 11967, 1, 1, 1, 233.12061), -- Common Item - Dragon Grinder
(21355, 5538, 1, 1, 1, 3596.87939), -- Dragon Grinder Edge
(21355, 1869, 1, 3, 2, 97138.592442), -- Iron Ore
(21355, 1864, 1, 3, 2, 291415.777326), -- Stem
(21355, 1880, 1, 1, 2, 29141.490852), -- Steel
(21355, 5550, 1, 1, 2, 3885.734835), -- Durable Metal Plate
(21355, 4043, 1, 1, 2, 9713.685483), -- Asofe
(21355, 959, 1, 1, 2, 11.728881), -- Scroll: Enchant Weapon (S-Grade)
(21355, 8732, 1, 1, 2, 2428.31277), -- Life Stone - Level 76
(21355, 8742, 1, 1, 2, 607.295394), -- Mid-Grade Life Stone - Level 76
(21355, 8752, 1, 1, 2, 60.382017), -- High-Grade Life Stone - Level 76
-- Grazing Nepenthes
(21356, 5277, 1, 1, -1, 2032), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21356, 5503, 1, 1, -1, 77205), -- Sealed Majestic Boots Lining
(21356, 4042, 1, 1, -1, 76189), -- Enria
(21356, 57, 2254, 4600, 0, 700000), -- Adena
(21356, 11975, 1, 1, 1, 150.035539), -- Common Item - Soul Bow
(21356, 5534, 1, 1, 1, 2316.964461), -- Soul Bow Stave
(21356, 1867, 1, 3, 2, 112524.85546), -- Animal Skin
(21356, 1872, 1, 3, 2, 75016.42143), -- Animal Bone
(21356, 1882, 1, 1, 2, 37508.43403), -- Leather
(21356, 1894, 1, 1, 2, 5922.3138), -- Crafted Leather
(21356, 4042, 1, 1, 2, 2813.32237), -- Enria
(21356, 960, 1, 1, 2, 67.44113), -- Scroll: Enchant Armor (S-Grade)
(21356, 8732, 1, 1, 2, 1406.43787), -- Life Stone - Level 76
(21356, 8742, 1, 1, 2, 351.49781), -- Mid-Grade Life Stone - Level 76
(21356, 8752, 1, 1, 2, 35.28377), -- High-Grade Life Stone - Level 76
(21356, 1344, 10, 30, 2, 210983.99233), -- Mithril Arrow
-- Varka Silenos Priest
(21357, 4040, 1, 1, -1, 151216), -- Mold Lubricant
(21357, 5480, 1, 1, -1, 33927), -- Sealed Leather Armor of Nightmare Fabric
(21357, 1808, 1, 1, -1, 3360), -- Recipe: Soulshot (S-Grade)
(21357, 57, 3727, 7609, 0, 700000), -- Adena
(21357, 11975, 1, 1, 1, 248.13336), -- Common Item - Soul Bow
(21357, 5534, 1, 1, 1, 3831.86664), -- Soul Bow Stave
(21357, 1865, 1, 3, 2, 155093.576078), -- Varnish
(21357, 1870, 1, 3, 2, 103395.603926), -- Coal
(21357, 1879, 1, 1, 2, 51697.972152), -- Cokes
(21357, 1875, 1, 1, 2, 20678.984634), -- Stone of Purity
(21357, 4040, 1, 1, 2, 6203.729428), -- Mold Lubricant
(21357, 959, 1, 1, 2, 12.253608), -- Scroll: Enchant Weapon (S-Grade)
(21357, 8732, 1, 1, 2, 2584.830532), -- Life Stone - Level 76
(21357, 8742, 1, 1, 2, 646.377822), -- Mid-Grade Life Stone - Level 76
(21357, 8752, 1, 1, 2, 64.67182), -- High-Grade Life Stone - Level 76
-- Varka Silenos Warrior
(21358, 5481, 1, 1, -1, 34116), -- Sealed Majestic Leather Armor Fabric
(21358, 3036, 1, 1, -1, 3379), -- Recipe: Spiritshot S
(21358, 5487, 1, 1, -1, 34237), -- Sealed Robe of Nightmare Fabric
(21358, 57, 3748, 7652, 0, 700000), -- Adena
(21358, 11973, 1, 1, 1, 249.5096), -- Common Item - Soul Separator
(21358, 5537, 1, 1, 1, 3850.4904), -- Soul Separator Head
(21358, 1866, 1, 1, 2, 187150.95308), -- Suede
(21358, 1871, 1, 3, 2, 93575.47654), -- Charcoal
(21358, 5220, 1, 1, 2, 11229.19616), -- Metal Hardener
(21358, 1885, 1, 1, 2, 23393.99322), -- High-Grade Suede
(21358, 4041, 1, 1, 2, 2441.00012), -- Mold Hardener
(21358, 960, 1, 1, 2, 112.17284), -- Scroll: Enchant Armor (S-Grade)
(21358, 8732, 1, 1, 2, 2339.25042), -- Life Stone - Level 76
(21358, 8742, 1, 1, 2, 584.68852), -- Mid-Grade Life Stone - Level 76
(21358, 8752, 1, 1, 2, 58.56812), -- High-Grade Life Stone - Level 76
(21358, 1344, 20, 60, 2, 175454.70098), -- Mithril Arrow
-- Grazing Bandersnatch
(21359, 5157, 1, 1, -1, 2165), -- Recipe: Soulshot (S) Compressed Package (100%)
(21359, 5523, 1, 1, -1, 16586), -- Sealed Majestic Plate Armor Pattern
(21359, 4042, 1, 1, -1, 81173), -- Enria
(21359, 57, 2396, 4907, 0, 700000), -- Adena
(21359, 11973, 1, 1, 1, 159.868712), -- Common Item - Soul Separator
(21359, 5537, 1, 1, 1, 2467.131288), -- Soul Separator Head
(21359, 1873, 1, 1, 2, 71931.638688), -- Silver Nugget
(21359, 1868, 1, 3, 2, 179829.515736), -- Thread
(21359, 1876, 1, 1, 2, 35965.819344), -- Mithril Ore
(21359, 1895, 1, 1, 2, 51379.74192), -- Metallic Fiber
(21359, 4042, 1, 1, 2, 2997.221448), -- Enria
(21359, 960, 1, 1, 2, 72.070752), -- Scroll: Enchant Armor (S-Grade)
(21359, 8732, 1, 1, 2, 1498.401216), -- Life Stone - Level 76
(21359, 8742, 1, 1, 2, 374.600304), -- Mid-Grade Life Stone - Level 76
(21359, 8752, 1, 1, 2, 37.292424), -- High-Grade Life Stone - Level 76
(21359, 1344, 30, 90, 2, 74929.698168), -- Mithril Arrow
-- Varka Silenos Medium
(21360, 1875, 1, 1, -1, 673928), -- Stone of Purity
(21360, 5527, 1, 1, -1, 120862), -- Sealed Helm of Nightmare Design
(21360, 5162, 1, 1, -1, 4493), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21360, 57, 4974, 10185, 0, 700000), -- Adena
(21360, 11973, 1, 1, 1, 331.786912), -- Common Item - Soul Separator
(21360, 5537, 1, 1, 1, 5120.213088), -- Soul Separator Head
(21360, 1872, 4, 12, 2, 69120.904002), -- Animal Bone
(21360, 1867, 1, 3, 2, 184322.525478), -- Animal Skin
(21360, 1881, 1, 1, 2, 55296.654318), -- Coarse Bone Powder
(21360, 1875, 1, 1, 2, 27648.499368), -- Stone of Purity
(21360, 4041, 1, 1, 2, 3606.400878), -- Mold Hardener
(21360, 959, 1, 1, 2, 16.532064), -- Scroll: Enchant Weapon (S-Grade)
(21360, 8732, 1, 1, 2, 3455.890212), -- Life Stone - Level 76
(21360, 8742, 1, 1, 2, 864.144762), -- Mid-Grade Life Stone - Level 76
(21360, 8752, 1, 1, 2, 86.448918), -- High-Grade Life Stone - Level 76
-- Varka Silenos Magus
(21361, 5514, 1, 1, -1, 123311), -- Sealed Gauntlets of Nightmare Design
(21361, 5481, 1, 1, -1, 32762), -- Sealed Majestic Leather Armor Fabric
(21361, 6901, 1, 1, -1, 7301), -- Recipe: Shining Arrow (100%)
(21361, 57, 3592, 7357, 0, 700000), -- Adena
(21361, 12263, 1, 1, 1, 282.605516), -- Common Item - Sealed Armor of Nightmare
(21361, 5522, 1, 1, 1, 2295.394484), -- Sealed Armor of Nightmare Pattern
(21361, 12262, 1, 1, 1, 282.605516), -- Common Item - Sealed Majestic Plate Armor
(21361, 5523, 1, 1, 1, 2295.394484), -- Sealed Majestic Plate Armor Pattern
(21361, 1869, 2, 6, 2, 67396.180938), -- Iron Ore
(21361, 1870, 2, 6, 2, 53916.846526), -- Coal
(21361, 1871, 3, 9, 2, 44930.787292), -- Charcoal
(21361, 1872, 1, 3, 2, 179722.658046), -- Animal Bone
(21361, 1867, 1, 3, 2, 119815.105364), -- Animal Skin
(21361, 959, 1, 1, 2, 10.804684), -- Scroll: Enchant Weapon (S-Grade)
(21361, 6672, 1, 1, 2, 22465.393646), -- Deluxe Chest Key - Grade 8
(21361, 8732, 1, 1, 2, 2246.392028), -- Life Stone - Level 76
(21361, 8742, 1, 1, 2, 561.843568), -- Mid-Grade Life Stone - Level 76
(21361, 8752, 1, 1, 2, 55.987908), -- High-Grade Life Stone - Level 76
-- Varka Silenos Officer
(21362, 5282, 1, 1, -1, 3561), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21362, 5515, 1, 1, -1, 135323), -- Sealed Majestic Gauntlets Design
(21362, 6901, 1, 1, -1, 8012), -- Recipe: Shining Arrow (100%)
(21362, 57, 3942, 8074, 0, 700000), -- Adena
(21362, 12266, 1, 1, 1, 413.217792), -- Common Item - Sealed Robe of Nightmare
(21362, 5487, 1, 1, 1, 3330.782208), -- Sealed Robe of Nightmare Fabric
(21362, 12259, 1, 1, 1, 413.217792), -- Common Item - Sealed Majestic Robe
(21362, 5488, 1, 1, 1, 3330.782208), -- Sealed Majestic Robe Fabric
(21362, 1894, 1, 1, 2, 11533.957968), -- Crafted Leather
(21362, 4039, 1, 1, 2, 10957.350235), -- Mold Glue
(21362, 4041, 1, 1, 2, 2858.24318), -- Mold Hardener
(21362, 4044, 1, 1, 2, 10957.350235), -- Thons
(21362, 960, 1, 1, 2, 131.641484), -- Scroll: Enchant Armor (S-Grade)
(21362, 8732, 1, 1, 2, 2739.224852), -- Life Stone - Level 76
(21362, 8742, 1, 1, 2, 684.806213), -- Mid-Grade Life Stone - Level 76
(21362, 8752, 1, 1, 2, 68.525704), -- High-Grade Life Stone - Level 76
(21362, 1344, 10, 30, 2, 410895.900129), -- Mithril Arrow
-- Grazing Flava
(21363, 960, 1, 1, -1, 3078), -- Scroll: Enchant Armor (S-Grade)
(21363, 1894, 1, 1, -1, 270029), -- Crafted Leather
(21363, 4042, 1, 1, -1, 128264), -- Enria
(21363, 57, 3795, 7746, 0, 700000), -- Adena
(21363, 12267, 1, 1, 1, 966.49809), -- Common Item - Sealed Boots of Nightmare
(21363, 5502, 1, 1, 1, 5998.75191), -- Sealed Boots of Nightmare Lining
(21363, 12260, 1, 1, 1, 966.49809), -- Common Item - Sealed Majestic Boots
(21363, 5503, 1, 1, 1, 5998.75191), -- Sealed Majestic Boots Lining
(21363, 12264, 1, 1, 1, 966.49809), -- Common Item - Sealed Gauntlet of Nightmare
(21363, 5514, 1, 1, 1, 5998.75191), -- Sealed Gauntlets of Nightmare Design
(21363, 12257, 1, 1, 1, 966.49809), -- Common Item - Sealed Majestic Gauntlet
(21363, 5515, 1, 1, 1, 5998.75191), -- Sealed Majestic Gauntlets Design
(21363, 1867, 1, 3, 2, 210484.007), -- Animal Skin
(21363, 1872, 1, 3, 2, 140322.37755), -- Animal Bone
(21363, 1882, 1, 1, 2, 70161.188775), -- Leather
(21363, 1894, 1, 1, 2, 11078.128825), -- Crafted Leather
(21363, 4042, 1, 1, 2, 5262.100175), -- Enria
(21363, 959, 1, 1, 2, 12.779575), -- Scroll: Enchant Weapon (S-Grade)
(21363, 8732, 1, 1, 2, 2630.82975), -- Life Stone - Level 76
(21363, 8742, 1, 1, 2, 657.927775), -- Mid-Grade Life Stone - Level 76
(21363, 8752, 1, 1, 2, 65.660575), -- High-Grade Life Stone - Level 76
-- Varka Silenos Priest
(21364, 6691, 1, 1, -1, 12779), -- Angel Slayer Blade
(21364, 6693, 1, 1, -1, 13011), -- Dragon Hunter Axe Blade
(21364, 6694, 1, 1, -1, 13011), -- Saint Spear Blade
(21364, 57, 2916, 5951, 0, 700000), -- Adena
(21364, 12268, 1, 1, 1, 943.780893), -- Common Item - Sealed Shield of Nightmare
(21364, 5495, 1, 1, 1, 5524.705406), -- Sealed Shield of Nightmare Fragment
(21364, 12269, 1, 1, 1, 660.302005), -- Common Item - Sealed Helm of Nightmare
(21364, 5527, 1, 1, 1, 4349.946601), -- Sealed Helm of Nightmare Design
(21364, 12261, 1, 1, 1, 660.302005), -- Common Item - Sealed Majestic Circlet
(21364, 5528, 1, 1, 1, 4349.96309), -- Sealed Majestic Circlet Design
(21364, 1868, 1, 3, 2, 218296.174564), -- Thread
(21364, 1873, 1, 1, 2, 87318.558353), -- Silver Nugget
(21364, 5549, 1, 1, 2, 21829.528929), -- Metallic Thread
(21364, 1889, 1, 1, 2, 14553.019286), -- Compound Braid
(21364, 4044, 1, 1, 2, 7276.509643), -- Thons
(21364, 960, 1, 1, 2, 87.199489), -- Scroll: Enchant Armor (S-Grade)
(21364, 8732, 1, 1, 2, 1819.23807), -- Life Stone - Level 76
(21364, 8742, 1, 1, 2, 454.588199), -- Mid-Grade Life Stone - Level 76
(21364, 8752, 1, 1, 2, 45.591611), -- High-Grade Life Stone - Level 76
(21364, 1344, 30, 90, 2, 90956.591856), -- Mithril Arrow
-- Varka Silenos Great Magus
(21365, 959, 1, 1, -1, 330), -- Scroll: Enchant Weapon (S-Grade)
(21365, 6688, 1, 1, -1, 17847), -- Forgotten Blade Edge
(21365, 6689, 1, 1, -1, 17511), -- Basalt Battlehammer Head
(21365, 57, 4071, 8308, 0, 700000), -- Adena
(21365, 12265, 1, 1, 1, 425.813736), -- Common Item - Sealed Leather Armor of Nightmare
(21365, 5480, 1, 1, 1, 3420.186264), -- Sealed Leather Armor of Nightmare Fabric
(21365, 12258, 1, 1, 1, 425.813736), -- Common Item - Sealed Majestic Leather Armor
(21365, 5481, 1, 1, 1, 3420.186264), -- Sealed Majestic Leather Armor Fabric
(21365, 1869, 2, 6, 2, 84685.16993), -- Iron Ore
(21365, 1870, 2, 6, 2, 67748.29407), -- Coal
(21365, 1871, 3, 9, 2, 56456.911725), -- Charcoal
(21365, 1872, 7, 21, 2, 32260.86652), -- Animal Bone
(21365, 1867, 1, 3, 2, 150551.369285), -- Animal Skin
(21365, 959, 1, 1, 2, 13.44071), -- Scroll: Enchant Weapon (S-Grade)
(21365, 8732, 1, 1, 2, 2822.944415), -- Life Stone - Level 76
(21365, 8742, 1, 1, 2, 705.637275), -- Mid-Grade Life Stone - Level 76
(21365, 8752, 1, 1, 2, 70.36607), -- High-Grade Life Stone - Level 76
-- Varka Silenos General
(21366, 6698, 1, 1, -1, 175150), -- Sealed Tateossian Earring Part
(21366, 6699, 1, 1, -1, 194352), -- Sealed Tateossian Ring Gem
(21366, 6700, 1, 1, -1, 106751), -- Sealed Tateossian Necklace Chain
(21366, 57, 4396, 8972, 0, 700000), -- Adena
(21366, 12263, 1, 1, 1, 345.090056), -- Common Item - Sealed Armor of Nightmare
(21366, 5522, 1, 1, 1, 2802.909944), -- Sealed Armor of Nightmare Pattern
(21366, 12262, 1, 1, 1, 345.090056), -- Common Item - Sealed Majestic Plate Armor
(21366, 5523, 1, 1, 1, 2802.909944), -- Sealed Majestic Plate Armor Pattern
(21366, 1894, 1, 1, 2, 12835.84337), -- Crafted Leather
(21366, 4039, 1, 1, 2, 12193.846396), -- Mold Glue
(21366, 4041, 1, 1, 2, 3181.039026), -- Mold Hardener
(21366, 4044, 1, 1, 2, 12193.846396), -- Thons
(21366, 960, 1, 1, 2, 146.367664), -- Scroll: Enchant Armor (S-Grade)
(21366, 8732, 1, 1, 2, 3048.598136), -- Life Stone - Level 76
(21366, 8742, 1, 1, 2, 762.149534), -- Mid-Grade Life Stone - Level 76
(21366, 8752, 1, 1, 2, 76.187646), -- High-Grade Life Stone - Level 76
(21366, 1344, 20, 60, 2, 228636.121832), -- Mithril Arrow
-- Grazing Elder Antelope
(21367, 6710, 1, 1, -1, 87307), -- Sealed Draconic Leather Helmet Pattern
(21367, 6711, 1, 1, -1, 26667), -- Sealed Major Arcana Robe Part
(21367, 6712, 1, 1, -1, 76629), -- Sealed Major Arcana Gloves fabric
(21367, 57, 2653, 5416, 0, 700000), -- Adena
(21367, 11975, 1, 1, 1, 176.612568), -- Common Item - Soul Bow
(21367, 5534, 1, 1, 1, 2727.387432), -- Soul Bow Stave
(21367, 1895, 1, 1, 2, 63086.223094), -- Metallic Fiber
(21367, 4040, 1, 1, 2, 4416.174838), -- Mold Lubricant
(21367, 4042, 1, 1, 2, 3680.086202), -- Enria
(21367, 4043, 1, 1, 2, 7360.172404), -- Asofe
(21367, 960, 1, 1, 2, 88.173566), -- Scroll: Enchant Armor (S-Grade)
(21367, 8732, 1, 1, 2, 1839.864612), -- Life Stone - Level 76
(21367, 8742, 1, 1, 2, 460.144642), -- Mid-Grade Life Stone - Level 76
(21367, 8752, 1, 1, 2, 46.050162), -- High-Grade Life Stone - Level 76
(21367, 1344, 10, 30, 2, 276001.11048), -- Mithril Arrow
-- Varka Silenos Grand Priest
(21368, 960, 1, 1, -1, 4349), -- Scroll: Enchant Armor (S-Grade)
(21368, 1895, 1, 7, -1, 776557), -- Metallic Fiber
(21368, 4042, 1, 1, -1, 181197), -- Enria
(21368, 57, 5359, 10941, 0, 700000), -- Adena
(21368, 11973, 1, 1, 1, 356.798728), -- Common Item - Soul Separator
(21368, 5537, 1, 1, 1, 5506.201272), -- Soul Separator Head
(21368, 1873, 2, 6, 2, 40142.0719), -- Silver Nugget
(21368, 1868, 3, 9, 2, 133807.59525), -- Thread
(21368, 1876, 1, 1, 2, 80284.55715), -- Mithril Ore
(21368, 1895, 1, 1, 2, 114692.2245), -- Metallic Fiber
(21368, 4042, 1, 1, 2, 6690.4831), -- Enria
(21368, 959, 1, 1, 2, 16.12065), -- Scroll: Enchant Weapon (S-Grade)
(21368, 6672, 1, 1, 2, 33452.00215), -- Deluxe Chest Key - Grade 8
(21368, 8732, 1, 1, 2, 3345.24155), -- Life Stone - Level 76
(21368, 8742, 1, 1, 2, 836.20705), -- Mid-Grade Life Stone - Level 76
(21368, 8752, 1, 1, 2, 83.4967), -- High-Grade Life Stone - Level 76
-- Varka's Commander
(21369, 5528, 1, 1, -1, 114809), -- Sealed Majestic Circlet Design
(21369, 5167, 1, 1, -1, 4268), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21369, 5529, 1, 1, -1, 26345), -- Dragon Slayer Edge
(21369, 57, 4725, 9675, 0, 700000), -- Adena
(21369, 11976, 1, 1, 1, 315.170583), -- Common Item - Tallum Glaive
(21369, 5541, 1, 1, 1, 4861.829417), -- Tallum Glaive Edge
(21369, 1868, 4, 12, 2, 88639.962635), -- Thread
(21369, 1873, 1, 1, 2, 141824.393235), -- Silver Nugget
(21369, 5549, 1, 1, 2, 35455.985054), -- Metallic Thread
(21369, 1889, 1, 1, 2, 23637.172363), -- Compound Braid
(21369, 4044, 1, 1, 2, 11818.812691), -- Thons
(21369, 960, 1, 1, 2, 141.794947), -- Scroll: Enchant Armor (S-Grade)
(21369, 8732, 1, 1, 2, 2954.589918), -- Life Stone - Level 76
(21369, 8742, 1, 1, 2, 738.873989), -- Mid-Grade Life Stone - Level 76
(21369, 8752, 1, 1, 2, 73.842097), -- High-Grade Life Stone - Level 76
(21369, 1344, 30, 90, 2, 147733.573071), -- Mithril Arrow
-- Varka's Elite Guard
(21370, 5550, 1, 1, -1, 103728), -- Durable Metal Plate
(21370, 4043, 1, 1, -1, 259321), -- Asofe
(21370, 5488, 1, 1, -1, 35032), -- Sealed Majestic Robe Fabric
(21370, 57, 3835, 7830, 0, 700000), -- Adena
(21370, 12266, 1, 1, 1, 401.18768), -- Common Item - Sealed Robe of Nightmare
(21370, 5487, 1, 1, 1, 3233.81232), -- Sealed Robe of Nightmare Fabric
(21370, 12259, 1, 1, 1, 401.18768), -- Common Item - Sealed Majestic Robe
(21370, 5488, 1, 1, 1, 3233.81232), -- Sealed Majestic Robe Fabric
(21370, 1869, 1, 3, 2, 106388.161938), -- Iron Ore
(21370, 1864, 1, 3, 2, 319164.485814), -- Stem
(21370, 1880, 1, 1, 2, 31916.353428), -- Steel
(21370, 5550, 1, 1, 2, 4255.735815), -- Durable Metal Plate
(21370, 4043, 1, 1, 2, 10638.625887), -- Asofe
(21370, 959, 1, 1, 2, 12.845709), -- Scroll: Enchant Weapon (S-Grade)
(21370, 8732, 1, 1, 2, 2659.53753), -- Life Stone - Level 76
(21370, 8742, 1, 1, 2, 665.122266), -- Mid-Grade Life Stone - Level 76
(21370, 8752, 1, 1, 2, 66.131613), -- High-Grade Life Stone - Level 76
-- Varka's Head Magus
(21371, 6713, 1, 1, -1, 119352), -- Sealed Major Arcana Boots Design
(21371, 6714, 1, 1, -1, 135984), -- Sealed Major Arcana Circlet Pattern
(21371, 7579, 1, 1, -1, 18329), -- Draconic Bow Shaft
(21371, 57, 4132, 8436, 0, 700000), -- Adena
(21371, 11973, 1, 1, 1, 275.129976), -- Common Item - Soul Separator
(21371, 5537, 1, 1, 1, 4245.870024), -- Soul Separator Head
(21371, 1894, 1, 1, 2, 12066.898272), -- Crafted Leather
(21371, 4039, 1, 1, 2, 11463.64769), -- Mold Glue
(21371, 4041, 1, 1, 2, 2990.31172), -- Mold Hardener
(21371, 4044, 1, 1, 2, 11463.64769), -- Thons
(21371, 960, 1, 1, 2, 137.724136), -- Scroll: Enchant Armor (S-Grade)
(21371, 8732, 1, 1, 2, 2865.794008), -- Life Stone - Level 76
(21371, 8742, 1, 1, 2, 716.448502), -- Mid-Grade Life Stone - Level 76
(21371, 8752, 1, 1, 2, 71.692016), -- High-Grade Life Stone - Level 76
(21371, 1344, 10, 30, 2, 429881.835966), -- Mithril Arrow
-- Varka's Head Guard
(21372, 960, 1, 1, -1, 2242), -- Scroll: Enchant Armor (S-Grade)
(21372, 1876, 1, 3, -1, 560482), -- Mithril Ore
(21372, 1895, 1, 3, -1, 800688), -- Metallic Fiber
(21372, 57, 2763, 5640, 0, 700000), -- Adena
(21372, 12266, 1, 1, 1, 289.053792), -- Common Item - Sealed Robe of Nightmare
(21372, 5487, 1, 1, 1, 2329.946208), -- Sealed Robe of Nightmare Fabric
(21372, 12259, 1, 1, 1, 289.053792), -- Common Item - Sealed Majestic Robe
(21372, 5488, 1, 1, 1, 2329.946208), -- Sealed Majestic Robe Fabric
(21372, 1873, 1, 1, 2, 91976.412717), -- Silver Nugget
(21372, 1868, 1, 3, 2, 229940.811849), -- Thread
(21372, 1876, 1, 1, 2, 45987.986415), -- Mithril Ore
(21372, 1895, 1, 1, 2, 65697.12345), -- Metallic Fiber
(21372, 4042, 1, 1, 2, 3832.295544), -- Enria
(21372, 959, 1, 1, 2, 9.237627), -- Scroll: Enchant Weapon (S-Grade)
(21372, 8732, 1, 1, 2, 1916.147772), -- Life Stone - Level 76
(21372, 8742, 1, 1, 2, 479.036943), -- Mid-Grade Life Stone - Level 76
(21372, 8752, 1, 1, 2, 47.947683), -- High-Grade Life Stone - Level 76
-- Varka's Prophet
(21373, 959, 1, 1, -1, 453), -- Scroll: Enchant Weapon (S-Grade)
(21373, 1895, 1, 7, -1, 808936), -- Metallic Fiber
(21373, 4040, 1, 1, -1, 226502), -- Mold Lubricant
(21373, 57, 5568, 11414, 0, 700000), -- Adena
(21373, 12266, 1, 1, 1, 584.012272), -- Common Item - Sealed Robe of Nightmare
(21373, 5487, 1, 1, 1, 4707.487728), -- Sealed Robe of Nightmare Fabric
(21373, 12259, 1, 1, 1, 584.012272), -- Common Item - Sealed Majestic Robe
(21373, 5488, 1, 1, 1, 4707.487728), -- Sealed Majestic Robe Fabric
(21373, 1895, 1, 1, 2, 149341.72716), -- Metallic Fiber
(21373, 4040, 1, 1, 2, 10453.87494), -- Mold Lubricant
(21373, 4042, 1, 1, 2, 8711.56245), -- Enria
(21373, 4043, 1, 1, 2, 17423.1249), -- Asofe
(21373, 959, 1, 1, 2, 20.874045), -- Scroll: Enchant Weapon (S-Grade)
(21373, 8732, 1, 1, 2, 4355.781225), -- Life Stone - Level 76
(21373, 8742, 1, 1, 2, 1088.89743), -- Mid-Grade Life Stone - Level 76
(21373, 8752, 1, 1, 2, 109.15785), -- High-Grade Life Stone - Level 76
-- Prophet's Guard
(21374, 6707, 1, 1, -1, 29364), -- Sealed Draconic Leather Armor Part
(21374, 6708, 1, 1, -1, 84378), -- Sealed Draconic Leather Gloves Fabric
(21374, 6709, 1, 1, -1, 84378), -- Sealed Draconic Leather Boots Design
(21374, 57, 2916, 5970, 0, 700000), -- Adena
(21374, 11976, 1, 1, 1, 194.508405), -- Common Item - Tallum Glaive
(21374, 5541, 1, 1, 1, 3000.491595), -- Tallum Glaive Edge
(21374, 1873, 1, 1, 2, 97251.988557), -- Silver Nugget
(21374, 1868, 1, 3, 2, 243130.203996), -- Thread
(21374, 1876, 1, 1, 2, 48626.226882), -- Mithril Ore
(21374, 1895, 1, 1, 2, 69465.639654), -- Metallic Fiber
(21374, 4042, 1, 1, 2, 4051.95297), -- Enria
(21374, 960, 1, 1, 2, 97.228263), -- Scroll: Enchant Armor (S-Grade)
(21374, 8732, 1, 1, 2, 2025.976485), -- Life Stone - Level 76
(21374, 8742, 1, 1, 2, 506.610423), -- Mid-Grade Life Stone - Level 76
(21374, 8752, 1, 1, 2, 51.17277), -- High-Grade Life Stone - Level 76
-- Disciple of Prophet
(21375, 960, 1, 1, -1, 2285), -- Scroll: Enchant Armor (S-Grade)
(21375, 4040, 1, 1, -1, 114238), -- Mold Lubricant
(21375, 1877, 1, 1, -1, 228476), -- Adamantite Nugget
(21375, 57, 2811, 5754, 0, 700000), -- Adena
(21375, 12265, 1, 1, 1, 294.559918), -- Common Item - Sealed Leather Armor of Nightmare
(21375, 5480, 1, 1, 1, 2365.940082), -- Sealed Leather Armor of Nightmare Fabric
(21375, 12258, 1, 1, 1, 294.559918), -- Common Item - Sealed Majestic Leather Armor
(21375, 5481, 1, 1, 1, 2365.940082), -- Sealed Majestic Leather Armor Fabric
(21375, 1871, 1, 1, 2, 234334.361266), -- Charcoal
(21375, 1866, 1, 1, 2, 156222.771126), -- Suede
(21375, 1877, 1, 1, 2, 9373.308986), -- Adamantite Nugget
(21375, 4041, 1, 1, 2, 2037.58692), -- Mold Hardener
(21375, 4040, 1, 1, 2, 4686.85907), -- Mold Lubricant
(21375, 959, 1, 1, 2, 9.410542), -- Scroll: Enchant Weapon (S-Grade)
(21375, 8732, 1, 1, 2, 1952.892042), -- Life Stone - Level 76
(21375, 8742, 1, 1, 2, 488.120722), -- Mid-Grade Life Stone - Level 76
(21375, 8752, 1, 1, 2, 48.689326), -- High-Grade Life Stone - Level 76
-- Scarlet Stakato Worker
(21376, 5544, 1, 1, -1, 27515), -- Branch of the Mother Tree Head
(21376, 4041, 1, 1, -1, 87314), -- Mold Hardener
(21376, 1875, 1, 1, -1, 669404), -- Stone of Purity
(21376, 57, 4952, 10108, 0, 700000), -- Adena
(21376, 11951, 1, 1, 1, 510.306986), -- Common Item - Bloody Orchid
(21376, 5536, 1, 1, 1, 6306.693014), -- Bloody Orchid Head
(21376, 1872, 4, 12, 2, 68656.883343), -- Animal Bone
(21376, 1867, 1, 3, 2, 183085.592703), -- Animal Skin
(21376, 1881, 1, 1, 2, 54925.575129), -- Coarse Bone Powder
(21376, 1875, 1, 1, 2, 27462.958701), -- Stone of Purity
(21376, 4041, 1, 1, 2, 3582.229218), -- Mold Hardener
(21376, 3036, 1, 1, 2, 183.116055), -- Recipe: Spiritshot S
(21376, 8732, 1, 1, 2, 3432.99819), -- Life Stone - Level 76
(21376, 8742, 1, 1, 2, 858.078411), -- Mid-Grade Life Stone - Level 76
(21376, 8752, 1, 1, 2, 85.56825), -- High-Grade Life Stone - Level 76
-- Scarlet Stakato Soldier
(21377, 5545, 1, 1, -1, 26960), -- Dark Legion's Edge Blade
(21377, 1808, 1, 1, -1, 4368), -- Recipe: Soulshot (S-Grade)
(21377, 5546, 1, 1, -1, 29613), -- Sword of Miracles Edge
(21377, 57, 4847, 9892, 0, 700000), -- Adena
(21377, 12227, 1, 1, 1, 659.092728), -- Common Item - Sealed Dark Crystal Breastplate
(21377, 5520, 1, 1, 1, 3899.53256), -- Sealed Dark Crystal Breastplate Pattern
(21377, 12233, 1, 1, 1, 405.844768), -- Common Item - Sealed Tallum Plate Armor
(21377, 5521, 1, 1, 1, 2751.661696), -- Sealed Tallum Plate Armor Pattern
(21377, 12220, 1, 1, 1, 1051.682296), -- Common Item - Sealed Dark Crystal Gaiters
(21377, 5524, 1, 1, 1, 5960.185952), -- Sealed Dark Crystal Gaiters Pattern
(21377, 1873, 1, 1, 2, 145136.73845), -- Silver Nugget
(21377, 1868, 4, 12, 2, 90710.631176), -- Thread
(21377, 1876, 1, 1, 2, 72568.595418), -- Mithril Ore
(21377, 1895, 1, 1, 2, 103669.228146), -- Metallic Fiber
(21377, 4042, 1, 1, 2, 6047.496048), -- Enria
(21377, 3957, 1, 1, 2, 161.049416), -- Recipe: Blessed Spiritshot S
(21377, 8732, 1, 1, 2, 3023.748024), -- Life Stone - Level 76
(21377, 8742, 1, 1, 2, 755.937006), -- Mid-Grade Life Stone - Level 76
(21377, 8752, 1, 1, 2, 75.548462), -- High-Grade Life Stone - Level 76
(21377, 1344, 150, 450, 2, 30237.027854), -- Mithril Arrow
-- Scarlet Stakato Noble
(21378, 1889, 1, 1, -1, 804585), -- Compound Braid
(21378, 5514, 1, 1, -1, 203830), -- Sealed Gauntlets of Nightmare Design
(21378, 5282, 1, 1, -1, 5364), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21378, 57, 5950, 12144, 0, 700000), -- Adena
(21378, 11973, 1, 1, 1, 396.111704), -- Common Item - Soul Separator
(21378, 5537, 1, 1, 1, 6112.888296), -- Soul Separator Head
(21378, 1868, 3, 9, 2, 165043.032308), -- Thread
(21378, 1873, 1, 1, 2, 198051.82573), -- Silver Nugget
(21378, 5549, 1, 1, 2, 49512.722732), -- Metallic Thread
(21378, 1889, 1, 1, 2, 33008.793422), -- Compound Braid
(21378, 4044, 1, 1, 2, 16504.396711), -- Thons
(21378, 959, 1, 1, 2, 19.630842), -- Scroll: Enchant Weapon (S-Grade)
(21378, 8732, 1, 1, 2, 4126.216028), -- Life Stone - Level 76
(21378, 8742, 1, 1, 2, 1031.554007), -- Mid-Grade Life Stone - Level 76
(21378, 8752, 1, 1, 2, 102.82822), -- High-Grade Life Stone - Level 76
-- Tepra Scorpion
(21379, 5515, 1, 1, -1, 171095), -- Sealed Majestic Gauntlets Design
(21379, 6901, 1, 1, -1, 10131), -- Recipe: Shining Arrow (100%)
(21379, 5522, 1, 1, -1, 34500), -- Sealed Armor of Nightmare Pattern
(21379, 57, 4995, 10193, 0, 700000), -- Adena
(21379, 12263, 1, 1, 1, 392.063083), -- Common Item - Sealed Armor of Nightmare
(21379, 5522, 1, 1, 1, 3184.436917), -- Sealed Armor of Nightmare Pattern
(21379, 12262, 1, 1, 1, 392.063083), -- Common Item - Sealed Majestic Plate Armor
(21379, 5523, 1, 1, 1, 3184.436917), -- Sealed Majestic Plate Armor Pattern
(21379, 1864, 5, 15, 2, 74810.101354), -- Stem
(21379, 1865, 3, 9, 2, 62341.909322), -- Varnish
(21379, 1866, 3, 9, 2, 35623.948184), -- Suede
(21379, 1873, 1, 1, 2, 149620.202708), -- Silver Nugget
(21379, 1868, 12, 36, 2, 31170.954661), -- Thread
(21379, 960, 1, 1, 2, 149.493015), -- Scroll: Enchant Armor (S-Grade)
(21379, 8732, 1, 1, 2, 3117.048008), -- Life Stone - Level 76
(21379, 8742, 1, 1, 2, 779.262002), -- Mid-Grade Life Stone - Level 76
(21379, 8752, 1, 1, 2, 77.831284), -- High-Grade Life Stone - Level 76
(21379, 1344, 40, 120, 2, 116890.249462), -- Mithril Arrow
-- Tepra Scarab
(21380, 5523, 1, 1, -1, 35175), -- Sealed Majestic Plate Armor Pattern
(21380, 5481, 1, 1, -1, 46347), -- Sealed Majestic Leather Armor Fabric
(21380, 1808, 1, 1, -1, 4591), -- Recipe: Soulshot (S-Grade)
(21380, 57, 5093, 10393, 0, 700000), -- Adena
(21380, 11974, 1, 1, 1, 84.750528), -- Common Item - Elysian
(21380, 5533, 1, 1, 1, 1307.639232), -- Elysian Head
(21380, 11970, 1, 1, 1, 84.750528), -- Common Item - Branch of the Mother Tree
(21380, 5544, 1, 1, 1, 1306.347456), -- Branch of the Mother Tree Head
(21380, 11969, 1, 1, 1, 84.750528), -- Common Item - Flaming Dragon Skull
(21380, 8342, 1, 1, 1, 1307.639232), -- Flaming Dragon Skull Piece
(21380, 11966, 1, 1, 1, 84.750528), -- Common Item - Doom Crusher
(21380, 8349, 1, 1, 1, 1307.371968), -- Doom Crusher Head
(21380, 1869, 2, 6, 2, 105935.778108), -- Iron Ore
(21380, 1870, 2, 6, 2, 84748.820292), -- Coal
(21380, 1871, 3, 9, 2, 70624.01691), -- Charcoal
(21380, 1872, 7, 21, 2, 40356.298512), -- Animal Bone
(21380, 1867, 1, 3, 2, 188330.217246), -- Animal Skin
(21380, 959, 1, 1, 2, 16.813476), -- Scroll: Enchant Weapon (S-Grade)
(21380, 8732, 1, 1, 2, 3531.324474), -- Life Stone - Level 76
(21380, 8742, 1, 1, 2, 882.70749), -- Mid-Grade Life Stone - Level 76
(21380, 8752, 1, 1, 2, 88.023492), -- High-Grade Life Stone - Level 76
-- Assassin Beetle
(21381, 3957, 1, 1, -1, 5018), -- Recipe: Blessed Spiritshot S
(21381, 5495, 1, 1, -1, 171455), -- Sealed Shield of Nightmare Fragment
(21381, 5157, 1, 1, -1, 5018), -- Recipe: Soulshot (S) Compressed Package (100%)
(21381, 57, 5566, 11364, 0, 700000), -- Adena
(21381, 11976, 1, 1, 1, 370.570473), -- Common Item - Tallum Glaive
(21381, 5541, 1, 1, 1, 5716.429527), -- Tallum Glaive Edge
(21381, 1867, 5, 15, 2, 55587.364488), -- Animal Skin
(21381, 1872, 1, 3, 2, 185291.704941), -- Animal Bone
(21381, 1882, 1, 1, 2, 92645.60748), -- Leather
(21381, 1894, 1, 1, 2, 14628.382755), -- Crafted Leather
(21381, 4042, 1, 1, 2, 6948.420561), -- Enria
(21381, 960, 1, 1, 2, 166.59354), -- Scroll: Enchant Armor (S-Grade)
(21381, 8732, 1, 1, 2, 3474.455271), -- Life Stone - Level 76
(21381, 8742, 1, 1, 2, 868.736313), -- Mid-Grade Life Stone - Level 76
(21381, 8752, 1, 1, 2, 86.726637), -- High-Grade Life Stone - Level 76
(21381, 1344, 40, 120, 2, 130283.008014), -- Mithril Arrow
-- Mercenary of Destruction
(21382, 5502, 1, 1, -1, 203124), -- Sealed Boots of Nightmare Lining
(21382, 5549, 1, 3, -1, 601349), -- Metallic Thread
(21382, 1889, 1, 1, -1, 801799), -- Compound Braid
(21382, 57, 5929, 12104, 0, 700000), -- Adena
(21382, 12265, 1, 1, 1, 620.231032), -- Common Item - Sealed Leather Armor of Nightmare
(21382, 5480, 1, 1, 1, 4981.768968), -- Sealed Leather Armor of Nightmare Fabric
(21382, 12258, 1, 1, 1, 620.231032), -- Common Item - Sealed Majestic Leather Armor
(21382, 5481, 1, 1, 1, 4981.768968), -- Sealed Majestic Leather Armor Fabric
(21382, 1868, 3, 9, 2, 164471.703564), -- Thread
(21382, 1873, 1, 1, 2, 197366.23059), -- Silver Nugget
(21382, 5549, 1, 1, 2, 49341.324756), -- Metallic Thread
(21382, 1889, 1, 1, 2, 32894.527026), -- Compound Braid
(21382, 4044, 1, 1, 2, 16447.263513), -- Thons
(21382, 959, 1, 1, 2, 19.562886), -- Scroll: Enchant Weapon (S-Grade)
(21382, 8732, 1, 1, 2, 4111.932324), -- Life Stone - Level 76
(21382, 8742, 1, 1, 2, 1027.983081), -- Mid-Grade Life Stone - Level 76
(21382, 8752, 1, 1, 2, 102.47226), -- High-Grade Life Stone - Level 76
-- Knight of Destruction
(21383, 5503, 1, 1, -1, 217116), -- Sealed Majestic Boots Lining
(21383, 5162, 1, 1, -1, 5714), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21383, 5514, 1, 1, -1, 217116), -- Sealed Gauntlets of Nightmare Design
(21383, 57, 6337, 12938, 0, 700000), -- Adena
(21383, 12263, 1, 1, 1, 497.574258), -- Common Item - Sealed Armor of Nightmare
(21383, 5522, 1, 1, 1, 4041.425742), -- Sealed Armor of Nightmare Pattern
(21383, 12262, 1, 1, 1, 497.574258), -- Common Item - Sealed Majestic Plate Armor
(21383, 5523, 1, 1, 1, 4041.425742), -- Sealed Majestic Plate Armor Pattern
(21383, 1864, 5, 15, 2, 94932.30272), -- Stem
(21383, 1865, 3, 9, 2, 79110.396755), -- Varnish
(21383, 1866, 3, 9, 2, 45206.06485), -- Suede
(21383, 1873, 4, 12, 2, 21096.308085), -- Silver Nugget
(21383, 1868, 12, 36, 2, 39554.981645), -- Thread
(21383, 960, 1, 1, 2, 189.85767), -- Scroll: Enchant Armor (S-Grade)
(21383, 8732, 1, 1, 2, 3955.368125), -- Life Stone - Level 76
(21383, 8742, 1, 1, 2, 988.733665), -- Mid-Grade Life Stone - Level 76
(21383, 8752, 1, 1, 2, 98.83002), -- High-Grade Life Stone - Level 76
(21383, 1344, 40, 120, 2, 148332.156465), -- Mithril Arrow
-- Necromancer of Destruction
(21384, 4041, 1, 1, -1, 104091), -- Mold Hardener
(21384, 1875, 1, 1, -1, 798032), -- Stone of Purity
(21384, 5533, 1, 1, -1, 32835), -- Elysian Head
(21384, 57, 5890, 12060, 0, 700000), -- Adena
(21384, 12265, 1, 1, 1, 617.297058), -- Common Item - Sealed Leather Armor of Nightmare
(21384, 5480, 1, 1, 1, 4958.202942), -- Sealed Leather Armor of Nightmare Fabric
(21384, 12258, 1, 1, 1, 617.297058), -- Common Item - Sealed Majestic Leather Armor
(21384, 5481, 1, 1, 1, 4958.202942), -- Sealed Majestic Leather Armor Fabric
(21384, 1872, 4, 12, 2, 81849.403138), -- Animal Bone
(21384, 1867, 1, 3, 2, 218265.210982), -- Animal Skin
(21384, 1881, 1, 1, 2, 65479.440942), -- Coarse Bone Powder
(21384, 1875, 1, 1, 2, 32739.924392), -- Stone of Purity
(21384, 4041, 1, 1, 2, 4270.513582), -- Mold Hardener
(21384, 959, 1, 1, 2, 19.576416), -- Scroll: Enchant Weapon (S-Grade)
(21384, 8732, 1, 1, 2, 4092.286628), -- Life Stone - Level 76
(21384, 8742, 1, 1, 2, 1023.275578), -- Mid-Grade Life Stone - Level 76
(21384, 8752, 1, 1, 2, 102.368342), -- High-Grade Life Stone - Level 76
-- Lavastone Golem
(21385, 5272, 1, 1, -1, 5032), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21385, 5534, 1, 1, -1, 31083), -- Soul Bow Stave
(21385, 5277, 1, 1, -1, 5032), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21385, 57, 5571, 11407, 0, 700000), -- Adena
(21385, 12263, 1, 1, 1, 438.213945), -- Common Item - Sealed Armor of Nightmare
(21385, 5522, 1, 1, 1, 3559.286055), -- Sealed Armor of Nightmare Pattern
(21385, 12262, 1, 1, 1, 438.213945), -- Common Item - Sealed Majestic Plate Armor
(21385, 5523, 1, 1, 1, 3559.286055), -- Sealed Majestic Plate Armor Pattern
(21385, 1873, 3, 9, 2, 27869.648028), -- Silver Nugget
(21385, 1868, 4, 12, 2, 104511.084644), -- Thread
(21385, 1876, 1, 1, 2, 83608.944084), -- Mithril Ore
(21385, 1895, 1, 1, 2, 119441.185044), -- Metallic Fiber
(21385, 4042, 1, 1, 2, 6967.507468), -- Enria
(21385, 960, 1, 1, 2, 167.247672), -- Scroll: Enchant Armor (S-Grade)
(21385, 8732, 1, 1, 2, 3483.562812), -- Life Stone - Level 76
(21385, 8742, 1, 1, 2, 870.986164), -- Mid-Grade Life Stone - Level 76
(21385, 8752, 1, 1, 2, 87.060432), -- High-Grade Life Stone - Level 76
(21385, 1344, 150, 450, 2, 34836.773652), -- Mithril Arrow
-- Magma Golem
(21386, 5537, 1, 1, -1, 32059), -- Soul Separator Head
(21386, 1877, 1, 1, -1, 467422), -- Adamantite Nugget
(21386, 4041, 1, 1, -1, 101613); -- Mold Hardener

INSERT INTO `droplist` VALUES
(21386, 57, 5749, 11773, 0, 700000), -- Adena
(21386, 12266, 1, 1, 1, 602.60928), -- Common Item - Sealed Robe of Nightmare
(21386, 5487, 1, 1, 1, 4857.39072), -- Sealed Robe of Nightmare Fabric
(21386, 12259, 1, 1, 1, 602.60928), -- Common Item - Sealed Majestic Robe
(21386, 5488, 1, 1, 1, 4857.39072), -- Sealed Majestic Robe Fabric
(21386, 1871, 1, 3, 2, 239703.293544), -- Charcoal
(21386, 1866, 1, 3, 2, 106534.669036), -- Suede
(21386, 1877, 1, 1, 2, 19176.155884), -- Adamantite Nugget
(21386, 4041, 1, 1, 2, 4168.712832), -- Mold Hardener
(21386, 4040, 1, 1, 2, 9588.270084), -- Mold Lubricant
(21386, 959, 1, 1, 2, 19.2142), -- Scroll: Enchant Weapon (S-Grade)
(21386, 8732, 1, 1, 2, 3995.016464), -- Life Stone - Level 76
(21386, 8742, 1, 1, 2, 998.754116), -- Mid-Grade Life Stone - Level 76
(21386, 8752, 1, 1, 2, 99.91384), -- High-Grade Life Stone - Level 76
-- Arimanes of Destruction
(21387, 5522, 1, 1, -1, 35740), -- Sealed Armor of Nightmare Pattern
(21387, 1895, 1, 7, -1, 749613), -- Metallic Fiber
(21387, 4042, 1, 1, -1, 174910), -- Enria
(21387, 57, 5163, 10575, 0, 700000), -- Adena
(21387, 12352, 1, 1, 1, 1588.748784), -- Common Item - Sealed Majestic Earring
(21387, 6342, 1, 1, 1, 14629.634096), -- Sealed Majestic Earring Gemstone
(21387, 12350, 1, 1, 1, 1192.680496), -- Common Item - Sealed Majestic Necklace
(21387, 6344, 1, 1, 1, 9467.47032), -- Sealed Majestic Necklace Beads
(21387, 12351, 1, 1, 1, 2383.098032), -- Common Item - Sealed Majestic Ring
(21387, 6346, 1, 1, 1, 21026.368272), -- Sealed Majestic Ring Gemstone
(21387, 1873, 2, 6, 2, 43054.66836), -- Silver Nugget
(21387, 1868, 3, 9, 2, 143515.5612), -- Thread
(21387, 1876, 1, 1, 2, 86109.33672), -- Mithril Ore
(21387, 1895, 1, 1, 2, 123013.39638), -- Metallic Fiber
(21387, 4042, 1, 1, 2, 7175.77806), -- Enria
(21387, 959, 1, 1, 2, 17.11332), -- Scroll: Enchant Weapon (S-Grade)
(21387, 8732, 1, 1, 2, 3587.6853), -- Life Stone - Level 76
(21387, 8742, 1, 1, 2, 896.81946), -- Mid-Grade Life Stone - Level 76
(21387, 8752, 1, 1, 2, 89.6412), -- High-Grade Life Stone - Level 76
-- Iblis of Destruction
(21388, 5523, 1, 1, -1, 54064), -- Sealed Majestic Plate Armor Pattern
(21388, 1808, 1, 1, -1, 7056), -- Recipe: Soulshot (S-Grade)
(21388, 5527, 1, 1, -1, 189805), -- Sealed Helm of Nightmare Design
(21388, 57, 7810, 15997, 0, 700000), -- Adena
(21388, 12267, 1, 1, 1, 1993.73837), -- Common Item - Sealed Boots of Nightmare
(21388, 5502, 1, 1, 1, 12374.51163), -- Sealed Boots of Nightmare Lining
(21388, 12260, 1, 1, 1, 1993.73837), -- Common Item - Sealed Majestic Boots
(21388, 5503, 1, 1, 1, 12374.51163), -- Sealed Majestic Boots Lining
(21388, 12264, 1, 1, 1, 1993.73837), -- Common Item - Sealed Gauntlet of Nightmare
(21388, 5514, 1, 1, 1, 12374.51163), -- Sealed Gauntlets of Nightmare Design
(21388, 12257, 1, 1, 1, 1993.73837), -- Common Item - Sealed Majestic Gauntlet
(21388, 5515, 1, 1, 1, 12374.51163), -- Sealed Majestic Gauntlets Design
(21388, 1872, 5, 15, 2, 78155.049882), -- Animal Bone
(21388, 1867, 9, 27, 2, 43419.2313), -- Animal Skin
(21388, 1881, 1, 1, 2, 78155.049882), -- Coarse Bone Powder
(21388, 1875, 1, 1, 2, 39077.30817), -- Stone of Purity
(21388, 4041, 1, 1, 2, 5097.153294), -- Mold Hardener
(21388, 960, 1, 1, 2, 234.546222), -- Scroll: Enchant Armor (S-Grade)
(21388, 8732, 1, 1, 2, 4884.717714), -- Life Stone - Level 76
(21388, 8742, 1, 1, 2, 1221.287814), -- Mid-Grade Life Stone - Level 76
(21388, 8752, 1, 1, 2, 122.258844), -- High-Grade Life Stone - Level 76
(21388, 1344, 40, 120, 2, 183175.396878), -- Mithril Arrow
-- Balor of Destruction
(21389, 959, 1, 1, -1, 580), -- Scroll: Enchant Weapon (S-Grade)
(21389, 6690, 1, 1, -1, 31391), -- Imperial Staff Head
(21389, 6691, 1, 1, -1, 31331), -- Angel Slayer Blade
(21389, 57, 7149, 14591, 0, 700000), -- Adena
(21389, 11968, 1, 1, 1, 158.573382), -- Common Item - Dragon Slayer
(21389, 5529, 1, 1, 1, 2447.158194), -- Dragon Slayer Edge
(21389, 11971, 1, 1, 1, 158.573382), -- Common Item - Sword of Miracles
(21389, 5546, 1, 1, 1, 2687.963466), -- Sword of Miracles Edge
(21389, 11964, 1, 1, 1, 158.573382), -- Common Item - Dark Legion's Edge
(21389, 5545, 1, 1, 1, 2447.158194), -- Dark Legion's Edge Blade
(21389, 1864, 4, 12, 2, 148668.54852), -- Stem
(21389, 1865, 2, 6, 2, 118935.09465), -- Varnish
(21389, 1866, 3, 9, 2, 66075.09996), -- Suede
(21389, 1873, 4, 12, 2, 29733.88026), -- Silver Nugget
(21389, 1868, 10, 30, 2, 56635.67814), -- Thread
(21389, 959, 1, 1, 2, 23.87784), -- Scroll: Enchant Weapon (S-Grade)
(21389, 8732, 1, 1, 2, 4955.50458), -- Life Stone - Level 76
(21389, 8742, 1, 1, 2, 1239.08934), -- Mid-Grade Life Stone - Level 76
(21389, 8752, 1, 1, 2, 123.22671), -- High-Grade Life Stone - Level 76
-- Ashuras of Destruction
(21390, 6701, 1, 1, -1, 89988), -- Sealed Imperial Crusader Breastplate Part
(21390, 6702, 1, 1, -1, 115839), -- Sealed Imperial Crusader Gaiters Pattern
(21390, 6703, 1, 1, -1, 240650), -- Sealed Imperial Crusader Gauntlets Design
(21390, 57, 8333, 17007, 0, 700000), -- Adena
(21390, 12352, 1, 1, 1, 2558.748663), -- Common Item - Sealed Majestic Earring
(21390, 6342, 1, 1, 1, 23561.658747), -- Sealed Majestic Earring Gemstone
(21390, 12350, 1, 1, 1, 1920.863547), -- Common Item - Sealed Majestic Necklace
(21390, 6344, 1, 1, 1, 15247.770615), -- Sealed Majestic Necklace Beads
(21390, 12351, 1, 1, 1, 3838.082499), -- Common Item - Sealed Majestic Ring
(21390, 6346, 1, 1, 1, 33863.875929), -- Sealed Majestic Ring Gemstone
(21390, 1872, 5, 15, 2, 83210.028993), -- Animal Bone
(21390, 1867, 9, 27, 2, 46227.53745), -- Animal Skin
(21390, 1881, 1, 1, 2, 83210.028993), -- Coarse Bone Powder
(21390, 1875, 1, 1, 2, 41604.783705), -- Stone of Purity
(21390, 4041, 1, 1, 2, 5426.831331), -- Mold Hardener
(21390, 960, 1, 1, 2, 249.716403), -- Scroll: Enchant Armor (S-Grade)
(21390, 8732, 1, 1, 2, 5200.655661), -- Life Stone - Level 76
(21390, 8742, 1, 1, 2, 1300.279311), -- Mid-Grade Life Stone - Level 76
(21390, 8752, 1, 1, 2, 130.166406), -- High-Grade Life Stone - Level 76
(21390, 1344, 40, 120, 2, 195022.971747), -- Mithril Arrow
-- Lavasillisk
(21391, 6695, 1, 1, -1, 28824), -- Demon Splinter Blade
(21391, 6696, 1, 1, -1, 29845), -- Heavens Divider Edge
(21391, 6697, 1, 1, -1, 28824), -- Arcana Mace Head
(21391, 57, 6703, 13681, 0, 700000), -- Adena
(21391, 11974, 1, 1, 1, 111.524267), -- Common Item - Elysian
(21391, 5533, 1, 1, 1, 1720.738623), -- Elysian Head
(21391, 11970, 1, 1, 1, 111.524267), -- Common Item - Branch of the Mother Tree
(21391, 5544, 1, 1, 1, 1719.038759), -- Branch of the Mother Tree Head
(21391, 11969, 1, 1, 1, 111.524267), -- Common Item - Flaming Dragon Skull
(21391, 8342, 1, 1, 1, 1720.738623), -- Flaming Dragon Skull Piece
(21391, 11966, 1, 1, 1, 111.524267), -- Common Item - Doom Crusher
(21391, 8349, 1, 1, 1, 1720.386927), -- Doom Crusher Head
(21391, 1869, 2, 6, 2, 100368.65358), -- Iron Ore
(21391, 1870, 3, 9, 2, 83640.54465), -- Coal
(21391, 1871, 3, 9, 2, 71691.687702), -- Charcoal
(21391, 1872, 8, 24, 2, 41820.029994), -- Animal Bone
(21391, 1867, 13, 39, 2, 24782.222046), -- Animal Skin
(21391, 960, 1, 1, 2, 200.650068), -- Scroll: Enchant Armor (S-Grade)
(21391, 8732, 1, 1, 2, 4182.148398), -- Life Stone - Level 76
(21391, 8742, 1, 1, 2, 1045.415934), -- Mid-Grade Life Stone - Level 76
(21391, 8752, 1, 1, 2, 104.686992), -- High-Grade Life Stone - Level 76
(21391, 1344, 40, 120, 2, 156825.960636), -- Mithril Arrow
-- Blazing Ifrit
(21392, 9630, 1, 1, -1, 88230), -- Orichalcum
(21392, 959, 1, 1, -1, 671), -- Scroll: Enchant Weapon (S-Grade)
(21392, 9991, 1, 1, -1, 39306), -- Sealed Dynasty Earring Gemstone
(21392, 57, 8265, 16868, 0, 700000), -- Adena
(21392, 9452, 1, 1, 1, 34.11387), -- Sealed Dynasty Earring
(21392, 9453, 1, 1, 1, 25.58151), -- Sealed Dynasty Necklace
(21392, 9454, 1, 1, 1, 51.170805), -- Sealed Dynasty Ring
(21392, 9991, 1, 1, 1, 2418.70608), -- Sealed Dynasty Earring Gemstone
(21392, 9992, 1, 1, 1, 1856.294325), -- Sealed Dynasty Necklace Gemstone
(21392, 9993, 1, 1, 1, 3399.13341), -- Sealed Dynasty Ring Gemstone
(21392, 1879, 1, 1, 2, 114623.20554), -- Cokes
(21392, 1885, 1, 1, 2, 57311.60277), -- High-Grade Suede
(21392, 9628, 1, 1, 2, 5394.08611), -- Leonard
(21392, 9630, 1, 1, 2, 3619.65136), -- Orichalcum
(21392, 9629, 1, 1, 2, 2990.24029), -- Adamantine
(21392, 9573, 1, 1, 2, 4776.01578), -- Life Stone - Level 80
(21392, 9574, 1, 1, 2, 1193.90618), -- Mid-Grade Life Stone - Level 80
(21392, 9575, 1, 1, 2, 119.46883), -- High-Grade Life Stone - Level 80
(21392, 9551, 1, 1, 2, 5501.82314), -- Holy Stone
-- Magma Drake
(21393, 959, 1, 1, -1, 604), -- Scroll: Enchant Weapon (S-Grade)
(21393, 1877, 1, 1, -1, 603958), -- Adamantite Nugget
(21393, 4041, 1, 1, -1, 131295), -- Mold Hardener
(21393, 57, 7443, 15195, 0, 700000), -- Adena
(21393, 11976, 1, 1, 1, 495.55506), -- Common Item - Tallum Glaive
(21393, 5541, 1, 1, 1, 7644.44494), -- Tallum Glaive Edge
(21393, 1871, 1, 3, 2, 309722.274576), -- Charcoal
(21393, 1866, 1, 3, 2, 137654.178744), -- Suede
(21393, 1877, 1, 1, 2, 24777.642936), -- Adamantite Nugget
(21393, 4041, 1, 1, 2, 5386.422528), -- Mold Hardener
(21393, 4040, 1, 1, 2, 12389.069736), -- Mold Lubricant
(21393, 959, 1, 1, 2, 24.8268), -- Scroll: Enchant Weapon (S-Grade)
(21393, 8732, 1, 1, 2, 5161.988256), -- Life Stone - Level 76
(21393, 8742, 1, 1, 2, 1290.497064), -- Mid-Grade Life Stone - Level 76
(21393, 8752, 1, 1, 2, 129.09936), -- High-Grade Life Stone - Level 76
-- Lavasaurus
(21394, 1808, 1, 1, -1, 5069), -- Recipe: Soulshot (S-Grade)
(21394, 5527, 1, 1, -1, 136356), -- Sealed Helm of Nightmare Design
(21394, 3036, 1, 1, -1, 5069), -- Recipe: Spiritshot S
(21394, 57, 5623, 11476, 0, 700000), -- Adena
(21394, 11967, 1, 1, 1, 374.33205), -- Common Item - Dragon Grinder
(21394, 5538, 1, 1, 1, 5775.66795), -- Dragon Grinder Edge
(21394, 1894, 1, 1, 2, 16417.24833), -- Crafted Leather
(21394, 4039, 1, 1, 2, 15596.123964), -- Mold Glue
(21394, 4041, 1, 1, 2, 4068.599634), -- Mold Hardener
(21394, 4044, 1, 1, 2, 15596.123964), -- Thons
(21394, 960, 1, 1, 2, 187.206576), -- Scroll: Enchant Armor (S-Grade)
(21394, 8732, 1, 1, 2, 3899.205624), -- Life Stone - Level 76
(21394, 8742, 1, 1, 2, 974.801406), -- Mid-Grade Life Stone - Level 76
(21394, 8752, 1, 1, 2, 97.445214), -- High-Grade Life Stone - Level 76
(21394, 1344, 20, 60, 2, 292429.245288), -- Mithril Arrow
-- Elder Lavasaurus
(21395, 6901, 1, 1, -1, 14948), -- Recipe: Shining Arrow (100%)
(21395, 10114, 1, 1, -1, 37063), -- Sealed Dynasty Sigil Piece
(21395, 960, 1, 1, -1, 5979), -- Scroll: Enchant Armor (S-Grade)
(21395, 57, 7372, 15047, 0, 700000), -- Adena
(21395, 9514, 1, 1, 1, 11.310494), -- Sealed Dynasty Breast Plate
(21395, 9515, 1, 1, 1, 18.095194), -- Sealed Dynasty Gaiter
(21395, 9530, 1, 1, 1, 2009.276932), -- Sealed Dynasty Breast Plate Piece
(21395, 9531, 1, 1, 1, 5943.31738), -- Sealed Dynasty Gaiters Piece
(21395, 1879, 1, 1, 2, 102210.625608), -- Cokes
(21395, 1885, 1, 1, 2, 51105.312804), -- High-Grade Suede
(21395, 9628, 1, 1, 2, 4809.958972), -- Leonard
(21395, 9630, 1, 1, 2, 3227.678272), -- Orichalcum
(21395, 9629, 1, 1, 2, 2666.426308), -- Adamantine
(21395, 9573, 1, 1, 2, 4258.819656), -- Life Stone - Level 80
(21395, 9574, 1, 1, 2, 1064.617736), -- Mid-Grade Life Stone - Level 80
(21395, 9575, 1, 1, 2, 106.531516), -- High-Grade Life Stone - Level 80
(21395, 9548, 1, 1, 2, 4906.029128), -- Earth Stone
-- Carrion Scarab
(21396, 3036, 1, 1, -1, 2766), -- Recipe: Spiritshot S
(21396, 6342, 1, 1, -1, 140959), -- Sealed Majestic Earring Gemstone
(21396, 4040, 1, 1, -1, 124452), -- Mold Lubricant
(21396, 57, 3069, 6264, 0, 700000), -- Adena
(21396, 11946, 1, 1, 1, 79.060934), -- Common Item - Dasparion's Staff
(21396, 5543, 1, 1, 1, 977.596656), -- Dasparion's Staff Head
(21396, 11949, 1, 1, 1, 79.060934), -- Common Item - Meteor Shower
(21396, 5532, 1, 1, 1, 968.466006), -- Meteor Shower Head
(21396, 11953, 1, 1, 1, 79.060934), -- Common Item - Spiritual Eye
(21396, 8341, 1, 1, 1, 967.227596), -- Spiritual Eye Piece
(21396, 11958, 1, 1, 1, 79.060934), -- Common Item - Destroyer Hammer
(21396, 8346, 1, 1, 1, 968.466006), -- Hammer Piece of Destroyer
(21396, 1871, 1, 1, 2, 255286.773236), -- Charcoal
(21396, 1866, 1, 1, 2, 170191.330771), -- Suede
(21396, 1877, 1, 1, 2, 10211.542264), -- Adamantite Nugget
(21396, 4041, 1, 1, 2, 2219.842339), -- Mold Hardener
(21396, 4040, 1, 1, 2, 5105.771132), -- Mold Lubricant
(21396, 5157, 1, 1, 2, 113.243614), -- Recipe: Soulshot (S) Compressed Package (100%)
(21396, 8732, 1, 1, 2, 2127.553252), -- Life Stone - Level 76
(21396, 8742, 1, 1, 2, 531.888313), -- Mid-Grade Life Stone - Level 76
(21396, 8752, 1, 1, 2, 53.055079), -- High-Grade Life Stone - Level 76
-- Carrion Scarab
(21397, 3036, 1, 1, -1, 2696), -- Recipe: Spiritshot S
(21397, 6342, 1, 1, -1, 137412), -- Sealed Majestic Earring Gemstone
(21397, 4040, 1, 1, -1, 121321), -- Mold Lubricant
(21397, 57, 2992, 6106, 0, 700000), -- Adena
(21397, 11946, 1, 1, 1, 77.064636), -- Common Item - Dasparion's Staff
(21397, 5543, 1, 1, 1, 952.912224), -- Dasparion's Staff Head
(21397, 11949, 1, 1, 1, 77.064636), -- Common Item - Meteor Shower
(21397, 5532, 1, 1, 1, 944.012124), -- Meteor Shower Head
(21397, 11953, 1, 1, 1, 77.064636), -- Common Item - Spiritual Eye
(21397, 8341, 1, 1, 1, 942.804984), -- Spiritual Eye Piece
(21397, 11958, 1, 1, 1, 77.064636), -- Common Item - Destroyer Hammer
(21397, 8346, 1, 1, 1, 944.012124), -- Hammer Piece of Destroyer
(21397, 1871, 1, 1, 2, 248862.818712), -- Charcoal
(21397, 1866, 1, 1, 2, 165908.690682), -- Suede
(21397, 1877, 1, 1, 2, 9954.582288), -- Adamantite Nugget
(21397, 4041, 1, 1, 2, 2163.982938), -- Mold Hardener
(21397, 4040, 1, 1, 2, 4977.291144), -- Mold Lubricant
(21397, 5157, 1, 1, 2, 110.393988), -- Recipe: Soulshot (S) Compressed Package (100%)
(21397, 8732, 1, 1, 2, 2074.016184), -- Life Stone - Level 76
(21397, 8742, 1, 1, 2, 518.504046), -- Mid-Grade Life Stone - Level 76
(21397, 8752, 1, 1, 2, 51.720018), -- High-Grade Life Stone - Level 76
-- Soldier Scarab
(21398, 6346, 1, 1, -1, 375006), -- Sealed Majestic Ring Gemstone
(21398, 5157, 1, 1, -1, 5119), -- Recipe: Soulshot (S) Compressed Package (100%)
(21398, 5480, 1, 1, -1, 51685), -- Sealed Leather Armor of Nightmare Fabric
(21398, 57, 5681, 11595, 0, 700000), -- Adena
(21398, 11960, 1, 1, 1, 585.376344), -- Common Item - Halberd
(21398, 5542, 1, 1, 1, 7170.623656), -- Halberd Edge
(21398, 1895, 1, 1, 2, 151890.192336), -- Metallic Fiber
(21398, 4040, 1, 1, 2, 10632.305664), -- Mold Lubricant
(21398, 4042, 1, 1, 2, 8860.25472), -- Enria
(21398, 4043, 1, 1, 2, 17720.50944), -- Asofe
(21398, 5167, 1, 1, 2, 236.325456), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21398, 8732, 1, 1, 2, 4430.12736), -- Life Stone - Level 76
(21398, 8742, 1, 1, 2, 1107.53184), -- Mid-Grade Life Stone - Level 76
(21398, 8752, 1, 1, 2, 110.753184), -- High-Grade Life Stone - Level 76
-- Soldier Scarab
(21399, 6346, 1, 1, -1, 329100), -- Sealed Majestic Ring Gemstone
(21399, 5157, 1, 1, -1, 4493), -- Recipe: Soulshot (S) Compressed Package (100%)
(21399, 5480, 1, 1, -1, 45358), -- Sealed Leather Armor of Nightmare Fabric
(21399, 57, 4986, 10175, 0, 700000), -- Adena
(21399, 11960, 1, 1, 1, 513.751518), -- Common Item - Halberd
(21399, 5542, 1, 1, 1, 6293.248482), -- Halberd Edge
(21399, 1895, 1, 1, 2, 133296.130696), -- Metallic Fiber
(21399, 4040, 1, 1, 2, 9330.722304), -- Mold Lubricant
(21399, 4042, 1, 1, 2, 7775.60192), -- Enria
(21399, 4043, 1, 1, 2, 15551.20384), -- Asofe
(21399, 5167, 1, 1, 2, 207.395016), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21399, 8732, 1, 1, 2, 3887.80096), -- Life Stone - Level 76
(21399, 8742, 1, 1, 2, 971.95024), -- Mid-Grade Life Stone - Level 76
(21399, 8752, 1, 1, 2, 97.195024), -- High-Grade Life Stone - Level 76
-- Hexa Beetle
(21400, 5528, 1, 1, -1, 112808), -- Sealed Majestic Circlet Design
(21400, 4042, 1, 1, -1, 157255), -- Enria
(21400, 1876, 1, 3, -1, 943530), -- Mithril Ore
(21400, 57, 4652, 9494, 0, 700000), -- Adena
(21400, 11976, 1, 1, 1, 309.691473), -- Common Item - Tallum Glaive
(21400, 5541, 1, 1, 1, 4777.308527), -- Tallum Glaive Edge
(21400, 1873, 1, 1, 2, 154835.8878), -- Silver Nugget
(21400, 1868, 3, 9, 2, 129029.58486), -- Thread
(21400, 1876, 1, 1, 2, 77417.9439), -- Mithril Ore
(21400, 1895, 1, 1, 2, 110596.7181), -- Metallic Fiber
(21400, 4042, 1, 1, 2, 6451.45512), -- Enria
(21400, 959, 1, 1, 2, 15.43872), -- Scroll: Enchant Weapon (S-Grade)
(21400, 8732, 1, 1, 2, 3225.72756), -- Life Stone - Level 76
(21400, 8742, 1, 1, 2, 806.67312), -- Mid-Grade Life Stone - Level 76
(21400, 8752, 1, 1, 2, 80.57082), -- High-Grade Life Stone - Level 76
-- Hexa Beetle
(21401, 5528, 1, 1, -1, 99266), -- Sealed Majestic Circlet Design
(21401, 4042, 1, 1, -1, 138377), -- Enria
(21401, 1876, 1, 3, -1, 830263), -- Mithril Ore
(21401, 57, 4094, 8354, 0, 700000), -- Adena
(21401, 11976, 1, 1, 1, 272.494404), -- Common Item - Tallum Glaive
(21401, 5541, 1, 1, 1, 4203.505596), -- Tallum Glaive Edge
(21401, 1873, 1, 1, 2, 136248.26406), -- Silver Nugget
(21401, 1868, 3, 9, 2, 113539.937022), -- Thread
(21401, 1876, 1, 1, 2, 68124.13203), -- Mithril Ore
(21401, 1895, 1, 1, 2, 97319.88537), -- Metallic Fiber
(21401, 4042, 1, 1, 2, 5676.975624), -- Enria
(21401, 959, 1, 1, 2, 13.585344), -- Scroll: Enchant Weapon (S-Grade)
(21401, 8732, 1, 1, 2, 2838.487812), -- Life Stone - Level 76
(21401, 8742, 1, 1, 2, 709.834224), -- Mid-Grade Life Stone - Level 76
(21401, 8752, 1, 1, 2, 70.898514), -- High-Grade Life Stone - Level 76
-- Katraxis
(21402, 5157, 1, 1, -1, 3808), -- Recipe: Soulshot (S) Compressed Package (100%)
(21402, 5534, 1, 1, -1, 23519), -- Soul Bow Stave
(21402, 4044, 1, 1, -1, 285564), -- Thons
(21402, 57, 4224, 8620, 0, 700000), -- Adena
(21402, 11975, 1, 1, 1, 281.156991), -- Common Item - Soul Bow
(21402, 5534, 1, 1, 1, 4341.843009), -- Soul Bow Stave
(21402, 1868, 3, 9, 2, 117154.17224), -- Thread
(21402, 1873, 1, 1, 2, 140585.1394), -- Silver Nugget
(21402, 5549, 1, 1, 2, 35146.11896), -- Metallic Thread
(21402, 1889, 1, 1, 2, 23430.96716), -- Compound Braid
(21402, 4044, 1, 1, 2, 11715.48358), -- Thons
(21402, 959, 1, 1, 2, 13.93476), -- Scroll: Enchant Weapon (S-Grade)
(21402, 8732, 1, 1, 2, 2928.95384), -- Life Stone - Level 76
(21402, 8742, 1, 1, 2, 732.23846), -- Mid-Grade Life Stone - Level 76
(21402, 8752, 1, 1, 2, 72.9916), -- High-Grade Life Stone - Level 76
-- Katraxis
(21403, 5157, 1, 1, -1, 4395), -- Recipe: Soulshot (S) Compressed Package (100%)
(21403, 5534, 1, 1, -1, 27147), -- Soul Bow Stave
(21403, 4044, 1, 1, -1, 329609), -- Thons
(21403, 57, 4875, 9950, 0, 700000), -- Adena
(21403, 11975, 1, 1, 1, 324.519512), -- Common Item - Soul Bow
(21403, 5534, 1, 1, 1, 5011.480488), -- Soul Bow Stave
(21403, 1868, 3, 9, 2, 135224.47414), -- Thread
(21403, 1873, 1, 1, 2, 162269.52215), -- Silver Nugget
(21403, 5549, 1, 1, 2, 40567.18906), -- Metallic Thread
(21403, 1889, 1, 1, 2, 27045.04801), -- Compound Braid
(21403, 4044, 1, 1, 2, 13522.524005), -- Thons
(21403, 959, 1, 1, 2, 16.08411), -- Scroll: Enchant Weapon (S-Grade)
(21403, 8732, 1, 1, 2, 3380.72674), -- Life Stone - Level 76
(21403, 8742, 1, 1, 2, 845.181685), -- Mid-Grade Life Stone - Level 76
(21403, 8752, 1, 1, 2, 84.2501), -- High-Grade Life Stone - Level 76
-- Tera Beetle
(21404, 5167, 1, 1, -1, 5086), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21404, 5515, 1, 1, -1, 193288), -- Sealed Majestic Gauntlets Design
(21404, 6901, 1, 1, -1, 11445), -- Recipe: Shining Arrow (100%)
(21404, 57, 5642, 11518, 0, 700000), -- Adena
(21404, 12266, 1, 1, 1, 590.19288), -- Common Item - Sealed Robe of Nightmare
(21404, 5487, 1, 1, 1, 4757.30712), -- Sealed Robe of Nightmare Fabric
(21404, 12259, 1, 1, 1, 590.19288), -- Common Item - Sealed Majestic Robe
(21404, 5488, 1, 1, 1, 4757.30712), -- Sealed Majestic Robe Fabric
(21404, 1869, 2, 6, 2, 117380.510895), -- Iron Ore
(21404, 1870, 2, 6, 2, 93904.408716), -- Coal
(21404, 1871, 3, 9, 2, 78253.67393), -- Charcoal
(21404, 1872, 7, 21, 2, 44716.280718), -- Animal Bone
(21404, 1867, 12, 36, 2, 26084.679759), -- Animal Skin
(21404, 959, 1, 1, 2, 18.632697), -- Scroll: Enchant Weapon (S-Grade)
(21404, 8732, 1, 1, 2, 3912.86637), -- Life Stone - Level 76
(21404, 8742, 1, 1, 2, 978.033919), -- Mid-Grade Life Stone - Level 76
(21404, 8752, 1, 1, 2, 97.912996), -- High-Grade Life Stone - Level 76
-- Tera Beetle
(21405, 5167, 1, 1, -1, 3634), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21405, 5515, 1, 1, -1, 138112), -- Sealed Majestic Gauntlets Design
(21405, 6901, 1, 1, -1, 8178), -- Recipe: Shining Arrow (100%)
(21405, 57, 4031, 8230, 0, 700000), -- Adena
(21405, 12266, 1, 1, 1, 421.716128), -- Common Item - Sealed Robe of Nightmare
(21405, 5487, 1, 1, 1, 3399.283872), -- Sealed Robe of Nightmare Fabric
(21405, 12259, 1, 1, 1, 421.716128), -- Common Item - Sealed Majestic Robe
(21405, 5488, 1, 1, 1, 3399.283872), -- Sealed Majestic Robe Fabric
(21405, 1869, 2, 6, 2, 83872.840106), -- Iron Ore
(21405, 1870, 2, 6, 2, 67098.428694), -- Coal
(21405, 1871, 3, 9, 2, 55915.357245), -- Charcoal
(21405, 1872, 7, 21, 2, 31951.408984), -- Animal Bone
(21405, 1867, 1, 3, 2, 149107.227797), -- Animal Skin
(21405, 959, 1, 1, 2, 13.311782), -- Scroll: Enchant Weapon (S-Grade)
(21405, 8732, 1, 1, 2, 2795.865743), -- Life Stone - Level 76
(21405, 8742, 1, 1, 2, 698.868555), -- Mid-Grade Life Stone - Level 76
(21405, 8752, 1, 1, 2, 69.691094), -- High-Grade Life Stone - Level 76
-- Knight of Empire
(21406, 5523, 1, 1, -1, 37932), -- Sealed Majestic Plate Armor Pattern
(21406, 5277, 1, 1, -1, 4950), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21406, 5527, 1, 1, -1, 133170), -- Sealed Helm of Nightmare Design
(21406, 57, 5491, 11210, 0, 700000), -- Adena
(21406, 12267, 1, 1, 1, 1398.83956), -- Common Item - Sealed Boots of Nightmare
(21406, 5502, 1, 1, 1, 8682.16044), -- Sealed Boots of Nightmare Lining
(21406, 12260, 1, 1, 1, 1398.83956), -- Common Item - Sealed Majestic Boots
(21406, 5503, 1, 1, 1, 8682.16044), -- Sealed Majestic Boots Lining
(21406, 12264, 1, 1, 1, 1398.83956), -- Common Item - Sealed Gauntlet of Nightmare
(21406, 5514, 1, 1, 1, 8682.16044), -- Sealed Gauntlets of Nightmare Design
(21406, 12257, 1, 1, 1, 1398.83956), -- Common Item - Sealed Majestic Gauntlet
(21406, 5515, 1, 1, 1, 8682.16044), -- Sealed Majestic Gauntlets Design
(21406, 1873, 2, 6, 2, 45695.578698), -- Silver Nugget
(21406, 1868, 3, 9, 2, 152318.59566), -- Thread
(21406, 1876, 1, 1, 2, 91391.157396), -- Mithril Ore
(21406, 1895, 1, 1, 2, 130558.858059), -- Metallic Fiber
(21406, 4042, 1, 1, 2, 7615.929783), -- Enria
(21406, 959, 1, 1, 2, 18.163026), -- Scroll: Enchant Weapon (S-Grade)
(21406, 8732, 1, 1, 2, 3807.748665), -- Life Stone - Level 76
(21406, 8742, 1, 1, 2, 951.829053), -- Mid-Grade Life Stone - Level 76
(21406, 8752, 1, 1, 2, 95.13966), -- High-Grade Life Stone - Level 76
-- Knight of Empire
(21407, 5523, 1, 1, -1, 24314), -- Sealed Majestic Plate Armor Pattern
(21407, 5277, 1, 1, -1, 3173), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21407, 5527, 1, 1, -1, 85361), -- Sealed Helm of Nightmare Design
(21407, 57, 3520, 7185, 0, 700000), -- Adena
(21407, 12267, 1, 1, 1, 896.66712), -- Common Item - Sealed Boots of Nightmare
(21407, 5502, 1, 1, 1, 5565.33288), -- Sealed Boots of Nightmare Lining
(21407, 12260, 1, 1, 1, 896.66712), -- Common Item - Sealed Majestic Boots
(21407, 5503, 1, 1, 1, 5565.33288), -- Sealed Majestic Boots Lining
(21407, 12264, 1, 1, 1, 896.66712), -- Common Item - Sealed Gauntlet of Nightmare
(21407, 5514, 1, 1, 1, 5565.33288), -- Sealed Gauntlets of Nightmare Design
(21407, 12257, 1, 1, 1, 896.66712), -- Common Item - Sealed Majestic Gauntlet
(21407, 5515, 1, 1, 1, 5565.33288), -- Sealed Majestic Gauntlets Design
(21407, 1873, 1, 1, 2, 117162.87789), -- Silver Nugget
(21407, 1868, 3, 9, 2, 97635.488193), -- Thread
(21407, 1876, 1, 1, 2, 58581.438945), -- Mithril Ore
(21407, 1895, 1, 1, 2, 83687.509155), -- Metallic Fiber
(21407, 4042, 1, 1, 2, 4881.756156), -- Enria
(21407, 959, 1, 1, 2, 11.682336), -- Scroll: Enchant Weapon (S-Grade)
(21407, 8732, 1, 1, 2, 2440.878078), -- Life Stone - Level 76
(21407, 8742, 1, 1, 2, 610.402056), -- Mid-Grade Life Stone - Level 76
(21407, 8752, 1, 1, 2, 60.967191), -- High-Grade Life Stone - Level 76
-- Royal Guard of Empire
(21408, 5282, 1, 1, -1, 4677), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21408, 5529, 1, 1, -1, 28873), -- Dragon Slayer Edge
(21408, 6901, 1, 1, -1, 10524), -- Recipe: Shining Arrow (100%)
(21408, 57, 5188, 10592, 0, 700000), -- Adena
(21408, 11968, 1, 1, 1, 115.141829), -- Common Item - Dragon Slayer
(21408, 5529, 1, 1, 1, 1776.907743), -- Dragon Slayer Edge
(21408, 11971, 1, 1, 1, 115.141829), -- Common Item - Sword of Miracles
(21408, 5546, 1, 1, 1, 1951.759027), -- Sword of Miracles Edge
(21408, 11964, 1, 1, 1, 115.141829), -- Common Item - Dark Legion's Edge
(21408, 5545, 1, 1, 1, 1776.907743), -- Dark Legion's Edge Blade
(21408, 1868, 3, 9, 2, 143918.699316), -- Thread
(21408, 1873, 1, 1, 2, 172702.60221), -- Silver Nugget
(21408, 5549, 1, 1, 2, 43175.446764), -- Metallic Thread
(21408, 1889, 1, 1, 2, 28783.902894), -- Compound Braid
(21408, 4044, 1, 1, 2, 14391.951447), -- Thons
(21408, 959, 1, 1, 2, 17.118234), -- Scroll: Enchant Weapon (S-Grade)
(21408, 8732, 1, 1, 2, 3598.089756), -- Life Stone - Level 76
(21408, 8742, 1, 1, 2, 899.522439), -- Mid-Grade Life Stone - Level 76
(21408, 8752, 1, 1, 2, 89.66694), -- High-Grade Life Stone - Level 76
-- Royal Guard of Empire
(21409, 5282, 1, 1, -1, 5231), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21409, 5529, 1, 1, -1, 32288), -- Dragon Slayer Edge
(21409, 6901, 1, 1, -1, 11769), -- Recipe: Shining Arrow (100%)
(21409, 57, 5802, 11844, 0, 700000), -- Adena
(21409, 11968, 1, 1, 1, 128.759697), -- Common Item - Dragon Slayer
(21409, 5529, 1, 1, 1, 1987.063299), -- Dragon Slayer Edge
(21409, 11971, 1, 1, 1, 128.759697), -- Common Item - Sword of Miracles
(21409, 5546, 1, 1, 1, 2182.594311), -- Sword of Miracles Edge
(21409, 11964, 1, 1, 1, 128.759697), -- Common Item - Dark Legion's Edge
(21409, 5545, 1, 1, 1, 1987.063299), -- Dark Legion's Edge Blade
(21409, 1868, 3, 9, 2, 160941.32978), -- Thread
(21409, 1873, 1, 1, 2, 193129.77805), -- Silver Nugget
(21409, 5549, 1, 1, 2, 48282.21662), -- Metallic Thread
(21409, 1889, 1, 1, 2, 32188.44827), -- Compound Braid
(21409, 4044, 1, 1, 2, 16094.224135), -- Thons
(21409, 959, 1, 1, 2, 19.14297), -- Scroll: Enchant Weapon (S-Grade)
(21409, 8732, 1, 1, 2, 4023.66998), -- Life Stone - Level 76
(21409, 8742, 1, 1, 2, 1005.917495), -- Mid-Grade Life Stone - Level 76
(21409, 8752, 1, 1, 2, 100.2727), -- High-Grade Life Stone - Level 76
-- Guardian Scarab
(21410, 5538, 1, 1, -1, 29251), -- Dragon Grinder Edge
(21410, 5282, 1, 1, -1, 4740), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21410, 5541, 1, 1, -1, 29245), -- Tallum Glaive Edge
(21410, 57, 5247, 10744, 0, 700000), -- Adena
(21410, 12352, 1, 1, 1, 1614.370707), -- Common Item - Sealed Majestic Earring
(21410, 6342, 1, 1, 1, 14865.567783), -- Sealed Majestic Earring Gemstone
(21410, 12350, 1, 1, 1, 1211.914983), -- Common Item - Sealed Majestic Necklace
(21410, 6344, 1, 1, 1, 9620.153235), -- Sealed Majestic Necklace Beads
(21410, 12351, 1, 1, 1, 2421.530511), -- Common Item - Sealed Majestic Ring
(21410, 6346, 1, 1, 1, 21365.462781), -- Sealed Majestic Ring Gemstone
(21410, 1867, 5, 15, 2, 52499.19648), -- Animal Skin
(21410, 1872, 1, 3, 2, 174997.78436), -- Animal Bone
(21410, 1882, 1, 1, 2, 87498.6608), -- Leather
(21410, 1894, 1, 1, 2, 13815.6998), -- Crafted Leather
(21410, 4042, 1, 1, 2, 6562.39956), -- Enria
(21410, 960, 1, 1, 2, 157.3384), -- Scroll: Enchant Armor (S-Grade)
(21410, 8732, 1, 1, 2, 3281.43116), -- Life Stone - Level 76
(21410, 8742, 1, 1, 2, 820.47348), -- Mid-Grade Life Stone - Level 76
(21410, 8752, 1, 1, 2, 81.90852), -- High-Grade Life Stone - Level 76
(21410, 1344, 40, 120, 2, 123045.10744), -- Mithril Arrow
-- Guardian Scarab
(21411, 5538, 1, 1, -1, 23844), -- Dragon Grinder Edge
(21411, 5282, 1, 1, -1, 3864), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21411, 5541, 1, 1, -1, 23839), -- Tallum Glaive Edge
(21411, 57, 4277, 8758, 0, 700000), -- Adena
(21411, 12352, 1, 1, 1, 1315.974822), -- Common Item - Sealed Majestic Earring
(21411, 6342, 1, 1, 1, 12117.856718), -- Sealed Majestic Earring Gemstone
(21411, 12350, 1, 1, 1, 987.907918), -- Common Item - Sealed Majestic Necklace
(21411, 6344, 1, 1, 1, 7841.99031), -- Sealed Majestic Necklace Beads
(21411, 12351, 1, 1, 1, 1973.941406), -- Common Item - Sealed Majestic Ring
(21411, 6346, 1, 1, 1, 17416.328826), -- Sealed Majestic Ring Gemstone
(21411, 1867, 5, 15, 2, 42795.875592), -- Animal Skin
(21411, 1872, 1, 3, 2, 142653.295869), -- Animal Bone
(21411, 1882, 1, 1, 2, 71326.45932), -- Leather
(21411, 1894, 1, 1, 2, 11262.171795), -- Crafted Leather
(21411, 4042, 1, 1, 2, 5349.484449), -- Enria
(21411, 960, 1, 1, 2, 128.25786), -- Scroll: Enchant Armor (S-Grade)
(21411, 8732, 1, 1, 2, 2674.930839), -- Life Stone - Level 76
(21411, 8742, 1, 1, 2, 668.827017), -- Mid-Grade Life Stone - Level 76
(21411, 8752, 1, 1, 2, 66.769533), -- High-Grade Life Stone - Level 76
(21411, 1344, 40, 120, 2, 100302.927726), -- Mithril Arrow
-- Ustralith
(21412, 1876, 1, 5, -1, 924871), -- Mithril Ore
(21412, 5545, 1, 1, -1, 38061), -- Dark Legion's Edge Blade
(21412, 1808, 1, 1, -1, 6166), -- Recipe: Soulshot (S-Grade)
(21412, 57, 6826, 13977, 0, 700000), -- Adena
(21412, 12268, 1, 1, 1, 2214.614004), -- Common Item - Sealed Shield of Nightmare
(21412, 5495, 1, 1, 1, 12963.909368), -- Sealed Shield of Nightmare Fragment
(21412, 12269, 1, 1, 1, 1549.42114), -- Common Item - Sealed Helm of Nightmare
(21412, 5527, 1, 1, 1, 10207.297828), -- Sealed Helm of Nightmare Design
(21412, 12261, 1, 1, 1, 1549.42114), -- Common Item - Sealed Majestic Circlet
(21412, 5528, 1, 1, 1, 10207.33652), -- Sealed Majestic Circlet Design
(21412, 1873, 3, 9, 2, 34149.084573), -- Silver Nugget
(21412, 1868, 4, 12, 2, 128058.950179), -- Thread
(21412, 1876, 1, 1, 2, 102447.253719), -- Mithril Ore
(21412, 1895, 1, 1, 2, 146353.019079), -- Metallic Fiber
(21412, 4042, 1, 1, 2, 8537.388113), -- Enria
(21412, 960, 1, 1, 2, 204.931002), -- Scroll: Enchant Armor (S-Grade)
(21412, 8732, 1, 1, 2, 4268.460117), -- Life Stone - Level 76
(21412, 8742, 1, 1, 2, 1067.231999), -- Mid-Grade Life Stone - Level 76
(21412, 8752, 1, 1, 2, 106.676412), -- High-Grade Life Stone - Level 76
(21412, 1344, 150, 450, 2, 42686.004807), -- Mithril Arrow
-- Ustralith
(21413, 1876, 1, 5, -1, 711201), -- Mithril Ore
(21413, 5545, 1, 1, -1, 29268), -- Dark Legion's Edge Blade
(21413, 1808, 1, 1, -1, 4741), -- Recipe: Soulshot (S-Grade)
(21413, 57, 5249, 10748, 0, 700000), -- Adena
(21413, 12268, 1, 1, 1, 1702.972461), -- Common Item - Sealed Shield of Nightmare
(21413, 5495, 1, 1, 1, 9968.861662), -- Sealed Shield of Nightmare Fragment
(21413, 12269, 1, 1, 1, 1191.458885), -- Common Item - Sealed Helm of Nightmare
(21413, 5527, 1, 1, 1, 7849.109177), -- Sealed Helm of Nightmare Design
(21413, 12261, 1, 1, 1, 1191.458885), -- Common Item - Sealed Majestic Circlet
(21413, 5528, 1, 1, 1, 7849.13893), -- Sealed Majestic Circlet Design
(21413, 1873, 1, 1, 2, 157558.238145), -- Silver Nugget
(21413, 1868, 4, 12, 2, 98473.837455), -- Thread
(21413, 1876, 1, 1, 2, 78778.87353), -- Mithril Ore
(21413, 1895, 1, 1, 2, 112541.458365), -- Metallic Fiber
(21413, 4042, 1, 1, 2, 6564.82428), -- Enria
(21413, 960, 1, 1, 2, 157.638285), -- Scroll: Enchant Armor (S-Grade)
(21413, 8732, 1, 1, 2, 3282.41214), -- Life Stone - Level 76
(21413, 8742, 1, 1, 2, 820.603035), -- Mid-Grade Life Stone - Level 76
(21413, 8752, 1, 1, 2, 82.011195), -- High-Grade Life Stone - Level 76
(21413, 1344, 150, 450, 2, 32825.10357), -- Mithril Arrow
-- Assassin of Empire
(21414, 4040, 1, 1, -1, 207354), -- Mold Lubricant
(21414, 1877, 1, 1, -1, 414708), -- Adamantite Nugget
(21414, 6344, 1, 1, -1, 151985), -- Sealed Majestic Necklace Beads
(21414, 57, 5101, 10446, 0, 700000), -- Adena
(21414, 11974, 1, 1, 1, 85.070169), -- Common Item - Elysian
(21414, 5533, 1, 1, 1, 1312.571061), -- Elysian Head
(21414, 11970, 1, 1, 1, 85.070169), -- Common Item - Branch of the Mother Tree
(21414, 5544, 1, 1, 1, 1311.274413), -- Branch of the Mother Tree Head
(21414, 11969, 1, 1, 1, 85.070169), -- Common Item - Flaming Dragon Skull
(21414, 8342, 1, 1, 1, 1312.571061), -- Flaming Dragon Skull Piece
(21414, 11966, 1, 1, 1, 85.070169), -- Common Item - Doom Crusher
(21414, 8349, 1, 1, 1, 1312.302789), -- Doom Crusher Head
(21414, 1871, 1, 3, 2, 127602.326264), -- Charcoal
(21414, 1866, 2, 6, 2, 63801.39372), -- Suede
(21414, 1877, 1, 1, 2, 15312.426728), -- Adamantite Nugget
(21414, 4041, 1, 1, 2, 3328.768368), -- Mold Hardener
(21414, 4040, 1, 1, 2, 7655.982776), -- Mold Lubricant
(21414, 960, 1, 1, 2, 153.110432), -- Scroll: Enchant Armor (S-Grade)
(21414, 8732, 1, 1, 2, 3189.954392), -- Life Stone - Level 76
(21414, 8742, 1, 1, 2, 797.373304), -- Mid-Grade Life Stone - Level 76
(21414, 8752, 1, 1, 2, 79.783448), -- High-Grade Life Stone - Level 76
(21414, 1344, 20, 60, 2, 239254.880568), -- Mithril Arrow
-- Assassin of Empire
(21415, 4040, 1, 1, -1, 209177), -- Mold Lubricant
(21415, 1877, 1, 1, -1, 418353), -- Adamantite Nugget
(21415, 6344, 1, 1, -1, 153322), -- Sealed Majestic Necklace Beads
(21415, 57, 5146, 10537, 0, 700000), -- Adena
(21415, 11974, 1, 1, 1, 85.815998), -- Common Item - Elysian
(21415, 5533, 1, 1, 1, 1324.078662), -- Elysian Head
(21415, 11970, 1, 1, 1, 85.815998), -- Common Item - Branch of the Mother Tree
(21415, 5544, 1, 1, 1, 1322.770646), -- Branch of the Mother Tree Head
(21415, 11969, 1, 1, 1, 85.815998), -- Common Item - Flaming Dragon Skull
(21415, 8342, 1, 1, 1, 1324.078662), -- Flaming Dragon Skull Piece
(21415, 11966, 1, 1, 1, 85.815998), -- Common Item - Doom Crusher
(21415, 8349, 1, 1, 1, 1323.808038), -- Doom Crusher Head
(21415, 1871, 1, 3, 2, 128724.02347), -- Charcoal
(21415, 1866, 2, 6, 2, 64362.24435), -- Suede
(21415, 1877, 1, 1, 2, 15447.03169), -- Adamantite Nugget
(21415, 4041, 1, 1, 2, 3358.03014), -- Mold Hardener
(21415, 4040, 1, 1, 2, 7723.28323), -- Mold Lubricant
(21415, 960, 1, 1, 2, 154.45636), -- Scroll: Enchant Armor (S-Grade)
(21415, 8732, 1, 1, 2, 3217.99591), -- Life Stone - Level 76
(21415, 8742, 1, 1, 2, 804.38267), -- Mid-Grade Life Stone - Level 76
(21415, 8752, 1, 1, 2, 80.48479), -- High-Grade Life Stone - Level 76
(21415, 1344, 20, 60, 2, 241358.06739), -- Mithril Arrow
-- Imperial Commander
(21416, 5480, 1, 1, -1, 48118), -- Sealed Leather Armor of Nightmare Fabric
(21416, 1885, 1, 1, -1, 893618), -- High-Grade Suede
(21416, 4041, 1, 1, -1, 93247), -- Mold Hardener
(21416, 57, 5276, 10804, 0, 700000), -- Adena
(21416, 11975, 1, 1, 1, 351.947979), -- Common Item - Soul Bow
(21416, 5534, 1, 1, 1, 5435.052021), -- Soul Bow Stave
(21416, 1866, 2, 6, 2, 65990.263896), -- Suede
(21416, 1871, 1, 3, 2, 131980.223688), -- Charcoal
(21416, 5220, 1, 1, 2, 15837.73632), -- Metal Hardener
(21416, 1885, 1, 1, 2, 32994.979896), -- High-Grade Suede
(21416, 4041, 1, 1, 2, 3443.065488), -- Mold Hardener
(21416, 960, 1, 1, 2, 158.438184), -- Scroll: Enchant Armor (S-Grade)
(21416, 8732, 1, 1, 2, 3299.5284), -- Life Stone - Level 76
(21416, 8742, 1, 1, 2, 824.730048), -- Mid-Grade Life Stone - Level 76
(21416, 8752, 1, 1, 2, 82.412184), -- High-Grade Life Stone - Level 76
(21416, 1344, 100, 300, 2, 49492.621896), -- Mithril Arrow
-- Imperial Commander
(21417, 5480, 1, 1, -1, 74982), -- Sealed Leather Armor of Nightmare Fabric
(21417, 1885, 1, 3, -1, 696251), -- High-Grade Suede
(21417, 4041, 1, 1, -1, 145305), -- Mold Hardener
(21417, 57, 8221, 16836, 0, 700000), -- Adena
(21417, 11975, 1, 1, 1, 548.447706), -- Common Item - Soul Bow
(21417, 5534, 1, 1, 1, 8469.552294), -- Soul Bow Stave
(21417, 1866, 2, 6, 2, 102830.835123), -- Suede
(21417, 1871, 1, 3, 2, 205661.196369), -- Charcoal
(21417, 5220, 1, 1, 2, 24679.51416), -- Metal Hardener
(21417, 1885, 1, 1, 2, 51415.180623), -- High-Grade Suede
(21417, 4041, 1, 1, 2, 5365.235394), -- Mold Hardener
(21417, 960, 1, 1, 2, 246.889917), -- Scroll: Enchant Armor (S-Grade)
(21417, 8732, 1, 1, 2, 5141.56545), -- Life Stone - Level 76
(21417, 8742, 1, 1, 2, 1285.154424), -- Mid-Grade Life Stone - Level 76
(21417, 8752, 1, 1, 2, 128.420667), -- High-Grade Life Stone - Level 76
(21417, 1344, 100, 300, 2, 77123.007873), -- Mithril Arrow
-- Imperial Royal Guard
(21418, 3036, 1, 1, -1, 3947), -- Recipe: Spiritshot S
(21418, 5528, 1, 1, -1, 106180), -- Sealed Majestic Circlet Design
(21418, 4044, 1, 1, -1, 296030), -- Thons
(21418, 57, 4369, 8949, 0, 700000), -- Adena
(21418, 12268, 1, 1, 1, 1417.703253), -- Common Item - Sealed Shield of Nightmare
(21418, 5495, 1, 1, 1, 8298.952526), -- Sealed Shield of Nightmare Fragment
(21418, 12269, 1, 1, 1, 991.874605), -- Common Item - Sealed Helm of Nightmare
(21418, 5527, 1, 1, 1, 6534.285121), -- Sealed Helm of Nightmare Design
(21418, 12261, 1, 1, 1, 991.874605), -- Common Item - Sealed Majestic Circlet
(21418, 5528, 1, 1, 1, 6534.30989), -- Sealed Majestic Circlet Design
(21418, 1868, 3, 9, 2, 121448.318628), -- Thread
(21418, 1873, 1, 1, 2, 145738.11993), -- Silver Nugget
(21418, 5549, 1, 1, 2, 36434.358012), -- Metallic Thread
(21418, 1889, 1, 1, 2, 24289.801302), -- Compound Braid
(21418, 4044, 1, 1, 2, 12144.900651), -- Thons
(21418, 959, 1, 1, 2, 14.445522), -- Scroll: Enchant Weapon (S-Grade)
(21418, 8732, 1, 1, 2, 3036.311148), -- Life Stone - Level 76
(21418, 8742, 1, 1, 2, 759.077787), -- Mid-Grade Life Stone - Level 76
(21418, 8752, 1, 1, 2, 75.66702), -- High-Grade Life Stone - Level 76
-- Imperial Royal Guard
(21419, 3036, 1, 1, -1, 4020), -- Recipe: Spiritshot S
(21419, 5528, 1, 1, -1, 108137), -- Sealed Majestic Circlet Design
(21419, 4044, 1, 1, -1, 301486), -- Thons
(21419, 57, 4450, 9114, 0, 700000), -- Adena
(21419, 12268, 1, 1, 1, 1443.803325), -- Common Item - Sealed Shield of Nightmare
(21419, 5495, 1, 1, 1, 8451.73715), -- Sealed Shield of Nightmare Fragment
(21419, 12269, 1, 1, 1, 1010.135125), -- Common Item - Sealed Helm of Nightmare
(21419, 5527, 1, 1, 1, 6654.582025), -- Sealed Helm of Nightmare Design
(21419, 12261, 1, 1, 1, 1010.135125), -- Common Item - Sealed Majestic Circlet
(21419, 5528, 1, 1, 1, 6654.60725), -- Sealed Majestic Circlet Design
(21419, 1868, 3, 9, 2, 123686.67024), -- Thread
(21419, 1873, 1, 1, 2, 148424.1444), -- Silver Nugget
(21419, 5549, 1, 1, 2, 37105.86096), -- Metallic Thread
(21419, 1889, 1, 1, 2, 24737.47416), -- Compound Braid
(21419, 4044, 1, 1, 2, 12368.73708), -- Thons
(21419, 959, 1, 1, 2, 14.71176), -- Scroll: Enchant Weapon (S-Grade)
(21419, 8732, 1, 1, 2, 3092.27184), -- Life Stone - Level 76
(21419, 8742, 1, 1, 2, 773.06796), -- Mid-Grade Life Stone - Level 76
(21419, 8752, 1, 1, 2, 77.0616), -- High-Grade Life Stone - Level 76
-- Ashuras
(21420, 5533, 1, 1, -1, 30317), -- Elysian Head
(21420, 5157, 1, 1, -1, 4912), -- Recipe: Soulshot (S) Compressed Package (100%)
(21420, 5534, 1, 1, -1, 30344), -- Soul Bow Stave
(21420, 57, 5438, 11138, 0, 700000), -- Adena
(21420, 11974, 1, 1, 1, 90.686718), -- Common Item - Elysian
(21420, 5533, 1, 1, 1, 1399.230342), -- Elysian Head
(21420, 11970, 1, 1, 1, 90.686718), -- Common Item - Branch of the Mother Tree
(21420, 5544, 1, 1, 1, 1397.848086), -- Branch of the Mother Tree Head
(21420, 11969, 1, 1, 1, 90.686718), -- Common Item - Flaming Dragon Skull
(21420, 8342, 1, 1, 1, 1399.230342), -- Flaming Dragon Skull Piece
(21420, 11966, 1, 1, 1, 90.686718), -- Common Item - Doom Crusher
(21420, 8349, 1, 1, 1, 1398.944358), -- Doom Crusher Head
(21420, 1873, 2, 6, 2, 45344.45058), -- Silver Nugget
(21420, 1868, 3, 9, 2, 151148.1686), -- Thread
(21420, 1876, 1, 1, 2, 90688.90116), -- Mithril Ore
(21420, 1895, 1, 1, 2, 129555.63439), -- Metallic Fiber
(21420, 4042, 1, 1, 2, 7557.40843), -- Enria
(21420, 959, 1, 1, 2, 18.02346), -- Scroll: Enchant Weapon (S-Grade)
(21420, 8732, 1, 1, 2, 3778.48965), -- Life Stone - Level 76
(21420, 8742, 1, 1, 2, 944.51513), -- Mid-Grade Life Stone - Level 76
(21420, 8752, 1, 1, 2, 94.4086), -- High-Grade Life Stone - Level 76
-- Ashuras
(21421, 5533, 1, 1, -1, 28459), -- Elysian Head
(21421, 5157, 1, 1, -1, 4611), -- Recipe: Soulshot (S) Compressed Package (100%)
(21421, 5534, 1, 1, -1, 28484), -- Soul Bow Stave
(21421, 57, 5104, 10455, 0, 700000), -- Adena
(21421, 11974, 1, 1, 1, 85.131053), -- Common Item - Elysian
(21421, 5533, 1, 1, 1, 1313.510457), -- Elysian Head
(21421, 11970, 1, 1, 1, 85.131053), -- Common Item - Branch of the Mother Tree
(21421, 5544, 1, 1, 1, 1312.212881), -- Branch of the Mother Tree Head
(21421, 11969, 1, 1, 1, 85.131053), -- Common Item - Flaming Dragon Skull
(21421, 8342, 1, 1, 1, 1313.510457), -- Flaming Dragon Skull Piece
(21421, 11966, 1, 1, 1, 85.131053), -- Common Item - Doom Crusher
(21421, 8349, 1, 1, 1, 1313.241993), -- Doom Crusher Head
(21421, 1873, 2, 6, 2, 42565.43478), -- Silver Nugget
(21421, 1868, 3, 9, 2, 141884.7826), -- Thread
(21421, 1876, 1, 1, 2, 85130.86956), -- Mithril Ore
(21421, 1895, 1, 1, 2, 121615.58549), -- Metallic Fiber
(21421, 4042, 1, 1, 2, 7094.23913), -- Enria
(21421, 959, 1, 1, 2, 16.91886), -- Scroll: Enchant Weapon (S-Grade)
(21421, 8732, 1, 1, 2, 3546.91815), -- Life Stone - Level 76
(21421, 8742, 1, 1, 2, 886.62883), -- Mid-Grade Life Stone - Level 76
(21421, 8752, 1, 1, 2, 88.6226), -- High-Grade Life Stone - Level 76
-- Dancer of Empire
(21422, 5162, 1, 1, -1, 5290), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21422, 5538, 1, 1, -1, 32647), -- Dragon Grinder Edge
(21422, 5167, 1, 1, -1, 5290), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21422, 57, 5855, 11994, 0, 700000), -- Adena
(21422, 11975, 1, 1, 1, 390.627591), -- Common Item - Soul Bow
(21422, 5534, 1, 1, 1, 6032.372409), -- Soul Bow Stave
(21422, 1867, 4, 12, 2, 81383.025885), -- Animal Skin
(21422, 1872, 1, 3, 2, 217021.839755), -- Animal Bone
(21422, 1882, 1, 1, 2, 108510.70118), -- Leather
(21422, 1894, 1, 1, 2, 17133.199545), -- Crafted Leather
(21422, 4042, 1, 1, 2, 8138.17137), -- Enria
(21422, 959, 1, 1, 2, 19.682775), -- Scroll: Enchant Weapon (S-Grade)
(21422, 8732, 1, 1, 2, 4069.085685), -- Life Stone - Level 76
(21422, 8742, 1, 1, 2, 1017.38077), -- Mid-Grade Life Stone - Level 76
(21422, 8752, 1, 1, 2, 101.913035), -- High-Grade Life Stone - Level 76
-- Dancer of Empire
(21423, 5162, 1, 1, -1, 5608), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21423, 5538, 1, 1, -1, 34609), -- Dragon Grinder Edge
(21423, 5167, 1, 1, -1, 5608), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21423, 57, 6207, 12714, 0, 700000), -- Adena
(21423, 11975, 1, 1, 1, 414.102953), -- Common Item - Soul Bow
(21423, 5534, 1, 1, 1, 6394.897047), -- Soul Bow Stave
(21423, 1867, 4, 12, 2, 86272.575462), -- Animal Skin
(21423, 1872, 1, 3, 2, 230060.664906), -- Animal Bone
(21423, 1882, 1, 1, 2, 115030.100616), -- Leather
(21423, 1894, 1, 1, 2, 18162.574254), -- Crafted Leather
(21423, 4042, 1, 1, 2, 8627.118444), -- Enria
(21423, 959, 1, 1, 2, 20.86533), -- Scroll: Enchant Weapon (S-Grade)
(21423, 8732, 1, 1, 2, 4313.559222), -- Life Stone - Level 76
(21423, 8742, 1, 1, 2, 1078.505724), -- Mid-Grade Life Stone - Level 76
(21423, 8752, 1, 1, 2, 108.036042), -- High-Grade Life Stone - Level 76
-- Ashkenas
(21424, 5544, 1, 1, -1, 43821), -- Branch of the Mother Tree Head
(21424, 5272, 1, 1, -1, 7107), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21424, 5545, 1, 1, -1, 43872), -- Dark Legion's Edge Blade
(21424, 57, 7867, 16114, 0, 700000), -- Adena
(21424, 11976, 1, 1, 1, 524.837859), -- Common Item - Tallum Glaive
(21424, 5541, 1, 1, 1, 8096.162141), -- Tallum Glaive Edge
(21424, 1873, 2, 6, 2, 59045.593376), -- Silver Nugget
(21424, 1868, 15, 45, 2, 39363.578736), -- Thread
(21424, 1876, 1, 1, 2, 118090.736208), -- Mithril Ore
(21424, 1895, 1, 1, 2, 168701.244816), -- Metallic Fiber
(21424, 4042, 1, 1, 2, 9840.782048), -- Enria
(21424, 959, 1, 1, 2, 23.428288), -- Scroll: Enchant Weapon (S-Grade)
(21424, 6672, 1, 1, 2, 49204.360784), -- Deluxe Chest Key - Grade 8
(21424, 8732, 1, 1, 2, 4920.391024), -- Life Stone - Level 76
(21424, 8742, 1, 1, 2, 1229.98512), -- Mid-Grade Life Stone - Level 76
(21424, 8752, 1, 1, 2, 123.8996), -- High-Grade Life Stone - Level 76
-- Ashkenas
(21425, 5544, 1, 1, -1, 44556), -- Branch of the Mother Tree Head
(21425, 5272, 1, 1, -1, 7227), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21425, 5545, 1, 1, -1, 44609), -- Dark Legion's Edge Blade
(21425, 57, 7999, 16385, 0, 700000), -- Adena
(21425, 11976, 1, 1, 1, 533.665314), -- Common Item - Tallum Glaive
(21425, 5541, 1, 1, 1, 8232.334686), -- Tallum Glaive Edge
(21425, 1873, 2, 6, 2, 66707.162457), -- Silver Nugget
(21425, 1868, 15, 45, 2, 44471.592777), -- Thread
(21425, 1876, 1, 1, 2, 133414.324914), -- Mithril Ore
(21425, 1895, 1, 1, 2, 190592.022282), -- Metallic Fiber
(21425, 4042, 1, 1, 2, 11117.78484), -- Enria
(21425, 959, 1, 1, 2, 26.751603), -- Scroll: Enchant Weapon (S-Grade)
(21425, 8732, 1, 1, 2, 5558.89242), -- Life Stone - Level 76
(21425, 8742, 1, 1, 2, 1389.723105), -- Mid-Grade Life Stone - Level 76
(21425, 8752, 1, 1, 2, 138.745602), -- High-Grade Life Stone - Level 76
-- Abraxion
(21426, 6698, 1, 1, -1, 293497), -- Sealed Tateossian Earring Part
(21426, 6699, 1, 1, -1, 325674), -- Sealed Tateossian Ring Gem
(21426, 6700, 1, 1, -1, 178881), -- Sealed Tateossian Necklace Chain
(21426, 57, 7369, 15040, 0, 700000), -- Adena
(21426, 11975, 1, 1, 1, 490.428288), -- Common Item - Soul Bow
(21426, 5534, 1, 1, 1, 7573.571712), -- Soul Bow Stave
(21426, 1873, 3, 9, 2, 36780.075875), -- Silver Nugget
(21426, 1868, 4, 12, 2, 137924.639105), -- Thread
(21426, 1876, 1, 1, 2, 110339.85881), -- Mithril Ore
(21426, 1895, 3, 9, 2, 22518.36864), -- Metallic Fiber
(21426, 4042, 1, 1, 2, 9194.926765), -- Enria
(21426, 960, 1, 1, 2, 220.55137), -- Scroll: Enchant Armor (S-Grade)
(21426, 8732, 1, 1, 2, 4597.64779), -- Life Stone - Level 76
(21426, 8742, 1, 1, 2, 1149.22754), -- Mid-Grade Life Stone - Level 76
(21426, 8752, 1, 1, 2, 115.07028), -- High-Grade Life Stone - Level 76
(21426, 1344, 150, 450, 2, 45974.633825), -- Mithril Arrow
-- Abraxion
(21427, 6698, 1, 1, -1, 199827), -- Sealed Tateossian Earring Part
(21427, 6699, 1, 1, -1, 221735), -- Sealed Tateossian Ring Gem
(21427, 6700, 1, 1, -1, 121791), -- Sealed Tateossian Necklace Chain
(21427, 57, 5017, 10240, 0, 700000), -- Adena
(21427, 11975, 1, 1, 1, 333.88533), -- Common Item - Soul Bow
(21427, 5534, 1, 1, 1, 5156.11467), -- Soul Bow Stave
(21427, 1873, 1, 1, 2, 150250.212959), -- Silver Nugget
(21427, 1868, 4, 12, 2, 93906.324561), -- Thread
(21427, 1876, 1, 1, 2, 75124.872326), -- Mithril Ore
(21427, 1895, 1, 1, 2, 107321.446883), -- Metallic Fiber
(21427, 4042, 1, 1, 2, 6260.327976), -- Enria
(21427, 960, 1, 1, 2, 150.326547), -- Scroll: Enchant Armor (S-Grade)
(21427, 8732, 1, 1, 2, 3130.163988), -- Life Stone - Level 76
(21427, 8742, 1, 1, 2, 782.540997), -- Mid-Grade Life Stone - Level 76
(21427, 8752, 1, 1, 2, 78.207269), -- High-Grade Life Stone - Level 76
(21427, 1344, 150, 450, 2, 31302.576494), -- Mithril Arrow
-- Hasturan
(21428, 6701, 1, 1, -1, 56000), -- Sealed Imperial Crusader Breastplate Part
(21428, 6702, 1, 1, -1, 72087), -- Sealed Imperial Crusader Gaiters Pattern
(21428, 6703, 1, 1, -1, 149756), -- Sealed Imperial Crusader Gauntlets Design
(21428, 57, 5187, 10587, 0, 700000), -- Adena
(21428, 11973, 1, 1, 1, 345.236088), -- Common Item - Soul Separator
(21428, 5537, 1, 1, 1, 5327.763912), -- Soul Separator Head
(21428, 1868, 4, 12, 2, 97090.53832), -- Thread
(21428, 1873, 1, 1, 2, 155345.35752), -- Silver Nugget
(21428, 5549, 1, 1, 2, 38836.215328), -- Metallic Thread
(21428, 1889, 1, 1, 2, 25890.644816), -- Compound Braid
(21428, 4044, 1, 1, 2, 12945.570512), -- Thons
(21428, 960, 1, 1, 2, 155.313104), -- Scroll: Enchant Armor (S-Grade)
(21428, 8732, 1, 1, 2, 3236.268576), -- Life Stone - Level 76
(21428, 8742, 1, 1, 2, 809.315248), -- Mid-Grade Life Stone - Level 76
(21428, 8752, 1, 1, 2, 80.881904), -- High-Grade Life Stone - Level 76
(21428, 1344, 30, 90, 2, 161817.894672), -- Mithril Arrow
-- Hasturan
(21429, 6701, 1, 1, -1, 58474), -- Sealed Imperial Crusader Breastplate Part
(21429, 6702, 1, 1, -1, 75272), -- Sealed Imperial Crusader Gaiters Pattern
(21429, 6703, 1, 1, -1, 156374), -- Sealed Imperial Crusader Gauntlets Design
(21429, 57, 5417, 11055, 0, 700000), -- Adena
(21429, 11973, 1, 1, 1, 360.450088), -- Common Item - Soul Separator
(21429, 5537, 1, 1, 1, 5562.549912), -- Soul Separator Head
(21429, 1868, 4, 12, 2, 101380.73607), -- Thread
(21429, 1873, 1, 1, 2, 162209.177712), -- Silver Nugget
(21429, 5549, 1, 1, 2, 40552.294428), -- Metallic Thread
(21429, 1889, 1, 1, 2, 27034.990605), -- Compound Braid
(21429, 4044, 1, 1, 2, 13517.303823), -- Thons
(21429, 960, 1, 1, 2, 162.374616), -- Scroll: Enchant Armor (S-Grade)
(21429, 8732, 1, 1, 2, 3379.230216), -- Life Stone - Level 76
(21429, 8742, 1, 1, 2, 844.807554), -- Mid-Grade Life Stone - Level 76
(21429, 8752, 1, 1, 2, 84.633939), -- High-Grade Life Stone - Level 76
(21429, 1344, 150, 450, 2, 33793.451037), -- Mithril Arrow
-- Arimanes
(21430, 6704, 1, 1, -1, 215960), -- Sealed Imperial Crusader Boots Design
(21430, 6705, 1, 1, -1, 211533), -- Sealed Imperial Crusader Shield Part
(21430, 6706, 1, 1, -1, 246054), -- Sealed Imperial Crusader Helmet Pattern
(21430, 57, 7481, 15268, 0, 700000), -- Adena
(21430, 12265, 1, 1, 1, 782.20854), -- Common Item - Sealed Leather Armor of Nightmare
(21430, 5480, 1, 1, 1, 6282.79146), -- Sealed Leather Armor of Nightmare Fabric
(21430, 12258, 1, 1, 1, 782.20854), -- Common Item - Sealed Majestic Leather Armor
(21430, 5481, 1, 1, 1, 6282.79146), -- Sealed Majestic Leather Armor Fabric
(21430, 1873, 3, 9, 2, 37336.541375), -- Silver Nugget
(21430, 1868, 4, 12, 2, 140011.374965), -- Thread
(21430, 1876, 1, 1, 2, 112009.24973), -- Mithril Ore
(21430, 1895, 3, 9, 2, 22859.06112), -- Metallic Fiber
(21430, 4042, 1, 1, 2, 9334.041745), -- Enria
(21430, 960, 1, 1, 2, 223.88821), -- Scroll: Enchant Armor (S-Grade)
(21430, 8732, 1, 1, 2, 4667.20807), -- Life Stone - Level 76
(21430, 8742, 1, 1, 2, 1166.61482), -- Mid-Grade Life Stone - Level 76
(21430, 8752, 1, 1, 2, 116.81124), -- High-Grade Life Stone - Level 76
(21430, 1344, 150, 450, 2, 46670.208725), -- Mithril Arrow
-- Arimanes
(21431, 6704, 1, 1, -1, 184208), -- Sealed Imperial Crusader Boots Design
(21431, 6705, 1, 1, -1, 180432), -- Sealed Imperial Crusader Shield Part
(21431, 6706, 1, 1, -1, 209877), -- Sealed Imperial Crusader Helmet Pattern
(21431, 57, 6381, 13023, 0, 700000), -- Adena
(21431, 12265, 1, 1, 1, 667.174616), -- Common Item - Sealed Leather Armor of Nightmare
(21431, 5480, 1, 1, 1, 5358.825384), -- Sealed Leather Armor of Nightmare Fabric
(21431, 12258, 1, 1, 1, 667.174616), -- Common Item - Sealed Majestic Leather Armor
(21431, 5481, 1, 1, 1, 5358.825384), -- Sealed Majestic Leather Armor Fabric
(21431, 1873, 3, 9, 2, 31847.001606), -- Silver Nugget
(21431, 1868, 4, 12, 2, 119426.146938), -- Thread
(21431, 1876, 1, 1, 2, 95541.004818), -- Mithril Ore
(21431, 1895, 1, 1, 2, 136486.962738), -- Metallic Fiber
(21431, 4042, 1, 1, 2, 7961.859486), -- Enria
(21431, 960, 1, 1, 2, 191.116044), -- Scroll: Enchant Armor (S-Grade)
(21431, 8732, 1, 1, 2, 3980.711574), -- Life Stone - Level 76
(21431, 8742, 1, 1, 2, 995.286978), -- Mid-Grade Life Stone - Level 76
(21431, 8752, 1, 1, 2, 99.485064), -- High-Grade Life Stone - Level 76
(21431, 1344, 150, 450, 2, 39808.424754), -- Mithril Arrow
-- Chakram Beetle
(21432, 5534, 1, 1, -1, 47043), -- Soul Bow Stave
(21432, 1808, 1, 1, -1, 7616), -- Recipe: Soulshot (S-Grade)
(21432, 5537, 1, 1, -1, 47011), -- Soul Separator Head
(21432, 57, 8447, 17245, 0, 700000), -- Adena
(21432, 11967, 1, 1, 1, 562.41108), -- Common Item - Dragon Grinder
(21432, 5538, 1, 1, 1, 8677.58892), -- Dragon Grinder Edge
(21432, 1873, 2, 6, 2, 70298.82743), -- Silver Nugget
(21432, 1868, 15, 45, 2, 46866.04423), -- Thread
(21432, 1876, 1, 1, 2, 140597.65486), -- Mithril Ore
(21432, 1895, 1, 1, 2, 200853.92918), -- Metallic Fiber
(21432, 4042, 1, 1, 2, 11716.3916), -- Enria
(21432, 959, 1, 1, 2, 28.19197), -- Scroll: Enchant Weapon (S-Grade)
(21432, 8732, 1, 1, 2, 5858.1958), -- Life Stone - Level 76
(21432, 8742, 1, 1, 2, 1464.54895), -- Mid-Grade Life Stone - Level 76
(21432, 8752, 1, 1, 2, 146.21598), -- High-Grade Life Stone - Level 76
-- Jamadar Beetle
(21433, 5538, 1, 1, -1, 45528), -- Dragon Grinder Edge
(21433, 5167, 1, 1, -1, 7377), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21433, 5541, 1, 1, -1, 45519), -- Tallum Glaive Edge
(21433, 57, 8184, 16701, 0, 700000), -- Adena
(21433, 12263, 1, 1, 1, 642.38492), -- Common Item - Sealed Armor of Nightmare
(21433, 5522, 1, 1, 1, 5217.61508), -- Sealed Armor of Nightmare Pattern
(21433, 12262, 1, 1, 1, 642.38492), -- Common Item - Sealed Majestic Plate Armor
(21433, 5523, 1, 1, 1, 5217.61508), -- Sealed Majestic Plate Armor Pattern
(21433, 1873, 2, 6, 2, 68095.101971), -- Silver Nugget
(21433, 1868, 15, 45, 2, 45396.888931), -- Thread
(21433, 1876, 1, 1, 2, 136190.203942), -- Mithril Ore
(21433, 1895, 1, 1, 2, 194557.566446), -- Metallic Fiber
(21433, 4042, 1, 1, 2, 11349.10652), -- Enria
(21433, 959, 1, 1, 2, 27.308209), -- Scroll: Enchant Weapon (S-Grade)
(21433, 8732, 1, 1, 2, 5674.55326), -- Life Stone - Level 76
(21433, 8742, 1, 1, 2, 1418.638315), -- Mid-Grade Life Stone - Level 76
(21433, 8752, 1, 1, 2, 141.632406), -- High-Grade Life Stone - Level 76
-- Priest of Blood 
(21434, 1877, 1, 3, -1, 631579), -- Adamantite Nugget
(21434, 6342, 1, 1, -1, 715346), -- Sealed Majestic Earring Gemstone
(21434, 5282, 1, 1, -1, 14035), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21434, 57, 15536, 31822, 0, 700000), -- Adena
(21434, 12265, 1, 1, 1, 1628.466286), -- Common Item - Sealed Leather Armor of Nightmare
(21434, 5480, 1, 1, 1, 13080.033714), -- Sealed Leather Armor of Nightmare Fabric
(21434, 12258, 1, 1, 1, 1628.466286), -- Common Item - Sealed Majestic Leather Armor
(21434, 5481, 1, 1, 1, 13080.033714), -- Sealed Majestic Leather Armor Fabric
(21434, 1871, 4, 12, 2, 161943.435939), -- Charcoal
(21434, 1866, 7, 21, 2, 57580.060248), -- Suede
(21434, 1877, 1, 1, 2, 51821.796352), -- Adamantite Nugget
(21434, 4041, 1, 1, 2, 11265.74805), -- Mold Hardener
(21434, 4040, 1, 1, 2, 25910.898176), -- Mold Lubricant
(21434, 959, 1, 1, 2, 51.896579), -- Scroll: Enchant Weapon (S-Grade)
(21434, 8732, 1, 1, 2, 10796.100127), -- Life Stone - Level 76
(21434, 8742, 1, 1, 2, 2698.944447), -- Mid-Grade Life Stone - Level 76
(21434, 8752, 1, 1, 2, 270.120082), -- High-Grade Life Stone - Level 76
-- Guide of Offering
(21435, 3036, 1, 1, -1, 9095), -- Recipe: Spiritshot S
(21435, 5538, 1, 1, -1, 56130), -- Dragon Grinder Edge
(21435, 1877, 1, 1, -1, 818535), -- Adamantite Nugget
(21435, 57, 10088, 20595, 0, 700000), -- Adena
(21435, 11975, 1, 1, 1, 671.602131), -- Common Item - Soul Bow
(21435, 5534, 1, 1, 1, 10371.397869), -- Soul Bow Stave
(21435, 1871, 9, 27, 2, 41976.180664), -- Charcoal
(21435, 1866, 2, 6, 2, 125928.541992), -- Suede
(21435, 1877, 1, 1, 2, 30222.759754), -- Adamantite Nugget
(21435, 4041, 1, 1, 2, 6570.109062), -- Mold Hardener
(21435, 4040, 1, 1, 2, 15111.54117), -- Mold Lubricant
(21435, 960, 1, 1, 2, 302.263082), -- Scroll: Enchant Armor (S-Grade)
(21435, 8732, 1, 1, 2, 6296.556134), -- Life Stone - Level 76
(21435, 8742, 1, 1, 2, 1574.21968), -- Mid-Grade Life Stone - Level 76
(21435, 8752, 1, 1, 2, 157.421968), -- High-Grade Life Stone - Level 76
(21435, 1344, 100, 300, 2, 94446.406494), -- Mithril Arrow
-- Leader of Offering
(21436, 1894, 1, 1, -1, 744816), -- Crafted Leather
(21436, 5541, 1, 1, -1, 58213), -- Tallum Glaive Edge
(21436, 3957, 1, 1, -1, 9434), -- Recipe: Blessed Spiritshot S
(21436, 57, 10464, 21364, 0, 700000), -- Adena
(21436, 11973, 1, 1, 1, 696.679488), -- Common Item - Soul Separator
(21436, 5537, 1, 1, 1, 10751.320512), -- Soul Separator Head
(21436, 1867, 4, 12, 2, 145143.457173), -- Animal Skin
(21436, 1872, 7, 21, 2, 77409.937913), -- Animal Bone
(21436, 1882, 1, 1, 2, 193524.609564), -- Leather
(21436, 1894, 1, 1, 2, 30556.764898), -- Crafted Leather
(21436, 4042, 1, 1, 2, 14514.392761), -- Enria
(21436, 959, 1, 1, 2, 34.812338), -- Scroll: Enchant Weapon (S-Grade)
(21436, 8732, 1, 1, 2, 7256.961162), -- Life Stone - Level 76
(21436, 8742, 1, 1, 2, 1814.475509), -- Mid-Grade Life Stone - Level 76
(21436, 8752, 1, 1, 2, 181.588682), -- High-Grade Life Stone - Level 76
-- Offering Bug
(21437, 1877, 1, 1, -1, 342037), -- Adamantite Nugget
(21437, 4041, 1, 1, -1, 74356), -- Mold Hardener
(21437, 5544, 1, 1, -1, 23432), -- Branch of the Mother Tree Head
(21437, 57, 4216, 8604, 0, 700000), -- Adena
(21437, 11974, 1, 1, 1, 70.16881), -- Common Item - Elysian
(21437, 5533, 1, 1, 1, 1082.65389), -- Elysian Head
(21437, 11970, 1, 1, 1, 70.16881), -- Common Item - Branch of the Mother Tree
(21437, 5544, 1, 1, 1, 1081.58437), -- Branch of the Mother Tree Head
(21437, 11969, 1, 1, 1, 70.16881), -- Common Item - Flaming Dragon Skull
(21437, 8342, 1, 1, 1, 1082.65389), -- Flaming Dragon Skull Piece
(21437, 11966, 1, 1, 1, 70.16881), -- Common Item - Doom Crusher
(21437, 8349, 1, 1, 1, 1082.43261), -- Doom Crusher Head
(21437, 1871, 1, 3, 2, 105242.258107), -- Charcoal
(21437, 1866, 2, 6, 2, 52621.319235), -- Suede
(21437, 1877, 1, 1, 2, 12629.192689), -- Adamantite Nugget
(21437, 4041, 1, 1, 2, 2745.460134), -- Mold Hardener
(21437, 4040, 1, 1, 2, 6314.406163), -- Mold Lubricant
(21437, 960, 1, 1, 2, 126.280516), -- Scroll: Enchant Armor (S-Grade)
(21437, 8732, 1, 1, 2, 2630.970871), -- Life Stone - Level 76
(21437, 8742, 1, 1, 2, 657.647627), -- Mid-Grade Life Stone - Level 76
(21437, 8752, 1, 1, 2, 65.802799), -- High-Grade Life Stone - Level 76
(21437, 1344, 20, 60, 2, 197329.661859), -- Mithril Arrow
-- Heathen Warrior
(21438, 4077, 1, 1, -1, 27694), -- Doom Shield Fragment
(21438, 6333, 1, 1, -1, 7068), -- Recipe: Sealed Phoenix Ring(70%)
(21438, 4078, 1, 1, -1, 8993), -- Blue Wolf Breastplate Part
(21438, 57, 244, 495, 0, 700000), -- Adena
(21438, 11930, 1, 1, 1, 9.888893), -- Common Item - Sword of Damascus
(21438, 4114, 1, 1, 1, 132.518596), -- Sword of Damascus Blade
(21438, 11929, 1, 1, 1, 9.888893), -- Common Item - Guardian Sword
(21438, 8330, 1, 1, 1, 132.295702), -- Guardian Sword Blade
(21438, 11943, 1, 1, 1, 9.888893), -- Common Item - Wizard's Tear
(21438, 8336, 1, 1, 1, 132.519023), -- Blade of the Wizard's Tear
(21438, 1873, 1, 1, 2, 7273.975644), -- Silver Nugget
(21438, 1868, 1, 1, 2, 36369.87822), -- Thread
(21438, 1876, 1, 1, 2, 3637.014368), -- Mithril Ore
(21438, 1895, 1, 1, 2, 5195.689304), -- Metallic Fiber
(21438, 4042, 1, 1, 2, 303.102228), -- Enria
(21438, 729, 1, 1, 2, 2.017496), -- Scroll: Enchant Weapon (A-Grade)
(21438, 8729, 1, 1, 2, 242.471164), -- Life Stone - Level 64
(21438, 8739, 1, 1, 2, 60.631064), -- Mid-Grade Life Stone - Level 64
(21438, 8749, 1, 1, 2, 6.052488), -- High-Grade Life Stone - Level 64
(21438, 8759, 1, 1, 2, 1.168024), -- Top-Grade Life Stone - Level 64
-- Heathen Executed 
(21439, 4116, 1, 1, -1, 2781), -- Deadman's Glory Stone
(21439, 5276, 1, 1, -1, 848), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21439, 4117, 1, 1, -1, 2781), -- Art of Battle Axe Blade
(21439, 57, 252, 511, 0, 700000), -- Adena
(21439, 11932, 1, 1, 1, 30.719619), -- Common Item - Lance
(21439, 4115, 1, 1, 1, 410.280381), -- Lance Blade
(21439, 1864, 1, 1, 2, 34176.672243), -- Stem
(21439, 1865, 1, 1, 2, 17088.271932), -- Varnish
(21439, 1866, 1, 1, 2, 11392.224081), -- Suede
(21439, 1873, 1, 1, 2, 6835.283097), -- Silver Nugget
(21439, 1868, 1, 1, 2, 34176.672243), -- Thread
(21439, 5456, 1, 1, 2, 6.290571), -- Recipe: Tallum Glaive(60%)
(21439, 8729, 1, 1, 2, 227.872725), -- Life Stone - Level 64
(21439, 8739, 1, 1, 2, 57.000276), -- Mid-Grade Life Stone - Level 64
(21439, 8749, 1, 1, 2, 5.648676), -- High-Grade Life Stone - Level 64
(21439, 8759, 1, 1, 2, 1.155411), -- Top-Grade Life Stone - Level 64
(21439, 1343, 10, 30, 2, 24411.908745), -- Silver Arrow
-- Heathen Archer
(21440, 4040, 1, 1, -1, 13968), -- Mold Lubricant
(21440, 1875, 1, 1, -1, 46559), -- Stone of Purity
(21440, 4099, 1, 1, -1, 31353), -- Sealed Doom Boots Part
(21440, 57, 275, 563, 0, 700000), -- Adena
(21440, 12201, 1, 1, 1, 45.76971), -- Common Item - Blue Wolf Tunic
(21440, 4084, 1, 1, 1, 448.23737), -- Blue Wolf Tunic Fabric
(21440, 12192, 1, 1, 1, 45.76971), -- Common Item - Tunic of Doom
(21440, 4085, 1, 1, 1, 448.23737), -- Tunic of Doom Pattern
(21440, 12203, 1, 1, 1, 73.27187), -- Common Item - Blue Wolf Stockings
(21440, 4086, 1, 1, 1, 605.22105), -- Blue Wolf Stockings Pattern
(21440, 12205, 1, 1, 1, 73.27187), -- Common Item - Stockings of Doom
(21440, 4087, 1, 1, 1, 605.22105), -- Stockings of Doom Pattern
(21440, 1865, 1, 1, 2, 18753.903808), -- Varnish
(21440, 1870, 1, 1, 2, 18753.903808), -- Coal
(21440, 1879, 1, 1, 2, 3125.627505), -- Cokes
(21440, 1875, 1, 1, 2, 1250.251002), -- Stone of Purity
(21440, 4040, 1, 1, 2, 375.047545), -- Mold Lubricant
(21440, 6335, 1, 1, 2, 72.16456), -- Recipe: Sealed Majestic Necklace(70%)
(21440, 8730, 1, 1, 2, 208.375167), -- Life Stone - Level 67
(21440, 8740, 1, 1, 2, 52.111139), -- Mid-Grade Life Stone - Level 67
(21440, 8750, 1, 1, 2, 5.204175), -- High-Grade Life Stone - Level 67
(21440, 8760, 1, 1, 2, 1.040835), -- Top-Grade Life Stone - Level 67
(21440, 1343, 10, 30, 2, 26791.370456), -- Silver Arrow
-- Heathen Grunt
(21441, 5448, 1, 1, -1, 252), -- Recipe: Soul Separator(60%)
(21441, 5494, 1, 1, -1, 14265), -- Sealed Dark Crystal Shield Fragment
(21441, 729, 1, 1, -1, 75), -- Scroll: Enchant Weapon (A-Grade)
(21441, 57, 269, 546, 0, 700000), -- Adena
(21441, 11946, 1, 1, 1, 6.911711), -- Common Item - Dasparion's Staff
(21441, 5543, 1, 1, 1, 85.464024), -- Dasparion's Staff Head
(21441, 11949, 1, 1, 1, 6.911711), -- Common Item - Meteor Shower
(21441, 5532, 1, 1, 1, 84.665799), -- Meteor Shower Head
(21441, 11953, 1, 1, 1, 6.911711), -- Common Item - Spiritual Eye
(21441, 8341, 1, 1, 1, 84.557534), -- Spiritual Eye Piece
(21441, 11958, 1, 1, 1, 6.911711), -- Common Item - Destroyer Hammer
(21441, 8346, 1, 1, 1, 84.665799), -- Hammer Piece of Destroyer
(21441, 1870, 1, 1, 2, 18239.901705), -- Coal
(21441, 1865, 1, 1, 2, 18239.901705), -- Varnish
(21441, 1874, 1, 1, 2, 1215.9804), -- Oriharukon Ore
(21441, 4043, 1, 1, 2, 607.9902), -- Asofe
(21441, 4039, 1, 1, 2, 607.9902), -- Mold Glue
(21441, 5442, 1, 1, 2, 6.78444), -- Recipe: Soul Bow(60%)
(21441, 8730, 1, 1, 2, 202.685145), -- Life Stone - Level 67
(21441, 8740, 1, 1, 2, 50.687595), -- Mid-Grade Life Stone - Level 67
(21441, 8750, 1, 1, 2, 5.08833), -- High-Grade Life Stone - Level 67
(21441, 8760, 1, 1, 2, 1.04376), -- Top-Grade Life Stone - Level 67
(21441, 1343, 10, 30, 2, 26056.94652), -- Silver Arrow
-- Heathen Knight
(21442, 5448, 1, 1, -1, 260), -- Recipe: Soul Separator(60%)
(21442, 6341, 1, 1, -1, 19393), -- Sealed Phoenix Earring Gemstone
(21442, 729, 1, 1, -1, 78), -- Scroll: Enchant Weapon (A-Grade)
(21442, 57, 278, 563, 0, 700000), -- Adena
(21442, 11946, 1, 1, 1, 7.118874), -- Common Item - Dasparion's Staff
(21442, 5543, 1, 1, 1, 88.025616), -- Dasparion's Staff Head
(21442, 11949, 1, 1, 1, 7.118874), -- Common Item - Meteor Shower
(21442, 5532, 1, 1, 1, 87.203466), -- Meteor Shower Head
(21442, 11953, 1, 1, 1, 7.118874), -- Common Item - Spiritual Eye
(21442, 8341, 1, 1, 1, 87.091956), -- Spiritual Eye Piece
(21442, 11958, 1, 1, 1, 7.118874), -- Common Item - Destroyer Hammer
(21442, 8346, 1, 1, 1, 87.203466), -- Hammer Piece of Destroyer
(21442, 1870, 1, 1, 2, 17258.6366), -- Coal
(21442, 1865, 1, 1, 2, 17258.6366), -- Varnish
(21442, 1874, 1, 1, 2, 1150.555195), -- Oriharukon Ore
(21442, 4043, 1, 1, 2, 575.308465), -- Asofe
(21442, 4039, 1, 1, 2, 575.308465), -- Mold Glue
(21442, 5450, 1, 1, 2, 6.42044), -- Recipe: Dragon Grinder(60%)
(21442, 8487, 1, 1, 2, 9.445455), -- Recipe: Destroyer Hammer (60%)
(21442, 8730, 1, 1, 2, 191.74891), -- Life Stone - Level 67
(21442, 8740, 1, 1, 2, 47.968095), -- Mid-Grade Life Stone - Level 67
(21442, 8750, 1, 1, 2, 4.81533), -- High-Grade Life Stone - Level 67
(21442, 8760, 1, 1, 2, 0.98776), -- Top-Grade Life Stone - Level 67
(21442, 1343, 10, 30, 2, 24655.168685), -- Silver Arrow
-- Raider of Pastureland
(21443, 4077, 1, 1, -1, 129349), -- Doom Shield Fragment
(21443, 3956, 1, 1, -1, 3834), -- Recipe: Blessed Spiritshot A
(21443, 4078, 1, 1, -1, 42002), -- Blue Wolf Breastplate Part
(21443, 57, 1140, 2309, 0, 700000), -- Adena
(21443, 12204, 1, 1, 1, 188.500962), -- Common Item - Blue Wolf Breastplate
(21443, 4078, 1, 1, 1, 2067.807105), -- Blue Wolf Breastplate Part
(21443, 12184, 1, 1, 1, 116.031201), -- Common Item - Doom Plate Armor
(21443, 4081, 1, 1, 1, 1395.250584), -- Doom Plate Armor Temper
(21443, 12193, 1, 1, 1, 301.516371), -- Common Item - Blue Wolf Gaiters
(21443, 4080, 1, 1, 1, 2911.893777), -- Blue Wolf Gaiters Material
(21443, 1872, 1, 1, 2, 102952.605825), -- Animal Bone
(21443, 1867, 1, 1, 2, 102952.605825), -- Animal Skin
(21443, 1881, 1, 1, 2, 10295.427456), -- Coarse Bone Powder
(21443, 1875, 1, 1, 2, 5147.713728), -- Stone of Purity
(21443, 4041, 1, 1, 2, 671.498964), -- Mold Hardener
(21443, 5156, 1, 1, 2, 102.794076), -- Recipe: Soulshot (A) Compressed Package (100%)
(21443, 8729, 1, 1, 2, 1029.609495), -- Life Stone - Level 64
(21443, 8739, 1, 1, 2, 257.318937), -- Mid-Grade Life Stone - Level 64
(21443, 8749, 1, 1, 2, 25.698519), -- High-Grade Life Stone - Level 64
(21443, 8759, 1, 1, 2, 5.006205), -- Top-Grade Life Stone - Level 64
(21443, 1343, 10, 30, 2, 110306.72097), -- Silver Arrow
-- Raider of Pastureland
(21444, 4077, 1, 1, -1, 108697), -- Doom Shield Fragment
(21444, 3956, 1, 1, -1, 3222), -- Recipe: Blessed Spiritshot A
(21444, 4078, 1, 1, -1, 35296), -- Blue Wolf Breastplate Part
(21444, 57, 958, 1940, 0, 700000), -- Adena
(21444, 12204, 1, 1, 1, 158.393732), -- Common Item - Blue Wolf Breastplate
(21444, 4078, 1, 1, 1, 1737.53853), -- Blue Wolf Breastplate Part
(21444, 12184, 1, 1, 1, 97.498786), -- Common Item - Doom Plate Armor
(21444, 4081, 1, 1, 1, 1172.402224), -- Doom Plate Armor Temper
(21444, 12193, 1, 1, 1, 253.358406), -- Common Item - Blue Wolf Gaiters
(21444, 4080, 1, 1, 1, 2446.808322), -- Blue Wolf Gaiters Material
(21444, 1872, 1, 1, 2, 86514.8985), -- Animal Bone
(21444, 1867, 1, 1, 2, 86514.8985), -- Animal Skin
(21444, 1881, 1, 1, 2, 8651.63008), -- Coarse Bone Powder
(21444, 1875, 1, 1, 2, 4325.81504), -- Stone of Purity
(21444, 4041, 1, 1, 2, 564.28552), -- Mold Hardener
(21444, 5156, 1, 1, 2, 86.38168), -- Recipe: Soulshot (A) Compressed Package (100%)
(21444, 8729, 1, 1, 2, 865.2191), -- Life Stone - Level 64
(21444, 8739, 1, 1, 2, 216.23466), -- Mid-Grade Life Stone - Level 64
(21444, 8749, 1, 1, 2, 21.59542), -- High-Grade Life Stone - Level 64
(21444, 8759, 1, 1, 2, 4.2069), -- Top-Grade Life Stone - Level 64
(21444, 1343, 10, 30, 2, 92694.8346), -- Silver Arrow
-- Alpine Bandersnatch
(21445, 5460, 1, 1, -1, 1366), -- Recipe: Dasparion's Staff(60%)
(21445, 4118, 1, 1, -1, 10349), -- Evil Spirit Head
(21445, 1875, 1, 1, -1, 166644), -- Stone of Purity
(21445, 57, 992, 2007, 0, 700000), -- Adena
(21445, 11930, 1, 1, 1, 40.204024), -- Common Item - Sword of Damascus
(21445, 4114, 1, 1, 1, 538.764128), -- Sword of Damascus Blade
(21445, 11929, 1, 1, 1, 40.204024), -- Common Item - Guardian Sword
(21445, 8330, 1, 1, 1, 537.857936), -- Guardian Sword Blade
(21445, 11943, 1, 1, 1, 40.204024), -- Common Item - Wizard's Tear
(21445, 8336, 1, 1, 1, 538.765864), -- Blade of the Wizard's Tear
(21445, 1865, 1, 1, 2, 73836.191018), -- Varnish
(21445, 1870, 1, 1, 2, 73836.191018), -- Coal
(21445, 1879, 1, 1, 2, 12306.003826), -- Cokes
(21445, 1875, 1, 1, 2, 4922.367918), -- Stone of Purity
(21445, 4040, 1, 1, 2, 1476.760794), -- Mold Lubricant
(21445, 6329, 1, 1, 2, 424.35655), -- Recipe: Sealed Phoenix Necklace(70%)
(21445, 8729, 1, 1, 2, 984.507196), -- Life Stone - Level 64
(21445, 8739, 1, 1, 2, 246.042768), -- Mid-Grade Life Stone - Level 64
(21445, 8749, 1, 1, 2, 24.537052), -- High-Grade Life Stone - Level 64
(21445, 8759, 1, 1, 2, 5.04186), -- Top-Grade Life Stone - Level 64
-- Raider of Pastureland
(21446, 1885, 1, 1, -1, 256299), -- High-Grade Suede
(21446, 4119, 1, 1, -1, 13462), -- Demon's Dagger Edge
(21446, 5468, 1, 1, -1, 1681), -- Recipe: Elemental Sword(60%)
(21446, 57, 1221, 2470, 0, 700000), -- Adena
(21446, 11935, 1, 1, 1, 49.445664), -- Common Item - Deadman's Glory
(21446, 4116, 1, 1, 1, 661.476322), -- Deadman's Glory Stone
(21446, 11938, 1, 1, 1, 49.445664), -- Common Item - Art of Battle Axe
(21446, 4117, 1, 1, 1, 661.476322), -- Art of Battle Axe Blade
(21446, 11934, 1, 1, 1, 49.445664), -- Common Item - Staff of Evil Spirits
(21446, 4118, 1, 1, 1, 626.710364), -- Evil Spirit Head
(21446, 1866, 1, 1, 2, 55059.359308), -- Suede
(21446, 1871, 1, 1, 2, 82589.038962), -- Charcoal
(21446, 5220, 1, 1, 2, 3303.4971), -- Metal Hardener
(21446, 1885, 1, 1, 2, 6882.554202), -- High-Grade Suede
(21446, 4041, 1, 1, 2, 718.174898), -- Mold Hardener
(21446, 6331, 1, 1, 2, 630.350219), -- Recipe: Sealed Phoenix Earring(70%)
(21446, 8729, 1, 1, 2, 1101.1657), -- Life Stone - Level 64
(21446, 8739, 1, 1, 2, 275.291425), -- Mid-Grade Life Stone - Level 64
(21446, 8749, 1, 1, 2, 27.663431), -- High-Grade Life Stone - Level 64
(21446, 8759, 1, 1, 2, 5.640117), -- Top-Grade Life Stone - Level 64
(21446, 1343, 10, 30, 2, 117984.264638), -- Silver Arrow
-- Raider of Pastureland
(21447, 5281, 1, 1, -1, 4242), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21447, 4118, 1, 1, -1, 13173), -- Evil Spirit Head
(21447, 4052, 1, 1, -1, 112651), -- Earring of Black Ore Piece
(21447, 57, 1260, 2556, 0, 700000), -- Adena
(21447, 12183, 1, 1, 1, 795.15921), -- Common Item - Doom Shield
(21447, 4077, 1, 1, 1, 7046.63529), -- Doom Shield Fragment
(21447, 12202, 1, 1, 1, 556.4742), -- Common Item - Blue Wolf Helmet
(21447, 4088, 1, 1, 1, 5920.12855), -- Blue Wolf Helmet Design
(21447, 12185, 1, 1, 1, 556.4742), -- Common Item - Doom Helmet
(21447, 4089, 1, 1, 1, 5920.12855), -- Doom Helmet Pattern
(21447, 1869, 1, 1, 2, 93985.86024), -- Iron Ore
(21447, 1870, 1, 1, 2, 93985.86024), -- Coal
(21447, 1871, 1, 1, 2, 93985.86024), -- Charcoal
(21447, 1872, 1, 3, 2, 62657.24016), -- Animal Bone
(21447, 1867, 1, 1, 2, 125314.48032), -- Animal Skin
(21447, 5462, 1, 1, 2, 34.896032), -- Recipe: Branch of the Mother Tree(60%)
(21447, 8729, 1, 1, 2, 1252.956176), -- Life Stone - Level 64
(21447, 8739, 1, 1, 2, 313.121152), -- Mid-Grade Life Stone - Level 64
(21447, 8749, 1, 1, 2, 31.123488), -- High-Grade Life Stone - Level 64
(21447, 8759, 1, 1, 2, 6.601952), -- Top-Grade Life Stone - Level 64
-- Raider of Pastureland
(21448, 5281, 1, 1, -1, 5348), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21448, 4118, 1, 1, -1, 16605), -- Evil Spirit Head
(21448, 57, 1059, 2148, 0, 700000), -- Adena
(21448, 12183, 1, 1, 1, 668.170812), -- Common Item - Doom Shield
(21448, 4077, 1, 1, 1, 5921.274588), -- Doom Shield Fragment
(21448, 12202, 1, 1, 1, 467.60424), -- Common Item - Blue Wolf Helmet
(21448, 4088, 1, 1, 1, 4974.67306), -- Blue Wolf Helmet Design
(21448, 12185, 1, 1, 1, 467.60424), -- Common Item - Doom Helmet
(21448, 4089, 1, 1, 1, 4974.67306), -- Doom Helmet Pattern
(21448, 1869, 1, 1, 2, 78979.630041), -- Iron Ore
(21448, 1870, 1, 1, 2, 78979.630041), -- Coal
(21448, 1871, 1, 1, 2, 78979.630041), -- Charcoal
(21448, 1872, 1, 1, 2, 105306.173388), -- Animal Bone
(21448, 1867, 1, 1, 2, 105306.173388), -- Animal Skin
(21448, 5462, 1, 1, 2, 29.180385), -- Recipe: Branch of the Mother Tree(60%)
(21448, 8729, 1, 1, 2, 1053.187434), -- Life Stone - Level 64
(21448, 8739, 1, 1, 2, 263.072394), -- Mid-Grade Life Stone - Level 64
(21448, 8749, 1, 1, 2, 26.486811), -- High-Grade Life Stone - Level 64
(21448, 8759, 1, 1, 2, 5.836077), -- Top-Grade Life Stone - Level 64
-- Raider of Pastureland
(21449, 4041, 1, 1, -1, 30535), -- Mold Hardener
(21449, 4040, 1, 1, -1, 70231), -- Mold Lubricant
(21449, 5496, 1, 1, -1, 82334), -- Sealed Dark Crystal Boots Lining
(21449, 57, 1389, 2824, 0, 700000), -- Adena
(21449, 11950, 1, 1, 1, 142.796808), -- Common Item - Blood Tornado
(21449, 5539, 1, 1, 1, 1749.203192), -- Blood Tornado Edge
(21449, 1871, 1, 1, 2, 103726.047588), -- Charcoal
(21449, 1866, 1, 1, 2, 69150.698392), -- Suede
(21449, 1877, 1, 1, 2, 4149.092728), -- Adamantite Nugget
(21449, 4041, 1, 1, 2, 901.953004), -- Mold Hardener
(21449, 4040, 1, 1, 2, 2074.546364), -- Mold Lubricant
(21449, 5448, 1, 1, 2, 38.481392), -- Recipe: Soul Separator(60%)
(21449, 8730, 1, 1, 2, 1152.445084), -- Life Stone - Level 67
(21449, 8740, 1, 1, 2, 288.065892), -- Mid-Grade Life Stone - Level 67
(21449, 8750, 1, 1, 2, 28.861044), -- High-Grade Life Stone - Level 67
(21449, 8760, 1, 1, 2, 5.808512), -- Top-Grade Life Stone - Level 67
-- Alpine Grendel
(21450, 5450, 1, 1, -1, 1258), -- Recipe: Dragon Grinder(60%)
(21450, 5497, 1, 1, -1, 79631), -- Sealed Tallum Boots Lining
(21450, 5456, 1, 1, -1, 1258), -- Recipe: Tallum Glaive(60%)
(21450, 57, 1343, 2731, 0, 700000), -- Adena
(21450, 11955, 1, 1, 1, 138.1173), -- Common Item - Carnage Bow
(21450, 5535, 1, 1, 1, 1711.8827), -- Carnage Bow Stave
(21450, 1872, 1, 1, 2, 121600.00595), -- Animal Bone
(21450, 1867, 1, 1, 2, 121600.00595), -- Animal Skin
(21450, 1881, 1, 1, 2, 12160.11875), -- Coarse Bone Powder
(21450, 1875, 1, 1, 2, 6079.86245), -- Stone of Purity
(21450, 4041, 1, 1, 2, 793.2139), -- Mold Hardener
(21450, 5450, 1, 1, 2, 33.8711), -- Recipe: Dragon Grinder(60%)
(21450, 8730, 1, 1, 2, 1013.37605), -- Life Stone - Level 67
(21450, 8740, 1, 1, 2, 253.24555), -- Mid-Grade Life Stone - Level 67
(21450, 8750, 1, 1, 2, 25.2064), -- High-Grade Life Stone - Level 67
(21450, 8760, 1, 1, 2, 5.12005), -- Top-Grade Life Stone - Level 67
(21450, 1343, 10, 30, 2, 130285.97385), -- Silver Arrow
-- Alpine Kookaburra
(21451, 1807, 1, 1, -1, 1522), -- Recipe: Soulshot (A-Grade)
(21451, 4080, 1, 1, -1, 23474), -- Blue Wolf Gaiters Material
(21451, 4041, 1, 1, -1, 9924), -- Mold Hardener
(21451, 57, 452, 917, 0, 700000), -- Adena
(21451, 11935, 1, 1, 1, 18.359472), -- Common Item - Deadman's Glory
(21451, 4116, 1, 1, 1, 245.610131), -- Deadman's Glory Stone
(21451, 11938, 1, 1, 1, 18.359472), -- Common Item - Art of Battle Axe
(21451, 4117, 1, 1, 1, 245.610131), -- Art of Battle Axe Blade
(21451, 11934, 1, 1, 1, 18.359472), -- Common Item - Staff of Evil Spirits
(21451, 4118, 1, 1, 1, 232.701322), -- Evil Spirit Head
(21451, 1866, 1, 1, 2, 20430.000432), -- Suede
(21451, 1871, 1, 1, 2, 30645.000648), -- Charcoal
(21451, 5220, 1, 1, 2, 1225.796048), -- Metal Hardener
(21451, 1885, 1, 1, 2, 2553.725192), -- High-Grade Suede
(21451, 4041, 1, 1, 2, 266.52064), -- Mold Hardener
(21451, 730, 1, 1, 2, 25.558136), -- Scroll: Enchant Armor (A-Grade)
(21451, 8729, 1, 1, 2, 408.631832), -- Life Stone - Level 64
(21451, 8739, 1, 1, 2, 102.133096), -- Mid-Grade Life Stone - Level 64
(21451, 8749, 1, 1, 2, 10.243144), -- High-Grade Life Stone - Level 64
(21451, 8759, 1, 1, 2, 2.088408), -- Top-Grade Life Stone - Level 64
(21451, 1343, 10, 30, 2, 43778.302424), -- Silver Arrow
-- Alpine Kookaburra
(21452, 1875, 1, 1, -1, 164372), -- Stone of Purity
(21452, 4081, 1, 1, -1, 24301), -- Doom Plate Armor Temper
(21452, 3035, 1, 1, -1, 3287), -- Recipe: Spiritshot A
(21452, 57, 981, 1985, 0, 700000), -- Adena
-- Alpine Kookaburra
(21453, 4082, 1, 1, -1, 23411), -- Blue Wolf Leather Armor Texture
(21453, 3956, 1, 1, -1, 2763), -- Recipe: Blessed Spiritshot A
(21453, 4083, 1, 1, -1, 23411), -- Leather Armor of Doom Design
(21453, 57, 824, 1668, 0, 700000), -- Adena
-- Alpine Kookaburra
(21454, 1884, 1, 3, -1, 758639), -- Cord
(21454, 1889, 1, 1, -1, 164372), -- Compound Braid
(21454, 4084, 1, 1, -1, 42850), -- Blue Wolf Tunic Fabric
(21454, 57, 981, 1985, 0, 700000), -- Adena
-- Alpine Kookaburra
(21455, 5156, 1, 1, -1, 2763), -- Recipe: Soulshot (A) Compressed Package (100%)
(21455, 4085, 1, 1, -1, 36008), -- Tunic of Doom Pattern
(21455, 5161, 1, 1, -1, 2763), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21455, 57, 824, 1668, 0, 700000), -- Adena
-- Alpine Kookaburra
(21456, 4086, 1, 1, -1, 70817), -- Blue Wolf Stockings Pattern
(21456, 1884, 1, 3, -1, 928569), -- Cord
(21456, 4039, 1, 1, -1, 100595), -- Mold Glue
(21456, 11935, 1, 1, 0, 48.526512), -- Common Item - Deadman's Glory
(21456, 4116, 1, 1, 0, 649.180051), -- Deadman's Glory Stone
(21456, 11938, 1, 1, 0, 48.526512), -- Common Item - Art of Battle Axe
(21456, 4117, 1, 1, 0, 649.180051), -- Art of Battle Axe Blade
(21456, 11934, 1, 1, 0, 48.526512), -- Common Item - Staff of Evil Spirits
(21456, 4118, 1, 1, 0, 615.060362), -- Evil Spirit Head
(21456, 1864, 1, 1, 1, 178285.32282), -- Stem
(21456, 1869, 1, 1, 1, 89142.842644), -- Iron Ore
(21456, 1878, 1, 1, 1, 35657.064564), -- Braided Hemp
(21456, 1884, 1, 1, 1, 54856.994524), -- Cord
(21456, 4039, 1, 1, 1, 2971.512664), -- Mold Glue
(21456, 5450, 1, 1, 1, 32.984588), -- Recipe: Dragon Grinder(60%)
(21456, 8729, 1, 1, 1, 1188.532572), -- Life Stone - Level 64
(21456, 8739, 1, 1, 1, 297.22376), -- Mid-Grade Life Stone - Level 64
(21456, 8749, 1, 1, 1, 29.722376), -- High-Grade Life Stone - Level 64
(21456, 8759, 1, 1, 1, 5.799488), -- Top-Grade Life Stone - Level 64
-- Alpine Kookaburra
(21457, 4087, 1, 1, -1, 59510), -- Stockings of Doom Pattern
(21457, 5166, 1, 1, -1, 3381), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21457, 4088, 1, 1, -1, 95843), -- Blue Wolf Helmet Design
(21457, 12341, 1, 1, 0, 579.36816), -- Common Item - Earring of Black Ore
(21457, 4052, 1, 1, 0, 4420.414656), -- Earring of Black Ore Piece
(21457, 12342, 1, 1, 0, 434.282688), -- Common Item - Necklace of Black Ore
(21457, 4054, 1, 1, 0, 2459.213568), -- Necklace of Black Ore Beads
(21457, 12343, 1, 1, 0, 867.04128), -- Common Item - Ring of Black Ore
(21457, 4053, 1, 1, 0, 5351.679648), -- Ring of Black Ore Gemstone
(21457, 1866, 1, 1, 1, 45399.926332), -- Suede
(21457, 1871, 1, 1, 1, 68099.99998), -- Charcoal
(21457, 5220, 1, 1, 1, 2724.044192), -- Metal Hardener
(21457, 1885, 1, 1, 1, 5675.018412), -- High-Grade Suede
(21457, 4041, 1, 1, 1, 592.18352), -- Mold Hardener
(21457, 5456, 1, 1, 1, 25.189896), -- Recipe: Tallum Glaive(60%)
(21457, 8729, 1, 1, 1, 907.941076), -- Life Stone - Level 64
(21457, 8739, 1, 1, 1, 226.930028), -- Mid-Grade Life Stone - Level 64
(21457, 8749, 1, 1, 1, 22.759292), -- High-Grade Life Stone - Level 64
(21457, 8759, 1, 1, 1, 4.640244), -- Top-Grade Life Stone - Level 64
(21457, 1343, 10, 30, 1, 97285.367028), -- Silver Arrow
-- Alpine Kookaburra
(21458, 5230, 1, 1, -1, 4024), -- Recipe: Mithril Arrow (100%)
(21458, 4089, 1, 1, -1, 114053), -- Doom Helmet Pattern
(21458, 4041, 1, 1, -1, 26242), -- Mold Hardener
(21458, 12188, 1, 1, 0, 592.716023), -- Common Item - Sealed Doom Boots
(21458, 4099, 1, 1, 0, 5002.533977), -- Sealed Doom Boots Part
(21458, 12189, 1, 1, 0, 592.716023), -- Common Item - Sealed Blue Wolf Boots
(21458, 4090, 1, 1, 0, 5002.533977), -- Sealed Blue Wolf Boots Design
(21458, 12187, 1, 1, 0, 592.716023), -- Common Item - Sealed Doom Gloves
(21458, 4091, 1, 1, 0, 5002.533977), -- Sealed Doom Gloves Part
(21458, 12190, 1, 1, 0, 592.716023), -- Common Item - Sealed Blue Wolf Gloves
(21458, 4096, 1, 1, 0, 5002.533977), -- Sealed Blue Wolf Gloves Fabric
(21458, 1871, 1, 1, 1, 81038.626932), -- Charcoal
(21458, 1866, 1, 1, 1, 54025.798869), -- Suede
(21458, 1877, 1, 1, 1, 3241.550787), -- Adamantite Nugget
(21458, 4041, 1, 1, 1, 704.722191), -- Mold Hardener
(21458, 4040, 1, 1, 1, 1620.704022), -- Mold Lubricant
(21458, 5462, 1, 1, 1, 29.97603), -- Recipe: Branch of the Mother Tree(60%)
(21458, 5370, 1, 1, 1, 698.584242), -- Recipe: Sealed Tallum Boots(60%)
(21458, 8729, 1, 1, 1, 1080.56451), -- Life Stone - Level 64
(21458, 8739, 1, 1, 1, 270.069756), -- Mid-Grade Life Stone - Level 64
(21458, 8749, 1, 1, 1, 26.978427), -- High-Grade Life Stone - Level 64
(21458, 8759, 1, 1, 1, 5.424234), -- Top-Grade Life Stone - Level 64
-- Alpine Kookaburra
(21459, 1894, 1, 1, -1, 88983), -- Crafted Leather
(21459, 4090, 1, 1, -1, 113850), -- Sealed Blue Wolf Boots Design
(21459, 5271, 1, 1, -1, 3381), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21459, 11933, 1, 1, 0, 122.33845), -- Common Item - Bellion Cestus
(21459, 4120, 1, 1, 0, 1636.66155), -- Bellion Cestus Edge
(21459, 1867, 1, 1, 1, 83233.038942), -- Animal Skin
(21459, 1872, 1, 1, 1, 83233.038942), -- Animal Bone
(21459, 1882, 1, 1, 1, 13872.081708), -- Leather
(21459, 1894, 1, 1, 1, 2190.386448), -- Crafted Leather
(21459, 4042, 1, 1, 1, 1040.323824), -- Enria
(21459, 5464, 1, 1, 1, 23.045148), -- Recipe: Dark Legion's Edge(60%)
(21459, 5364, 1, 1, 1, 511.657155), -- Recipe: Sealed Dark Crystal Shield(60%)
(21459, 8729, 1, 1, 1, 832.368798), -- Life Stone - Level 64
(21459, 8739, 1, 1, 1, 207.955026), -- Mid-Grade Life Stone - Level 64
(21459, 8749, 1, 1, 1, 20.850372), -- High-Grade Life Stone - Level 64
(21459, 8759, 1, 1, 1, 4.115205), -- Top-Grade Life Stone - Level 64
(21459, 1343, 10, 30, 1, 89178.138432), -- Silver Arrow
-- Alpine Kookaburra
(21460, 4091, 1, 1, -1, 231933), -- Sealed Doom Gloves Part
(21460, 5276, 1, 1, -1, 6888), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21460, 4096, 1, 1, -1, 231933), -- Sealed Blue Wolf Gloves Fabric
(21460, 57, 2055, 4158, 0, 700000), -- Adena
-- Alpine Kookaburra
(21461, 4042, 1, 1, -1, 89502), -- Enria
(21461, 1876, 1, 3, -1, 537011), -- Mithril Ore
(21461, 4099, 1, 1, -1, 241083), -- Sealed Doom Boots Part
(21461, 57, 2136, 4322, 0, 700000), -- Adena
-- Alpine Kookaburra
(21462, 5281, 1, 1, -1, 6888), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21462, 4114, 1, 1, -1, 22614), -- Sword of Damascus Blade
(21462, 5438, 1, 1, -1, 2823), -- Recipe: Meteor Shower(60%)
(21462, 57, 2055, 4158, 0, 700000), -- Adena
-- Alpine Kookaburra
(21463, 4115, 1, 1, -1, 21675), -- Lance Blade
(21463, 4041, 1, 1, -1, 43205), -- Mold Hardener
(21463, 1875, 1, 1, -1, 331238), -- Stone of Purity
(21463, 57, 1976, 3999, 0, 700000), -- Adena
-- Alpine Kookaburra
(21464, 4116, 1, 1, -1, 27632), -- Deadman's Glory Stone
(21464, 5444, 1, 1, -1, 3455), -- Recipe: Carnage Bow(60%)
(21464, 4117, 1, 1, -1, 27632), -- Art of Battle Axe Blade
(21464, 11935, 1, 1, 0, 101.69592), -- Common Item - Deadman's Glory
(21464, 4116, 1, 1, 0, 1360.472035), -- Deadman's Glory Stone
(21464, 11938, 1, 1, 0, 101.69592), -- Common Item - Art of Battle Axe
(21464, 4117, 1, 1, 0, 1360.472035), -- Art of Battle Axe Blade
(21464, 11934, 1, 1, 0, 101.69592), -- Common Item - Staff of Evil Spirits
(21464, 4118, 1, 1, 0, 1288.96817), -- Evil Spirit Head
(21464, 1867, 1, 3, 1, 124524.651092), -- Animal Skin
(21464, 1872, 1, 1, 1, 249049.302184), -- Animal Bone
(21464, 1882, 1, 1, 1, 41508.074378), -- Leather
(21464, 1894, 1, 1, 1, 6553.748812), -- Crafted Leather
(21464, 4042, 1, 1, 1, 3112.966492), -- Enria
(21464, 729, 1, 1, 1, 20.541984), -- Scroll: Enchant Weapon (A-Grade)
(21464, 8729, 1, 1, 1, 2490.287602), -- Life Stone - Level 64
(21464, 8739, 1, 1, 1, 622.67889), -- Mid-Grade Life Stone - Level 64
(21464, 8749, 1, 1, 1, 62.05391), -- High-Grade Life Stone - Level 64
(21464, 8759, 1, 1, 1, 13.694656), -- Top-Grade Life Stone - Level 64
-- Alpine Kookaburra
(21465, 5446, 1, 1, -1, 3592), -- Recipe: Bloody Orchid(60%)
(21465, 4118, 1, 1, -1, 27213), -- Evil Spirit Head
(21465, 5220, 1, 1, -1, 262919), -- Metal Hardener
(21465, 12341, 1, 1, 0, 1501.586625), -- Common Item - Earring of Black Ore
(21465, 4052, 1, 1, 0, 11456.67985), -- Earring of Black Ore Piece
(21465, 12342, 1, 1, 0, 1125.55905), -- Common Item - Necklace of Black Ore
(21465, 4054, 1, 1, 0, 6373.7058), -- Necklace of Black Ore Beads
(21465, 12343, 1, 1, 0, 2247.168), -- Common Item - Ring of Black Ore
(21465, 4053, 1, 1, 0, 13870.300675), -- Ring of Black Ore Gemstone
(21465, 1874, 1, 1, 1, 10786.421376), -- Oriharukon Ore
(21465, 1878, 1, 1, 1, 64718.956017), -- Braided Hemp
(21465, 1884, 1, 1, 1, 99567.361404), -- Cord
(21465, 1889, 1, 1, 1, 10786.421376), -- Compound Braid
(21465, 5220, 1, 1, 1, 6472.02393), -- Metal Hardener
(21465, 730, 1, 1, 1, 134.744715), -- Scroll: Enchant Armor (A-Grade)
(21465, 5370, 1, 1, 1, 1394.928621), -- Recipe: Sealed Tallum Boots(60%)
(21465, 8729, 1, 1, 1, 2157.198723), -- Life Stone - Level 64
(21465, 8739, 1, 1, 1, 539.406621), -- Mid-Grade Life Stone - Level 64
(21465, 8749, 1, 1, 1, 53.897886), -- High-Grade Life Stone - Level 64
(21465, 8759, 1, 1, 1, 10.694025), -- Top-Grade Life Stone - Level 64
(21465, 1343, 10, 30, 1, 231138.945306), -- Silver Arrow
-- Alpine Kookaburra
(21466, 4042, 1, 1, -1, 105392), -- Enria
(21466, 4119, 1, 1, -1, 27679), -- Demon's Dagger Edge
(21466, 5452, 1, 1, -1, 3455), -- Recipe: Blood Tornado(60%)
(21466, 12188, 1, 1, 0, 1241.946768), -- Common Item - Sealed Doom Boots
(21466, 4099, 1, 1, 0, 10482.053232), -- Sealed Doom Boots Part
(21466, 12189, 1, 1, 0, 1241.946768), -- Common Item - Sealed Blue Wolf Boots
(21466, 4090, 1, 1, 0, 10482.053232), -- Sealed Blue Wolf Boots Design
(21466, 12187, 1, 1, 0, 1241.946768), -- Common Item - Sealed Doom Gloves
(21466, 4091, 1, 1, 0, 10482.053232), -- Sealed Doom Gloves Part
(21466, 12190, 1, 1, 0, 1241.946768), -- Common Item - Sealed Blue Wolf Gloves
(21466, 4096, 1, 1, 0, 10482.053232), -- Sealed Blue Wolf Gloves Fabric
(21466, 1867, 1, 3, 1, 113204.20656), -- Animal Skin
(21466, 1872, 1, 1, 1, 226408.02256), -- Animal Bone
(21466, 1882, 1, 1, 1, 37734.73552), -- Leather
(21466, 1894, 1, 1, 1, 5957.9928), -- Crafted Leather
(21466, 4042, 1, 1, 1, 2829.99776), -- Enria
(21466, 5434, 1, 1, 1, 62.88016), -- Recipe: Dragon Slayer(60%)
(21466, 5368, 1, 1, 1, 1463.81888), -- Recipe: Sealed Dark Crystal Boots(60%)
(21466, 8729, 1, 1, 1, 2264.07632), -- Life Stone - Level 64
(21466, 8739, 1, 1, 1, 565.92144), -- Mid-Grade Life Stone - Level 64
(21466, 8749, 1, 1, 1, 56.6312), -- High-Grade Life Stone - Level 64
(21466, 8759, 1, 1, 1, 11.7168), -- Top-Grade Life Stone - Level 64
-- Alpine Kookaburra
(21467, 4120, 1, 1, -1, 26575), -- Bellion Cestus Edge
(21467, 5458, 1, 1, -1, 3323), -- Recipe: Halberd(60%)
(21467, 4121, 1, 1, -1, 26486), -- Bow of Peril Shaft
(21467, 11933, 1, 1, 0, 293.3619), -- Common Item - Bellion Cestus
(21467, 4120, 1, 1, 0, 3924.6381), -- Bellion Cestus Edge
(21467, 1864, 4, 12, 1, 37424.6215), -- Stem
(21467, 1869, 1, 1, 1, 149698.486), -- Iron Ore
(21467, 1878, 1, 1, 1, 59879.3944), -- Braided Hemp
(21467, 1884, 1, 1, 1, 92121.8872), -- Cord
(21467, 4039, 1, 1, 1, 4990.0893), -- Mold Glue
(21467, 5440, 1, 1, 1, 55.3476), -- Recipe: Elysian(60%)
(21467, 5368, 1, 1, 1, 1290.6054), -- Recipe: Sealed Dark Crystal Boots(60%)
(21467, 8729, 1, 1, 1, 1995.868), -- Life Stone - Level 64
(21467, 8739, 1, 1, 1, 498.967), -- Mid-Grade Life Stone - Level 64
(21467, 8749, 1, 1, 1, 49.8967), -- High-Grade Life Stone - Level 64
(21467, 8759, 1, 1, 1, 10.0632), -- Top-Grade Life Stone - Level 64
(21467, 1343, 30, 90, 1, 71284.7737), -- Silver Arrow
-- Alpine Kookaburra
(21468, 5220, 1, 1, -1, 348382), -- Metal Hardener
(21468, 5370, 1, 1, -1, 37541), -- Recipe: Sealed Tallum Boots(60%)
(21468, 4052, 1, 1, -1, 308357), -- Earring of Black Ore Piece
(21468, 57, 3464, 7010, 0, 700000), -- Adena
-- Alpine Kookaburra
(21469, 5460, 1, 1, -1, 4540), -- Recipe: Dasparion's Staff(60%)
(21469, 4053, 1, 1, -1, 356108), -- Ring of Black Ore Gemstone
(21469, 5468, 1, 1, -1, 4540), -- Recipe: Elemental Sword(60%)
(21469, 57, 3305, 6687, 0, 700000), -- Adena
-- Alpine Buffalo
(21470, 5156, 1, 1, -1, 1625), -- Recipe: Soulshot (A) Compressed Package (100%)
(21470, 4114, 1, 1, -1, 5334), -- Sword of Damascus Blade
(21470, 5161, 1, 1, -1, 1625), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21470, 57, 480, 982, 0, 700000), -- Adena
(21470, 12188, 1, 1, 1, 239.326871), -- Common Item - Sealed Doom Boots
(21470, 4099, 1, 1, 1, 2019.923129), -- Sealed Doom Boots Part
(21470, 12189, 1, 1, 1, 239.326871), -- Common Item - Sealed Blue Wolf Boots
(21470, 4090, 1, 1, 1, 2019.923129), -- Sealed Blue Wolf Boots Design
(21470, 12187, 1, 1, 1, 239.326871), -- Common Item - Sealed Doom Gloves
(21470, 4091, 1, 1, 1, 2019.923129), -- Sealed Doom Gloves Part
(21470, 12190, 1, 1, 1, 239.326871), -- Common Item - Sealed Blue Wolf Gloves
(21470, 4096, 1, 1, 1, 2019.923129), -- Sealed Blue Wolf Gloves Fabric
(21470, 1866, 1, 1, 2, 21814.538384), -- Suede
(21470, 1871, 1, 1, 2, 32721.807576), -- Charcoal
(21470, 5220, 1, 1, 2, 1308.879474), -- Metal Hardener
(21470, 1885, 1, 1, 2, 2726.817298), -- High-Grade Suede
(21470, 4041, 1, 1, 2, 284.507838), -- Mold Hardener
(21470, 6337, 1, 1, 2, 167.800464), -- Recipe: Sealed Majestic Earring(70%)
(21470, 5364, 1, 1, 2, 268.193904), -- Recipe: Sealed Dark Crystal Shield(60%)
(21470, 8730, 1, 1, 2, 363.567672), -- Life Stone - Level 67
(21470, 8740, 1, 1, 2, 90.891918), -- Mid-Grade Life Stone - Level 67
(21470, 8750, 1, 1, 2, 9.083216), -- High-Grade Life Stone - Level 67
(21470, 8760, 1, 1, 2, 1.912256), -- Top-Grade Life Stone - Level 67
-- Alpine Buffalo
(21471, 4115, 1, 1, -1, 11485), -- Lance Blade
(21471, 1894, 1, 1, -1, 92378), -- Crafted Leather
(21471, 4042, 1, 1, -1, 43879), -- Enria
(21471, 57, 1047, 2119, 0, 700000), -- Adena
-- Alpine Buffalo
(21472, 4116, 1, 1, -1, 9668), -- Deadman's Glory Stone
(21472, 5166, 1, 1, -1, 2950), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21472, 4117, 1, 1, -1, 9668), -- Art of Battle Axe Blade
(21472, 57, 880, 1780, 0, 700000), -- Adena
-- Alpine Buffalo
(21473, 5230, 1, 1, -1, 3510), -- Recipe: Mithril Arrow (100%)
(21473, 4118, 1, 1, -1, 10900), -- Evil Spirit Head
(21473, 4043, 1, 1, -1, 87759), -- Asofe
(21473, 57, 1047, 2119, 0, 700000), -- Adena
-- Alpine Buffalo
(21474, 4039, 1, 1, -1, 73747), -- Mold Glue
(21474, 4119, 1, 1, -1, 9684), -- Demon's Dagger Edge
(21474, 5271, 1, 1, -1, 2950), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21474, 57, 880, 1780, 0, 700000), -- Adena
-- Alpine Buffalo
(21475, 4120, 1, 1, -1, 14081), -- Bellion Cestus Edge
(21475, 5276, 1, 1, -1, 4296), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21475, 4121, 1, 1, -1, 14034), -- Bow of Peril Shaft
(21475, 12201, 1, 1, 0, 211.145724), -- Common Item - Blue Wolf Tunic
(21475, 4084, 1, 1, 0, 2067.817428), -- Blue Wolf Tunic Fabric
(21475, 12192, 1, 1, 0, 211.145724), -- Common Item - Tunic of Doom
(21475, 4085, 1, 1, 0, 2067.817428), -- Tunic of Doom Pattern
(21475, 12203, 1, 1, 0, 338.019228), -- Common Item - Blue Wolf Stockings
(21475, 4086, 1, 1, 0, 2792.01762), -- Blue Wolf Stockings Pattern
(21475, 12205, 1, 1, 0, 338.019228), -- Common Item - Stockings of Doom
(21475, 4087, 1, 1, 0, 2792.01762), -- Stockings of Doom Pattern
(21475, 1871, 1, 1, 1, 86530.60944), -- Charcoal
(21475, 1866, 1, 1, 1, 57687.16464), -- Suede
(21475, 1877, 1, 1, 1, 3461.10336), -- Adamantite Nugget
(21475, 4041, 1, 1, 1, 752.50944), -- Mold Hardener
(21475, 4040, 1, 1, 1, 1730.55168), -- Mold Lubricant
(21475, 5440, 1, 1, 1, 32.17968), -- Recipe: Elysian(60%)
(21475, 8730, 1, 1, 1, 961.53984), -- Life Stone - Level 67
(21475, 8740, 1, 1, 1, 240.38496), -- Mid-Grade Life Stone - Level 67
(21475, 8750, 1, 1, 1, 23.92848), -- High-Grade Life Stone - Level 67
(21475, 8760, 1, 1, 1, 4.67568), -- Top-Grade Life Stone - Level 67
(21475, 1343, 10, 30, 1, 123615.3528), -- Silver Arrow
-- Alpine Buffalo
(21476, 4041, 1, 1, -1, 23547), -- Mold Hardener
(21476, 1875, 1, 1, -1, 180524), -- Stone of Purity
(21476, 4052, 1, 1, -1, 95871), -- Earring of Black Ore Piece
(21476, 12204, 1, 1, 0, 177.511148), -- Common Item - Blue Wolf Breastplate
(21476, 4078, 1, 1, 0, 1947.25167), -- Blue Wolf Breastplate Part
(21476, 12184, 1, 1, 0, 109.266454), -- Common Item - Doom Plate Armor
(21476, 4081, 1, 1, 0, 1313.905936), -- Doom Plate Armor Temper
(21476, 12193, 1, 1, 0, 283.937634), -- Common Item - Blue Wolf Gaiters
(21476, 4080, 1, 1, 0, 2742.127158), -- Blue Wolf Gaiters Material
(21476, 1872, 1, 1, 1, 106648.442776), -- Animal Bone
(21476, 1867, 1, 1, 1, 106648.442776), -- Animal Skin
(21476, 1881, 1, 1, 1, 10664.890509), -- Coarse Bone Powder
(21476, 1875, 1, 1, 1, 5332.329676), -- Stone of Purity
(21476, 4041, 1, 1, 1, 695.551413), -- Mold Hardener
(21476, 5442, 1, 1, 1, 29.588096), -- Recipe: Soul Bow(60%)
(21476, 8730, 1, 1, 1, 888.798665), -- Life Stone - Level 67
(21476, 8740, 1, 1, 1, 222.141877), -- Mid-Grade Life Stone - Level 67
(21476, 8750, 1, 1, 1, 22.191072), -- High-Grade Life Stone - Level 67
(21476, 8760, 1, 1, 1, 4.62314), -- Top-Grade Life Stone - Level 67
-- Alpine Buffalo
(21477, 5281, 1, 1, -1, 4296), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21477, 4053, 1, 1, -1, 138121), -- Ring of Black Ore Gemstone
(21477, 5438, 1, 1, -1, 1761), -- Recipe: Meteor Shower(60%)
(21477, 12201, 1, 1, 0, 211.145724), -- Common Item - Blue Wolf Tunic
(21477, 4084, 1, 1, 0, 2067.817428), -- Blue Wolf Tunic Fabric
(21477, 12192, 1, 1, 0, 211.145724), -- Common Item - Tunic of Doom
(21477, 4085, 1, 1, 0, 2067.817428), -- Tunic of Doom Pattern
(21477, 12203, 1, 1, 0, 338.019228), -- Common Item - Blue Wolf Stockings
(21477, 4086, 1, 1, 0, 2792.01762), -- Blue Wolf Stockings Pattern
(21477, 12205, 1, 1, 0, 338.019228), -- Common Item - Stockings of Doom
(21477, 4087, 1, 1, 0, 2792.01762), -- Stockings of Doom Pattern
(21477, 1865, 1, 1, 1, 86530.44636), -- Varnish
(21477, 1870, 1, 1, 1, 86530.44636), -- Coal
(21477, 1879, 1, 1, 1, 14421.84768), -- Cokes
(21477, 1875, 1, 1, 1, 5768.6751), -- Stone of Purity
(21477, 4040, 1, 1, 1, 1730.76246), -- Mold Lubricant
(21477, 5448, 1, 1, 1, 31.986), -- Recipe: Soul Separator(60%)
(21477, 8730, 1, 1, 1, 961.49916), -- Life Stone - Level 67
(21477, 8740, 1, 1, 1, 240.21486), -- Mid-Grade Life Stone - Level 67
(21477, 8750, 1, 1, 1, 23.9895), -- High-Grade Life Stone - Level 67
(21477, 8760, 1, 1, 1, 4.7979), -- Top-Grade Life Stone - Level 67
(21477, 1343, 10, 30, 1, 123615.33462), -- Silver Arrow
-- Alpine Buffalo
(21478, 4054, 1, 1, -1, 53336), -- Necklace of Black Ore Beads
(21478, 1885, 1, 1, -1, 225655), -- High-Grade Suede
(21478, 4041, 1, 1, -1, 23547), -- Mold Hardener
(21478, 12341, 1, 1, 0, 618.61674), -- Common Item - Earring of Black Ore
(21478, 4052, 1, 1, 0, 4719.870184), -- Earring of Black Ore Piece
(21478, 12342, 1, 1, 0, 463.702632), -- Common Item - Necklace of Black Ore
(21478, 4054, 1, 1, 0, 2625.809952), -- Necklace of Black Ore Beads
(21478, 12343, 1, 1, 0, 925.77792), -- Common Item - Ring of Black Ore
(21478, 4053, 1, 1, 0, 5714.222572), -- Ring of Black Ore Gemstone
(21478, 1866, 1, 1, 1, 53324.090928), -- Suede
(21478, 1871, 1, 1, 1, 79986.136392), -- Charcoal
(21478, 5220, 1, 1, 1, 3199.393242), -- Metal Hardener
(21478, 1885, 1, 1, 1, 6665.511366), -- High-Grade Suede
(21478, 4041, 1, 1, 1, 695.602248), -- Mold Hardener
(21478, 5450, 1, 1, 1, 29.587752), -- Recipe: Dragon Grinder(60%)
(21478, 8730, 1, 1, 1, 888.792864), -- Life Stone - Level 67
(21478, 8740, 1, 1, 1, 222.198216), -- Mid-Grade Life Stone - Level 67
(21478, 8750, 1, 1, 1, 22.190814), -- High-Grade Life Stone - Level 67
(21478, 8760, 1, 1, 1, 4.496178), -- Top-Grade Life Stone - Level 67
-- Alpine Buffalo
(21479, 4077, 1, 1, -1, 248161), -- Doom Shield Fragment
(21479, 5444, 1, 1, -1, 3015), -- Recipe: Carnage Bow(60%)
(21479, 4078, 1, 1, -1, 80582), -- Blue Wolf Breastplate Part
(21479, 57, 2194, 4439, 0, 700000), -- Adena
-- Alpine Buffalo
(21480, 5446, 1, 1, -1, 3133), -- Recipe: Bloody Orchid(60%)
(21480, 4080, 1, 1, -1, 117952), -- Blue Wolf Gaiters Material
(21480, 1889, 1, 1, -1, 382283), -- Compound Braid
(21480, 57, 2281, 4615, 0, 700000), -- Adena
-- Alpine Buffalo
(21481, 5550, 1, 1, -1, 73555), -- Durable Metal Plate
(21481, 4081, 1, 1, -1, 54372), -- Doom Plate Armor Temper
(21481, 5452, 1, 1, -1, 3015), -- Recipe: Blood Tornado(60%)
(21481, 57, 2194, 4439, 0, 700000), -- Adena
-- Alpine Buffalo
(21482, 4082, 1, 1, -1, 59949), -- Blue Wolf Leather Armor Texture
(21482, 5458, 1, 1, -1, 2899), -- Recipe: Halberd(60%)
(21482, 4083, 1, 1, -1, 59949), -- Leather Armor of Doom Design
(21482, 57, 2110, 4270, 0, 700000), -- Adena
-- Alpine Buffalo
(21483, 4040, 1, 1, -1, 135041), -- Mold Lubricant
(21483, 1877, 1, 1, -1, 270082), -- Adamantite Nugget
(21483, 5364, 1, 1, -1, 55345), -- Recipe: Sealed Dark Crystal Shield(60%)
(21483, 11944, 1, 1, 0, 325.746792), -- Common Item - Bow of Peril
(21483, 4121, 1, 1, 0, 4343.253208), -- Bow of Peril Shaft
(21483, 1871, 1, 1, 1, 181313.40119), -- Charcoal
(21483, 1866, 1, 1, 1, 120875.45165), -- Suede
(21483, 1877, 1, 1, 1, 7252.39287), -- Adamantite Nugget
(21483, 4041, 1, 1, 1, 1576.74332), -- Mold Hardener
(21483, 4040, 1, 1, 1, 3626.42015), -- Mold Lubricant
(21483, 6335, 1, 1, 1, 697.54337), -- Recipe: Sealed Majestic Necklace(70%)
(21483, 8730, 1, 1, 1, 2014.77729), -- Life Stone - Level 67
(21483, 8740, 1, 1, 1, 503.80618), -- Mid-Grade Life Stone - Level 67
(21483, 8750, 1, 1, 1, 50.55959), -- High-Grade Life Stone - Level 67
(21483, 8760, 1, 1, 1, 10.29089), -- Top-Grade Life Stone - Level 67
(21483, 1343, 20, 60, 1, 129508.6135), -- Silver Arrow
-- Alpine Buffalo
(21484, 5460, 1, 1, -1, 3835), -- Recipe: Dasparion's Staff(60%)
(21484, 4085, 1, 1, -1, 121974), -- Tunic of Doom Pattern
(21484, 5468, 1, 1, -1, 3835), -- Recipe: Elemental Sword(60%)
(21484, 12201, 1, 1, 0, 459.883116), -- Common Item - Blue Wolf Tunic
(21484, 4084, 1, 1, 0, 4503.782052), -- Blue Wolf Tunic Fabric
(21484, 12192, 1, 1, 0, 459.883116), -- Common Item - Tunic of Doom
(21484, 4085, 1, 1, 0, 4503.782052), -- Tunic of Doom Pattern
(21484, 12203, 1, 1, 0, 736.218252), -- Common Item - Blue Wolf Stockings
(21484, 4086, 1, 1, 0, 6081.11658), -- Blue Wolf Stockings Pattern
(21484, 12205, 1, 1, 0, 736.218252), -- Common Item - Stockings of Doom
(21484, 4087, 1, 1, 0, 6081.11658), -- Stockings of Doom Pattern
(21484, 1872, 1, 3, 1, 138208.768048), -- Animal Bone
(21484, 1867, 1, 1, 1, 276417.536096), -- Animal Skin
(21484, 1881, 1, 1, 1, 27641.661229), -- Coarse Bone Powder
(21484, 1875, 1, 1, 1, 13821.061566), -- Stone of Purity
(21484, 4041, 1, 1, 1, 1802.807409), -- Mold Hardener
(21484, 6337, 1, 1, 1, 1063.300706), -- Recipe: Sealed Majestic Earring(70%)
(21484, 8730, 1, 1, 1, 2303.510261), -- Life Stone - Level 67
(21484, 8740, 1, 1, 1, 575.993041), -- Mid-Grade Life Stone - Level 67
(21484, 8750, 1, 1, 1, 57.737875), -- High-Grade Life Stone - Level 67
(21484, 8760, 1, 1, 1, 10.623769), -- Top-Grade Life Stone - Level 67
-- Alpine Buffalo
(21485, 4086, 1, 1, -1, 158443), -- Blue Wolf Stockings Pattern
(21485, 4040, 1, 1, -1, 135041), -- Mold Lubricant
(21485, 5368, 1, 1, -1, 58207), -- Recipe: Sealed Dark Crystal Boots(60%)
(21485, 12341, 1, 1, 0, 1542.477405), -- Common Item - Earring of Black Ore
(21485, 4052, 1, 1, 0, 11768.664898), -- Earring of Black Ore Piece
(21485, 12342, 1, 1, 0, 1156.209954), -- Common Item - Necklace of Black Ore
(21485, 4054, 1, 1, 0, 6547.272744), -- Necklace of Black Ore Beads
(21485, 12343, 1, 1, 0, 2308.36224), -- Common Item - Ring of Black Ore
(21485, 4053, 1, 1, 0, 14248.012759), -- Ring of Black Ore Gemstone
(21485, 1865, 1, 3, 1, 60437.885667), -- Varnish
(21485, 1870, 1, 1, 1, 181313.235834), -- Coal
(21485, 1879, 1, 1, 1, 30218.73225), -- Cokes
(21485, 1875, 1, 1, 1, 12087.4929), -- Stone of Purity
(21485, 4040, 1, 1, 1, 3626.24787), -- Mold Lubricant
(21485, 6339, 1, 1, 1, 1394.905104), -- Recipe: Sealed Majestic Ring(70%)
(21485, 8730, 1, 1, 1, 2014.441761), -- Life Stone - Level 67
(21485, 8740, 1, 1, 1, 503.715732), -- Mid-Grade Life Stone - Level 67
(21485, 8750, 1, 1, 1, 50.54004), -- High-Grade Life Stone - Level 67
(21485, 8760, 1, 1, 1, 10.108008), -- Top-Grade Life Stone - Level 67
(21485, 1343, 20, 60, 1, 129509.694834), -- Silver Arrow
-- Alpine Buffalo
(21486, 4087, 1, 1, -1, 152379), -- Stockings of Doom Pattern
(21486, 5470, 1, 1, -1, 3548), -- Recipe: Tallum Blade(60%)
(21486, 4088, 1, 1, -1, 245413), -- Blue Wolf Helmet Design
(21486, 12204, 1, 1, 0, 425.68653), -- Common Item - Blue Wolf Breastplate
(21486, 4078, 1, 1, 0, 4669.671825), -- Blue Wolf Breastplate Part
(21486, 12184, 1, 1, 0, 262.030065), -- Common Item - Doom Plate Armor
(21486, 4081, 1, 1, 0, 3150.85596), -- Doom Plate Armor Temper
(21486, 12193, 1, 1, 0, 680.906115), -- Common Item - Blue Wolf Gaiters
(21486, 4080, 1, 1, 0, 6575.849505), -- Blue Wolf Gaiters Material
(21486, 1866, 1, 1, 1, 127874.48184), -- Suede
(21486, 1871, 1, 1, 1, 191811.54888), -- Charcoal
(21486, 5220, 1, 1, 1, 7672.62888), -- Metal Hardener
(21486, 1885, 1, 1, 1, 15984.44064), -- High-Grade Suede
(21486, 4041, 1, 1, 1, 1667.85696), -- Mold Hardener
(21486, 729, 1, 1, 1, 21.21336), -- Scroll: Enchant Weapon (A-Grade)
(21486, 8730, 1, 1, 1, 2131.07328), -- Life Stone - Level 67
(21486, 8740, 1, 1, 1, 532.76832), -- Mid-Grade Life Stone - Level 67
(21486, 8750, 1, 1, 1, 53.20728), -- High-Grade Life Stone - Level 67
(21486, 8760, 1, 1, 1, 10.78056), -- Top-Grade Life Stone - Level 67
-- Alpine Buffalo
(21487, 5428, 1, 1, -1, 7816), -- Recipe: Sealed Tallum Helmet(60%)
(21487, 4089, 1, 1, -1, 351478), -- Doom Helmet Pattern
(21487, 1894, 1, 1, -1, 326320), -- Crafted Leather
(21487, 57, 3699, 7484, 0, 700000), -- Adena
-- Alpine Buffalo
(21488, 4044, 1, 1, -1, 295712), -- Thons
(21488, 4090, 1, 1, -1, 398265), -- Sealed Blue Wolf Boots Design
(21488, 5426, 1, 1, -1, 6995), -- Recipe: Sealed Dark Crystal Helmet(60%)
(21488, 57, 3528, 7139, 0, 700000), -- Adena
-- Alpine Cougar
(21489, 4040, 1, 1, -1, 25994), -- Mold Lubricant
(21489, 1877, 1, 1, -1, 51987), -- Adamantite Nugget
(21489, 6343, 1, 1, -1, 27789), -- Sealed Phoenix Necklace Beads
(21489, 57, 514, 1045, 0, 700000), -- Adena
(21489, 11950, 1, 1, 1, 52.8318), -- Common Item - Blood Tornado
(21489, 5539, 1, 1, 1, 647.1682), -- Blood Tornado Edge
(21489, 1871, 1, 1, 2, 38390.683626), -- Charcoal
(21489, 1866, 1, 1, 2, 25593.789084), -- Suede
(21489, 1877, 1, 1, 2, 1535.646156), -- Adamantite Nugget
(21489, 4041, 1, 1, 2, 333.827358), -- Mold Hardener
(21489, 4040, 1, 1, 2, 767.823078), -- Mold Lubricant
(21489, 5456, 1, 1, 2, 14.242584), -- Recipe: Tallum Glaive(60%)
(21489, 8730, 1, 1, 2, 426.538518), -- Life Stone - Level 67
(21489, 8740, 1, 1, 2, 106.617834), -- Mid-Grade Life Stone - Level 67
(21489, 8750, 1, 1, 2, 10.681938), -- High-Grade Life Stone - Level 67
(21489, 8760, 1, 1, 2, 2.149824), -- Top-Grade Life Stone - Level 67
-- Alpine Cougar
(21490, 5450, 1, 1, -1, 1040), -- Recipe: Dragon Grinder(60%)
(21490, 6345, 1, 1, -1, 107412), -- Sealed Phoenix Ring Gemstone
(21490, 5456, 1, 1, -1, 1040), -- Recipe: Tallum Glaive(60%)
(21490, 57, 1116, 2260, 0, 700000), -- Adena
-- Alpine Cougar
(21491, 5478, 1, 1, -1, 19841), -- Sealed Dark Crystal Leather Armor Pattern
(21491, 730, 1, 1, -1, 1966), -- Scroll: Enchant Armor (A-Grade)
(21491, 4041, 1, 1, -1, 20517), -- Mold Hardener
(21491, 57, 938, 1899, 0, 700000), -- Adena
-- Alpine Cougar
(21492, 4040, 1, 1, -1, 56155), -- Mold Lubricant
(21492, 5479, 1, 1, -1, 16614), -- Sealed Tallum Leather Armor Pattern
(21492, 5462, 1, 1, -1, 1040), -- Recipe: Branch of the Mother Tree(60%)
(21492, 57, 1116, 2260, 0, 700000), -- Adena
-- Alpine Cougar
(21493, 5482, 1, 1, -1, 31142), -- Sealed Dark Crystal Leggings Design
(21493, 5464, 1, 1, -1, 874), -- Recipe: Dark Legion's Edge(60%)
(21493, 5485, 1, 1, -1, 19841), -- Sealed Tallum Tunic Texture
(21493, 57, 938, 1899, 0, 700000), -- Adena
-- Alpine Cougar
(21494, 729, 1, 1, -1, 382), -- Scroll: Enchant Weapon (A-Grade)
(21494, 4042, 1, 1, -1, 57282), -- Enria
(21494, 1876, 1, 1, -1, 687390), -- Mithril Ore
(21494, 11955, 1, 1, 0, 139.759776), -- Common Item - Carnage Bow
(21494, 5535, 1, 1, 0, 1732.240224), -- Carnage Bow Stave
(21494, 1873, 1, 1, 1, 36917.122), -- Silver Nugget
(21494, 1868, 1, 1, 1, 184584.807), -- Thread
(21494, 1876, 1, 1, 1, 18458.561), -- Mithril Ore
(21494, 1895, 1, 1, 1, 26369.3155), -- Metallic Fiber
(21494, 4042, 1, 1, 1, 1538.1465), -- Enria
(21494, 6337, 1, 1, 1, 473.3685), -- Recipe: Sealed Majestic Earring(70%)
(21494, 8730, 1, 1, 1, 1025.431), -- Life Stone - Level 67
(21494, 8740, 1, 1, 1, 256.5585), -- Mid-Grade Life Stone - Level 67
(21494, 8750, 1, 1, 1, 25.696), -- High-Grade Life Stone - Level 67
(21494, 8760, 1, 1, 1, 5.2195), -- Top-Grade Life Stone - Level 67
(21494, 1343, 10, 30, 1, 131845.7745), -- Silver Arrow
-- Alpine Cougar
(21495, 5486, 1, 1, -1, 17090), -- Sealed Dark Crystal Robe Fabric
(21495, 5466, 1, 1, -1, 1070), -- Recipe: Sword of Miracles(60%)
(21495, 5489, 1, 1, -1, 38120), -- Sealed Tallum Stockings Fabric
(21495, 11951, 1, 1, 0, 117.452202), -- Common Item - Bloody Orchid
(21495, 5536, 1, 1, 0, 1451.547798), -- Bloody Orchid Head
(21495, 1873, 1, 1, 1, 34125.1218), -- Silver Nugget
(21495, 1868, 1, 1, 1, 170625.609), -- Thread
(21495, 1876, 1, 1, 1, 17062.68564), -- Mithril Ore
(21495, 1895, 1, 1, 1, 24375.19392), -- Metallic Fiber
(21495, 4042, 1, 1, 1, 1421.78652), -- Enria
(21495, 6339, 1, 1, 1, 656.1324), -- Recipe: Sealed Majestic Ring(70%)
(21495, 8730, 1, 1, 1, 948.024), -- Life Stone - Level 67
(21495, 8740, 1, 1, 1, 237.006), -- Mid-Grade Life Stone - Level 67
(21495, 8750, 1, 1, 1, 23.7006), -- High-Grade Life Stone - Level 67
(21495, 8760, 1, 1, 1, 4.74012), -- Top-Grade Life Stone - Level 67
-- Alpine Cougar
(21496, 6335, 1, 1, -1, 13219), -- Recipe: Sealed Majestic Necklace(70%)
(21496, 5494, 1, 1, -1, 72182), -- Sealed Dark Crystal Shield Fragment
(21496, 730, 1, 1, -1, 2864), -- Scroll: Enchant Armor (A-Grade)
(21496, 11946, 1, 1, 0, 34.935215), -- Common Item - Dasparion's Staff
(21496, 5543, 1, 1, 0, 431.97756), -- Dasparion's Staff Head
(21496, 11949, 1, 1, 0, 34.935215), -- Common Item - Meteor Shower
(21496, 5532, 1, 1, 0, 427.942935), -- Meteor Shower Head
(21496, 11953, 1, 1, 0, 34.935215), -- Common Item - Spiritual Eye
(21496, 8341, 1, 1, 0, 427.39571), -- Spiritual Eye Piece
(21496, 11958, 1, 1, 0, 34.935215), -- Common Item - Destroyer Hammer
(21496, 8346, 1, 1, 0, 427.942935), -- Hammer Piece of Destroyer
(21496, 1873, 1, 1, 1, 36917.152052), -- Silver Nugget
(21496, 1868, 1, 1, 1, 184585.359222), -- Thread
(21496, 1876, 1, 1, 1, 18458.576026), -- Mithril Ore
(21496, 1895, 1, 1, 1, 26369.451614), -- Metallic Fiber
(21496, 4042, 1, 1, 1, 1538.381768), -- Enria
(21496, 729, 1, 1, 1, 10.426988), -- Scroll: Enchant Weapon (A-Grade)
(21496, 8730, 1, 1, 1, 1025.454166), -- Life Stone - Level 67
(21496, 8740, 1, 1, 1, 256.263282), -- Mid-Grade Life Stone - Level 67
(21496, 8750, 1, 1, 1, 25.666432), -- High-Grade Life Stone - Level 67
(21496, 8760, 1, 1, 1, 5.213494), -- Top-Grade Life Stone - Level 67
(21496, 1343, 10, 30, 1, 131846.054956), -- Silver Arrow
-- Alpine Cougar
(21497, 1884, 1, 3, -1, 888675), -- Cord
(21497, 4039, 1, 1, -1, 96273), -- Mold Glue
(21497, 5496, 1, 1, -1, 67718), -- Sealed Dark Crystal Boots Lining
(21497, 11957, 1, 1, 0, 39.1401), -- Common Item - Tallum Blade
(21497, 5548, 1, 1, 0, 483.72485), -- Tallum Blade Edge
(21497, 11952, 1, 1, 0, 39.1401), -- Common Item - Elemental Sword
(21497, 5547, 1, 1, 0, 483.72485), -- Elemental Sword Edge
(21497, 11954, 1, 1, 0, 39.1401), -- Common Item - Inferno Master
(21497, 8331, 1, 1, 0, 485.13), -- Infernal Master Blade
(21497, 1864, 1, 1, 1, 155113.9595), -- Stem
(21497, 1869, 1, 1, 1, 77556.97975), -- Iron Ore
(21497, 1878, 1, 1, 1, 31022.7919), -- Braided Hemp
(21497, 1884, 1, 1, 1, 47727.444983), -- Cord
(21497, 4039, 1, 1, 1, 2585.337856), -- Mold Glue
(21497, 730, 1, 1, 1, 64.696565), -- Scroll: Enchant Armor (A-Grade)
(21497, 5366, 1, 1, 1, 419.107504), -- Recipe: Sealed Shield of Nightmare(60%)
(21497, 8730, 1, 1, 1, 861.884483), -- Life Stone - Level 67
(21497, 8740, 1, 1, 1, 215.550019), -- Mid-Grade Life Stone - Level 67
(21497, 8750, 1, 1, 1, 21.460324), -- High-Grade Life Stone - Level 67
(21497, 8760, 1, 1, 1, 3.787116), -- Top-Grade Life Stone - Level 67
-- Alpine Cougar
(21498, 6337, 1, 1, -1, 30171), -- Recipe: Sealed Majestic Earring(70%)
(21498, 5497, 1, 1, -1, 137944), -- Sealed Tallum Boots Lining
(21498, 6339, 1, 1, -1, 45256), -- Recipe: Sealed Majestic Ring(70%)
(21498, 57, 2339, 4736, 0, 700000), -- Adena
-- Alpine Cougar
(21499, 5508, 1, 1, -1, 143386), -- Sealed Dark Crystal Gloves Design
(21499, 729, 1, 1, -1, 679), -- Scroll: Enchant Weapon (A-Grade)
(21499, 1895, 1, 3, -1, 873628), -- Metallic Fiber
(21499, 57, 2431, 4922, 0, 700000), -- Adena
-- Alpine Cougar
(21500, 4042, 1, 1, -1, 98055), -- Enria
(21500, 5509, 1, 1, -1, 137944), -- Sealed Tallum Gloves Design
(21500, 5434, 1, 1, -1, 2179), -- Recipe: Dragon Slayer(60%)
(21500, 57, 2339, 4736, 0, 700000), -- Adena
-- Alpine Cougar
(21501, 5520, 1, 1, -1, 36486), -- Sealed Dark Crystal Breastplate Pattern
(21501, 5440, 1, 1, -1, 2096), -- Recipe: Elysian(60%)
(21501, 5521, 1, 1, -1, 25746), -- Sealed Tallum Plate Armor Pattern
(21501, 57, 2250, 4554, 0, 700000), -- Adena
-- Alpine Cougar
(21502, 730, 1, 1, -1, 6001), -- Scroll: Enchant Armor (A-Grade)
(21502, 1885, 1, 1, -1, 600140), -- High-Grade Suede
(21502, 5432, 1, 1, -1, 27279), -- Recipe: Sealed Majestic Circlet (60%)
(21502, 1866, 20, 60, 0, 40289.129628), -- Suede
(21502, 1871, 9, 27, 0, 134297.09876), -- Charcoal
(21502, 5220, 1, 1, 0, 96693.828782), -- Metal Hardener
(21502, 1885, 4, 12, 0, 22382.987002), -- High-Grade Suede
(21502, 4041, 1, 1, 0, 21020.504942), -- Mold Hardener
(21502, 5450, 1, 1, 0, 895.28655), -- Recipe: Dragon Grinder(60%)
(21502, 8730, 1, 1, 0, 26859.419752), -- Life Stone - Level 67
(21502, 8740, 1, 1, 0, 6714.854938), -- Mid-Grade Life Stone - Level 67
(21502, 8750, 1, 1, 0, 671.362006), -- High-Grade Life Stone - Level 67
(21502, 8760, 1, 1, 0, 134.190076), -- Top-Grade Life Stone - Level 67
(21502, 1343, 560, 1680, 0, 61667.337564), -- Silver Arrow
-- Alpine Cougar
(21503, 5524, 1, 1, -1, 73781), -- Sealed Dark Crystal Gaiters Pattern
(21503, 5442, 1, 1, -1, 2773), -- Recipe: Soul Bow(60%)
(21503, 5525, 1, 1, -1, 115718), -- Sealed Dark Crystal Helmet Design
(21503, 11960, 1, 1, 0, 304.386642), -- Common Item - Halberd
(21503, 5542, 1, 1, 0, 3728.613358), -- Halberd Edge
(21503, 1867, 1, 3, 1, 147412.635304), -- Animal Skin
(21503, 1872, 1, 3, 1, 98275.193368), -- Animal Bone
(21503, 1882, 1, 1, 1, 49137.441936), -- Leather
(21503, 1894, 1, 1, 1, 7758.445728), -- Crafted Leather
(21503, 4042, 1, 1, 1, 3685.168872), -- Enria
(21503, 5456, 1, 1, 1, 82.01644), -- Recipe: Tallum Glaive(60%)
(21503, 8730, 1, 1, 1, 2456.779248), -- Life Stone - Level 67
(21503, 8740, 1, 1, 1, 614.34956), -- Mid-Grade Life Stone - Level 67
(21503, 8750, 1, 1, 1, 61.280208), -- High-Grade Life Stone - Level 67
(21503, 8760, 1, 1, 1, 12.689336), -- Top-Grade Life Stone - Level 67
-- Alpine Cougar
(21504, 5448, 1, 1, -1, 2667), -- Recipe: Soul Separator(60%)
(21504, 5526, 1, 1, -1, 111326), -- Sealed Tallum Helm Design
(21504, 729, 1, 1, -1, 800), -- Scroll: Enchant Weapon (A-Grade)
(21504, 11955, 1, 1, 0, 292.808676), -- Common Item - Carnage Bow
(21504, 5535, 1, 1, 0, 3629.191324), -- Carnage Bow Stave
(21504, 1868, 1, 3, 1, 177272.199325), -- Thread
(21504, 1873, 1, 1, 1, 70908.87973), -- Silver Nugget
(21504, 5549, 1, 1, 1, 17727.034278), -- Metallic Thread
(21504, 1889, 1, 1, 1, 11818.022852), -- Compound Braid
(21504, 4044, 1, 1, 1, 5909.011426), -- Thons
(21504, 5462, 1, 1, 1, 65.721693), -- Recipe: Branch of the Mother Tree(60%)
(21504, 5432, 1, 1, 1, 671.326672), -- Recipe: Sealed Majestic Circlet (60%)
(21504, 8730, 1, 1, 1, 1969.794245), -- Life Stone - Level 67
(21504, 8740, 1, 1, 1, 492.355734), -- Mid-Grade Life Stone - Level 67
(21504, 8750, 1, 1, 1, 49.384097), -- High-Grade Life Stone - Level 67
(21504, 8760, 1, 1, 1, 10.025343), -- Top-Grade Life Stone - Level 67
(21504, 1343, 30, 90, 1, 84415.244605), -- Silver Arrow
-- Alpine Cougar
(21505, 4043, 1, 1, -1, 230869), -- Asofe
(21505, 5366, 1, 1, -1, 37438), -- Recipe: Sealed Shield of Nightmare(60%)
(21505, 5532, 1, 1, -1, 23356), -- Meteor Shower Head
(21505, 11951, 1, 1, 0, 281.615796), -- Common Item - Bloody Orchid
(21505, 5536, 1, 1, 0, 3480.384204), -- Bloody Orchid Head
(21505, 1869, 1, 1, 1, 185986.368396), -- Iron Ore
(21505, 1864, 1, 3, 1, 185986.368396), -- Stem
(21505, 1880, 1, 1, 1, 18598.475772), -- Steel
(21505, 5550, 1, 1, 1, 2479.635702), -- Durable Metal Plate
(21505, 4043, 1, 1, 1, 6199.491924), -- Asofe
(21505, 5464, 1, 1, 1, 68.856399), -- Recipe: Dark Legion's Edge(60%)
(21505, 5430, 1, 1, 1, 704.67075), -- Recipe: Sealed Helm of Nightmare(60%)
(21505, 8730, 1, 1, 1, 2066.497308), -- Life Stone - Level 67
(21505, 8740, 1, 1, 1, 516.624327), -- Mid-Grade Life Stone - Level 67
(21505, 8750, 1, 1, 1, 51.541632), -- High-Grade Life Stone - Level 67
(21505, 8760, 1, 1, 1, 10.469394), -- Top-Grade Life Stone - Level 67
-- Alpine Cougar
(21506, 5450, 1, 1, -1, 3673), -- Recipe: Dragon Grinder(60%)
(21506, 5535, 1, 1, -1, 33842), -- Carnage Bow Stave
(21506, 5456, 1, 1, -1, 3673), -- Recipe: Tallum Glaive(60%)
(21506, 57, 3943, 7984, 0, 700000), -- Adena
-- Alpine Cougar
(21507, 5536, 1, 1, -1, 32189), -- Bloody Orchid Head
(21507, 5430, 1, 1, -1, 1946), -- Recipe: Sealed Helm of Nightmare(60%)
(21507, 4041, 1, 1, -1, 82270), -- Mold Hardener
(21507, 57, 3762, 7615, 0, 700000), -- Adena
-- Splinter Stakato
(21508, 4120, 1, 1, -1, 14317), -- Bellion Cestus Edge
(21508, 5444, 1, 1, -1, 1790), -- Recipe: Carnage Bow(60%)
(21508, 4121, 1, 1, -1, 14269), -- Bow of Peril Shaft
(21508, 57, 1298, 2632, 0, 700000), -- Adena
(21508, 12341, 1, 1, 1, 748.51476), -- Common Item - Earring of Black Ore
(21508, 4052, 1, 1, 1, 5710.955216), -- Earring of Black Ore Piece
(21508, 12342, 1, 1, 1, 561.071568), -- Common Item - Necklace of Black Ore
(21508, 4054, 1, 1, 1, 3177.181248), -- Necklace of Black Ore Beads
(21508, 12343, 1, 1, 1, 1120.17408), -- Common Item - Ring of Black Ore
(21508, 4053, 1, 1, 1, 6914.103128), -- Ring of Black Ore Gemstone
(21508, 1875, 1, 1, 2, 5865.551329), -- Stone of Purity
(21508, 1879, 1, 1, 2, 14663.905338), -- Cokes
(21508, 1885, 1, 1, 2, 7331.952669), -- High-Grade Suede
(21508, 5550, 1, 1, 2, 1173.121072), -- Durable Metal Plate
(21508, 5549, 1, 1, 2, 8798.354009), -- Metallic Thread
(21508, 5466, 1, 1, 2, 32.580693), -- Recipe: Sword of Miracles(60%)
(21508, 6670, 1, 1, 2, 14663.905338), -- Deluxe Chest Key - Grade 6
(21508, 8729, 1, 1, 2, 1173.121072), -- Life Stone - Level 64
(21508, 8739, 1, 1, 2, 293.280268), -- Mid-Grade Life Stone - Level 64
(21508, 8749, 1, 1, 2, 29.338833), -- High-Grade Life Stone - Level 64
(21508, 8759, 1, 1, 2, 5.889379), -- Top-Grade Life Stone - Level 64
-- Splinter Stakato Worker
(21509, 4091, 1, 1, -1, 128386), -- Sealed Doom Gloves Part
(21509, 6333, 1, 1, -1, 32834), -- Recipe: Sealed Phoenix Ring(70%)
(21509, 4096, 1, 1, -1, 128386), -- Sealed Blue Wolf Gloves Fabric
(21509, 57, 1127, 2304, 0, 700000), -- Adena
(21509, 12194, 1, 1, 1, 230.798464), -- Common Item - Blue Wolf Leather Armor
(21509, 4082, 1, 1, 1, 2386.201536), -- Blue Wolf Leather Armor Texture
(21509, 12186, 1, 1, 1, 230.798464), -- Common Item - Leather Armor of Doom
(21509, 4083, 1, 1, 1, 2386.201536), -- Leather Armor of Doom Design
(21509, 1869, 1, 1, 2, 76794.567802), -- Iron Ore
(21509, 1864, 1, 1, 2, 153589.135604), -- Stem
(21509, 1880, 1, 1, 2, 7679.351038), -- Steel
(21509, 5550, 1, 1, 2, 1023.93697), -- Durable Metal Plate
(21509, 4043, 1, 1, 2, 2559.666188), -- Asofe
(21509, 5440, 1, 1, 2, 28.550394), -- Recipe: Elysian(60%)
(21509, 8730, 1, 1, 2, 853.339554), -- Life Stone - Level 67
(21509, 8740, 1, 1, 2, 213.24677), -- Mid-Grade Life Stone - Level 67
(21509, 8750, 1, 1, 2, 21.500914), -- High-Grade Life Stone - Level 67
(21509, 8760, 1, 1, 2, 4.229688), -- Top-Grade Life Stone - Level 67
(21509, 1343, 10, 30, 2, 109706.475078), -- Silver Arrow
-- Splinter Stakato Soldier
(21510, 5508, 1, 1, -1, 81999), -- Sealed Dark Crystal Gloves Design
(21510, 730, 1, 1, -1, 2914), -- Scroll: Enchant Armor (A-Grade)
(21510, 1875, 1, 1, -1, 233152), -- Stone of Purity
(21510, 57, 1383, 2812, 0, 700000), -- Adena
(21510, 11951, 1, 1, 1, 142.2302), -- Common Item - Bloody Orchid
(21510, 5536, 1, 1, 1, 1757.7698), -- Bloody Orchid Head
(21510, 1865, 1, 1, 2, 103304.194552), -- Varnish
(21510, 1870, 1, 1, 2, 103304.194552), -- Coal
(21510, 1879, 1, 1, 2, 17217.443854), -- Cokes
(21510, 1875, 1, 1, 2, 6886.83697), -- Stone of Purity
(21510, 4040, 1, 1, 2, 2066.168234), -- Mold Lubricant
(21510, 5456, 1, 1, 2, 38.188618), -- Recipe: Tallum Glaive(60%)
(21510, 8730, 1, 1, 2, 1147.767114), -- Life Stone - Level 67
(21510, 8740, 1, 1, 2, 287.00035), -- Mid-Grade Life Stone - Level 67
(21510, 8750, 1, 1, 2, 28.582892), -- High-Grade Life Stone - Level 67
(21510, 8760, 1, 1, 2, 5.622864), -- Top-Grade Life Stone - Level 67
-- Splinter Stakato Drone
(21511, 1875, 1, 1, -1, 301961), -- Stone of Purity
(21511, 5539, 1, 1, -1, 15274), -- Blood Tornado Edge
(21511, 5462, 1, 1, -1, 1678), -- Recipe: Branch of the Mother Tree(60%)
(21511, 57, 1793, 3640, 0, 700000), -- Adena
(21511, 11946, 1, 1, 1, 46.046685), -- Common Item - Dasparion's Staff
(21511, 5543, 1, 1, 1, 569.37204), -- Dasparion's Staff Head
(21511, 11949, 1, 1, 1, 46.046685), -- Common Item - Meteor Shower
(21511, 5532, 1, 1, 1, 564.054165), -- Meteor Shower Head
(21511, 11953, 1, 1, 1, 46.046685), -- Common Item - Spiritual Eye
(21511, 8341, 1, 1, 1, 563.33289), -- Spiritual Eye Piece
(21511, 11958, 1, 1, 1, 46.046685), -- Common Item - Destroyer Hammer
(21511, 8346, 1, 1, 1, 564.054165), -- Hammer Piece of Destroyer
(21511, 1872, 1, 1, 2, 162171.716226), -- Animal Bone
(21511, 1867, 1, 1, 2, 162171.716226), -- Animal Skin
(21511, 1881, 1, 1, 2, 16217.30331), -- Coarse Bone Powder
(21511, 1875, 1, 1, 2, 8108.432176), -- Stone of Purity
(21511, 4041, 1, 1, 2, 1057.449822), -- Mold Hardener
(21511, 6337, 1, 1, 2, 623.759318), -- Recipe: Sealed Majestic Earring(70%)
(21511, 8730, 1, 1, 2, 1351.551682), -- Life Stone - Level 67
(21511, 8740, 1, 1, 2, 337.99766), -- Mid-Grade Life Stone - Level 67
(21511, 8750, 1, 1, 2, 33.799766), -- High-Grade Life Stone - Level 67
(21511, 8760, 1, 1, 2, 6.58437), -- Top-Grade Life Stone - Level 67
(21511, 1343, 20, 60, 2, 86877.689444), -- Silver Arrow
-- Splinter Stakato Drone
(21512, 730, 1, 1, -1, 4407), -- Scroll: Enchant Armor (A-Grade)
(21512, 4041, 1, 1, -1, 45985), -- Mold Hardener
(21512, 1875, 1, 1, -1, 352548), -- Stone of Purity
(21512, 57, 2091, 4255, 0, 700000), -- Adena
(21512, 11951, 1, 1, 1, 214.992176), -- Common Item - Bloody Orchid
(21512, 5536, 1, 1, 1, 2657.007824), -- Bloody Orchid Head
(21512, 1872, 1, 3, 2, 63113.582088), -- Animal Bone
(21512, 1867, 1, 1, 2, 189341.13186), -- Animal Skin
(21512, 1881, 1, 1, 2, 18934.305984), -- Coarse Bone Powder
(21512, 1875, 1, 1, 2, 9467.152992), -- Stone of Purity
(21512, 4041, 1, 1, 2, 1234.678392), -- Mold Hardener
(21512, 5462, 1, 1, 2, 52.441056), -- Recipe: Branch of the Mother Tree(60%)
(21512, 8730, 1, 1, 2, 1577.858832), -- Life Stone - Level 67
(21512, 8740, 1, 1, 2, 394.464708), -- Mid-Grade Life Stone - Level 67
(21512, 8750, 1, 1, 2, 39.330792), -- High-Grade Life Stone - Level 67
(21512, 8760, 1, 1, 2, 7.71192), -- Top-Grade Life Stone - Level 67
(21512, 1343, 20, 60, 2, 101433.341376), -- Silver Arrow
-- Needle Stakato
(21513, 5486, 1, 1, -1, 22058), -- Sealed Dark Crystal Robe Fabric
(21513, 5442, 1, 1, -1, 1381), -- Recipe: Soul Bow(60%)
(21513, 5489, 1, 1, -1, 49202), -- Sealed Tallum Stockings Fabric
(21513, 57, 1474, 2999, 0, 700000), -- Adena
(21513, 12224, 1, 1, 1, 599.752132), -- Common Item - Sealed Dark Crystal Boots
(21513, 5496, 1, 1, 1, 3227.247868), -- Sealed Dark Crystal Boots Lining
(21513, 12231, 1, 1, 1, 599.752132), -- Common Item - Sealed Tallum Boots
(21513, 5497, 1, 1, 1, 3227.247868), -- Sealed Tallum Boots Lining
(21513, 12221, 1, 1, 1, 599.752132), -- Common Item - Sealed Dark Crystal Gloves
(21513, 5508, 1, 1, 1, 3227.247868), -- Sealed Dark Crystal Gloves Design
(21513, 12229, 1, 1, 1, 599.752132), -- Common Item - Sealed Tallum Gloves
(21513, 5509, 1, 1, 1, 3227.247868), -- Sealed Tallum Gloves Design
(21513, 1895, 1, 1, 2, 34957.114227), -- Metallic Fiber
(21513, 4040, 1, 1, 2, 2446.985763), -- Mold Lubricant
(21513, 4042, 1, 1, 2, 2039.177456), -- Enria
(21513, 4043, 1, 1, 2, 4078.309605), -- Asofe
(21513, 5464, 1, 1, 2, 45.307), -- Recipe: Dark Legion's Edge(60%)
(21513, 8730, 1, 1, 2, 1359.436535), -- Life Stone - Level 67
(21513, 8740, 1, 1, 2, 339.847807), -- Mid-Grade Life Stone - Level 67
(21513, 8750, 1, 1, 2, 33.98025), -- High-Grade Life Stone - Level 67
(21513, 8760, 1, 1, 2, 6.841357), -- Top-Grade Life Stone - Level 67
-- Needle Stakato Worker
(21514, 4039, 1, 1, -1, 86637), -- Mold Glue
(21514, 5479, 1, 1, -1, 15379), -- Sealed Tallum Leather Armor Pattern
(21514, 5462, 1, 1, -1, 963), -- Recipe: Branch of the Mother Tree(60%)
(21514, 57, 1283, 2614, 0, 700000), -- Adena
(21514, 11946, 1, 1, 1, 33.033082), -- Common Item - Dasparion's Staff
(21514, 5543, 1, 1, 1, 408.457488), -- Dasparion's Staff Head
(21514, 11949, 1, 1, 1, 33.033082), -- Common Item - Meteor Shower
(21514, 5532, 1, 1, 1, 404.642538), -- Meteor Shower Head
(21514, 11953, 1, 1, 1, 33.033082), -- Common Item - Spiritual Eye
(21514, 8341, 1, 1, 1, 404.125108), -- Spiritual Eye Piece
(21514, 11958, 1, 1, 1, 33.033082), -- Common Item - Destroyer Hammer
(21514, 8346, 1, 1, 1, 404.642538), -- Hammer Piece of Destroyer
(21514, 1864, 1, 1, 2, 191935.256553), -- Stem
(21514, 1869, 1, 1, 2, 95967.4333), -- Iron Ore
(21514, 1878, 1, 1, 2, 38386.97332), -- Braided Hemp
(21514, 1884, 1, 1, 2, 59056.822038), -- Cord
(21514, 4039, 1, 1, 2, 3198.784459), -- Mold Glue
(21514, 5272, 1, 1, 2, 42.504877), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21514, 8730, 1, 1, 2, 1066.131502), -- Life Stone - Level 67
(21514, 8740, 1, 1, 2, 266.727852), -- Mid-Grade Life Stone - Level 67
(21514, 8750, 1, 1, 2, 26.516804), -- High-Grade Life Stone - Level 67
(21514, 8760, 1, 1, 2, 5.849295), -- Top-Grade Life Stone - Level 67
-- Needle Stakato Soldier
(21515, 5524, 1, 1, -1, 31247), -- Sealed Dark Crystal Gaiters Pattern
(21515, 5442, 1, 1, -1, 1174), -- Recipe: Soul Bow(60%)
(21515, 5525, 1, 1, -1, 49008), -- Sealed Dark Crystal Helmet Design
(21515, 57, 1563, 3192, 0, 700000), -- Adena
(21515, 11951, 1, 1, 1, 161.094416), -- Common Item - Bloody Orchid
(21515, 5536, 1, 1, 1, 1990.905584), -- Bloody Orchid Head
(21515, 1873, 1, 1, 2, 39019.6404), -- Silver Nugget
(21515, 1868, 1, 1, 2, 195097.356504), -- Thread
(21515, 1876, 1, 1, 2, 19509.8202), -- Mithril Ore
(21515, 1895, 1, 1, 2, 27870.930144), -- Metallic Fiber
(21515, 4042, 1, 1, 2, 1625.888808), -- Enria
(21515, 5277, 1, 1, 2, 43.543044), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21515, 6670, 1, 1, 2, 16258.042584), -- Deluxe Chest Key - Grade 6
(21515, 8730, 1, 1, 2, 1083.925872), -- Life Stone - Level 67
(21515, 8740, 1, 1, 2, 270.981468), -- Mid-Grade Life Stone - Level 67
(21515, 8750, 1, 1, 2, 27.055872), -- High-Grade Life Stone - Level 67
(21515, 8760, 1, 1, 2, 5.495724), -- Top-Grade Life Stone - Level 67
(21515, 1344, 10, 30, 2, 121935.31938), -- Mithril Arrow
-- Needle Stakato Drone
(21516, 6337, 1, 1, -1, 19666), -- Recipe: Sealed Majestic Earring(70%)
(21516, 6345, 1, 1, -1, 146702), -- Sealed Phoenix Ring Gemstone
(21516, 6339, 1, 1, -1, 29498), -- Recipe: Sealed Majestic Ring(70%)
(21516, 57, 1894, 3856, 0, 700000), -- Adena
(21516, 11951, 1, 1, 1, 194.930232), -- Common Item - Bloody Orchid
(21516, 5536, 1, 1, 1, 2409.069768), -- Bloody Orchid Head
(21516, 1873, 1, 1, 2, 56636.885492), -- Silver Nugget
(21516, 1868, 1, 1, 2, 283185.252854), -- Thread
(21516, 1876, 1, 1, 2, 28318.442746), -- Mithril Ore
(21516, 1895, 1, 1, 2, 40455.036122), -- Metallic Fiber
(21516, 4042, 1, 1, 2, 2359.801446), -- Enria
(21516, 5282, 1, 1, 2, 62.729944), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21516, 8731, 1, 1, 2, 1311.138369), -- Life Stone - Level 70
(21516, 8741, 1, 1, 2, 327.681418), -- Mid-Grade Life Stone - Level 70
(21516, 8751, 1, 1, 2, 32.603063), -- High-Grade Life Stone - Level 70
(21516, 8761, 1, 1, 2, 7.428546), -- Top-Grade Life Stone - Level 70
-- Needle Stakato Drone
(21517, 5479, 1, 1, -1, 28262), -- Sealed Tallum Leather Armor Pattern
(21517, 5462, 1, 1, -1, 1769), -- Recipe: Branch of the Mother Tree(60%)
(21517, 5478, 1, 1, -1, 40163), -- Sealed Dark Crystal Leather Armor Pattern
(21517, 57, 2357, 4804, 0, 700000), -- Adena
(21517, 12222, 1, 1, 1, 426.904319), -- Common Item - Sealed Dark Crystal Leather Armor
(21517, 5478, 1, 1, 1, 2471.584192), -- Sealed Dark Crystal Leather Armor Pattern
(21517, 12230, 1, 1, 1, 262.427916), -- Common Item - Sealed Tallum Leather Armor
(21517, 5479, 1, 1, 1, 1739.176381), -- Sealed Tallum Leather Armor Pattern
(21517, 12228, 1, 1, 1, 683.540879), -- Common Item - Sealed Dark Crystal Leggings
(21517, 5482, 1, 1, 1, 3879.366313), -- Sealed Dark Crystal Leggings Design
(21517, 1864, 4, 12, 2, 44088.436778), -- Stem
(21517, 1865, 2, 6, 2, 35270.59454); -- Varnish

INSERT INTO `droplist` VALUES
(21517, 1866, 1, 1, 2, 117568.519398), -- Suede
(21517, 1873, 1, 1, 2, 70541.18908), -- Silver Nugget
(21517, 1868, 1, 3, 2, 117568.519398), -- Thread
(21517, 5162, 1, 1, 2, 78.215612), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21517, 8731, 1, 1, 2, 1632.847702), -- Life Stone - Level 70
(21517, 8741, 1, 1, 2, 408.115124), -- Mid-Grade Life Stone - Level 70
(21517, 8751, 1, 1, 2, 40.65663), -- High-Grade Life Stone - Level 70
(21517, 8761, 1, 1, 2, 8.905738), -- Top-Grade Life Stone - Level 70
-- Frenzied Stakato Soldier
(21518, 4041, 1, 1, -1, 28954), -- Mold Hardener
(21518, 5509, 1, 1, -1, 78069), -- Sealed Tallum Gloves Design
(21518, 5462, 1, 1, -1, 1233), -- Recipe: Branch of the Mother Tree(60%)
(21518, 57, 1317, 2677, 0, 700000), -- Adena
(21518, 11955, 1, 1, 1, 135.354954), -- Common Item - Carnage Bow
(21518, 5535, 1, 1, 1, 1677.645046), -- Carnage Bow Stave
(21518, 1866, 1, 1, 2, 59607.885623), -- Suede
(21518, 1871, 1, 1, 2, 89411.973365), -- Charcoal
(21518, 5220, 1, 1, 2, 3576.594879), -- Metal Hardener
(21518, 1885, 1, 1, 2, 7450.877005), -- High-Grade Suede
(21518, 4041, 1, 1, 2, 777.407202), -- Mold Hardener
(21518, 5462, 1, 1, 2, 33.044154), -- Recipe: Branch of the Mother Tree(60%)
(21518, 8730, 1, 1, 2, 993.353647), -- Life Stone - Level 67
(21518, 8740, 1, 1, 2, 248.410877), -- Mid-Grade Life Stone - Level 67
(21518, 8750, 1, 1, 2, 24.928046), -- High-Grade Life Stone - Level 67
(21518, 8760, 1, 1, 2, 4.927637), -- Top-Grade Life Stone - Level 67
(21518, 1343, 10, 30, 2, 127731.597565), -- Silver Arrow
-- Frenzied Stakato Drone
(21519, 5448, 1, 1, -1, 1118), -- Recipe: Soul Separator(60%)
(21519, 5526, 1, 1, -1, 46659), -- Sealed Tallum Helm Design
(21519, 729, 1, 1, -1, 335), -- Scroll: Enchant Weapon (A-Grade)
(21519, 57, 1488, 3039, 0, 700000), -- Adena
(21519, 12224, 1, 1, 1, 607.000247), -- Common Item - Sealed Dark Crystal Boots
(21519, 5496, 1, 1, 1, 3266.249753), -- Sealed Dark Crystal Boots Lining
(21519, 12231, 1, 1, 1, 607.000247), -- Common Item - Sealed Tallum Boots
(21519, 5497, 1, 1, 1, 3266.249753), -- Sealed Tallum Boots Lining
(21519, 12221, 1, 1, 1, 607.000247), -- Common Item - Sealed Dark Crystal Gloves
(21519, 5508, 1, 1, 1, 3266.249753), -- Sealed Dark Crystal Gloves Design
(21519, 12229, 1, 1, 1, 607.000247), -- Common Item - Sealed Tallum Gloves
(21519, 5509, 1, 1, 1, 3266.249753), -- Sealed Tallum Gloves Design
(21519, 1873, 1, 1, 2, 44579.3375), -- Silver Nugget
(21519, 1868, 1, 1, 2, 222896.6875), -- Thread
(21519, 1876, 1, 1, 2, 22289.5062), -- Mithril Ore
(21519, 1895, 1, 1, 2, 31842.2446), -- Metallic Fiber
(21519, 4042, 1, 1, 2, 1857.6214), -- Enria
(21519, 5282, 1, 1, 2, 49.4152), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21519, 8730, 1, 1, 2, 1238.3059), -- Life Stone - Level 67
(21519, 8740, 1, 1, 2, 309.4952), -- Mid-Grade Life Stone - Level 67
(21519, 8750, 1, 1, 2, 30.8845), -- High-Grade Life Stone - Level 67
(21519, 8760, 1, 1, 2, 6.502), -- Top-Grade Life Stone - Level 67
-- Eye of Splendor
(21520, 4049, 1, 1, -1, 159526), -- Adamantite Earring Gemstone
(21520, 4129, 1, 1, -1, 32915), -- Recipe: Earrings of Black Ore (100%)
(21520, 4050, 1, 1, -1, 188436), -- Adamantite Ring Wire
(21520, 57, 1203, 2445, 0, 700000), -- Adena
(21520, 12338, 1, 1, 1, 1227.274644), -- Common Item - Adamantite Earring
(21520, 4049, 1, 1, 1, 7853.442654), -- Adamantite Earring Gemstone
(21520, 12339, 1, 1, 1, 921.385206), -- Common Item - Adamantite Necklace
(21520, 4051, 1, 1, 1, 5806.70106), -- Adamantite Necklace Chain
(21520, 12340, 1, 1, 1, 1848.48042), -- Common Item - Adamantite Ring
(21520, 4050, 1, 1, 1, 9276.716016), -- Adamantite Ring Wire
(21520, 1895, 1, 1, 2, 25667.75232), -- Metallic Fiber
(21520, 4040, 1, 1, 2, 1796.769408), -- Mold Lubricant
(21520, 4042, 1, 1, 2, 1497.352416), -- Enria
(21520, 4043, 1, 1, 2, 2994.571104), -- Asofe
(21520, 947, 1, 1, 2, 35.972832), -- Scroll: Enchant Weapon (B-Grade)
(21520, 8728, 1, 1, 2, 1497.352416), -- Life Stone - Level 61
(21520, 8738, 1, 1, 2, 374.304672), -- Mid-Grade Life Stone - Level 61
(21520, 8748, 1, 1, 2, 37.44384), -- High-Grade Life Stone - Level 61
(21520, 8758, 1, 1, 2, 7.488768), -- Top-Grade Life Stone - Level 61
(21520, 1832, 1, 1, 2, 99818.992224), -- Greater Antidote
-- Claws of Splendor
(21521, 4130, 1, 1, -1, 48542), -- Recipe: Ring of Black Ore (100%)
(21521, 4051, 1, 1, -1, 115966), -- Adamantite Necklace Chain
(21521, 947, 1, 1, -1, 1196), -- Scroll: Enchant Weapon (B-Grade)
(21521, 57, 1183, 2404, 0, 700000), -- Adena
(21521, 78, 1, 1, 1, 4.407042), -- Great Sword
(21521, 4104, 1, 1, 1, 842.293074), -- Great Sword Blade
(21521, 142, 1, 1, 1, 4.407042), -- Keshanberk
(21521, 4107, 1, 1, 1, 829.2429), -- Keshanberk Blade
(21521, 148, 1, 1, 1, 4.407042), -- Sword of Valhalla
(21521, 4108, 1, 1, 1, 829.2429), -- Sword of Valhalla Blade
(21521, 1868, 1, 1, 2, 160591.3517), -- Thread
(21521, 1873, 1, 1, 2, 32118.3903), -- Silver Nugget
(21521, 5549, 1, 1, 2, 8029.5226), -- Metallic Thread
(21521, 1889, 1, 1, 2, 5352.9151), -- Compound Braid
(21521, 4044, 1, 1, 2, 2676.6075), -- Thons
(21521, 948, 1, 1, 2, 200.6331), -- Scroll: Enchant Armor (B-Grade)
(21521, 8728, 1, 1, 2, 1338.1538), -- Life Stone - Level 61
(21521, 8738, 1, 1, 2, 334.6884), -- Mid-Grade Life Stone - Level 61
(21521, 8748, 1, 1, 2, 33.5888), -- High-Grade Life Stone - Level 61
(21521, 8758, 1, 1, 2, 6.5978), -- Top-Grade Life Stone - Level 61
(21521, 1832, 1, 1, 2, 89217.5509), -- Greater Antidote
-- Claws of Splendor
(21522, 4130, 1, 1, -1, 57851), -- Recipe: Ring of Black Ore (100%)
(21522, 4051, 1, 1, -1, 138206), -- Adamantite Necklace Chain
(21522, 947, 1, 1, -1, 1425), -- Scroll: Enchant Weapon (B-Grade)
(21522, 57, 1409, 2865, 0, 700000), -- Adena
(21522, 78, 1, 1, 1, 5.251988), -- Great Sword
(21522, 4104, 1, 1, 1, 1003.782836), -- Great Sword Blade
(21522, 142, 1, 1, 1, 5.251988), -- Keshanberk
(21522, 4107, 1, 1, 1, 988.2306), -- Keshanberk Blade
(21522, 148, 1, 1, 1, 5.251988), -- Sword of Valhalla
(21522, 4108, 1, 1, 1, 988.2306), -- Sword of Valhalla Blade
(21522, 1868, 1, 1, 2, 191390.191928), -- Thread
(21522, 1873, 1, 1, 2, 38278.181352), -- Silver Nugget
(21522, 5549, 1, 1, 2, 9569.455984), -- Metallic Thread
(21522, 1889, 1, 1, 2, 6379.518184), -- Compound Braid
(21522, 4044, 1, 1, 2, 3189.9378), -- Thons
(21522, 948, 1, 1, 2, 239.111304), -- Scroll: Enchant Armor (B-Grade)
(21522, 8728, 1, 1, 2, 1594.790192), -- Life Stone - Level 61
(21522, 8738, 1, 1, 2, 398.876256), -- Mid-Grade Life Stone - Level 61
(21522, 8748, 1, 1, 2, 40.030592), -- High-Grade Life Stone - Level 61
(21522, 8758, 1, 1, 2, 7.863152), -- Top-Grade Life Stone - Level 61
(21522, 1832, 1, 1, 2, 106328.043256), -- Greater Antidote
-- Flash of Splendor
(21523, 4159, 1, 1, -1, 8709), -- Recipe: Blue Wolf Leather Armor (100%)
(21523, 4070, 1, 1, -1, 110051), -- Stockings of Zubei Fabric
(21523, 948, 1, 1, -1, 7686), -- Scroll: Enchant Armor (B-Grade)
(21523, 57, 1218, 2471, 0, 700000), -- Adena
(21523, 357, 1, 1, 1, 14.22495), -- Zubei's Breastplate
(21523, 4056, 1, 1, 1, 2055.231313), -- Zubei's Breastplate Part
(21523, 2376, 1, 1, 1, 14.22495), -- Avadon Breastplate
(21523, 4064, 1, 1, 1, 2055.231313), -- Avadon Breastplate Part
(21523, 383, 1, 1, 1, 22.75992), -- Zubei's Gaiters
(21523, 4057, 1, 1, 1, 3176.27328), -- Zubei's Gaiter Material
(21523, 2379, 1, 1, 1, 22.75992), -- Avadon Gaiters
(21523, 4065, 1, 1, 1, 3176.294354), -- Avadon Gaiters Material
(21523, 1864, 1, 3, 2, 75674.68986), -- Stem
(21523, 1865, 1, 1, 2, 75674.68986), -- Varnish
(21523, 1866, 1, 1, 2, 50449.79324), -- Suede
(21523, 1873, 1, 1, 2, 30269.875944), -- Silver Nugget
(21523, 1868, 1, 1, 2, 151349.37972), -- Thread
(21523, 4160, 1, 1, 2, 214.464635), -- Recipe: Leather Armor of Doom (100%)
(21523, 6670, 1, 1, 2, 12612.44831), -- Deluxe Chest Key - Grade 6
(21523, 8728, 1, 1, 2, 1261.244831), -- Life Stone - Level 61
(21523, 8738, 1, 1, 2, 315.190722), -- Mid-Grade Life Stone - Level 61
(21523, 8748, 1, 1, 2, 31.326295), -- High-Grade Life Stone - Level 61
(21523, 8758, 1, 1, 2, 6.265259), -- Top-Grade Life Stone - Level 61
(21523, 1832, 1, 1, 2, 84083.631324), -- Greater Antidote
-- Blade of Splendor
(21524, 4159, 1, 1, -1, 9286), -- Recipe: Blue Wolf Leather Armor (100%)
(21524, 4070, 1, 1, -1, 117344), -- Stockings of Zubei Fabric
(21524, 948, 1, 1, -1, 8195), -- Scroll: Enchant Armor (B-Grade)
(21524, 57, 1299, 2634, 0, 700000), -- Adena
(21524, 12151, 1, 1, 1, 515.581772), -- Common Item - Zubei's Leather Shirt
(21524, 4066, 1, 1, 1, 3804.706272), -- Zubei's Leather Shirt Fabric
(21524, 12165, 1, 1, 1, 316.421566), -- Common Item - Avadon Leather Armor
(21524, 4068, 1, 1, 1, 2922.96599), -- Avadon Leather Armor Lining
(21524, 12150, 1, 1, 1, 825.460494), -- Common Item - Zubei's Leather Gaiters
(21524, 4067, 1, 1, 1, 5776.863906), -- Zubei's Leather Gaiter Texture
(21524, 1869, 1, 1, 2, 88025.00568), -- Iron Ore
(21524, 1870, 1, 1, 2, 88025.00568), -- Coal
(21524, 1871, 1, 1, 2, 88025.00568), -- Charcoal
(21524, 1872, 1, 3, 2, 39122.170782), -- Animal Bone
(21524, 1867, 1, 1, 2, 117366.512346), -- Animal Skin
(21524, 4161, 1, 1, 2, 365.232864), -- Recipe: Blue Wolf Tunic (100%)
(21524, 8728, 1, 1, 2, 1467.245322), -- Life Stone - Level 61
(21524, 8738, 1, 1, 2, 366.68991), -- Mid-Grade Life Stone - Level 61
(21524, 8748, 1, 1, 2, 36.911832), -- High-Grade Life Stone - Level 61
(21524, 8758, 1, 1, 2, 7.28523), -- Top-Grade Life Stone - Level 61
(21524, 1343, 20, 60, 2, 62874.934674), -- Silver Arrow
-- Blade of Splendor
(21525, 4049, 1, 1, -1, 171939), -- Adamantite Earring Gemstone
(21525, 4129, 1, 1, -1, 35476), -- Recipe: Earrings of Black Ore (100%)
(21525, 4050, 1, 1, -1, 203099), -- Adamantite Ring Wire
(21525, 57, 1299, 2634, 0, 700000), -- Adena
(21525, 11915, 1, 1, 1, 138.54252), -- Common Item - Kris
(21525, 4109, 1, 1, 1, 1363.95748), -- Kris Edge
(21525, 11919, 1, 1, 1, 138.54252), -- Common Item - Hell Knife
(21525, 4110, 1, 1, 1, 1363.95748), -- Hell Knife Edge
(21525, 1894, 1, 1, 2, 3397.463606), -- Crafted Leather
(21525, 4039, 1, 1, 2, 3227.597982), -- Mold Glue
(21525, 4041, 1, 1, 2, 841.922946), -- Mold Hardener
(21525, 4044, 1, 1, 2, 3227.597982), -- Thons
(21525, 947, 1, 1, 2, 38.688256), -- Scroll: Enchant Weapon (B-Grade)
(21525, 8728, 1, 1, 2, 1613.874554), -- Life Stone - Level 61
(21525, 8738, 1, 1, 2, 403.50642), -- Mid-Grade Life Stone - Level 61
(21525, 8748, 1, 1, 2, 40.350642), -- High-Grade Life Stone - Level 61
(21525, 8758, 1, 1, 2, 8.009678), -- Top-Grade Life Stone - Level 61
(21525, 1343, 10, 30, 2, 138326.987934), -- Silver Arrow
-- Wisdom of Splendor
(21526, 5549, 1, 1, -1, 365298), -- Metallic Thread
(21526, 1889, 1, 1, -1, 243532), -- Compound Braid
(21526, 4052, 1, 1, -1, 129332), -- Earring of Black Ore Piece
(21526, 57, 1449, 2935, 0, 700000), -- Adena
(21526, 11930, 1, 1, 1, 58.731224), -- Common Item - Sword of Damascus
(21526, 4114, 1, 1, 1, 787.042528), -- Sword of Damascus Blade
(21526, 11929, 1, 1, 1, 58.731224), -- Common Item - Guardian Sword
(21526, 8330, 1, 1, 1, 785.718736), -- Guardian Sword Blade
(21526, 11943, 1, 1, 1, 58.731224), -- Common Item - Wizard's Tear
(21526, 8336, 1, 1, 1, 787.045064), -- Blade of the Wizard's Tear
(21526, 1868, 1, 1, 2, 215806.53255), -- Thread
(21526, 1873, 1, 1, 2, 43161.30651), -- Silver Nugget
(21526, 5549, 1, 1, 2, 10790.255994), -- Metallic Thread
(21526, 1889, 1, 1, 2, 7193.598174), -- Compound Braid
(21526, 4044, 1, 1, 2, 3596.65782), -- Thons
(21526, 1807, 1, 1, 2, 143.809806), -- Recipe: Soulshot (A-Grade)
(21526, 8729, 1, 1, 2, 1438.663128), -- Life Stone - Level 64
(21526, 8739, 1, 1, 2, 359.665782), -- Mid-Grade Life Stone - Level 64
(21526, 8749, 1, 1, 2, 35.881818), -- High-Grade Life Stone - Level 64
(21526, 8759, 1, 1, 2, 7.628418), -- Top-Grade Life Stone - Level 64
-- Fury of Splendor
(21527, 4040, 1, 1, -1, 64217), -- Mold Lubricant
(21527, 4081, 1, 1, -1, 31646), -- Doom Plate Armor Temper
(21527, 5161, 1, 1, -1, 4281), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21527, 57, 1273, 2578, 0, 700000), -- Adena
(21527, 12183, 1, 1, 1, 802.386192), -- Common Item - Doom Shield
(21527, 4077, 1, 1, 1, 7110.680208), -- Doom Shield Fragment
(21527, 12202, 1, 1, 1, 561.53184), -- Common Item - Blue Wolf Helmet
(21527, 4088, 1, 1, 1, 5973.93496), -- Blue Wolf Helmet Design
(21527, 12185, 1, 1, 1, 561.53184), -- Common Item - Doom Helmet
(21527, 4089, 1, 1, 1, 5973.93496), -- Doom Helmet Pattern
(21527, 1871, 1, 1, 2, 86221.05624), -- Charcoal
(21527, 1866, 1, 1, 2, 57480.70416), -- Suede
(21527, 1877, 1, 1, 2, 3448.732496), -- Adamantite Nugget
(21527, 4041, 1, 1, 2, 749.617088), -- Mold Hardener
(21527, 4040, 1, 1, 2, 1724.50344), -- Mold Lubricant
(21527, 5166, 1, 1, 2, 114.966896), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21527, 8729, 1, 1, 2, 1149.66896), -- Life Stone - Level 64
(21527, 8739, 1, 1, 2, 287.280048), -- Mid-Grade Life Stone - Level 64
(21527, 8749, 1, 1, 2, 28.81032), -- High-Grade Life Stone - Level 64
(21527, 8759, 1, 1, 2, 5.762064), -- Top-Grade Life Stone - Level 64
(21527, 1343, 10, 30, 2, 123172.898288), -- Silver Arrow
-- Fury of Splendor
(21528, 4040, 1, 1, -1, 79165), -- Mold Lubricant
(21528, 4081, 1, 1, -1, 39013), -- Doom Plate Armor Temper
(21528, 5161, 1, 1, -1, 5278), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21528, 57, 1570, 3179, 0, 700000), -- Adena
(21528, 12183, 1, 1, 1, 989.178822), -- Common Item - Doom Shield
(21528, 4077, 1, 1, 1, 8766.021078), -- Doom Shield Fragment
(21528, 12202, 1, 1, 1, 692.25444), -- Common Item - Blue Wolf Helmet
(21528, 4088, 1, 1, 1, 7364.64561), -- Blue Wolf Helmet Design
(21528, 12185, 1, 1, 1, 692.25444), -- Common Item - Doom Helmet
(21528, 4089, 1, 1, 1, 7364.64561), -- Doom Helmet Pattern
(21528, 1871, 1, 1, 2, 106291.24569), -- Charcoal
(21528, 1866, 1, 1, 2, 70860.83046), -- Suede
(21528, 1877, 1, 1, 2, 4251.514526), -- Adamantite Nugget
(21528, 4041, 1, 1, 2, 924.109928), -- Mold Hardener
(21528, 4040, 1, 1, 2, 2125.92639), -- Mold Lubricant
(21528, 5166, 1, 1, 2, 141.728426), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21528, 8729, 1, 1, 2, 1417.28426), -- Life Stone - Level 64
(21528, 8739, 1, 1, 2, 354.151938), -- Mid-Grade Life Stone - Level 64
(21528, 8749, 1, 1, 2, 35.51667), -- High-Grade Life Stone - Level 64
(21528, 8759, 1, 1, 2, 7.103334), -- Top-Grade Life Stone - Level 64
(21528, 1343, 10, 30, 2, 151844.588378), -- Silver Arrow
-- Soul of Splendor
(21529, 4082, 1, 1, -1, 34211), -- Blue Wolf Leather Armor Texture
(21529, 5166, 1, 1, -1, 4037), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21529, 4083, 1, 1, -1, 34211), -- Leather Armor of Doom Design
(21529, 57, 1201, 2431, 0, 700000), -- Adena
(21529, 12201, 1, 1, 1, 198.380952), -- Common Item - Blue Wolf Tunic
(21529, 4084, 1, 1, 1, 1942.807944), -- Blue Wolf Tunic Fabric
(21529, 12192, 1, 1, 1, 198.380952), -- Common Item - Tunic of Doom
(21529, 4085, 1, 1, 1, 1942.807944), -- Tunic of Doom Pattern
(21529, 12203, 1, 1, 1, 317.584344), -- Common Item - Blue Wolf Stockings
(21529, 4086, 1, 1, 1, 2623.22676), -- Blue Wolf Stockings Pattern
(21529, 12205, 1, 1, 1, 317.584344), -- Common Item - Stockings of Doom
(21529, 4087, 1, 1, 1, 2623.22676), -- Stockings of Doom Pattern
(21529, 1867, 1, 1, 2, 108403.127844), -- Animal Skin
(21529, 1872, 1, 1, 2, 108403.127844), -- Animal Bone
(21529, 1882, 1, 1, 2, 18067.187974), -- Leather
(21529, 1894, 1, 1, 2, 2852.800973), -- Crafted Leather
(21529, 4042, 1, 1, 2, 1355.088735), -- Enria
(21529, 5230, 1, 1, 2, 108.539464), -- Recipe: Mithril Arrow (100%)
(21529, 8729, 1, 1, 2, 1084.070988), -- Life Stone - Level 64
(21529, 8739, 1, 1, 2, 271.017747), -- Mid-Grade Life Stone - Level 64
(21529, 8749, 1, 1, 2, 27.134866), -- High-Grade Life Stone - Level 64
(21529, 8759, 1, 1, 2, 5.294608), -- Top-Grade Life Stone - Level 64
(21529, 1832, 1, 1, 2, 90335.608957), -- Greater Antidote
-- Victory of Splendor
(21530, 4120, 1, 1, -1, 14136), -- Bellion Cestus Edge
(21530, 5470, 1, 1, -1, 1768), -- Recipe: Tallum Blade(60%)
(21530, 4121, 1, 1, -1, 14088), -- Bow of Peril Shaft
(21530, 57, 1284, 2598, 0, 700000), -- Adena
(21530, 11933, 1, 1, 1, 156.0702), -- Common Item - Bellion Cestus
(21530, 4120, 1, 1, 1, 2087.9298), -- Bellion Cestus Edge
(21530, 1874, 1, 1, 2, 5791.093324), -- Oriharukon Ore
(21530, 1878, 1, 1, 2, 34746.439727), -- Braided Hemp
(21530, 1884, 1, 1, 2, 53456.172088), -- Cord
(21530, 1889, 1, 1, 2, 5791.093324), -- Compound Braid
(21530, 5220, 1, 1, 2, 3474.631951), -- Metal Hardener
(21530, 6333, 1, 1, 2, 997.320232), -- Recipe: Sealed Phoenix Ring(70%)
(21530, 6670, 1, 1, 2, 14477.73331), -- Deluxe Chest Key - Grade 6
(21530, 8729, 1, 1, 2, 1158.170578), -- Life Stone - Level 64
(21530, 8739, 1, 1, 2, 289.602753), -- Mid-Grade Life Stone - Level 64
(21530, 8749, 1, 1, 2, 28.972297), -- High-Grade Life Stone - Level 64
(21530, 8759, 1, 1, 2, 5.770416), -- Top-Grade Life Stone - Level 64
-- Punishment of Splendor
(21531, 1876, 1, 1, -1, 727098), -- Mithril Ore
(21531, 1895, 1, 3, -1, 519356), -- Metallic Fiber
(21531, 4052, 1, 1, -1, 128713), -- Earring of Black Ore Piece
(21531, 57, 1443, 2919, 0, 700000), -- Adena
(21531, 11944, 1, 1, 1, 175.396752), -- Common Item - Bow of Peril
(21531, 4121, 1, 1, 1, 2338.603248), -- Bow of Peril Shaft
(21531, 1873, 1, 1, 2, 39049.704768), -- Silver Nugget
(21531, 1868, 1, 1, 2, 195248.099239), -- Thread
(21531, 1876, 1, 1, 2, 19524.852384), -- Mithril Ore
(21531, 1895, 1, 1, 2, 27892.464291), -- Metallic Fiber
(21531, 4042, 1, 1, 2, 1627.071032), -- Enria
(21531, 1807, 1, 1, 2, 130.352507), -- Recipe: Soulshot (A-Grade)
(21531, 8729, 1, 1, 2, 1301.826666), -- Life Stone - Level 64
(21531, 8739, 1, 1, 2, 325.244366), -- Mid-Grade Life Stone - Level 64
(21531, 8749, 1, 1, 2, 32.694277), -- High-Grade Life Stone - Level 64
(21531, 8759, 1, 1, 2, 6.369015), -- Top-Grade Life Stone - Level 64
(21531, 1343, 10, 30, 2, 139462.321455), -- Silver Arrow
-- Shout of Splendor
(21532, 4054, 1, 1, -1, 74152), -- Necklace of Black Ore Beads
(21532, 1894, 1, 1, -1, 132094), -- Crafted Leather
(21532, 4042, 1, 1, -1, 62745), -- Enria
(21532, 57, 1492, 3025, 0, 700000), -- Adena
(21532, 11935, 1, 1, 1, 60.546192), -- Common Item - Deadman's Glory
(21532, 4116, 1, 1, 1, 809.977441), -- Deadman's Glory Stone
(21532, 11938, 1, 1, 1, 60.546192), -- Common Item - Art of Battle Axe
(21532, 4117, 1, 1, 1, 809.977441), -- Art of Battle Axe Blade
(21532, 11934, 1, 1, 1, 60.546192), -- Common Item - Staff of Evil Spirits
(21532, 4118, 1, 1, 1, 767.406542), -- Evil Spirit Head
(21532, 1867, 1, 1, 2, 148270.557621), -- Animal Skin
(21532, 1872, 1, 1, 2, 148270.557621), -- Animal Bone
(21532, 1882, 1, 1, 2, 24711.814428), -- Leather
(21532, 1894, 1, 1, 2, 3901.969314), -- Crafted Leather
(21532, 4042, 1, 1, 2, 1853.287398), -- Enria
(21532, 5450, 1, 1, 2, 41.118375), -- Recipe: Dragon Grinder(60%)
(21532, 8729, 1, 1, 2, 1482.564129), -- Life Stone - Level 64
(21532, 8739, 1, 1, 2, 370.723269), -- Mid-Grade Life Stone - Level 64
(21532, 8749, 1, 1, 2, 37.171011), -- High-Grade Life Stone - Level 64
(21532, 8759, 1, 1, 2, 7.236834), -- Top-Grade Life Stone - Level 64
-- Alliance of Splendor
(21533, 4077, 1, 1, -1, 144198), -- Doom Shield Fragment
(21533, 5470, 1, 1, -1, 1752), -- Recipe: Tallum Blade(60%)
(21533, 5348, 1, 1, -1, 6310), -- Recipe: Sealed Dark Crystal Robe(60%)
(21533, 57, 1270, 2576, 0, 700000), -- Adena
(21533, 12341, 1, 1, 1, 732.298035), -- Common Item - Earring of Black Ore
(21533, 4052, 1, 1, 1, 5587.226206), -- Earring of Black Ore Piece
(21533, 12342, 1, 1, 1, 548.915838), -- Common Item - Necklace of Black Ore
(21533, 4054, 1, 1, 1, 3108.346968), -- Necklace of Black Ore Beads
(21533, 12343, 1, 1, 1, 1095.90528), -- Common Item - Ring of Black Ore
(21533, 4053, 1, 1, 1, 6764.307673), -- Ring of Black Ore Gemstone
(21533, 1871, 1, 1, 2, 86078.01318), -- Charcoal
(21533, 1866, 1, 1, 2, 57385.250838), -- Suede
(21533, 1877, 1, 1, 2, 3443.065758), -- Adamantite Nugget
(21533, 4041, 1, 1, 2, 748.421118), -- Mold Hardener
(21533, 4040, 1, 1, 2, 1721.669802), -- Mold Lubricant
(21533, 5456, 1, 1, 2, 31.766136), -- Recipe: Tallum Glaive(60%)
(21533, 8729, 1, 1, 2, 1147.688586), -- Life Stone - Level 64
(21533, 8739, 1, 1, 2, 286.990608), -- Mid-Grade Life Stone - Level 64
(21533, 8749, 1, 1, 2, 28.75383), -- High-Grade Life Stone - Level 64
(21533, 8759, 1, 1, 2, 5.750766), -- Top-Grade Life Stone - Level 64
(21533, 1343, 10, 30, 2, 122968.629378), -- Silver Arrow
-- Alliance of Splendor
(21534, 4077, 1, 1, -1, 190615), -- Doom Shield Fragment
(21534, 5470, 1, 1, -1, 2316), -- Recipe: Tallum Blade(60%)
(21534, 5348, 1, 1, -1, 8341), -- Recipe: Sealed Dark Crystal Robe(60%)
(21534, 57, 1679, 3405, 0, 700000), -- Adena
(21534, 12341, 1, 1, 1, 968.035845), -- Common Item - Earring of Black Ore
(21534, 4052, 1, 1, 1, 7385.838802), -- Earring of Black Ore Piece
(21534, 12342, 1, 1, 1, 725.620146), -- Common Item - Necklace of Black Ore
(21534, 4054, 1, 1, 1, 4108.970856), -- Necklace of Black Ore Beads
(21534, 12343, 1, 1, 1, 1448.69376), -- Common Item - Ring of Black Ore
(21534, 4053, 1, 1, 1, 8941.840591), -- Ring of Black Ore Gemstone
(21534, 1871, 1, 1, 2, 113786.83134), -- Charcoal
(21534, 1866, 1, 1, 2, 75857.766894), -- Suede
(21534, 1877, 1, 1, 2, 4551.400854), -- Adamantite Nugget
(21534, 4041, 1, 1, 2, 989.340534), -- Mold Hardener
(21534, 4040, 1, 1, 2, 2275.881426), -- Mold Lubricant
(21534, 5456, 1, 1, 2, 41.991768), -- Recipe: Tallum Glaive(60%)
(21534, 8729, 1, 1, 2, 1517.133618), -- Life Stone - Level 64
(21534, 8739, 1, 1, 2, 379.373904), -- Mid-Grade Life Stone - Level 64
(21534, 8749, 1, 1, 2, 38.00979), -- High-Grade Life Stone - Level 64
(21534, 8759, 1, 1, 2, 7.601958), -- Top-Grade Life Stone - Level 64
(21534, 1343, 10, 30, 2, 162552.667914), -- Silver Arrow
-- Signet of Splendor
(21535, 1876, 1, 1, -1, 759357), -- Mithril Ore
(21535, 1877, 1, 1, -1, 151871), -- Adamantite Nugget
(21535, 4052, 1, 1, -1, 134423), -- Earring of Black Ore Piece
(21535, 57, 1504, 3050, 0, 700000), -- Adena
(21535, 11930, 1, 1, 1, 61.047124), -- Common Item - Sword of Damascus
(21535, 4114, 1, 1, 1, 818.077328), -- Sword of Damascus Blade
(21535, 11929, 1, 1, 1, 61.047124), -- Common Item - Guardian Sword
(21535, 8330, 1, 1, 1, 816.701336), -- Guardian Sword Blade
(21535, 11943, 1, 1, 1, 61.047124), -- Common Item - Wizard's Tear
(21535, 8336, 1, 1, 1, 818.079964), -- Blade of the Wizard's Tear
(21535, 1876, 1, 1, 2, 20391.1506), -- Mithril Ore
(21535, 1880, 1, 1, 2, 10195.5753), -- Steel
(21535, 1877, 1, 1, 2, 4078.3176), -- Adamantite Nugget
(21535, 1881, 1, 1, 2, 13594.1733), -- Coarse Bone Powder
(21535, 1882, 1, 1, 2, 22656.8826), -- Leather
(21535, 6335, 1, 1, 2, 392.1291), -- Recipe: Sealed Majestic Necklace(70%)
(21535, 8729, 1, 1, 2, 1359.4392), -- Life Stone - Level 64
(21535, 8739, 1, 1, 2, 339.8598), -- Mid-Grade Life Stone - Level 64
(21535, 8749, 1, 1, 2, 33.8985), -- High-Grade Life Stone - Level 64
(21535, 8759, 1, 1, 2, 6.7797), -- Top-Grade Life Stone - Level 64
(21535, 1343, 10, 30, 2, 145651.7943), -- Silver Arrow
-- Crown of Splendor
(21536, 5446, 1, 1, -1, 2006), -- Recipe: Bloody Orchid(60%)
(21536, 4053, 1, 1, -1, 157335), -- Ring of Black Ore Gemstone
(21536, 5452, 1, 1, -1, 2006), -- Recipe: Blood Tornado(60%)
(21536, 57, 1454, 2949, 0, 700000), -- Adena
(21536, 11939, 1, 1, 1, 177.0771), -- Common Item - Demon's Dagger
(21536, 4119, 1, 1, 1, 2372.9229), -- Demon's Dagger Edge
(21536, 1894, 1, 1, 2, 3804.400284), -- Crafted Leather
(21536, 4039, 1, 1, 2, 3614.193251), -- Mold Glue
(21536, 4041, 1, 1, 2, 942.824556), -- Mold Hardener
(21536, 4044, 1, 1, 2, 3614.193251), -- Thons
(21536, 6337, 1, 1, 2, 556.017249), -- Recipe: Sealed Majestic Earring(70%)
(21536, 6670, 1, 1, 2, 18070.901349), -- Deluxe Chest Key - Grade 6
(21536, 8729, 1, 1, 2, 1445.683791), -- Life Stone - Level 64
(21536, 8739, 1, 1, 2, 361.429061), -- Mid-Grade Life Stone - Level 64
(21536, 8749, 1, 1, 2, 36.152642), -- High-Grade Life Stone - Level 64
(21536, 8759, 1, 1, 2, 7.204566), -- Top-Grade Life Stone - Level 64
-- Fang of Splendor
(21537, 1874, 1, 1, -1, 246235), -- Oriharukon Ore
(21537, 4043, 1, 1, -1, 123118), -- Asofe
(21537, 4099, 1, 1, -1, 165815), -- Sealed Doom Boots Part
(21537, 57, 1456, 2976, 0, 700000), -- Adena
(21537, 11944, 1, 1, 1, 178.187472), -- Common Item - Bow of Peril
(21537, 4121, 1, 1, 1, 2375.812528), -- Bow of Peril Shaft
(21537, 1870, 1, 1, 2, 99183.032124), -- Coal
(21537, 1865, 1, 1, 2, 99183.032124), -- Varnish
(21537, 1874, 1, 1, 2, 6612.24476), -- Oriharukon Ore
(21537, 4043, 1, 1, 2, 3306.12238), -- Asofe
(21537, 4039, 1, 1, 2, 3306.12238), -- Mold Glue
(21537, 5442, 1, 1, 2, 36.651824), -- Recipe: Soul Bow(60%)
(21537, 8300, 1, 1, 2, 54.125368), -- Recipe: Infernal Master (60%)
(21537, 8730, 1, 1, 2, 1102.111824), -- Life Stone - Level 67
(21537, 8740, 1, 1, 2, 275.527956), -- Mid-Grade Life Stone - Level 67
(21537, 8750, 1, 1, 2, 27.488868), -- High-Grade Life Stone - Level 67
(21537, 8760, 1, 1, 2, 5.540392), -- Top-Grade Life Stone - Level 67
-- Fang of Splendor
(21538, 1874, 1, 1, -1, 301635), -- Oriharukon Ore
(21538, 4043, 1, 1, -1, 150818), -- Asofe
(21538, 4099, 1, 1, -1, 203121), -- Sealed Doom Boots Part
(21538, 57, 1784, 3645, 0, 700000), -- Adena
(21538, 11944, 1, 1, 1, 218.304072), -- Common Item - Bow of Peril
(21538, 4121, 1, 1, 1, 2910.695928), -- Bow of Peril Shaft
(21538, 1870, 1, 1, 2, 133647.416725), -- Coal
(21538, 1865, 1, 1, 2, 133647.416725), -- Varnish
(21538, 1874, 1, 1, 2, 8909.92347), -- Oriharukon Ore
(21538, 4043, 1, 1, 2, 4454.961735), -- Asofe
(21538, 4039, 1, 1, 2, 4454.961735), -- Mold Glue
(21538, 5442, 1, 1, 2, 49.37518), -- Recipe: Soul Bow(60%)
(21538, 8730, 1, 1, 2, 1484.987245), -- Life Stone - Level 67
(21538, 8740, 1, 1, 2, 371.175045), -- Mid-Grade Life Stone - Level 67
(21538, 8750, 1, 1, 2, 37.031385), -- High-Grade Life Stone - Level 67
(21538, 8760, 1, 1, 2, 7.750755), -- Top-Grade Life Stone - Level 67
-- Wailing of Splendor
(21539, 1807, 1, 1, -1, 5356), -- Recipe: Soulshot (A-Grade)
(21539, 4114, 1, 1, -1, 17583), -- Sword of Damascus Blade
(21539, 3035, 1, 1, -1, 5356), -- Recipe: Spiritshot A
(21539, 57, 1584, 3236, 0, 700000), -- Adena
(21539, 12201, 1, 1, 1, 263.219748), -- Common Item - Blue Wolf Tunic
(21539, 4084, 1, 1, 1, 2577.794956), -- Blue Wolf Tunic Fabric
(21539, 12192, 1, 1, 1, 263.219748), -- Common Item - Tunic of Doom
(21539, 4085, 1, 1, 1, 2577.794956), -- Tunic of Doom Pattern
(21539, 12203, 1, 1, 1, 421.383556), -- Common Item - Blue Wolf Stockings
(21539, 4086, 1, 1, 1, 3480.60174), -- Blue Wolf Stockings Pattern
(21539, 12205, 1, 1, 1, 421.383556), -- Common Item - Stockings of Doom
(21539, 4087, 1, 1, 1, 3480.60174), -- Stockings of Doom Pattern
(21539, 1871, 1, 1, 2, 107870.988181), -- Charcoal
(21539, 1866, 1, 1, 2, 71914.106411), -- Suede
(21539, 1877, 1, 1, 2, 4314.688664), -- Adamantite Nugget
(21539, 4041, 1, 1, 2, 938.095056), -- Mold Hardener
(21539, 4040, 1, 1, 2, 2157.344332), -- Mold Lubricant
(21539, 5448, 1, 1, 2, 40.115907), -- Recipe: Soul Separator(60%)
(21539, 8730, 1, 1, 2, 1198.677016), -- Life Stone - Level 67
(21539, 8740, 1, 1, 2, 299.669254), -- Mid-Grade Life Stone - Level 67
(21539, 8750, 1, 1, 2, 29.829777), -- High-Grade Life Stone - Level 67
(21539, 8760, 1, 1, 2, 5.828807), -- Top-Grade Life Stone - Level 67
(21539, 1343, 10, 30, 2, 154101.656595), -- Silver Arrow
-- Wailing of Splendor
(21540, 1807, 1, 1, -1, 5356), -- Recipe: Soulshot (A-Grade)
(21540, 4053, 1, 1, -1, 172185), -- Ring of Black Ore Gemstone
(21540, 3035, 1, 1, -1, 5356), -- Recipe: Spiritshot A
(21540, 57, 1584, 3236, 0, 700000), -- Adena
(21540, 11935, 1, 1, 1, 64.599888), -- Common Item - Deadman's Glory
(21540, 4116, 1, 1, 1, 864.207149), -- Deadman's Glory Stone
(21540, 11938, 1, 1, 1, 64.599888), -- Common Item - Art of Battle Axe
(21540, 4117, 1, 1, 1, 864.207149), -- Art of Battle Axe Blade
(21540, 11934, 1, 1, 1, 64.599888), -- Common Item - Staff of Evil Spirits
(21540, 4118, 1, 1, 1, 818.786038), -- Evil Spirit Head
(21540, 1894, 1, 1, 2, 3784.936896), -- Crafted Leather
(21540, 4039, 1, 1, 2, 3595.55526), -- Mold Glue
(21540, 4041, 1, 1, 2, 937.978263), -- Mold Hardener
(21540, 4044, 1, 1, 2, 3595.55526), -- Thons
(21540, 729, 1, 1, 2, 11.962719), -- Scroll: Enchant Weapon (A-Grade)
(21540, 5394, 1, 1, 2, 929.890791), -- Recipe: Sealed Tallum Gloves(60%)
(21540, 8730, 1, 1, 2, 1198.462257), -- Life Stone - Level 67
(21540, 8740, 1, 1, 2, 299.573442), -- Mid-Grade Life Stone - Level 67
(21540, 8750, 1, 1, 2, 29.991042), -- High-Grade Life Stone - Level 67
(21540, 8760, 1, 1, 2, 6.065604), -- Top-Grade Life Stone - Level 67
(21540, 1343, 10, 30, 2, 154099.028466), -- Silver Arrow
-- Pilgrim of Splendor
(21541, 1874, 1, 1, -1, 272060), -- Oriharukon Ore
(21541, 4043, 1, 1, -1, 136030), -- Asofe
(21541, 4084, 1, 1, -1, 70923), -- Blue Wolf Tunic Fabric
(21541, 57, 1619, 3277, 0, 700000), -- Adena
(21541, 11930, 1, 1, 1, 65.632606), -- Common Item - Sword of Damascus
(21541, 4114, 1, 1, 1, 879.526232), -- Sword of Damascus Blade
(21541, 11929, 1, 1, 1, 65.632606), -- Common Item - Guardian Sword
(21541, 8330, 1, 1, 1, 878.046884), -- Guardian Sword Blade
(21541, 11943, 1, 1, 1, 65.632606), -- Common Item - Wizard's Tear
(21541, 8336, 1, 1, 1, 879.529066), -- Blade of the Wizard's Tear
(21541, 1870, 1, 1, 2, 100452.93293), -- Coal
(21541, 1865, 1, 1, 2, 100452.93293), -- Varnish
(21541, 1874, 1, 1, 2, 6696.982368), -- Oriharukon Ore
(21541, 4043, 1, 1, 2, 3348.491184), -- Asofe
(21541, 4039, 1, 1, 2, 3348.491184), -- Mold Glue
(21541, 5271, 1, 1, 2, 134.112696), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21541, 5392, 1, 1, 2, 865.964236), -- Recipe: Sealed Dark Crystal Gloves(60%)
(21541, 8729, 1, 1, 2, 1339.32437), -- Life Stone - Level 64
(21541, 8739, 1, 1, 2, 334.921222), -- Mid-Grade Life Stone - Level 64
(21541, 8749, 1, 1, 2, 33.528174), -- High-Grade Life Stone - Level 64
(21541, 8759, 1, 1, 2, 6.849842), -- Top-Grade Life Stone - Level 64
(21541, 1343, 10, 30, 2, 143503.468864), -- Silver Arrow
-- Disciple of Pilgrim
(21542, 1807, 1, 1, -1, 3783), -- Recipe: Soulshot (A-Grade)
(21542, 4053, 1, 1, -1, 121630), -- Ring of Black Ore Gemstone
(21542, 3035, 1, 1, -1, 3783), -- Recipe: Spiritshot A
(21542, 57, 1125, 2280, 0, 700000), -- Adena
(21542, 11939, 1, 1, 1, 136.870182), -- Common Item - Demon's Dagger
(21542, 4119, 1, 1, 1, 1834.129818), -- Demon's Dagger Edge
(21542, 1869, 1, 1, 2, 76198.948452), -- Iron Ore
(21542, 1864, 1, 1, 2, 152398.246935), -- Stem
(21542, 1880, 1, 1, 2, 7619.824839), -- Steel
(21542, 5550, 1, 1, 2, 1016.139993), -- Durable Metal Plate
(21542, 4043, 1, 1, 2, 2539.824936), -- Asofe
(21542, 3035, 1, 1, 2, 101.50899), -- Recipe: Spiritshot A
(21542, 8729, 1, 1, 2, 1016.139993), -- Life Stone - Level 64
(21542, 8739, 1, 1, 2, 254.122506), -- Mid-Grade Life Stone - Level 64
(21542, 8749, 1, 1, 2, 25.552263), -- High-Grade Life Stone - Level 64
(21542, 8759, 1, 1, 2, 5.250465), -- Top-Grade Life Stone - Level 64
(21542, 1343, 10, 30, 2, 108855.440628), -- Silver Arrow
-- Page of Pilgrim
(21543, 4054, 1, 1, -1, 63772), -- Necklace of Black Ore Beads
(21543, 1877, 1, 1, -1, 129509), -- Adamantite Nugget
(21543, 4041, 1, 1, -1, 28154), -- Mold Hardener
(21543, 57, 1284, 2601, 0, 700000), -- Adena
(21543, 11935, 1, 1, 1, 31.237596), -- Common Item - Deadman's Glory
(21543, 4116, 1, 1, 1, 417.895101), -- Deadman's Glory Stone
(21543, 11938, 1, 1, 1, 31.237596), -- Common Item - Art of Battle Axe
(21543, 4117, 1, 1, 1, 417.895101), -- Art of Battle Axe Blade
(21543, 11934, 1, 1, 1, 31.237596), -- Common Item - Staff of Evil Spirits
(21543, 4118, 1, 1, 1, 395.931861), -- Evil Spirit Head
(21543, 11941, 1, 1, 1, 31.237596), -- Common Item - Kaim Vanul's Bones
(21543, 8340, 1, 1, 1, 417.895101), -- Bones Head of Kaim Vanul
(21543, 11936, 1, 1, 1, 31.237596), -- Common Item - Star Buster
(21543, 8348, 1, 1, 1, 417.194856), -- Star Buster Head
(21543, 1871, 1, 1, 2, 95637.298175), -- Charcoal
(21543, 1866, 1, 1, 2, 63758.142875), -- Suede
(21543, 1877, 1, 1, 2, 3825.4718), -- Adamantite Nugget
(21543, 4041, 1, 1, 2, 831.58055), -- Mold Hardener
(21543, 4040, 1, 1, 2, 1912.7359), -- Mold Lubricant
(21543, 3956, 1, 1, 2, 127.471), -- Recipe: Blessed Spiritshot A
(21543, 8729, 1, 1, 2, 1275.213175), -- Life Stone - Level 64
(21543, 8739, 1, 1, 2, 318.845225), -- Mid-Grade Life Stone - Level 64
(21543, 8749, 1, 1, 2, 31.86775), -- High-Grade Life Stone - Level 64
(21543, 8759, 1, 1, 2, 6.37355), -- Top-Grade Life Stone - Level 64
-- Judge of Splendor
(21544, 4115, 1, 1, -1, 19727), -- Lance Blade
(21544, 4041, 1, 1, -1, 39321), -- Mold Hardener
(21544, 1875, 1, 1, -1, 301461), -- Stone of Purity
(21544, 57, 1783, 3643, 0, 700000), -- Adena
(21544, 12341, 1, 1, 1, 1033.02591), -- Common Item - Earring of Black Ore
(21544, 4052, 1, 1, 1, 7881.694556), -- Earring of Black Ore Piece
(21544, 12342, 1, 1, 1, 774.335388), -- Common Item - Necklace of Black Ore
(21544, 4054, 1, 1, 1, 4384.830768), -- Necklace of Black Ore Beads
(21544, 12343, 1, 1, 1, 1545.95328), -- Common Item - Ring of Black Ore
(21544, 4053, 1, 1, 1, 9542.160098), -- Ring of Black Ore Gemstone
(21544, 1872, 1, 1, 2, 161903.412132), -- Animal Bone
(21544, 1867, 1, 1, 2, 161903.412132), -- Animal Skin
(21544, 1881, 1, 1, 2, 16190.482), -- Coarse Bone Powder
(21544, 1875, 1, 1, 2, 8095.241), -- Stone of Purity
(21544, 4041, 1, 1, 2, 1055.901), -- Mold Hardener
(21544, 5450, 1, 1, 2, 45.051776), -- Recipe: Dragon Grinder(60%)
(21544, 5392, 1, 1, 2, 1046.749858), -- Recipe: Sealed Dark Crystal Gloves(60%)
(21544, 8730, 1, 1, 2, 1349.089511), -- Life Stone - Level 67
(21544, 8740, 1, 1, 2, 337.184386), -- Mid-Grade Life Stone - Level 67
(21544, 8750, 1, 1, 2, 33.788832), -- High-Grade Life Stone - Level 67
(21544, 8760, 1, 1, 2, 6.687373), -- Top-Grade Life Stone - Level 67
-- Judge of Fire
(21545, 4054, 1, 1, -1, 64024), -- Necklace of Black Ore Beads
(21545, 5230, 1, 1, -1, 4334), -- Recipe: Mithril Arrow (100%)
(21545, 4052, 1, 1, -1, 115082), -- Earring of Black Ore Piece
(21545, 57, 1288, 2611, 0, 700000), -- Adena
(21545, 12204, 1, 1, 1, 213.072782), -- Common Item - Blue Wolf Breastplate
(21545, 4078, 1, 1, 1, 2337.353655), -- Blue Wolf Breastplate Part
(21545, 12184, 1, 1, 1, 131.156311), -- Common Item - Doom Plate Armor
(21545, 4081, 1, 1, 1, 1577.126824), -- Doom Plate Armor Temper
(21545, 12193, 1, 1, 1, 340.820181), -- Common Item - Blue Wolf Gaiters
(21545, 4080, 1, 1, 1, 3291.470247), -- Blue Wolf Gaiters Material
(21545, 1864, 1, 3, 2, 87285.899846), -- Stem
(21545, 1865, 1, 1, 2, 87285.899846), -- Varnish
(21545, 1866, 1, 1, 2, 58190.750805), -- Suede
(21545, 1873, 1, 1, 2, 34914.450483), -- Silver Nugget
(21545, 1868, 1, 3, 2, 58190.750805), -- Thread
(21545, 6339, 1, 1, 2, 671.388209), -- Recipe: Sealed Majestic Ring(70%)
(21545, 8729, 1, 1, 2, 1163.950833), -- Life Stone - Level 64
(21545, 8739, 1, 1, 2, 291.100889), -- Mid-Grade Life Stone - Level 64
(21545, 8749, 1, 1, 2, 28.974272), -- High-Grade Life Stone - Level 64
(21545, 8759, 1, 1, 2, 5.885399), -- Top-Grade Life Stone - Level 64
(21545, 1343, 10, 30, 2, 124693.948613), -- Silver Arrow
-- Judge of Light
(21546, 4077, 1, 1, -1, 166838), -- Doom Shield Fragment
(21546, 5458, 1, 1, -1, 2027), -- Recipe: Halberd(60%)
(21546, 4078, 1, 1, -1, 54175), -- Blue Wolf Breastplate Part
(21546, 57, 1469, 2980, 0, 700000), -- Adena
(21546, 12201, 1, 1, 1, 243.018618), -- Common Item - Blue Wolf Tunic
(21546, 4084, 1, 1, 1, 2379.958846), -- Blue Wolf Tunic Fabric
(21546, 12192, 1, 1, 1, 243.018618), -- Common Item - Tunic of Doom
(21546, 4085, 1, 1, 1, 2379.958846), -- Tunic of Doom Pattern
(21546, 12203, 1, 1, 1, 389.043946), -- Common Item - Blue Wolf Stockings
(21546, 4086, 1, 1, 1, 3213.47859), -- Blue Wolf Stockings Pattern
(21546, 12205, 1, 1, 1, 389.043946), -- Common Item - Stockings of Doom
(21546, 4087, 1, 1, 1, 3213.47859), -- Stockings of Doom Pattern
(21546, 1869, 1, 1, 2, 99593.287534), -- Iron Ore
(21546, 1870, 1, 1, 2, 99593.287534), -- Coal
(21546, 1871, 1, 1, 2, 99593.287534), -- Charcoal
(21546, 1872, 1, 3, 2, 66395.662359), -- Animal Bone
(21546, 1867, 1, 3, 2, 44263.774906), -- Animal Skin
(21546, 729, 1, 1, 2, 11.124243), -- Scroll: Enchant Weapon (A-Grade)
(21546, 5394, 1, 1, 2, 858.626756), -- Recipe: Sealed Tallum Gloves(60%)
(21546, 8729, 1, 1, 2, 1327.905007), -- Life Stone - Level 64
(21546, 8739, 1, 1, 2, 332.079254), -- Mid-Grade Life Stone - Level 64
(21546, 8749, 1, 1, 2, 33.372729), -- High-Grade Life Stone - Level 64
(21546, 8759, 1, 1, 2, 6.592144), -- Top-Grade Life Stone - Level 64
-- Corrupted Knight
(21547, 5230, 1, 1, -1, 4131), -- Recipe: Mithril Arrow (100%)
(21547, 4085, 1, 1, -1, 53851), -- Tunic of Doom Pattern
(21547, 5271, 1, 1, -1, 4131), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21547, 57, 1229, 2488, 0, 700000), -- Adena
(21547, 11935, 1, 1, 1, 49.822752), -- Common Item - Deadman's Glory
(21547, 4116, 1, 1, 1, 666.520946), -- Deadman's Glory Stone
(21547, 11938, 1, 1, 1, 49.822752), -- Common Item - Art of Battle Axe
(21547, 4117, 1, 1, 1, 666.520946), -- Art of Battle Axe Blade
(21547, 11934, 1, 1, 1, 49.822752), -- Common Item - Staff of Evil Spirits
(21547, 4118, 1, 1, 1, 631.489852), -- Evil Spirit Head
(21547, 1895, 1, 1, 2, 26151.096726), -- Metallic Fiber
(21547, 4040, 1, 1, 2, 1830.577806), -- Mold Lubricant
(21547, 4042, 1, 1, 2, 1525.475754), -- Enria
(21547, 4043, 1, 1, 2, 3050.951508), -- Asofe
(21547, 5276, 1, 1, 2, 122.047722), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21547, 5346, 1, 1, 2, 263.763864), -- Recipe: Sealed Tallum Tunic(60%)
(21547, 8729, 1, 1, 2, 1220.373702), -- Life Stone - Level 64
(21547, 8739, 1, 1, 2, 305.102052), -- Mid-Grade Life Stone - Level 64
(21547, 8749, 1, 1, 2, 30.503304), -- High-Grade Life Stone - Level 64
(21547, 8759, 1, 1, 2, 6.107562), -- Top-Grade Life Stone - Level 64
-- Resurrected Knight
(21548, 4086, 1, 1, -1, 62149), -- Blue Wolf Stockings Pattern
(21548, 4044, 1, 1, -1, 88283), -- Thons
(21548, 5549, 1, 1, -1, 264849), -- Metallic Thread
(21548, 57, 1050, 2127, 0, 700000), -- Adena
(21548, 11933, 1, 1, 1, 127.76335), -- Common Item - Bellion Cestus
(21548, 4120, 1, 1, 1, 1709.23665), -- Bellion Cestus Edge
(21548, 1868, 1, 1, 2, 120357.597125), -- Thread
(21548, 1873, 1, 1, 2, 24071.519425), -- Silver Nugget
(21548, 5549, 1, 1, 2, 6017.81642), -- Metallic Thread
(21548, 1889, 1, 1, 2, 4011.962195), -- Compound Braid
(21548, 4044, 1, 1, 2, 2005.854225), -- Thons
(21548, 5281, 1, 1, 2, 80.18342), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21548, 6670, 1, 1, 2, 10029.778615), -- Deluxe Chest Key - Grade 6
(21548, 5346, 1, 1, 2, 173.307835), -- Recipe: Sealed Tallum Tunic(60%)
(21548, 8729, 1, 1, 2, 802.34169), -- Life Stone - Level 64
(21548, 8739, 1, 1, 2, 200.712295), -- Mid-Grade Life Stone - Level 64
(21548, 8749, 1, 1, 2, 20.045855), -- High-Grade Life Stone - Level 64
(21548, 8759, 1, 1, 2, 4.05992), -- Top-Grade Life Stone - Level 64
(21548, 1343, 10, 30, 2, 85969.82098), -- Silver Arrow
-- Corrupted Guard
(21549, 6329, 1, 1, -1, 18422), -- Recipe: Sealed Phoenix Necklace(70%)
(21549, 4053, 1, 1, -1, 137396), -- Ring of Black Ore Gemstone
(21549, 6331, 1, 1, -1, 24469), -- Recipe: Sealed Phoenix Earring(70%)
(21549, 57, 1273, 2574, 0, 700000), -- Adena
(21549, 12183, 1, 1, 1, 801.047862), -- Common Item - Doom Shield
(21549, 4077, 1, 1, 1, 7098.820038), -- Doom Shield Fragment
(21549, 12202, 1, 1, 1, 560.59524), -- Common Item - Blue Wolf Helmet
(21549, 4088, 1, 1, 1, 5963.97081), -- Blue Wolf Helmet Design
(21549, 12185, 1, 1, 1, 560.59524), -- Common Item - Doom Helmet
(21549, 4089, 1, 1, 1, 5963.97081), -- Doom Helmet Pattern
(21549, 1864, 1, 3, 2, 86076.332076), -- Stem
(21549, 1865, 1, 1, 2, 86076.332076), -- Varnish
(21549, 1866, 1, 1, 2, 57384.221384), -- Suede
(21549, 1873, 1, 1, 2, 34430.35759), -- Silver Nugget
(21549, 1868, 1, 1, 2, 172152.664152), -- Thread
(21549, 3035, 1, 1, 2, 114.782462), -- Recipe: Spiritshot A
(21549, 5354, 1, 1, 2, 396.481405), -- Recipe: Sealed Tallum Stockings(60%)
(21549, 8729, 1, 1, 2, 1147.82462), -- Life Stone - Level 64
(21549, 8739, 1, 1, 2, 286.956155), -- Mid-Grade Life Stone - Level 64
(21549, 8749, 1, 1, 2, 28.476565), -- High-Grade Life Stone - Level 64
(21549, 8759, 1, 1, 2, 6.571515), -- Top-Grade Life Stone - Level 64
-- Corrupted Guard
(21550, 6329, 1, 1, -1, 18791), -- Recipe: Sealed Phoenix Necklace(70%)
(21550, 4053, 1, 1, -1, 140144), -- Ring of Black Ore Gemstone
(21550, 6331, 1, 1, -1, 24958), -- Recipe: Sealed Phoenix Earring(70%)
(21550, 57, 1298, 2625, 0, 700000), -- Adena
(21550, 12183, 1, 1, 1, 817.069584), -- Common Item - Doom Shield
(21550, 4077, 1, 1, 1, 7240.803216), -- Doom Shield Fragment
(21550, 12202, 1, 1, 1, 571.80768), -- Common Item - Blue Wolf Helmet
(21550, 4088, 1, 1, 1, 6083.25592), -- Blue Wolf Helmet Design
(21550, 12185, 1, 1, 1, 571.80768), -- Common Item - Doom Helmet
(21550, 4089, 1, 1, 1, 6083.25592), -- Doom Helmet Pattern
(21550, 1864, 1, 3, 2, 87797.854788), -- Stem
(21550, 1865, 1, 1, 2, 87797.854788), -- Varnish
(21550, 1866, 1, 1, 2, 58531.903192), -- Suede
(21550, 1873, 1, 1, 2, 35118.96317), -- Silver Nugget
(21550, 1868, 1, 1, 2, 175595.709576), -- Thread
(21550, 3035, 1, 1, 2, 117.078106), -- Recipe: Spiritshot A
(21550, 5354, 1, 1, 2, 404.411015), -- Recipe: Sealed Tallum Stockings(60%)
(21550, 8729, 1, 1, 2, 1170.78106), -- Life Stone - Level 64
(21550, 8739, 1, 1, 2, 292.695265), -- Mid-Grade Life Stone - Level 64
(21550, 8749, 1, 1, 2, 29.046095), -- High-Grade Life Stone - Level 64
(21550, 8759, 1, 1, 2, 6.702945), -- Top-Grade Life Stone - Level 64
-- Resurrected Guard
(21551, 5460, 1, 1, -1, 2017), -- Recipe: Dasparion's Staff(60%)
(21551, 4080, 1, 1, -1, 75921), -- Blue Wolf Gaiters Material
(21551, 1884, 1, 5, -1, 757104), -- Cord
(21551, 57, 1462, 2965, 0, 700000), -- Adena
(21551, 12188, 1, 1, 1, 724.892676), -- Common Item - Sealed Doom Boots
(21551, 4099, 1, 1, 1, 6118.107324), -- Sealed Doom Boots Part
(21551, 12189, 1, 1, 1, 724.892676), -- Common Item - Sealed Blue Wolf Boots
(21551, 4090, 1, 1, 1, 6118.107324), -- Sealed Blue Wolf Boots Design
(21551, 12187, 1, 1, 1, 724.892676), -- Common Item - Sealed Doom Gloves
(21551, 4091, 1, 1, 1, 6118.107324), -- Sealed Doom Gloves Part
(21551, 12190, 1, 1, 1, 724.892676), -- Common Item - Sealed Blue Wolf Gloves
(21551, 4096, 1, 1, 1, 6118.107324), -- Sealed Blue Wolf Gloves Fabric
(21551, 1874, 1, 1, 2, 6607.441026), -- Oriharukon Ore
(21551, 1878, 1, 1, 2, 39644.123808), -- Braided Hemp
(21551, 1884, 1, 1, 2, 60990.919524), -- Cord
(21551, 1889, 1, 1, 2, 6607.441026), -- Compound Braid
(21551, 5220, 1, 1, 2, 3964.360146), -- Metal Hardener
(21551, 730, 1, 1, 2, 82.530984), -- Scroll: Enchant Armor (A-Grade)
(21551, 8729, 1, 1, 2, 1321.54044), -- Life Stone - Level 64
(21551, 8739, 1, 1, 2, 330.38511), -- Mid-Grade Life Stone - Level 64
(21551, 8749, 1, 1, 2, 32.907924), -- High-Grade Life Stone - Level 64
(21551, 8759, 1, 1, 2, 6.52935), -- Top-Grade Life Stone - Level 64
(21551, 1343, 10, 30, 2, 141585.820662), -- Silver Arrow
-- Resurrected Guard
(21552, 5460, 1, 1, -1, 1911), -- Recipe: Dasparion's Staff(60%)
(21552, 4080, 1, 1, -1, 71939), -- Blue Wolf Gaiters Material
(21552, 1884, 1, 5, -1, 717399), -- Cord
(21552, 57, 1385, 2810, 0, 700000), -- Adena
(21552, 12188, 1, 1, 1, 686.863088), -- Common Item - Sealed Doom Boots
(21552, 4099, 1, 1, 1, 5797.136912), -- Sealed Doom Boots Part
(21552, 12189, 1, 1, 1, 686.863088), -- Common Item - Sealed Blue Wolf Boots
(21552, 4090, 1, 1, 1, 5797.136912), -- Sealed Blue Wolf Boots Design
(21552, 12187, 1, 1, 1, 686.863088), -- Common Item - Sealed Doom Gloves
(21552, 4091, 1, 1, 1, 5797.136912), -- Sealed Doom Gloves Part
(21552, 12190, 1, 1, 1, 686.863088), -- Common Item - Sealed Blue Wolf Gloves
(21552, 4096, 1, 1, 1, 5797.136912), -- Sealed Blue Wolf Gloves Fabric
(21552, 1874, 1, 1, 2, 6260.945922), -- Oriharukon Ore
(21552, 1878, 1, 1, 2, 37565.180576), -- Braided Hemp
(21552, 1884, 1, 1, 2, 57792.547428), -- Cord
(21552, 1889, 1, 1, 2, 6260.945922), -- Compound Braid
(21552, 5220, 1, 1, 2, 3756.468562), -- Metal Hardener
(21552, 730, 1, 1, 2, 78.203048), -- Scroll: Enchant Armor (A-Grade)
(21552, 8729, 1, 1, 2, 1252.23868), -- Life Stone - Level 64
(21552, 8739, 1, 1, 2, 313.05967), -- Mid-Grade Life Stone - Level 64
(21552, 8749, 1, 1, 2, 31.182228), -- High-Grade Life Stone - Level 64
(21552, 8759, 1, 1, 2, 6.18695), -- Top-Grade Life Stone - Level 64
(21552, 1343, 10, 30, 2, 134161.041014), -- Silver Arrow
-- Trampled Man
(21553, 5346, 1, 1, -1, 7455), -- Recipe: Sealed Tallum Tunic(60%)
(21553, 4080, 1, 1, -1, 53208), -- Blue Wolf Gaiters Material
(21553, 1895, 1, 1, -1, 739065), -- Metallic Fiber
(21553, 57, 1025, 2078, 0, 700000), -- Adena
(21553, 12188, 1, 1, 1, 508.023389), -- Common Item - Sealed Doom Boots
(21553, 4099, 1, 1, 1, 4287.726611), -- Sealed Doom Boots Part
(21553, 12189, 1, 1, 1, 508.023389), -- Common Item - Sealed Blue Wolf Boots
(21553, 4090, 1, 1, 1, 4287.726611), -- Sealed Blue Wolf Boots Design
(21553, 12187, 1, 1, 1, 508.023389), -- Common Item - Sealed Doom Gloves
(21553, 4091, 1, 1, 1, 4287.726611), -- Sealed Doom Gloves Part
(21553, 12190, 1, 1, 1, 508.023389), -- Common Item - Sealed Blue Wolf Gloves
(21553, 4096, 1, 1, 1, 4287.726611), -- Sealed Blue Wolf Gloves Fabric
(21553, 1873, 1, 1, 2, 27784.737656), -- Silver Nugget
(21553, 1868, 1, 1, 2, 138923.282376), -- Thread
(21553, 1876, 1, 1, 2, 13892.267352), -- Mithril Ore
(21553, 1895, 1, 1, 2, 19846.270176), -- Metallic Fiber
(21553, 4042, 1, 1, 2, 1157.638208), -- Enria
(21553, 5462, 1, 1, 2, 25.774904), -- Recipe: Branch of the Mother Tree(60%)
(21553, 5348, 1, 1, 2, 136.789648), -- Recipe: Sealed Dark Crystal Robe(60%)
(21553, 8729, 1, 1, 2, 926.069976), -- Life Stone - Level 64
(21553, 8739, 1, 1, 2, 231.568232), -- Mid-Grade Life Stone - Level 64
(21553, 8749, 1, 1, 2, 23.136528), -- High-Grade Life Stone - Level 64
(21553, 8759, 1, 1, 2, 4.464944), -- Top-Grade Life Stone - Level 64
-- Trampled Man
(21554, 5346, 1, 1, -1, 7455), -- Recipe: Sealed Tallum Tunic(60%)
(21554, 4080, 1, 1, -1, 53208), -- Blue Wolf Gaiters Material
(21554, 1895, 1, 1, -1, 739065), -- Metallic Fiber
(21554, 57, 1025, 2078, 0, 700000), -- Adena
(21554, 12188, 1, 1, 1, 508.023389), -- Common Item - Sealed Doom Boots
(21554, 4099, 1, 1, 1, 4287.726611), -- Sealed Doom Boots Part
(21554, 12189, 1, 1, 1, 508.023389), -- Common Item - Sealed Blue Wolf Boots
(21554, 4090, 1, 1, 1, 4287.726611), -- Sealed Blue Wolf Boots Design
(21554, 12187, 1, 1, 1, 508.023389), -- Common Item - Sealed Doom Gloves
(21554, 4091, 1, 1, 1, 4287.726611), -- Sealed Doom Gloves Part
(21554, 12190, 1, 1, 1, 508.023389), -- Common Item - Sealed Blue Wolf Gloves
(21554, 4096, 1, 1, 1, 4287.726611), -- Sealed Blue Wolf Gloves Fabric
(21554, 1873, 1, 1, 2, 27784.737656), -- Silver Nugget
(21554, 1868, 1, 1, 2, 138923.282376), -- Thread
(21554, 1876, 1, 1, 2, 13892.267352), -- Mithril Ore
(21554, 1895, 1, 1, 2, 19846.270176), -- Metallic Fiber
(21554, 4042, 1, 1, 2, 1157.638208), -- Enria
(21554, 5462, 1, 1, 2, 25.774904), -- Recipe: Branch of the Mother Tree(60%)
(21554, 5348, 1, 1, 2, 136.789648), -- Recipe: Sealed Dark Crystal Robe(60%)
(21554, 8729, 1, 1, 2, 926.069976), -- Life Stone - Level 64
(21554, 8739, 1, 1, 2, 231.568232), -- Mid-Grade Life Stone - Level 64
(21554, 8749, 1, 1, 2, 23.136528), -- High-Grade Life Stone - Level 64
(21554, 8759, 1, 1, 2, 4.464944), -- Top-Grade Life Stone - Level 64
-- Slaughter Executioner
(21555, 4082, 1, 1, -1, 35533), -- Blue Wolf Leather Armor Texture
(21555, 5354, 1, 1, -1, 14491), -- Recipe: Sealed Tallum Stockings(60%)
(21555, 4083, 1, 1, -1, 35533), -- Leather Armor of Doom Design
(21555, 57, 1246, 2527, 0, 700000), -- Adena
(21555, 11933, 1, 1, 1, 151.68855), -- Common Item - Bellion Cestus
(21555, 4120, 1, 1, 1, 2029.31145), -- Bellion Cestus Edge
(21555, 1872, 1, 1, 2, 112591.8011), -- Animal Bone
(21555, 1867, 1, 1, 2, 112591.8011), -- Animal Skin
(21555, 1881, 1, 1, 2, 11259.228975), -- Coarse Bone Powder
(21555, 1875, 1, 1, 2, 5629.492325), -- Stone of Purity
(21555, 4041, 1, 1, 2, 734.196625), -- Mold Hardener
(21555, 5466, 1, 1, 2, 31.2736), -- Recipe: Sword of Miracles(60%)
(21555, 8300, 1, 1, 2, 46.177425), -- Recipe: Infernal Master (60%)
(21555, 8729, 1, 1, 2, 1125.8496), -- Life Stone - Level 64
(21555, 8739, 1, 1, 2, 281.4624), -- Mid-Grade Life Stone - Level 64
(21555, 8749, 1, 1, 2, 28.097375), -- High-Grade Life Stone - Level 64
(21555, 8759, 1, 1, 2, 5.619475), -- Top-Grade Life Stone - Level 64
-- Slaughter Executioner
(21556, 4082, 1, 1, -1, 34673), -- Blue Wolf Leather Armor Texture
(21556, 5354, 1, 1, -1, 14141), -- Recipe: Sealed Tallum Stockings(60%)
(21556, 4083, 1, 1, -1, 34673), -- Leather Armor of Doom Design
(21556, 57, 1216, 2466, 0, 700000), -- Adena
(21556, 11933, 1, 1, 1, 148.0024), -- Common Item - Bellion Cestus
(21556, 4120, 1, 1, 1, 1979.9976), -- Bellion Cestus Edge
(21556, 1872, 1, 1, 2, 109867.846792), -- Animal Bone
(21556, 1867, 1, 1, 2, 109867.846792), -- Animal Skin
(21556, 1881, 1, 1, 2, 10986.832362), -- Coarse Bone Powder
(21556, 1875, 1, 1, 2, 5493.296974), -- Stone of Purity
(21556, 4041, 1, 1, 2, 716.43407), -- Mold Hardener
(21556, 5466, 1, 1, 2, 30.516992), -- Recipe: Sword of Miracles(60%)
(21556, 8300, 1, 1, 2, 45.060246), -- Recipe: Infernal Master (60%)
(21556, 8729, 1, 1, 2, 1098.611712), -- Life Stone - Level 64
(21556, 8739, 1, 1, 2, 274.652928), -- Mid-Grade Life Stone - Level 64
(21556, 8749, 1, 1, 2, 27.41761), -- High-Grade Life Stone - Level 64
(21556, 8759, 1, 1, 2, 5.483522), -- Top-Grade Life Stone - Level 64
-- Bone Snatcher
(21557, 4082, 1, 1, -1, 41024), -- Blue Wolf Leather Armor Texture
(21557, 5470, 1, 1, -1, 1984), -- Recipe: Tallum Blade(60%)
(21557, 4083, 1, 1, -1, 41024), -- Leather Armor of Doom Design
(21557, 57, 1438, 2917, 0, 700000), -- Adena
(21557, 12204, 1, 1, 1, 237.995628), -- Common Item - Blue Wolf Breastplate
(21557, 4078, 1, 1, 1, 2610.75087), -- Blue Wolf Breastplate Part
(21557, 12184, 1, 1, 1, 146.497494), -- Common Item - Doom Plate Armor
(21557, 4081, 1, 1, 1, 1761.601296), -- Doom Plate Armor Temper
(21557, 12193, 1, 1, 1, 380.685474), -- Common Item - Blue Wolf Gaiters
(21557, 4080, 1, 1, 1, 3676.469238), -- Blue Wolf Gaiters Material
(21557, 1876, 1, 1, 2, 19498.52454), -- Mithril Ore
(21557, 1880, 1, 1, 2, 9749.26227), -- Steel
(21557, 1877, 1, 1, 2, 3899.704908), -- Adamantite Nugget
(21557, 1881, 1, 1, 2, 12999.01636), -- Coarse Bone Powder
(21557, 1882, 1, 1, 2, 21664.888076), -- Leather
(21557, 5440, 1, 1, 2, 36.119978), -- Recipe: Elysian(60%)
(21557, 8729, 1, 1, 2, 1299.901636), -- Life Stone - Level 64
(21557, 8739, 1, 1, 2, 324.871016), -- Mid-Grade Life Stone - Level 64
(21557, 8749, 1, 1, 2, 32.570616), -- High-Grade Life Stone - Level 64
(21557, 8759, 1, 1, 2, 6.472366), -- Top-Grade Life Stone - Level 64
(21557, 1343, 10, 30, 2, 139274.668234), -- Silver Arrow
-- Bone Snatcher
(21558, 4082, 1, 1, -1, 41024), -- Blue Wolf Leather Armor Texture
(21558, 5470, 1, 1, -1, 1984), -- Recipe: Tallum Blade(60%)
(21558, 4083, 1, 1, -1, 41024), -- Leather Armor of Doom Design
(21558, 57, 1438, 2917, 0, 700000), -- Adena
(21558, 12204, 1, 1, 1, 237.995628), -- Common Item - Blue Wolf Breastplate
(21558, 4078, 1, 1, 1, 2610.75087), -- Blue Wolf Breastplate Part
(21558, 12184, 1, 1, 1, 146.497494), -- Common Item - Doom Plate Armor
(21558, 4081, 1, 1, 1, 1761.601296), -- Doom Plate Armor Temper
(21558, 12193, 1, 1, 1, 380.685474), -- Common Item - Blue Wolf Gaiters
(21558, 4080, 1, 1, 1, 3676.469238), -- Blue Wolf Gaiters Material
(21558, 1876, 1, 1, 2, 19498.52454), -- Mithril Ore
(21558, 1880, 1, 1, 2, 9749.26227), -- Steel
(21558, 1877, 1, 1, 2, 3899.704908), -- Adamantite Nugget
(21558, 1881, 1, 1, 2, 12999.01636), -- Coarse Bone Powder
(21558, 1882, 1, 1, 2, 21664.888076), -- Leather
(21558, 5440, 1, 1, 2, 36.119978), -- Recipe: Elysian(60%)
(21558, 8729, 1, 1, 2, 1299.901636), -- Life Stone - Level 64
(21558, 8739, 1, 1, 2, 324.871016), -- Mid-Grade Life Stone - Level 64
(21558, 8749, 1, 1, 2, 32.570616), -- High-Grade Life Stone - Level 64
(21558, 8759, 1, 1, 2, 6.472366), -- Top-Grade Life Stone - Level 64
(21558, 1343, 10, 30, 2, 139274.668234), -- Silver Arrow
-- Bone Maker
(21559, 6329, 1, 1, -1, 22819), -- Recipe: Sealed Phoenix Necklace(70%)
(21559, 4085, 1, 1, -1, 69006), -- Tunic of Doom Pattern
(21559, 6331, 1, 1, -1, 30310), -- Recipe: Sealed Phoenix Earring(70%)
(21559, 57, 1573, 3190, 0, 700000), -- Adena
(21559, 12188, 1, 1, 1, 779.818418), -- Common Item - Sealed Doom Boots
(21559, 4099, 1, 1, 1, 6581.681582), -- Sealed Doom Boots Part
(21559, 12189, 1, 1, 1, 779.818418), -- Common Item - Sealed Blue Wolf Boots
(21559, 4090, 1, 1, 1, 6581.681582), -- Sealed Blue Wolf Boots Design
(21559, 12187, 1, 1, 1, 779.818418), -- Common Item - Sealed Doom Gloves
(21559, 4091, 1, 1, 1, 6581.681582), -- Sealed Doom Gloves Part
(21559, 12190, 1, 1, 1, 779.818418), -- Common Item - Sealed Blue Wolf Gloves
(21559, 4096, 1, 1, 1, 6581.681582), -- Sealed Blue Wolf Gloves Fabric
(21559, 1864, 1, 3, 2, 106622.530437), -- Stem
(21559, 1869, 1, 1, 2, 106622.530437), -- Iron Ore
(21559, 1878, 1, 1, 2, 42648.916327), -- Braided Hemp
(21559, 1884, 1, 1, 2, 65614.049207), -- Cord
(21559, 4039, 1, 1, 2, 3554.036424), -- Mold Glue
(21559, 5448, 1, 1, 2, 39.297598), -- Recipe: Soul Separator(60%)
(21559, 8729, 1, 1, 2, 1421.422874), -- Life Stone - Level 64
(21559, 8739, 1, 1, 2, 355.595338), -- Mid-Grade Life Stone - Level 64
(21559, 8749, 1, 1, 2, 35.463686), -- High-Grade Life Stone - Level 64
(21559, 8759, 1, 1, 2, 7.188585), -- Top-Grade Life Stone - Level 64
(21559, 1343, 10, 30, 2, 152317.969087), -- Silver Arrow
-- Bone Shaper
(21560, 4086, 1, 1, -1, 93173), -- Blue Wolf Stockings Pattern
(21560, 4040, 1, 1, -1, 79412), -- Mold Lubricant
(21560, 1875, 1, 1, -1, 264705), -- Stone of Purity
(21560, 57, 1573, 3190, 0, 700000), -- Adena
(21560, 12201, 1, 1, 1, 260.17494), -- Common Item - Blue Wolf Tunic
(21560, 4084, 1, 1, 1, 2547.97618), -- Blue Wolf Tunic Fabric
(21560, 12192, 1, 1, 1, 260.17494), -- Common Item - Tunic of Doom
(21560, 4085, 1, 1, 1, 2547.97618), -- Tunic of Doom Pattern
(21560, 12203, 1, 1, 1, 416.50918), -- Common Item - Blue Wolf Stockings
(21560, 4086, 1, 1, 1, 3440.3397), -- Blue Wolf Stockings Pattern
(21560, 12205, 1, 1, 1, 416.50918), -- Common Item - Stockings of Doom
(21560, 4087, 1, 1, 1, 3440.3397), -- Stockings of Doom Pattern
(21560, 1865, 1, 1, 2, 117284.817933), -- Varnish
(21560, 1870, 1, 1, 2, 117284.817933), -- Coal
(21560, 1879, 1, 1, 2, 19547.602819), -- Cokes
(21560, 1875, 1, 1, 2, 7819.094393), -- Stone of Purity
(21560, 4040, 1, 1, 2, 2345.808216), -- Mold Lubricant
(21560, 5450, 1, 1, 2, 43.411301), -- Recipe: Dragon Grinder(60%)
(21560, 8729, 1, 1, 2, 1563.872144), -- Life Stone - Level 64
(21560, 8739, 1, 1, 2, 390.968036), -- Mid-Grade Life Stone - Level 64
(21560, 8749, 1, 1, 2, 39.150069), -- High-Grade Life Stone - Level 64
(21560, 8759, 1, 1, 2, 7.457156), -- Top-Grade Life Stone - Level 64
-- Sacrificed Man
(21561, 4116, 1, 1, -1, 14604), -- Deadman's Glory Stone
(21561, 3956, 1, 1, -1, 4456), -- Recipe: Blessed Spiritshot A
(21561, 4117, 1, 1, -1, 14604), -- Art of Battle Axe Blade
(21561, 57, 1318, 2693, 0, 700000), -- Adena
(21561, 12204, 1, 1, 1, 219.094228), -- Common Item - Blue Wolf Breastplate
(21561, 4078, 1, 1, 1, 2403.40737), -- Blue Wolf Breastplate Part
(21561, 12184, 1, 1, 1, 134.862794), -- Common Item - Doom Plate Armor
(21561, 4081, 1, 1, 1, 1621.696496), -- Doom Plate Armor Temper
(21561, 12193, 1, 1, 1, 350.451774), -- Common Item - Blue Wolf Gaiters
(21561, 4080, 1, 1, 1, 3384.487338), -- Blue Wolf Gaiters Material
(21561, 1865, 1, 1, 2, 82265.67213), -- Varnish
(21561, 1870, 1, 1, 2, 82265.67213), -- Coal
(21561, 1879, 1, 1, 2, 13711.104258), -- Cokes
(21561, 1875, 1, 1, 2, 5484.378142), -- Stone of Purity
(21561, 4040, 1, 1, 2, 1645.281662), -- Mold Lubricant
(21561, 5456, 1, 1, 2, 30.509376), -- Recipe: Tallum Glaive(60%)
(21561, 6670, 1, 1, 2, 13711.104258), -- Deluxe Chest Key - Grade 6
(21561, 8730, 1, 1, 2, 914.010056), -- Life Stone - Level 67
(21561, 8740, 1, 1, 2, 228.502514), -- Mid-Grade Life Stone - Level 67
(21561, 8750, 1, 1, 2, 22.882032), -- High-Grade Life Stone - Level 67
(21561, 8760, 1, 1, 2, 4.449284), -- Top-Grade Life Stone - Level 67
(21561, 1343, 10, 30, 2, 117522.434158), -- Silver Arrow
-- Guillotine's Ghost
(21562, 5156, 1, 1, -1, 4614), -- Recipe: Soulshot (A) Compressed Package (100%)
(21562, 4118, 1, 1, -1, 14328), -- Evil Spirit Head
(21562, 5220, 1, 1, -1, 138433), -- Metal Hardener
(21562, 57, 1364, 2788, 0, 700000), -- Adena
(21562, 12201, 1, 1, 1, 226.760124), -- Common Item - Blue Wolf Tunic
(21562, 4084, 1, 1, 1, 2220.734228), -- Blue Wolf Tunic Fabric
(21562, 12192, 1, 1, 1, 226.760124), -- Common Item - Tunic of Doom
(21562, 4085, 1, 1, 1, 2220.734228), -- Tunic of Doom Pattern
(21562, 12203, 1, 1, 1, 363.016028), -- Common Item - Blue Wolf Stockings
(21562, 4086, 1, 1, 1, 2998.48962), -- Blue Wolf Stockings Pattern
(21562, 12205, 1, 1, 1, 363.016028), -- Common Item - Stockings of Doom
(21562, 4087, 1, 1, 1, 2998.48962), -- Stockings of Doom Pattern
(21562, 1866, 1, 1, 2, 68151.289752), -- Suede
(21562, 1871, 1, 1, 2, 102226.934628), -- Charcoal
(21562, 5220, 1, 1, 2, 4089.010653), -- Metal Hardener
(21562, 1885, 1, 1, 2, 8518.911219), -- High-Grade Suede
(21562, 4041, 1, 1, 2, 889.020132), -- Mold Hardener
(21562, 5462, 1, 1, 2, 37.814868), -- Recipe: Branch of the Mother Tree(60%)
(21562, 8730, 1, 1, 2, 1135.928976), -- Life Stone - Level 67
(21562, 8740, 1, 1, 2, 283.982244), -- Mid-Grade Life Stone - Level 67
(21562, 8750, 1, 1, 2, 28.361151), -- High-Grade Life Stone - Level 67
(21562, 8760, 1, 1, 2, 5.746377), -- Top-Grade Life Stone - Level 67
-- Bone Collector
(21563, 4042, 1, 1, -1, 67020), -- Enria
(21563, 4119, 1, 1, -1, 17601), -- Demon's Dagger Edge
(21563, 5161, 1, 1, -1, 5362), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21563, 57, 1585, 3240, 0, 700000), -- Adena
(21563, 12204, 1, 1, 1, 263.593524), -- Common Item - Blue Wolf Breastplate
(21563, 4078, 1, 1, 1, 2891.55321), -- Blue Wolf Breastplate Part
(21563, 12184, 1, 1, 1, 162.254202), -- Common Item - Doom Plate Armor
(21563, 4081, 1, 1, 1, 1951.072368), -- Doom Plate Armor Temper
(21563, 12193, 1, 1, 1, 421.630542), -- Common Item - Blue Wolf Gaiters
(21563, 4080, 1, 1, 1, 4071.896154), -- Blue Wolf Gaiters Material
(21563, 1867, 1, 1, 2, 143975.18135), -- Animal Skin
(21563, 1872, 1, 1, 2, 143975.18135), -- Animal Bone
(21563, 1882, 1, 1, 2, 23996.021348), -- Leather
(21563, 1894, 1, 1, 2, 3788.845476), -- Crafted Leather
(21563, 4042, 1, 1, 2, 1799.748938), -- Enria
(21563, 5464, 1, 1, 2, 39.762996), -- Recipe: Dark Legion's Edge(60%)
(21563, 8730, 1, 1, 2, 1199.990415), -- Life Stone - Level 67
(21563, 8740, 1, 1, 2, 300.115946), -- Mid-Grade Life Stone - Level 67
(21563, 8750, 1, 1, 2, 29.822247), -- High-Grade Life Stone - Level 67
(21563, 8760, 1, 1, 2, 6.153797), -- Top-Grade Life Stone - Level 67
(21563, 1343, 10, 30, 2, 154258.176137), -- Silver Arrow
-- Skull Collector
(21564, 4120, 1, 1, -1, 16716), -- Bellion Cestus Edge
(21564, 5166, 1, 1, -1, 5101), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21564, 4121, 1, 1, -1, 16660), -- Bow of Peril Shaft
(21564, 57, 1508, 3082, 0, 700000), -- Adena
(21564, 12194, 1, 1, 1, 308.716096), -- Common Item - Blue Wolf Leather Armor
(21564, 4082, 1, 1, 1, 3191.783904), -- Blue Wolf Leather Armor Texture
(21564, 12186, 1, 1, 1, 308.716096), -- Common Item - Leather Armor of Doom
(21564, 4083, 1, 1, 1, 3191.783904), -- Leather Armor of Doom Design
(21564, 1868, 1, 1, 2, 225993.28272), -- Thread
(21564, 1873, 1, 1, 2, 45198.77472), -- Silver Nugget
(21564, 5549, 1, 1, 2, 11299.69368), -- Metallic Thread
(21564, 1889, 1, 1, 2, 7533.12912), -- Compound Braid
(21564, 4044, 1, 1, 2, 3766.56456), -- Thons
(21564, 5466, 1, 1, 2, 41.95248), -- Recipe: Sword of Miracles(60%)
(21564, 8730, 1, 1, 2, 1255.62), -- Life Stone - Level 67
(21564, 8740, 1, 1, 2, 313.75728), -- Mid-Grade Life Stone - Level 67
(21564, 8750, 1, 1, 2, 31.31664), -- High-Grade Life Stone - Level 67
(21564, 8760, 1, 1, 2, 5.9088), -- Top-Grade Life Stone - Level 67
-- Bone Animator
(21565, 5520, 1, 1, -1, 24990), -- Sealed Dark Crystal Breastplate Pattern
(21565, 5464, 1, 1, -1, 1435), -- Recipe: Dark Legion's Edge(60%)
(21565, 5521, 1, 1, -1, 17634), -- Sealed Tallum Plate Armor Pattern
(21565, 57, 1533, 3116, 0, 700000), -- Adena
(21565, 11960, 1, 1, 1, 157.589712), -- Common Item - Halberd
(21565, 5542, 1, 1, 1, 1930.410288), -- Halberd Edge
(21565, 1867, 1, 1, 2, 152625.960268), -- Animal Skin
(21565, 1872, 1, 1, 2, 152625.960268), -- Animal Bone
(21565, 1882, 1, 1, 2, 25437.603664), -- Leather
(21565, 1894, 1, 1, 2, 4016.445932), -- Crafted Leather
(21565, 4042, 1, 1, 2, 1907.92176), -- Enria
(21565, 5464, 1, 1, 2, 42.2855), -- Recipe: Dark Legion's Edge(60%)
(21565, 8730, 1, 1, 2, 1271.94784), -- Life Stone - Level 67
(21565, 8740, 1, 1, 2, 317.98696), -- Mid-Grade Life Stone - Level 67
(21565, 8750, 1, 1, 2, 31.798696), -- High-Grade Life Stone - Level 67
(21565, 8760, 1, 1, 2, 6.089112), -- Top-Grade Life Stone - Level 67
-- Skull Animator
(21566, 729, 1, 1, -1, 471), -- Scroll: Enchant Weapon (A-Grade)
(21566, 4044, 1, 1, -1, 141272), -- Thons
(21566, 5549, 1, 1, -1, 423817), -- Metallic Thread
(21566, 57, 1676, 3408, 0, 700000), -- Adena
(21566, 11955, 1, 1, 1, 172.310664), -- Common Item - Carnage Bow
(21566, 5535, 1, 1, 1, 2135.689336), -- Carnage Bow Stave
(21566, 1868, 1, 1, 2, 227616.740652), -- Thread
(21566, 1873, 1, 1, 2, 45523.164072), -- Silver Nugget
(21566, 5549, 1, 1, 2, 11380.791018), -- Metallic Thread
(21566, 1889, 1, 1, 2, 7587.347394), -- Compound Braid
(21566, 4044, 1, 1, 2, 3793.443624), -- Thons
(21566, 5466, 1, 1, 2, 42.333432), -- Recipe: Sword of Miracles(60%)
(21566, 8730, 1, 1, 2, 1264.481208), -- Life Stone - Level 67
(21566, 8740, 1, 1, 2, 316.120302), -- Mid-Grade Life Stone - Level 67
(21566, 8750, 1, 1, 2, 31.750074), -- High-Grade Life Stone - Level 67
(21566, 8760, 1, 1, 2, 6.442044), -- Top-Grade Life Stone - Level 67
(21566, 1343, 10, 30, 2, 162583.38618), -- Silver Arrow
-- Bone Slayer
(21567, 5524, 1, 1, -1, 49929), -- Sealed Dark Crystal Gaiters Pattern
(21567, 5466, 1, 1, -1, 1876), -- Recipe: Sword of Miracles(60%)
(21567, 5525, 1, 1, -1, 78309), -- Sealed Dark Crystal Helmet Design
(21567, 57, 2004, 4074, 0, 700000), -- Adena
(21567, 11951, 1, 1, 1, 205.934358), -- Common Item - Bloody Orchid
(21567, 5536, 1, 1, 1, 2545.065642), -- Bloody Orchid Head
(21567, 1869, 1, 1, 2, 149636.751902), -- Iron Ore
(21567, 1864, 1, 1, 2, 299273.503804), -- Stem
(21567, 1880, 1, 1, 2, 14963.580478), -- Steel
(21567, 5550, 1, 1, 2, 1995.112493), -- Durable Metal Plate
(21567, 4043, 1, 1, 2, 4988.018013), -- Asofe
(21567, 6335, 1, 1, 2, 575.376615), -- Recipe: Sealed Majestic Necklace(70%)
(21567, 8730, 1, 1, 2, 1662.672671), -- Life Stone - Level 67
(21567, 8740, 1, 1, 2, 415.786558), -- Mid-Grade Life Stone - Level 67
(21567, 8750, 1, 1, 2, 41.673368), -- High-Grade Life Stone - Level 67
(21567, 8760, 1, 1, 2, 8.524098), -- Top-Grade Life Stone - Level 67
-- Devil Bat
(21568, 6335, 1, 1, -1, 15379), -- Recipe: Sealed Majestic Necklace(70%)
(21568, 5526, 1, 1, -1, 61809), -- Sealed Tallum Helm Design
(21568, 730, 1, 1, -1, 3332), -- Scroll: Enchant Armor (A-Grade)
(21568, 57, 1582, 3215, 0, 700000), -- Adena
(21568, 11951, 1, 1, 1, 162.591576), -- Common Item - Bloody Orchid
(21568, 5536, 1, 1, 1, 2009.408424), -- Bloody Orchid Head
(21568, 1870, 1, 1, 2, 107370.567872), -- Coal
(21568, 1865, 1, 1, 2, 107370.567872), -- Varnish
(21568, 1874, 1, 1, 2, 7157.858415), -- Oriharukon Ore
(21568, 4043, 1, 1, 2, 3579.121468), -- Asofe
(21568, 4039, 1, 1, 2, 3579.121468), -- Mold Glue
(21568, 6337, 1, 1, 2, 550.634072), -- Recipe: Sealed Majestic Earring(70%)
(21568, 8730, 1, 1, 2, 1193.168663), -- Life Stone - Level 67
(21568, 8740, 1, 1, 2, 298.388296), -- Mid-Grade Life Stone - Level 67
(21568, 8750, 1, 1, 2, 29.992638), -- High-Grade Life Stone - Level 67
(21568, 8760, 1, 1, 2, 6.152336), -- Top-Grade Life Stone - Level 67
(21568, 1343, 10, 30, 2, 153385.4269), -- Silver Arrow
-- Devil Bat
(21569, 6335, 1, 1, -1, 11646), -- Recipe: Sealed Majestic Necklace(70%)
(21569, 5526, 1, 1, -1, 46809), -- Sealed Tallum Helm Design
(21569, 730, 1, 1, -1, 2523), -- Scroll: Enchant Armor (A-Grade)
(21569, 57, 1198, 2435, 0, 700000), -- Adena
(21569, 11951, 1, 1, 1, 123.14141), -- Common Item - Bloody Orchid
(21569, 5536, 1, 1, 1, 1521.85859), -- Bloody Orchid Head
(21569, 1870, 1, 1, 2, 81313.475328), -- Coal
(21569, 1865, 1, 1, 2, 81313.475328), -- Varnish
(21569, 1874, 1, 1, 2, 5420.76246), -- Oriharukon Ore
(21569, 4043, 1, 1, 2, 2710.526832), -- Asofe
(21569, 4039, 1, 1, 2, 2710.526832), -- Mold Glue
(21569, 6337, 1, 1, 2, 417.004128), -- Recipe: Sealed Majestic Earring(70%)
(21569, 8730, 1, 1, 2, 903.606012), -- Life Stone - Level 67
(21569, 8740, 1, 1, 2, 225.974304), -- Mid-Grade Life Stone - Level 67
(21569, 8750, 1, 1, 2, 22.713912), -- High-Grade Life Stone - Level 67
(21569, 8760, 1, 1, 2, 4.659264), -- Top-Grade Life Stone - Level 67
(21569, 1343, 10, 30, 2, 116161.2756), -- Silver Arrow
-- Ghost of Betrayer
(21570, 5542, 1, 1, -1, 10630), -- Halberd Edge
(21570, 5464, 1, 1, -1, 1167), -- Recipe: Dark Legion's Edge(60%)
(21570, 5543, 1, 1, -1, 10730), -- Dasparion's Staff Head
(21570, 57, 1248, 2533, 0, 700000), -- Adena
(21570, 11950, 1, 1, 1, 128.154852), -- Common Item - Blood Tornado
(21570, 5539, 1, 1, 1, 1569.845148), -- Blood Tornado Edge
(21570, 1872, 1, 1, 2, 124147.312934), -- Animal Bone
(21570, 1867, 1, 1, 2, 124147.312934), -- Animal Skin
(21570, 1881, 1, 1, 2, 12414.67734), -- Coarse Bone Powder
(21570, 1875, 1, 1, 2, 6207.33867), -- Stone of Purity
(21570, 4041, 1, 1, 2, 809.570767), -- Mold Hardener
(21570, 6339, 1, 1, 2, 716.231385), -- Recipe: Sealed Majestic Ring(70%)
(21570, 8730, 1, 1, 2, 1034.556445), -- Life Stone - Level 67
(21570, 8740, 1, 1, 2, 258.706553), -- Mid-Grade Life Stone - Level 67
(21570, 8750, 1, 1, 2, 25.897632), -- High-Grade Life Stone - Level 67
(21570, 8760, 1, 1, 2, 5.39534), -- Top-Grade Life Stone - Level 67
-- Ghost of Rebellion Soldier
(21571, 729, 1, 1, -1, 461), -- Scroll: Enchant Weapon (A-Grade)
(21571, 4042, 1, 1, -1, 69170), -- Enria
(21571, 4043, 1, 1, -1, 138340), -- Asofe
(21571, 57, 1643, 3335, 0, 700000), -- Adena
(21571, 11955, 1, 1, 1, 168.72708), -- Common Item - Carnage Bow
(21571, 5535, 1, 1, 1, 2091.27292), -- Carnage Bow Stave
(21571, 1895, 1, 1, 2, 31841.79004), -- Metallic Fiber
(21571, 4040, 1, 1, 2, 2228.86916), -- Mold Lubricant
(21571, 4042, 1, 1, 2, 1857.52464), -- Enria
(21571, 4043, 1, 1, 2, 3714.84877), -- Asofe
(21571, 729, 1, 1, 2, 12.43162), -- Scroll: Enchant Weapon (A-Grade)
(21571, 8487, 1, 1, 2, 60.95504), -- Recipe: Destroyer Hammer (60%)
(21571, 8730, 1, 1, 2, 1238.34976), -- Life Stone - Level 67
(21571, 8740, 1, 1, 2, 309.58744), -- Mid-Grade Life Stone - Level 67
(21571, 8750, 1, 1, 2, 30.87854), -- High-Grade Life Stone - Level 67
(21571, 8760, 1, 1, 2, 6.21581), -- Top-Grade Life Stone - Level 67
(21571, 1343, 10, 30, 2, 159208.54918), -- Silver Arrow
-- Bone Sweeper
(21572, 5547, 1, 1, -1, 14592), -- Elemental Sword Edge
(21572, 5466, 1, 1, -1, 1589), -- Recipe: Sword of Miracles(60%)
(21572, 5548, 1, 1, -1, 14592), -- Tallum Blade Edge
(21572, 57, 1698, 3447, 0, 700000), -- Adena
(21572, 11951, 1, 1, 1, 174.41914), -- Common Item - Bloody Orchid
(21572, 5536, 1, 1, 1, 2155.58086), -- Bloody Orchid Head
(21572, 1868, 1, 1, 2, 230344.648344), -- Thread
(21572, 1873, 1, 1, 2, 46068.989935), -- Silver Nugget
(21572, 5549, 1, 1, 2, 11517.172151), -- Metallic Thread
(21572, 1889, 1, 1, 2, 7678.215211), -- Compound Braid
(21572, 4044, 1, 1, 2, 3838.95694), -- Thons
(21572, 730, 1, 1, 2, 96.124589), -- Scroll: Enchant Armor (A-Grade)
(21572, 5352, 1, 1, 2, 148.857514), -- Recipe: Sealed Majestic Robe(60%)
(21572, 8730, 1, 1, 2, 1279.752757), -- Life Stone - Level 67
(21572, 8740, 1, 1, 2, 320.013522), -- Mid-Grade Life Stone - Level 67
(21572, 8750, 1, 1, 2, 31.941086), -- High-Grade Life Stone - Level 67
(21572, 8760, 1, 1, 2, 6.327951), -- Top-Grade Life Stone - Level 67
-- Atrox
(21573, 6335, 1, 1, -1, 17007), -- Recipe: Sealed Majestic Necklace(70%)
(21573, 6341, 1, 1, -1, 122303), -- Sealed Phoenix Earring Gemstone
(21573, 730, 1, 1, -1, 3685), -- Scroll: Enchant Armor (A-Grade)
(21573, 57, 1750, 3554, 0, 700000), -- Adena
(21573, 12225, 1, 1, 1, 903.270963), -- Common Item - Sealed Dark Crystal Shield
(21573, 5494, 1, 1, 1, 4571.868806), -- Sealed Dark Crystal Shield Fragment
(21573, 12226, 1, 1, 1, 632.813696), -- Common Item - Sealed Dark Crystal Helmet
(21573, 5525, 1, 1, 1, 3365.109684), -- Sealed Dark Crystal Helmet Design
(21573, 12234, 1, 1, 1, 632.813696), -- Common Item - Sealed Tallum Helmet
(21573, 5526, 1, 1, 1, 3365.123155), -- Sealed Tallum Helm Design
(21573, 1873, 1, 1, 2, 47496.60231), -- Silver Nugget
(21573, 1868, 1, 3, 2, 118741.505775), -- Thread
(21573, 1876, 1, 1, 2, 23748.301155), -- Mithril Ore
(21573, 1895, 1, 1, 2, 33925.974255), -- Metallic Fiber
(21573, 4042, 1, 1, 2, 1979.12441), -- Enria
(21573, 5434, 1, 1, 2, 44.095305), -- Recipe: Dragon Slayer(60%)
(21573, 8730, 1, 1, 2, 1319.283855), -- Life Stone - Level 67
(21573, 8740, 1, 1, 2, 329.72165), -- Mid-Grade Life Stone - Level 67
(21573, 8750, 1, 1, 2, 32.972165), -- High-Grade Life Stone - Level 67
(21573, 8760, 1, 1, 2, 6.753335), -- Top-Grade Life Stone - Level 67
(21573, 1343, 10, 30, 2, 169630.665785), -- Silver Arrow
-- Bone Grinder
(21574, 5448, 1, 1, -1, 2000), -- Recipe: Soul Separator(60%)
(21574, 5494, 1, 1, -1, 113405), -- Sealed Dark Crystal Shield Fragment
(21574, 729, 1, 1, -1, 600), -- Scroll: Enchant Weapon (A-Grade)
(21574, 57, 2136, 4345, 0, 700000), -- Adena
(21574, 11960, 1, 1, 1, 219.553866), -- Common Item - Halberd
(21574, 5542, 1, 1, 1, 2689.446134), -- Halberd Edge
(21574, 1868, 1, 3, 2, 199376.20096), -- Thread
(21574, 1873, 1, 1, 2, 79750.480384), -- Silver Nugget
(21574, 5549, 1, 1, 2, 19937.620096), -- Metallic Thread
(21574, 1889, 1, 1, 2, 13291.885002), -- Compound Braid
(21574, 4044, 1, 1, 2, 6645.735094), -- Thons
(21574, 5466, 1, 1, 2, 73.836892), -- Recipe: Sword of Miracles(60%)
(21574, 10305, 1, 1, 2, 797.687322), -- Transformation Sealbook: Oel Mahum
(21574, 1343, 30, 90, 2, 94940.55425), -- Silver Arrow
-- Bone Grinder
(21575, 5448, 1, 1, -1, 1127), -- Recipe: Soul Separator(60%)
(21575, 5494, 1, 1, -1, 63890), -- Sealed Dark Crystal Shield Fragment
(21575, 729, 1, 1, -1, 338), -- Scroll: Enchant Weapon (A-Grade)
(21575, 57, 1203, 2448, 0, 700000), -- Adena
(21575, 11960, 1, 1, 1, 123.701886), -- Common Item - Halberd
(21575, 5542, 1, 1, 1, 1515.298114), -- Halberd Edge
(21575, 1868, 1, 1, 2, 224648.956168), -- Thread
(21575, 1873, 1, 1, 2, 44929.700634), -- Silver Nugget
(21575, 5549, 1, 1, 2, 11232.538408), -- Metallic Thread
(21575, 1889, 1, 1, 2, 7488.509938), -- Compound Braid
(21575, 4044, 1, 1, 2, 3744.02847), -- Thons
(21575, 5466, 1, 1, 2, 41.675816), -- Recipe: Sword of Miracles(60%)
(21575, 10305, 1, 1, 2, 449.374016), -- Transformation Sealbook: Oel Mahum
(21575, 1343, 10, 30, 2, 160463.21655), -- Silver Arrow
-- Ghost of Guillotine 
(21576, 5450, 1, 1, -1, 1316), -- Recipe: Dragon Grinder(60%)
(21576, 5497, 1, 1, -1, 83285), -- Sealed Tallum Boots Lining
(21576, 5456, 1, 1, -1, 1316), -- Recipe: Tallum Glaive(60%)
(21576, 57, 1405, 2858, 0, 700000), -- Adena
(21576, 11951, 1, 1, 1, 144.401082), -- Common Item - Bloody Orchid
(21576, 5536, 1, 1, 1, 1784.598918), -- Bloody Orchid Head
(21576, 1873, 1, 1, 2, 38154.28234), -- Silver Nugget
(21576, 1868, 1, 1, 2, 190770.58179), -- Thread
(21576, 1876, 1, 1, 2, 19077.14117), -- Mithril Ore
(21576, 1895, 1, 1, 2, 27252.999535), -- Metallic Fiber
(21576, 4042, 1, 1, 2, 1589.692605), -- Enria
(21576, 6337, 1, 1, 2, 489.231945), -- Recipe: Sealed Majestic Earring(70%)
(21576, 8730, 1, 1, 2, 1059.79507), -- Life Stone - Level 67
(21576, 8740, 1, 1, 2, 265.156245), -- Mid-Grade Life Stone - Level 67
(21576, 8750, 1, 1, 2, 26.55712), -- High-Grade Life Stone - Level 67
(21576, 8760, 1, 1, 2, 5.394415), -- Top-Grade Life Stone - Level 67
(21576, 1343, 10, 30, 2, 136264.167765), -- Silver Arrow
-- Ghost of Guillotine 
(21577, 5450, 1, 1, -1, 1270), -- Recipe: Dragon Grinder(60%)
(21577, 5497, 1, 1, -1, 80418), -- Sealed Tallum Boots Lining
(21577, 5456, 1, 1, -1, 1270), -- Recipe: Tallum Glaive(60%)
(21577, 57, 1356, 2760, 0, 700000), -- Adena
(21577, 11951, 1, 1, 1, 139.460454), -- Common Item - Bloody Orchid
(21577, 5536, 1, 1, 1, 1723.539546), -- Bloody Orchid Head
(21577, 1873, 1, 1, 2, 36840.80516), -- Silver Nugget
(21577, 1868, 1, 1, 2, 184203.22446), -- Thread
(21577, 1876, 1, 1, 2, 18420.40258), -- Mithril Ore
(21577, 1895, 1, 1, 2, 26314.80359), -- Metallic Fiber
(21577, 4042, 1, 1, 2, 1534.96677), -- Enria
(21577, 6337, 1, 1, 2, 472.38993), -- Recipe: Sealed Majestic Earring(70%)
(21577, 8730, 1, 1, 2, 1023.31118), -- Life Stone - Level 67
(21577, 8740, 1, 1, 2, 256.02813), -- Mid-Grade Life Stone - Level 67
(21577, 8750, 1, 1, 2, 25.64288), -- High-Grade Life Stone - Level 67
(21577, 8760, 1, 1, 2, 5.20871), -- Top-Grade Life Stone - Level 67
(21577, 1343, 10, 30, 2, 131573.21661), -- Silver Arrow
-- Behemoth Zombie
(21578, 5482, 1, 1, -1, 42487), -- Sealed Dark Crystal Leggings Design
(21578, 5464, 1, 1, -1, 1192), -- Recipe: Dark Legion's Edge(60%)
(21578, 5485, 1, 1, -1, 27069), -- Sealed Tallum Tunic Texture
(21578, 57, 1588, 3238, 0, 700000), -- Adena
(21578, 11950, 1, 1, 1, 163.627632), -- Common Item - Blood Tornado
(21578, 5539, 1, 1, 1, 2004.372368), -- Blood Tornado Edge
(21578, 1871, 1, 1, 2, 108051.58614), -- Charcoal
(21578, 1866, 1, 1, 2, 72034.39076), -- Suede
(21578, 1877, 1, 1, 2, 4321.998614), -- Adamantite Nugget
(21578, 4041, 1, 1, 2, 939.734042), -- Mold Hardener
(21578, 4040, 1, 1, 2, 2161.161386), -- Mold Lubricant
(21578, 5277, 1, 1, 2, 47.975384), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21578, 8730, 1, 1, 2, 1200.681232), -- Life Stone - Level 67
(21578, 8740, 1, 1, 2, 300.170308), -- Mid-Grade Life Stone - Level 67
(21578, 8750, 1, 1, 2, 30.146694), -- High-Grade Life Stone - Level 67
(21578, 8760, 1, 1, 2, 6.159002), -- Top-Grade Life Stone - Level 67
(21578, 1344, 10, 30, 2, 135063.996438), -- Mithril Arrow
-- Ghost of Rebellion Leader
(21579, 729, 1, 1, -1, 374), -- Scroll: Enchant Weapon (A-Grade)
(21579, 4042, 1, 1, -1, 56029), -- Enria
(21579, 1876, 1, 1, -1, 672353), -- Mithril Ore
(21579, 57, 1659, 3381, 0, 700000), -- Adena
(21579, 11955, 1, 1, 1, 170.892162), -- Common Item - Carnage Bow
(21579, 5535, 1, 1, 1, 2118.107838), -- Carnage Bow Stave
(21579, 1873, 1, 1, 2, 49650.7685), -- Silver Nugget
(21579, 1868, 1, 1, 2, 248253.8425), -- Thread
(21579, 1876, 1, 1, 2, 24825.203208), -- Mithril Ore
(21579, 1895, 1, 1, 2, 35464.679464), -- Metallic Fiber
(21579, 4042, 1, 1, 2, 2068.947976), -- Enria
(21579, 5282, 1, 1, 2, 55.036768), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21579, 8730, 1, 1, 2, 1379.177956), -- Life Stone - Level 67
(21579, 8740, 1, 1, 2, 344.703968), -- Mid-Grade Life Stone - Level 67
(21579, 8750, 1, 1, 2, 34.39798), -- High-Grade Life Stone - Level 67
(21579, 8760, 1, 1, 2, 7.24168), -- Top-Grade Life Stone - Level 67
-- Bone Caster
(21580, 5486, 1, 1, -1, 20169), -- Sealed Dark Crystal Robe Fabric
(21580, 5466, 1, 1, -1, 1262), -- Recipe: Sword of Miracles(60%)
(21580, 5489, 1, 1, -1, 44988), -- Sealed Tallum Stockings Fabric
(21580, 57, 1682, 3428, 0, 700000), -- Adena
(21580, 11951, 1, 1, 1, 173.221412), -- Common Item - Bloody Orchid
(21580, 5536, 1, 1, 1, 2140.778588), -- Bloody Orchid Head
(21580, 1873, 1, 1, 2, 45765.053124), -- Silver Nugget
(21580, 1868, 1, 1, 2, 228825.742384), -- Thread
(21580, 1876, 1, 1, 2, 22882.764944), -- Mithril Ore
(21580, 1895, 1, 1, 2, 32689.32366), -- Metallic Fiber
(21580, 4042, 1, 1, 2, 1907.056), -- Enria
(21580, 5282, 1, 1, 2, 51.013748), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21580, 8730, 1, 1, 2, 1271.052824), -- Life Stone - Level 67
(21580, 8740, 1, 1, 2, 318.001588), -- Mid-Grade Life Stone - Level 67
(21580, 8750, 1, 1, 2, 31.943188), -- High-Grade Life Stone - Level 67
(21580, 8760, 1, 1, 2, 6.197932), -- Top-Grade Life Stone - Level 67
(21580, 1344, 10, 30, 2, 143015.850608), -- Mithril Arrow
-- Bone Puppeteer
(21581, 6335, 1, 1, -1, 14337), -- Recipe: Sealed Majestic Necklace(70%)
(21581, 5494, 1, 1, -1, 78289), -- Sealed Dark Crystal Shield Fragment
(21581, 730, 1, 1, -1, 3106), -- Scroll: Enchant Armor (A-Grade)
(21581, 57, 1839, 3749, 0, 700000), -- Adena
(21581, 11950, 1, 1, 1, 189.43974), -- Common Item - Blood Tornado
(21581, 5539, 1, 1, 1, 2320.56026), -- Blood Tornado Edge
(21581, 1865, 1, 1, 2, 137639.296222), -- Varnish
(21581, 1870, 1, 1, 2, 137639.296222), -- Coal
(21581, 1879, 1, 1, 2, 22939.830676), -- Cokes
(21581, 1875, 1, 1, 2, 9175.807404), -- Stone of Purity
(21581, 4040, 1, 1, 2, 2752.679788), -- Mold Lubricant
(21581, 1808, 1, 1, 2, 61.184536), -- Recipe: Soulshot (S-Grade)
(21581, 8730, 1, 1, 2, 1529.301234), -- Life Stone - Level 67
(21581, 8740, 1, 1, 2, 382.40335), -- Mid-Grade Life Stone - Level 67
(21581, 8750, 1, 1, 2, 38.084252), -- High-Grade Life Stone - Level 67
(21581, 8760, 1, 1, 2, 8.116316), -- Top-Grade Life Stone - Level 67
-- Vampire Soldier
(21582, 4041, 1, 1, -1, 32122), -- Mold Hardener
(21582, 5220, 1, 1, -1, 147761), -- Metal Hardener
(21582, 5496, 1, 1, -1, 86612), -- Sealed Dark Crystal Boots Lining
(21582, 57, 1823, 3716, 0, 700000), -- Adena
(21582, 11955, 1, 1, 1, 187.76487), -- Common Item - Carnage Bow
(21582, 5535, 1, 1, 1, 2327.23513), -- Carnage Bow Stave
(21582, 1866, 1, 1, 2, 82663.495092), -- Suede
(21582, 1871, 1, 1, 2, 123995.242638), -- Charcoal
(21582, 5220, 1, 1, 2, 4959.976836), -- Metal Hardener
(21582, 1885, 1, 1, 2, 10332.841926), -- High-Grade Suede
(21582, 4041, 1, 1, 2, 1078.371438), -- Mold Hardener
(21582, 3036, 1, 1, 2, 55.07709), -- Recipe: Spiritshot S
(21582, 8730, 1, 1, 2, 1377.686934), -- Life Stone - Level 67
(21582, 8740, 1, 1, 2, 344.516694), -- Mid-Grade Life Stone - Level 67
(21582, 8750, 1, 1, 2, 34.565622), -- High-Grade Life Stone - Level 67
(21582, 8760, 1, 1, 2, 6.837156), -- Top-Grade Life Stone - Level 67
(21582, 1344, 10, 30, 2, 154993.388574), -- Mithril Arrow
-- Bone Scavenger
(21583, 1884, 1, 5, -1, 772646), -- Cord
(21583, 4039, 1, 1, -1, 125555), -- Mold Glue
(21583, 5532, 1, 1, -1, 12702), -- Meteor Shower Head
(21583, 57, 1857, 3793, 0, 700000), -- Adena
(21583, 11946, 1, 1, 1, 47.854653), -- Common Item - Dasparion's Staff
(21583, 5543, 1, 1, 1, 591.727752), -- Dasparion's Staff Head
(21583, 11949, 1, 1, 1, 47.854653), -- Common Item - Meteor Shower
(21583, 5532, 1, 1, 1, 586.201077), -- Meteor Shower Head
(21583, 11953, 1, 1, 1, 47.854653), -- Common Item - Spiritual Eye
(21583, 8341, 1, 1, 1, 585.451482), -- Spiritual Eye Piece
(21583, 11958, 1, 1, 1, 47.854653), -- Common Item - Destroyer Hammer
(21583, 8346, 1, 1, 1, 586.201077), -- Hammer Piece of Destroyer
(21583, 1864, 4, 12, 2, 43461.312186), -- Stem
(21583, 1869, 1, 1, 2, 173844.30309), -- Iron Ore
(21583, 1878, 1, 1, 2, 69537.721236), -- Braided Hemp
(21583, 1884, 1, 1, 2, 106981.364193), -- Cord
(21583, 4039, 1, 1, 2, 5794.967712), -- Mold Glue
(21583, 3036, 1, 1, 2, 77.070801), -- Recipe: Spiritshot S
(21583, 10305, 1, 1, 2, 695.528517), -- Transformation Sealbook: Oel Mahum
(21583, 1344, 30, 90, 2, 72434.732265), -- Mithril Arrow
-- Bone Scavenger
(21584, 1884, 1, 5, -1, 720616), -- Cord
(21584, 4039, 1, 1, -1, 117100), -- Mold Glue
(21584, 5532, 1, 1, -1, 11847), -- Meteor Shower Head
(21584, 57, 1732, 3537, 0, 700000), -- Adena
(21584, 11946, 1, 1, 1, 44.63421), -- Common Item - Dasparion's Staff
(21584, 5543, 1, 1, 1, 551.90664), -- Dasparion's Staff Head
(21584, 11949, 1, 1, 1, 44.63421), -- Common Item - Meteor Shower
(21584, 5532, 1, 1, 1, 546.75189), -- Meteor Shower Head
(21584, 11953, 1, 1, 1, 44.63421), -- Common Item - Spiritual Eye
(21584, 8341, 1, 1, 1, 546.05274), -- Spiritual Eye Piece
(21584, 11958, 1, 1, 1, 44.63421), -- Common Item - Destroyer Hammer
(21584, 8346, 1, 1, 1, 546.75189), -- Hammer Piece of Destroyer
(21584, 1864, 4, 12, 2, 40534.643066), -- Stem
(21584, 1869, 1, 1, 2, 162137.69029), -- Iron Ore
(21584, 1878, 1, 1, 2, 64855.076116), -- Braided Hemp
(21584, 1884, 1, 1, 2, 99777.277633), -- Cord
(21584, 4039, 1, 1, 2, 5404.736672), -- Mold Glue
(21584, 3036, 1, 1, 2, 71.880881), -- Recipe: Spiritshot S
(21584, 10305, 1, 1, 2, 648.691877), -- Transformation Sealbook: Oel Mahum
(21584, 1344, 30, 90, 2, 67557.003465), -- Mithril Arrow
-- Vampire Magician
(21585, 5536, 1, 1, -1, 9955), -- Bloody Orchid Head
(21585, 730, 1, 1, -1, 2438), -- Scroll: Enchant Armor (A-Grade)
(21585, 5352, 1, 1, -1, 3785), -- Recipe: Sealed Majestic Robe(60%)
(21585, 57, 1443, 2946, 0, 700000), -- Adena
(21585, 11955, 1, 1, 1, 148.718736), -- Common Item - Carnage Bow
(21585, 5535, 1, 1, 1, 1843.281264), -- Carnage Bow Stave
(21585, 1873, 1, 1, 2, 39287.676435), -- Silver Nugget
(21585, 1868, 1, 1, 2, 196438.79146), -- Thread
(21585, 1876, 1, 1, 2, 19644.04286), -- Mithril Ore
(21585, 1895, 1, 1, 2, 28062.626025), -- Metallic Fiber
(21585, 4042, 1, 1, 2, 1637.14), -- Enria
(21585, 3036, 1, 1, 2, 43.793495), -- Recipe: Spiritshot S
(21585, 8730, 1, 1, 2, 1091.15381), -- Life Stone - Level 67
(21585, 8740, 1, 1, 2, 272.993095), -- Mid-Grade Life Stone - Level 67
(21585, 8750, 1, 1, 2, 27.422095), -- High-Grade Life Stone - Level 67
(21585, 8760, 1, 1, 2, 5.320705), -- Top-Grade Life Stone - Level 67
(21585, 1344, 10, 30, 2, 122774.04002), -- Mithril Arrow
-- Vampire Adept
(21586, 1895, 1, 3, -1, 501916), -- Metallic Fiber
(21586, 5539, 1, 1, -1, 11848), -- Blood Tornado Edge
(21586, 5462, 1, 1, -1, 1301), -- Recipe: Branch of the Mother Tree(60%)
(21586, 57, 1733, 3538, 0, 700000), -- Adena
(21586, 11951, 1, 1, 1, 178.53633), -- Common Item - Bloody Orchid
(21586, 5536, 1, 1, 1, 2206.46367), -- Bloody Orchid Head
(21586, 1873, 1, 1, 2, 51890.294), -- Silver Nugget
(21586, 1868, 1, 1, 2, 259451.47), -- Thread
(21586, 1876, 1, 1, 2, 25944.957792), -- Mithril Ore
(21586, 1895, 1, 1, 2, 37064.333536), -- Metallic Fiber
(21586, 4042, 1, 1, 2, 2162.269024), -- Enria
(21586, 3957, 1, 1, 2, 57.519232), -- Recipe: Blessed Spiritshot S
(21586, 8730, 1, 1, 2, 1441.386544), -- Life Stone - Level 67
(21586, 8740, 1, 1, 2, 360.252032), -- Mid-Grade Life Stone - Level 67
(21586, 8750, 1, 1, 2, 35.94952), -- High-Grade Life Stone - Level 67
(21586, 8760, 1, 1, 2, 7.56832), -- Top-Grade Life Stone - Level 67
-- Vampire Warrior
(21587, 5542, 1, 1, -1, 12411), -- Halberd Edge
(21587, 5464, 1, 1, -1, 1363), -- Recipe: Dark Legion's Edge(60%)
(21587, 5543, 1, 1, -1, 12528), -- Dasparion's Staff Head
(21587, 57, 1815, 3706, 0, 700000), -- Adena
(21587, 11950, 1, 1, 1, 187.024572), -- Common Item - Blood Tornado
(21587, 5539, 1, 1, 1, 2290.975428), -- Blood Tornado Edge
(21587, 1865, 1, 1, 2, 123538.193216), -- Varnish
(21587, 1870, 1, 1, 2, 123538.193216), -- Coal
(21587, 1879, 1, 1, 2, 20589.554), -- Cokes
(21587, 1875, 1, 1, 2, 8235.8216), -- Stone of Purity
(21587, 4040, 1, 1, 2, 2470.74648), -- Mold Lubricant
(21587, 5157, 1, 1, 2, 54.760608), -- Recipe: Soulshot (S) Compressed Package (100%)
(21587, 8730, 1, 1, 2, 1372.492064), -- Life Stone - Level 67
(21587, 8740, 1, 1, 2, 343.34032), -- Mid-Grade Life Stone - Level 67
(21587, 8750, 1, 1, 2, 34.334032), -- High-Grade Life Stone - Level 67
(21587, 8760, 1, 1, 2, 6.953728), -- Top-Grade Life Stone - Level 67
(21587, 1344, 10, 30, 2, 154423.610736), -- Mithril Arrow
-- Vampire Wizard
(21588, 5478, 1, 1, -1, 25534), -- Sealed Dark Crystal Leather Armor Pattern
(21588, 729, 1, 1, -1, 337), -- Scroll: Enchant Weapon (A-Grade)
(21588, 5350, 1, 1, -1, 3928), -- Recipe: Sealed Robe of Nightmare(60%)
(21588, 57, 1499, 3053, 0, 700000), -- Adena
(21588, 11957, 1, 1, 1, 51.43059), -- Common Item - Tallum Blade
(21588, 5548, 1, 1, 1, 635.620615), -- Tallum Blade Edge
(21588, 11952, 1, 1, 1, 51.43059), -- Common Item - Elemental Sword
(21588, 5547, 1, 1, 1, 635.620615), -- Elemental Sword Edge
(21588, 11954, 1, 1, 1, 51.43059), -- Common Item - Inferno Master
(21588, 8331, 1, 1, 1, 637.467), -- Infernal Master Blade
(21588, 1873, 1, 1, 2, 40769.081556), -- Silver Nugget
(21588, 1868, 1, 1, 2, 203845.40778), -- Thread
(21588, 1876, 1, 1, 2, 20384.753044), -- Mithril Ore
(21588, 1895, 1, 1, 2, 29120.77254), -- Metallic Fiber
(21588, 4042, 1, 1, 2, 1698.552532), -- Enria
(21588, 6901, 1, 1, 2, 101.88768), -- Recipe: Shining Arrow (100%)
(21588, 8731, 1, 1, 2, 943.734636), -- Life Stone - Level 70
(21588, 8741, 1, 1, 2, 236.039792), -- Mid-Grade Life Stone - Level 70
(21588, 8751, 1, 1, 2, 23.773792), -- High-Grade Life Stone - Level 70
(21588, 8761, 1, 1, 2, 4.669852), -- Top-Grade Life Stone - Level 70
(21588, 1344, 10, 30, 2, 127403.326796), -- Mithril Arrow
-- Vampire Wizard
(21589, 5478, 1, 1, -1, 26193), -- Sealed Dark Crystal Leather Armor Pattern
(21589, 729, 1, 1, -1, 346), -- Scroll: Enchant Weapon (A-Grade)
(21589, 5350, 1, 1, -1, 4030), -- Recipe: Sealed Robe of Nightmare(60%)
(21589, 57, 1538, 3132, 0, 700000), -- Adena
(21589, 11957, 1, 1, 1, 52.77681), -- Common Item - Tallum Blade
(21589, 5548, 1, 1, 1, 652.258285), -- Tallum Blade Edge
(21589, 11952, 1, 1, 1, 52.77681), -- Common Item - Elemental Sword
(21589, 5547, 1, 1, 1, 652.258285), -- Elemental Sword Edge
(21589, 11954, 1, 1, 1, 52.77681), -- Common Item - Inferno Master
(21589, 8331, 1, 1, 1, 654.153), -- Infernal Master Blade
(21589, 1873, 1, 1, 2, 41822.467533), -- Silver Nugget
(21589, 1868, 1, 1, 2, 209112.337665), -- Thread
(21589, 1876, 1, 1, 2, 20911.451517), -- Mithril Ore
(21589, 1895, 1, 1, 2, 29873.191095), -- Metallic Fiber
(21589, 4042, 1, 1, 2, 1742.439501), -- Enria
(21589, 6901, 1, 1, 2, 104.52024), -- Recipe: Shining Arrow (100%)
(21589, 8731, 1, 1, 2, 968.118723), -- Life Stone - Level 70
(21589, 8741, 1, 1, 2, 242.138556), -- Mid-Grade Life Stone - Level 70
(21589, 8751, 1, 1, 2, 24.388056), -- High-Grade Life Stone - Level 70
(21589, 8761, 1, 1, 2, 4.790511), -- Top-Grade Life Stone - Level 70
(21589, 1344, 10, 30, 2, 130695.156603), -- Mithril Arrow
-- Vampire Magister
(21590, 5482, 1, 1, -1, 40077), -- Sealed Dark Crystal Leggings Design
(21590, 5440, 1, 1, -1, 1125), -- Recipe: Elysian(60%)
(21590, 5485, 1, 1, -1, 25534), -- Sealed Tallum Tunic Texture
(21590, 57, 1499, 3053, 0, 700000), -- Adena
(21590, 11950, 1, 1, 1, 154.34433), -- Common Item - Blood Tornado
(21590, 5539, 1, 1, 1, 1890.65567), -- Blood Tornado Edge
(21590, 1864, 1, 3, 2, 101922.66196), -- Stem
(21590, 1869, 1, 1, 2, 101922.66196), -- Iron Ore
(21590, 1878, 1, 1, 2, 40769.24054), -- Braided Hemp
(21590, 1884, 1, 1, 2, 62721.60433), -- Cord
(21590, 4039, 1, 1, 2, 3397.36348), -- Mold Glue
(21590, 3036, 1, 1, 2, 45.25717), -- Recipe: Spiritshot S
(21590, 8731, 1, 1, 2, 943.80972), -- Life Stone - Level 70
(21590, 8741, 1, 1, 2, 235.95243), -- Mid-Grade Life Stone - Level 70
(21590, 8751, 1, 1, 2, 23.72706), -- High-Grade Life Stone - Level 70
(21590, 8761, 1, 1, 2, 4.83329), -- Top-Grade Life Stone - Level 70
(21590, 1344, 10, 30, 2, 127402.88806), -- Mithril Arrow
-- Vampire Magister
(21591, 5482, 1, 1, -1, 46877), -- Sealed Dark Crystal Leggings Design
(21591, 5440, 1, 1, -1, 1315), -- Recipe: Elysian(60%)
(21591, 5485, 1, 1, -1, 29866), -- Sealed Tallum Tunic Texture
(21591, 57, 1754, 3571, 0, 700000), -- Adena
(21591, 11950, 1, 1, 1, 180.533808), -- Common Item - Blood Tornado
(21591, 5539, 1, 1, 1, 2211.466192), -- Blood Tornado Edge
(21591, 1864, 1, 3, 2, 119217.113252), -- Stem
(21591, 1869, 1, 1, 2, 119217.113252), -- Iron Ore
(21591, 1878, 1, 1, 2, 47686.762381), -- Braided Hemp
(21591, 1884, 1, 1, 2, 73364.536847), -- Cord
(21591, 4039, 1, 1, 2, 3973.931415), -- Mold Glue
(21591, 3036, 1, 1, 2, 53.068672), -- Recipe: Spiritshot S
(21591, 8731, 1, 1, 2, 1103.662538), -- Life Stone - Level 70
(21591, 8741, 1, 1, 2, 276.122934), -- Mid-Grade Life Stone - Level 70
(21591, 8751, 1, 1, 2, 27.778133), -- High-Grade Life Stone - Level 70
(21591, 8761, 1, 1, 2, 5.389787), -- Top-Grade Life Stone - Level 70
(21591, 1344, 30, 90, 2, 49673.520789), -- Mithril Arrow
-- Vampire Magister
(21592, 5482, 1, 1, -1, 34520), -- Sealed Dark Crystal Leggings Design
(21592, 5440, 1, 1, -1, 969), -- Recipe: Elysian(60%)
(21592, 5485, 1, 1, -1, 21993), -- Sealed Tallum Tunic Texture
(21592, 57, 1292, 2630, 0, 700000), -- Adena
(21592, 11950, 1, 1, 1, 132.909714), -- Common Item - Blood Tornado
(21592, 5539, 1, 1, 1, 1628.090286), -- Blood Tornado Edge
(21592, 1864, 1, 1, 2, 175577.430272), -- Stem
(21592, 1869, 1, 1, 2, 87788.715136), -- Iron Ore
(21592, 1878, 1, 1, 2, 35115.392805), -- Braided Hemp
(21592, 1884, 1, 1, 2, 54024.03989), -- Cord
(21592, 4039, 1, 1, 2, 2926.166172), -- Mold Glue
(21592, 3036, 1, 1, 2, 39.164748), -- Recipe: Spiritshot S
(21592, 8731, 1, 1, 2, 812.668521), -- Life Stone - Level 70
(21592, 8741, 1, 1, 2, 203.283692), -- Mid-Grade Life Stone - Level 70
(21592, 8751, 1, 1, 2, 20.514868), -- High-Grade Life Stone - Level 70
(21592, 8761, 1, 1, 2, 4.196223), -- Top-Grade Life Stone - Level 70
(21592, 1344, 10, 30, 2, 109735.427673), -- Mithril Arrow
-- Vampire Warlord
(21593, 5448, 1, 1, -1, 1551), -- Recipe: Soul Separator(60%)
(21593, 5494, 1, 1, -1, 87939), -- Sealed Dark Crystal Shield Fragment
(21593, 729, 1, 1, -1, 465), -- Scroll: Enchant Weapon (A-Grade)
(21593, 57, 2068, 4210, 0, 700000), -- Adena
(21593, 11950, 1, 1, 1, 212.83668), -- Common Item - Blood Tornado
(21593, 5539, 1, 1, 1, 2607.16332), -- Blood Tornado Edge
(21593, 1873, 1, 1, 2, 61841.835264), -- Silver Nugget
(21593, 1868, 1, 1, 2, 309210.077568), -- Thread
(21593, 1876, 1, 1, 2, 30920.917632), -- Mithril Ore
(21593, 1895, 1, 1, 2, 44172.868224), -- Metallic Fiber
(21593, 4042, 1, 1, 2, 2576.668032), -- Enria
(21593, 5162, 1, 1, 2, 68.494848), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21593, 8731, 1, 1, 2, 1431.632448), -- Life Stone - Level 70
(21593, 8741, 1, 1, 2, 357.795456), -- Mid-Grade Life Stone - Level 70
(21593, 8751, 1, 1, 2, 35.599296), -- High-Grade Life Stone - Level 70
(21593, 8761, 1, 1, 2, 8.111232), -- Top-Grade Life Stone - Level 70
-- Vampire Warlord
(21594, 5448, 1, 1, -1, 1454), -- Recipe: Soul Separator(60%)
(21594, 5494, 1, 1, -1, 82446), -- Sealed Dark Crystal Shield Fragment
(21594, 729, 1, 1, -1, 436), -- Scroll: Enchant Weapon (A-Grade)
(21594, 57, 1939, 3947, 0, 700000), -- Adena
(21594, 11950, 1, 1, 1, 199.477782), -- Common Item - Blood Tornado
(21594, 5539, 1, 1, 1, 2443.522218), -- Blood Tornado Edge
(21594, 1873, 1, 1, 2, 57979.190808), -- Silver Nugget
(21594, 1868, 1, 1, 2, 289896.798996), -- Thread
(21594, 1876, 1, 1, 2, 28989.595404), -- Mithril Ore
(21594, 1895, 1, 1, 2, 41413.828428), -- Metallic Fiber
(21594, 4042, 1, 1, 2, 2415.729204), -- Enria
(21594, 5162, 1, 1, 2, 64.216656), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21594, 8731, 1, 1, 2, 1342.212606), -- Life Stone - Level 70
(21594, 8741, 1, 1, 2, 335.447532), -- Mid-Grade Life Stone - Level 70
(21594, 8751, 1, 1, 2, 33.375762), -- High-Grade Life Stone - Level 70
(21594, 8761, 1, 1, 2, 7.604604), -- Top-Grade Life Stone - Level 70
-- Vampire Warlord
(21595, 5448, 1, 1, -1, 1028), -- Recipe: Soul Separator(60%)
(21595, 5494, 1, 1, -1, 58278), -- Sealed Dark Crystal Shield Fragment
(21595, 729, 1, 1, -1, 308), -- Scroll: Enchant Weapon (A-Grade)
(21595, 57, 1370, 2790, 0, 700000), -- Adena
(21595, 11950, 1, 1, 1, 141.060906), -- Common Item - Blood Tornado
(21595, 5539, 1, 1, 1, 1727.939094), -- Blood Tornado Edge
(21595, 1873, 1, 1, 2, 40983.198388), -- Silver Nugget
(21595, 1868, 1, 1, 2, 204916.589206), -- Thread
(21595, 1876, 1, 1, 2, 20491.599194), -- Mithril Ore
(21595, 1895, 1, 1, 2, 29273.798458), -- Metallic Fiber
(21595, 4042, 1, 1, 2, 1707.583494), -- Enria
(21595, 5162, 1, 1, 2, 45.392216), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21595, 8731, 1, 1, 2, 948.757041), -- Life Stone - Level 70
(21595, 8741, 1, 1, 2, 237.114602), -- Mid-Grade Life Stone - Level 70
(21595, 8751, 1, 1, 2, 23.592007), -- High-Grade Life Stone - Level 70
(21595, 8761, 1, 1, 2, 5.375394), -- Top-Grade Life Stone - Level 70
-- Requiem Lord
(21596, 6337, 1, 1, -1, 25686), -- Recipe: Sealed Majestic Earring(70%)
(21596, 5535, 1, 1, -1, 17090), -- Carnage Bow Stave
(21596, 6339, 1, 1, -1, 38529), -- Recipe: Sealed Majestic Ring(70%)
(21596, 57, 1981, 4028, 0, 700000), -- Adena
(21596, 11960, 1, 1, 1, 203.628852), -- Common Item - Halberd
(21596, 5542, 1, 1, 1, 2494.371148), -- Halberd Edge
(21596, 1872, 1, 1, 2, 164389.655484), -- Animal Bone
(21596, 1867, 1, 1, 2, 164389.655484), -- Animal Skin
(21596, 1881, 1, 1, 2, 16439.054449), -- Coarse Bone Powder
(21596, 1875, 1, 1, 2, 8219.304973), -- Stone of Purity
(21596, 4041, 1, 1, 2, 1072.141236), -- Mold Hardener
(21596, 729, 1, 1, 2, 13.779593), -- Scroll: Enchant Weapon (A-Grade)
(21596, 5350, 1, 1, 2, 159.576577), -- Recipe: Sealed Robe of Nightmare(60%)
(21596, 8730, 1, 1, 2, 1369.958246), -- Life Stone - Level 67
(21596, 8740, 1, 1, 2, 342.26731), -- Mid-Grade Life Stone - Level 67
(21596, 8750, 1, 1, 2, 34.226731), -- High-Grade Life Stone - Level 67
(21596, 8760, 1, 1, 2, 6.667545), -- Top-Grade Life Stone - Level 67
(21596, 1343, 20, 60, 2, 88066.712372), -- Silver Arrow
-- Requiem Behemoth
(21597, 4043, 1, 1, -1, 105426), -- Asofe
(21597, 5550, 1, 1, -1, 42170), -- Durable Metal Plate
(21597, 4052, 1, 1, -1, 111977), -- Earring of Black Ore Piece
(21597, 57, 1247, 2548, 0, 700000), -- Adena
(21597, 11944, 1, 1, 1, 152.582616), -- Common Item - Bow of Peril
(21597, 4121, 1, 1, 1, 2034.417384), -- Bow of Peril Shaft
(21597, 1869, 1, 1, 2, 84930.721004), -- Iron Ore
(21597, 1864, 1, 1, 2, 169861.442008), -- Stem
(21597, 1880, 1, 1, 2, 8493.150123), -- Steel
(21597, 5550, 1, 1, 2, 1132.498039), -- Durable Metal Plate
(21597, 4043, 1, 1, 2, 2831.050041), -- Asofe
(21597, 6335, 1, 1, 2, 326.524581), -- Recipe: Sealed Majestic Necklace(70%)
(21597, 8730, 1, 1, 2, 943.683347), -- Life Stone - Level 67
(21597, 8740, 1, 1, 2, 236.018365), -- Mid-Grade Life Stone - Level 67
(21597, 8750, 1, 1, 2, 23.40678), -- High-Grade Life Stone - Level 67
(21597, 8760, 1, 1, 2, 4.681356), -- Top-Grade Life Stone - Level 67
(21597, 1343, 10, 30, 2, 121329.824356), -- Silver Arrow
-- Requiem Behemoth
(21598, 5230, 1, 1, -1, 4723), -- Recipe: Mithril Arrow (100%)
(21598, 4053, 1, 1, -1, 151817), -- Ring of Black Ore Gemstone
(21598, 5271, 1, 1, -1, 4723), -- Recipe: Greater Soulshot (A) Compressed Package(100%)
(21598, 57, 1396, 2854, 0, 700000), -- Adena
(21598, 12201, 1, 1, 1, 232.088538), -- Common Item - Blue Wolf Tunic
(21598, 4084, 1, 1, 1, 2272.917086), -- Blue Wolf Tunic Fabric
(21598, 12192, 1, 1, 1, 232.088538), -- Common Item - Tunic of Doom
(21598, 4085, 1, 1, 1, 2272.917086), -- Tunic of Doom Pattern
(21598, 12203, 1, 1, 1, 371.546186), -- Common Item - Blue Wolf Stockings
(21598, 4086, 1, 1, 1, 3068.94819), -- Blue Wolf Stockings Pattern
(21598, 12205, 1, 1, 1, 371.546186), -- Common Item - Stockings of Doom
(21598, 4087, 1, 1, 1, 3068.94819), -- Stockings of Doom Pattern
(21598, 1870, 1, 1, 2, 104621.868848), -- Coal
(21598, 1865, 1, 1, 2, 104621.868848), -- Varnish
(21598, 1874, 1, 1, 2, 6974.776242), -- Oriharukon Ore
(21598, 4043, 1, 1, 2, 3487.50073), -- Asofe
(21598, 4039, 1, 1, 2, 3487.50073), -- Mold Glue
(21598, 6337, 1, 1, 2, 536.469276), -- Recipe: Sealed Majestic Earring(70%)
(21598, 8730, 1, 1, 2, 1162.575316), -- Life Stone - Level 67
(21598, 8740, 1, 1, 2, 290.53122), -- Mid-Grade Life Stone - Level 67
(21598, 8750, 1, 1, 2, 29.053122), -- High-Grade Life Stone - Level 67
(21598, 8760, 1, 1, 2, 5.855668), -- Top-Grade Life Stone - Level 67
-- Requiem Priest
(21599, 6337, 1, 1, -1, 21949), -- Recipe: Sealed Majestic Earring(70%)
(21599, 5497, 1, 1, -1, 100352), -- Sealed Tallum Boots Lining
(21599, 6339, 1, 1, -1, 32923), -- Recipe: Sealed Majestic Ring(70%)
(21599, 57, 2112, 4305, 0, 700000), -- Adena
(21599, 11951, 1, 1, 1, 217.537348), -- Common Item - Bloody Orchid
(21599, 5536, 1, 1, 1, 2688.462652), -- Bloody Orchid Head
(21599, 1867, 1, 1, 2, 210707.58995), -- Animal Skin
(21599, 1872, 1, 1, 2, 210707.58995), -- Animal Bone
(21599, 1882, 1, 1, 2, 35117.85382), -- Leather
(21599, 1894, 1, 1, 2, 5545.04719), -- Crafted Leather
(21599, 4042, 1, 1, 2, 2634.0492), -- Enria
(21599, 3957, 1, 1, 2, 70.0545), -- Recipe: Blessed Spiritshot S
(21599, 8730, 1, 1, 2, 1756.0328), -- Life Stone - Level 67
(21599, 8740, 1, 1, 2, 439.0082), -- Mid-Grade Life Stone - Level 67
(21599, 8750, 1, 1, 2, 43.90082), -- High-Grade Life Stone - Level 67
(21599, 8760, 1, 1, 2, 8.87357), -- Top-Grade Life Stone - Level 67
-- Requiem Behemoth
(21600, 1884, 1, 5, -1, 714570), -- Cord
(21600, 5509, 1, 1, -1, 81677), -- Sealed Tallum Gloves Design
(21600, 5462, 1, 1, -1, 1290), -- Recipe: Branch of the Mother Tree(60%)
(21600, 57, 1378, 2803, 0, 700000), -- Adena
(21600, 11957, 1, 1, 1, 47.21742), -- Common Item - Tallum Blade
(21600, 5548, 1, 1, 1, 583.55087), -- Tallum Blade Edge
(21600, 11952, 1, 1, 1, 47.21742), -- Common Item - Elemental Sword
(21600, 5547, 1, 1, 1, 583.55087), -- Elemental Sword Edge
(21600, 11954, 1, 1, 1, 47.21742), -- Common Item - Inferno Master
(21600, 8331, 1, 1, 1, 585.246), -- Infernal Master Blade
(21600, 1864, 1, 3, 2, 93543.607194), -- Stem
(21600, 1869, 1, 1, 2, 93543.607194), -- Iron Ore
(21600, 1878, 1, 1, 2, 37417.52691), -- Braided Hemp
(21600, 1884, 1, 1, 2, 57565.135134), -- Cord
(21600, 4039, 1, 1, 2, 3118.022202), -- Mold Glue
(21600, 729, 1, 1, 2, 10.50405), -- Scroll: Enchant Weapon (A-Grade)
(21600, 8730, 1, 1, 2, 1039.480788), -- Life Stone - Level 67
(21600, 8740, 1, 1, 2, 259.660116), -- Mid-Grade Life Stone - Level 67
(21600, 8750, 1, 1, 2, 26.050044), -- High-Grade Life Stone - Level 67
(21600, 8760, 1, 1, 2, 5.041944), -- Top-Grade Life Stone - Level 67
(21600, 1343, 10, 30, 2, 133633.364424), -- Silver Arrow
-- Requiem Behemoth
(21601, 5520, 1, 1, -1, 27079), -- Sealed Dark Crystal Breastplate Pattern
(21601, 5464, 1, 1, -1, 1555), -- Recipe: Dark Legion's Edge(60%)
(21601, 5521, 1, 1, -1, 19108), -- Sealed Tallum Plate Armor Pattern
(21601, 57, 1661, 3379, 0, 700000), -- Adena
(21601, 11946, 1, 1, 1, 42.675578), -- Common Item - Dasparion's Staff
(21601, 5543, 1, 1, 1, 527.687952), -- Dasparion's Staff Head
(21601, 11949, 1, 1, 1, 42.675578), -- Common Item - Meteor Shower
(21601, 5532, 1, 1, 1, 522.759402), -- Meteor Shower Head
(21601, 11953, 1, 1, 1, 42.675578), -- Common Item - Spiritual Eye
(21601, 8341, 1, 1, 1, 522.090932), -- Spiritual Eye Piece
(21601, 11958, 1, 1, 1, 42.675578), -- Common Item - Destroyer Hammer
(21601, 8346, 1, 1, 1, 522.759402), -- Hammer Piece of Destroyer
(21601, 1871, 1, 1, 2, 124041.7755), -- Charcoal
(21601, 1866, 1, 1, 2, 82694.444625), -- Suede
(21601, 1877, 1, 1, 2, 4961.7405), -- Adamantite Nugget
(21601, 4041, 1, 1, 2, 1078.677), -- Mold Hardener
(21601, 4040, 1, 1, 2, 2480.87025), -- Mold Lubricant
(21601, 730, 1, 1, 2, 103.3515), -- Scroll: Enchant Armor (A-Grade)
(21601, 8730, 1, 1, 2, 1378.3095), -- Life Stone - Level 67
(21601, 8740, 1, 1, 2, 344.577375), -- Mid-Grade Life Stone - Level 67
(21601, 8750, 1, 1, 2, 34.522875), -- High-Grade Life Stone - Level 67
(21601, 8760, 1, 1, 2, 6.730875), -- Top-Grade Life Stone - Level 67
-- Zaken's Pikeman
(21602, 5231, 1, 1, -1, 105371), -- Recipe: Metal Hardener (100%)
(21602, 1902, 1, 1, -1, 149462), -- Elven Earring Beads
(21602, 1825, 1, 1, -1, 105371), -- Recipe: Oriharukon
(21602, 57, 583, 1185, 0, 700000), -- Adena
(21602, 1125, 1, 1, 1, 164.178675), -- Assault Boots
(21602, 1957, 1, 1, 1, 6889.959775), -- Assault Boots Part
(21602, 2427, 1, 1, 1, 164.178675), -- Salamander Skin Boots
(21602, 2931, 1, 1, 1, 6889.959775), -- Salamander Skin Boot Lining
(21602, 2428, 1, 1, 1, 164.178675), -- Plate Boots
(21602, 2932, 1, 1, 1, 6889.959775), -- Plate Boots Design
(21602, 61, 1, 1, 1, 164.178675), -- Mithril Plate Gloves
(21602, 1949, 1, 1, 1, 6889.959775), -- Mithril Gloves Design
(21602, 607, 1, 1, 1, 164.178675), -- Ogre Power Gauntlets
(21602, 1963, 1, 1, 1, 6889.959775), -- Ogre Power Gauntlets Part
(21602, 2451, 1, 1, 1, 164.178675), -- Sage's Worn Gloves
(21602, 2933, 1, 1, 1, 6890.129075), -- Sage's Worn Gloves Lining
(21602, 1865, 1, 1, 2, 105824.795083), -- Varnish
(21602, 1870, 1, 1, 2, 105824.795083), -- Coal
(21602, 1879, 1, 1, 2, 17637.425469), -- Cokes
(21602, 1875, 1, 1, 2, 7054.87328), -- Stone of Purity
(21602, 2162, 1, 1, 2, 5112.360438), -- Recipe: Aquastone Necklace
(21602, 5159, 1, 1, 2, 352.743664), -- Recipe: Spiritshot (C) Compressed Package (100%)
(21602, 2312, 1, 1, 2, 462.006983), -- Recipe: Crystallized Ice Bow
-- Zaken's Pikeman
(21603, 5231, 1, 1, -1, 149211), -- Recipe: Metal Hardener (100%)
(21603, 1902, 1, 1, -1, 211647), -- Elven Earring Beads
(21603, 1825, 1, 1, -1, 149211), -- Recipe: Oriharukon
(21603, 57, 826, 1678, 0, 700000), -- Adena
(21603, 1125, 1, 1, 1, 232.483986), -- Assault Boots
(21603, 1957, 1, 1, 1, 9756.476058), -- Assault Boots Part
(21603, 2427, 1, 1, 1, 232.483986), -- Salamander Skin Boots
(21603, 2931, 1, 1, 1, 9756.476058), -- Salamander Skin Boot Lining
(21603, 2428, 1, 1, 1, 232.483986), -- Plate Boots
(21603, 2932, 1, 1, 1, 9756.476058), -- Plate Boots Design
(21603, 61, 1, 1, 1, 232.483986), -- Mithril Plate Gloves
(21603, 1949, 1, 1, 1, 9756.476058), -- Mithril Gloves Design
(21603, 607, 1, 1, 1, 232.483986), -- Ogre Power Gauntlets
(21603, 1963, 1, 1, 1, 9756.476058), -- Ogre Power Gauntlets Part
(21603, 2451, 1, 1, 1, 232.483986), -- Sage's Worn Gloves
(21603, 2933, 1, 1, 1, 9756.715794), -- Sage's Worn Gloves Lining
(21603, 1865, 1, 1, 2, 149853.630262), -- Varnish
(21603, 1870, 1, 1, 2, 149853.630262), -- Coal
(21603, 1879, 1, 1, 2, 24975.547866), -- Cokes
(21603, 1875, 1, 1, 2, 9990.08192), -- Stone of Purity
(21603, 2162, 1, 1, 2, 7239.378732), -- Recipe: Aquastone Necklace
(21603, 5159, 1, 1, 2, 499.504096), -- Recipe: Spiritshot (C) Compressed Package (100%)
(21603, 2312, 1, 1, 2, 654.226862), -- Recipe: Crystallized Ice Bow
-- Zaken's Elite Pikeman
(21604, 4469, 1, 1, -1, 19300), -- Dye of STR (Str+1 Con-1)
(21604, 1905, 1, 1, -1, 328557), -- Omen Beast's Eye Earring Gemstone
(21604, 1805, 1, 1, -1, 11259), -- Recipe: Soulshot (C-Grade)
(21604, 57, 1336, 2712, 0, 700000), -- Adena
(21604, 353, 1, 1, 1, 281.9227), -- Half Plate Armor
(21604, 1950, 1, 1, 1, 13762.5163), -- Half Plate Temper
(21604, 380, 1, 1, 1, 451.0835), -- Plate Gaiters
(21604, 1951, 1, 1, 1, 21404.4775), -- Plate Gaiters Part
(21604, 1867, 1, 3, 2, 226141.22874), -- Animal Skin
(21604, 1872, 1, 3, 2, 150760.664055), -- Animal Bone
(21604, 1882, 1, 1, 2, 75380.564685), -- Leather
(21604, 1894, 1, 1, 2, 11902.292385), -- Crafted Leather
(21604, 1805, 1, 1, 2, 1130.250135), -- Recipe: Soulshot (C-Grade)
-- Zaken's Archer
(21605, 1874, 1, 1, -1, 109271), -- Oriharukon Ore
(21605, 1875, 1, 1, -1, 109271), -- Stone of Purity
(21605, 1905, 1, 1, -1, 159442), -- Omen Beast's Eye Earring Gemstone
(21605, 57, 645, 1322, 0, 700000), -- Adena
(21605, 281, 1, 1, 1, 43.937055), -- Crystallized Ice Bow
(21605, 2074, 1, 1, 1, 2743.062945), -- Crystallized Ice Bow Shaft
(21605, 1872, 1, 1, 2, 93896.55652), -- Animal Bone
(21605, 1867, 1, 1, 2, 93896.55652), -- Animal Skin
(21605, 1881, 1, 1, 2, 9389.655652), -- Coarse Bone Powder
(21605, 1875, 1, 1, 2, 4694.827826), -- Stone of Purity
(21605, 2209, 1, 1, 2, 5294.880108), -- Recipe: Eldarake
(21605, 2205, 1, 1, 2, 2228.491358), -- Recipe: Chain Gaiters
(21605, 2299, 1, 1, 2, 307.598788), -- Recipe: Big Hammer
(21605, 8723, 1, 1, 2, 2816.81137), -- Life Stone - Level 46
(21605, 8733, 1, 1, 2, 704.149514), -- Mid-Grade Life Stone - Level 46
(21605, 8743, 1, 1, 2, 70.39362), -- High-Grade Life Stone - Level 46
(21605, 8753, 1, 1, 2, 14.078724), -- Top-Grade Life Stone - Level 46
-- Zaken's Archer
(21606, 1874, 1, 1, -1, 154734), -- Oriharukon Ore
(21606, 1875, 1, 1, -1, 154734), -- Stone of Purity
(21606, 1905, 1, 1, -1, 225779), -- Omen Beast's Eye Earring Gemstone
(21606, 57, 914, 1872, 0, 700000), -- Adena
(21606, 281, 1, 1, 1, 62.224455), -- Crystallized Ice Bow
(21606, 2074, 1, 1, 1, 3884.775545), -- Crystallized Ice Bow Shaft
(21606, 1872, 1, 1, 2, 132962.53152), -- Animal Bone
(21606, 1867, 1, 1, 2, 132962.53152), -- Animal Skin
(21606, 1881, 1, 1, 2, 13296.253152), -- Coarse Bone Powder
(21606, 1875, 1, 1, 2, 6648.126576), -- Stone of Purity
(21606, 2209, 1, 1, 2, 7497.832608), -- Recipe: Eldarake
(21606, 2205, 1, 1, 2, 3155.662608), -- Recipe: Chain Gaiters
(21606, 2299, 1, 1, 2, 435.576288), -- Recipe: Big Hammer
(21606, 8723, 1, 1, 2, 3988.75512), -- Life Stone - Level 46
(21606, 8733, 1, 1, 2, 997.113264), -- Mid-Grade Life Stone - Level 46
(21606, 8743, 1, 1, 2, 99.68112), -- High-Grade Life Stone - Level 46
(21606, 8753, 1, 1, 2, 19.936224), -- Top-Grade Life Stone - Level 46
-- Zaken's Elite Archer
(21607, 1908, 1, 1, -1, 343437), -- Moonstone Earring Wire
(21607, 2163, 1, 1, -1, 185036), -- Recipe: Earring of Protection
(21607, 1909, 1, 1, -1, 489763), -- Aquastone Ring Wire
(21607, 57, 1428, 2926, 0, 700000), -- Adena
(21607, 354, 1, 1, 1, 220.540424), -- Chain Mail Shirt
(21607, 1959, 1, 1, 1, 11541.781628), -- Chain Mail Shirt Material
(21607, 381, 1, 1, 1, 352.807728), -- Chain Gaiters
(21607, 1960, 1, 1, 1, 23478.87022), -- Chain Gaiters Part
(21607, 1875, 1, 1, 2, 11426.934725), -- Stone of Purity
(21607, 1879, 1, 1, 2, 28567.382425), -- Cokes
(21607, 1885, 1, 1, 2, 14283.736825), -- High-Grade Suede
(21607, 5550, 1, 1, 2, 2285.3687), -- Durable Metal Plate
(21607, 5549, 1, 1, 2, 17140.4477), -- Metallic Thread
(21607, 2163, 1, 1, 2, 8745.102175), -- Recipe: Earring of Protection
(21607, 8723, 1, 1, 2, 6856.197325), -- Life Stone - Level 46
(21607, 8733, 1, 1, 2, 1714.026525), -- Mid-Grade Life Stone - Level 46
(21607, 8743, 1, 1, 2, 171.411775), -- High-Grade Life Stone - Level 46
(21607, 8753, 1, 1, 2, 34.391825), -- Top-Grade Life Stone - Level 46
-- Zaken's Watchman
(21608, 1871, 1, 3, -1, 672407), -- Charcoal
(21608, 1879, 1, 1, -1, 224136), -- Cokes
(21608, 1906, 1, 1, -1, 184854), -- Mithril Ring Wire
(21608, 57, 532, 1080, 0, 700000), -- Adena
(21608, 439, 1, 1, 1, 109.209568), -- Karmian Tunic
(21608, 1962, 1, 1, 1, 5085.111961), -- Karmian Tunic Pattern
(21608, 471, 1, 1, 1, 174.536344), -- Karmian Stockings
(21608, 1954, 1, 1, 1, 8448.142127), -- Karmian Stocking Design
(21608, 1865, 1, 1, 2, 45398.748968), -- Varnish
(21608, 1870, 1, 1, 2, 45398.748968), -- Coal
(21608, 1879, 1, 1, 2, 7566.420949), -- Cokes
(21608, 1875, 1, 1, 2, 3026.590707), -- Stone of Purity
(21608, 4040, 1, 1, 2, 907.943721), -- Mold Lubricant
(21608, 3000, 1, 1, 2, 2910.153316), -- Recipe: Dwarven Chain Shield
(21608, 2303, 1, 1, 2, 198.267312), -- Recipe: Skull Graver
(21608, 2990, 1, 1, 2, 3603.084175), -- Recipe: Chain Boots
(21608, 3033, 1, 1, 2, 151.379772), -- Recipe: Spiritshot C
(21608, 3954, 1, 1, 2, 151.379772), -- Recipe: Blessed Spiritshot C
(21608, 8723, 1, 1, 2, 1815.999079), -- Life Stone - Level 46
(21608, 8733, 1, 1, 2, 454.027679), -- Mid-Grade Life Stone - Level 46
(21608, 8743, 1, 1, 2, 45.436259), -- High-Grade Life Stone - Level 46
(21608, 8753, 1, 1, 2, 8.819323), -- Top-Grade Life Stone - Level 46
-- Zaken's Watchman
(21609, 1871, 1, 5, -1, 634776), -- Charcoal
(21609, 1879, 1, 1, -1, 317388), -- Cokes
(21609, 1906, 1, 1, -1, 261763), -- Mithril Ring Wire
(21609, 57, 753, 1530, 0, 700000), -- Adena
(21609, 439, 1, 1, 1, 154.64176), -- Karmian Tunic
(21609, 1962, 1, 1, 1, 7200.565645), -- Karmian Tunic Pattern
(21609, 471, 1, 1, 1, 247.14508), -- Karmian Stockings
(21609, 1954, 1, 1, 1, 11962.647515), -- Karmian Stocking Design
(21609, 1865, 1, 1, 2, 64286.665112), -- Varnish
(21609, 1870, 1, 1, 2, 64286.665112), -- Coal
(21609, 1879, 1, 1, 2, 10714.391491), -- Cokes
(21609, 1875, 1, 1, 2, 4285.788213), -- Stone of Purity
(21609, 4040, 1, 1, 2, 1285.689039), -- Mold Lubricant
(21609, 3000, 1, 1, 2, 4120.907644), -- Recipe: Dwarven Chain Shield
(21609, 2303, 1, 1, 2, 280.755408), -- Recipe: Skull Graver
(21609, 2990, 1, 1, 2, 5102.128825), -- Recipe: Chain Boots
(21609, 3033, 1, 1, 2, 214.360548), -- Recipe: Spiritshot C
(21609, 3954, 1, 1, 2, 214.360548), -- Recipe: Blessed Spiritshot C
(21609, 8723, 1, 1, 2, 2571.536161), -- Life Stone - Level 46
(21609, 8733, 1, 1, 2, 642.923561), -- Mid-Grade Life Stone - Level 46
(21609, 8743, 1, 1, 2, 64.339781), -- High-Grade Life Stone - Level 46
(21609, 8753, 1, 1, 2, 12.488557), -- Top-Grade Life Stone - Level 46
-- Zaken's High Grade Watchman
(21610, 4043, 1, 1, -1, 115864), -- Asofe
(21610, 1869, 1, 7, -1, 868979), -- Iron Ore
(21610, 2163, 1, 1, -1, 177343), -- Recipe: Earring of Protection
(21610, 57, 1375, 2793, 0, 700000), -- Adena
(21610, 397, 1, 1, 1, 282.259744), -- Mithril Shirt
(21610, 1961, 1, 1, 1, 13142.826463), -- Mithril Shirt Fabric
(21610, 2387, 1, 1, 1, 451.101352), -- Reinforced Mithril Gaiters
(21610, 2935, 1, 1, 1, 21834.812441), -- Reinforced Mithril Gaiters Fragment
(21610, 1869, 1, 1, 2, 164277.135296), -- Iron Ore
(21610, 1864, 1, 3, 2, 164277.135296), -- Stem
(21610, 1880, 1, 1, 2, 16427.67616), -- Steel
(21610, 5550, 1, 1, 2, 2190.232256), -- Durable Metal Plate
(21610, 4043, 1, 1, 2, 5475.767488), -- Asofe
(21610, 2164, 1, 1, 2, 12636.53024), -- Recipe: Ring of Protection
(21610, 8723, 1, 1, 2, 6571.070464), -- Life Stone - Level 46
(21610, 8733, 1, 1, 2, 1642.767616), -- Mid-Grade Life Stone - Level 46
(21610, 8743, 1, 1, 2, 164.42624), -- High-Grade Life Stone - Level 46
(21610, 8753, 1, 1, 2, 33.258944), -- Top-Grade Life Stone - Level 46
-- Unpleasant Humming
(21611, 2320, 1, 1, -1, 5440), -- Recipe: Cursed Staff
(21611, 2066, 1, 1, -1, 12245), -- Heavy Doom Hammer Head
(21611, 1908, 1, 1, -1, 147842), -- Moonstone Earring Wire
(21611, 57, 615, 1258, 0, 700000), -- Adena
(21611, 631, 1, 1, 1, 241.128), -- Eldarake
(21611, 1964, 1, 1, 1, 9936.86715), -- Eldarake Temper
(21611, 2495, 1, 1, 1, 241.128), -- Chain Shield
(21611, 2945, 1, 1, 1, 9936.86715), -- Chain Shield Fragment
(21611, 2413, 1, 1, 1, 168.7896), -- Chain Hood
(21611, 2936, 1, 1, 1, 9025.2201), -- Chain Hood Pattern
(21611, 1867, 1, 1, 2, 81983.522937), -- Animal Skin
(21611, 1872, 1, 1, 2, 81983.522937), -- Animal Bone
(21611, 1882, 1, 1, 2, 13663.885935), -- Leather
(21611, 1894, 1, 1, 2, 2157.444762), -- Crafted Leather
(21611, 4042, 1, 1, 2, 1024.817361), -- Enria
(21611, 2230, 1, 1, 2, 1191.715596), -- Recipe: Theca Leather Gaiters
(21611, 2326, 1, 1, 2, 214.168791), -- Recipe: Horn of Glory
(21611, 6668, 1, 1, 2, 21959.868513), -- Deluxe Chest Key - Grade 4
(21611, 8723, 1, 1, 2, 2459.520201), -- Life Stone - Level 46
(21611, 8733, 1, 1, 2, 614.931882), -- Mid-Grade Life Stone - Level 46
(21611, 8743, 1, 1, 2, 61.576119), -- High-Grade Life Stone - Level 46
(21611, 8753, 1, 1, 2, 12.024966), -- Top-Grade Life Stone - Level 46
-- Unpleasant Humming
(21612, 2320, 1, 1, -1, 7703), -- Recipe: Cursed Staff
(21612, 2066, 1, 1, -1, 17339), -- Heavy Doom Hammer Head
(21612, 1908, 1, 1, -1, 209352), -- Moonstone Earring Wire
(21612, 57, 871, 1781, 0, 700000), -- Adena
(21612, 631, 1, 1, 1, 341.44704), -- Eldarake
(21612, 1964, 1, 1, 1, 14071.007412), -- Eldarake Temper
(21612, 2495, 1, 1, 1, 341.44704), -- Chain Shield
(21612, 2945, 1, 1, 1, 14071.007412), -- Chain Shield Fragment
(21612, 2413, 1, 1, 1, 239.012928), -- Chain Hood
(21612, 2936, 1, 1, 1, 12780.078168), -- Chain Hood Pattern
(21612, 1867, 1, 1, 2, 116093.005566), -- Animal Skin
(21612, 1872, 1, 1, 2, 116093.005566), -- Animal Bone
(21612, 1882, 1, 1, 2, 19348.78533), -- Leather
(21612, 1894, 1, 1, 2, 3055.055916), -- Crafted Leather
(21612, 4042, 1, 1, 2, 1451.195598), -- Enria
(21612, 2230, 1, 1, 2, 1687.532328), -- Recipe: Theca Leather Gaiters
(21612, 2326, 1, 1, 2, 303.274338), -- Recipe: Horn of Glory
(21612, 6668, 1, 1, 2, 31096.335534), -- Deluxe Chest Key - Grade 4
(21612, 8723, 1, 1, 2, 3482.810718), -- Life Stone - Level 46
(21612, 8733, 1, 1, 2, 870.776076), -- Mid-Grade Life Stone - Level 46
(21612, 8743, 1, 1, 2, 87.195042), -- High-Grade Life Stone - Level 46
(21612, 8753, 1, 1, 2, 17.027988), -- Top-Grade Life Stone - Level 46
-- Unpleasant Shout
(21613, 2219, 1, 1, -1, 234342), -- Recipe: Crimson Boots
(21613, 2062, 1, 1, -1, 29591), -- Scythe Edge
(21613, 1864, 1, 15, -1, 943225), -- Stem
(21613, 57, 1486, 3039, 0, 700000), -- Adena
(21613, 226, 1, 1, 1, 50.575783), -- Cursed Dagger
(21613, 2070, 1, 1, 1, 3539.924217), -- Cursed Dagger Blade
(21613, 232, 1, 1, 1, 50.575783), -- Dark Elven Dagger
(21613, 2072, 1, 1, 1, 3539.924217), -- Dark Elven Dagger Edge
(21613, 1869, 1, 1, 2, 178313.227248), -- Iron Ore
(21613, 1864, 1, 3, 2, 178313.227248), -- Stem
(21613, 1880, 1, 1, 2, 17831.491376), -- Steel
(21613, 5550, 1, 1, 2, 2377.560292), -- Durable Metal Plate
(21613, 4043, 1, 1, 2, 5943.689916), -- Asofe
(21613, 2251, 1, 1, 2, 29718.871208), -- Recipe: Steel Arrow
(21613, 8723, 1, 1, 2, 7132.680876), -- Life Stone - Level 46
(21613, 8733, 1, 1, 2, 1783.064812), -- Mid-Grade Life Stone - Level 46
(21613, 8743, 1, 1, 2, 178.348644), -- High-Grade Life Stone - Level 46
(21613, 8753, 1, 1, 2, 35.83838), -- Top-Grade Life Stone - Level 46
-- Death Flyer
(21614, 2328, 1, 1, -1, 3746), -- Recipe: Sword of Delusion
(21614, 1967, 1, 1, -1, 87860), -- Plated Leather Gaiters Material
(21614, 2166, 1, 1, -1, 54607), -- Recipe: Earrings of Binding (100%)
(21614, 57, 636, 1297, 0, 700000), -- Adena
(21614, 227, 1, 1, 1, 16.152476), -- Stiletto
(21614, 2083, 1, 1, 1, 1185.847524), -- Stiletto Edge
(21614, 242, 1, 1, 1, 16.152476), -- Soulfire Dirk
(21614, 2084, 1, 1, 1, 1185.847524), -- Soulfire Dirk Blade
(21614, 1868, 1, 1, 2, 129774.441057), -- Thread
(21614, 1873, 1, 1, 2, 25954.853586), -- Silver Nugget
(21614, 5549, 1, 1, 2, 6488.79996), -- Metallic Thread
(21614, 1889, 1, 1, 2, 4325.751222), -- Compound Braid
(21614, 4044, 1, 1, 2, 2162.875611), -- Thons
(21614, 2229, 1, 1, 2, 786.515961), -- Recipe: Theca Leather Armor
(21614, 952, 1, 1, 2, 865.115619), -- Scroll: Enchant Armor (C-Grade)
(21614, 8724, 1, 1, 2, 2162.875611), -- Life Stone - Level 49
(21614, 8734, 1, 1, 2, 540.675621), -- Mid-Grade Life Stone - Level 49
(21614, 8744, 1, 1, 2, 54.015624), -- High-Grade Life Stone - Level 49
(21614, 8754, 1, 1, 2, 11.080128), -- Top-Grade Life Stone - Level 49
-- Death Flyer
(21615, 2328, 1, 1, -1, 5305), -- Recipe: Sword of Delusion
(21615, 1967, 1, 1, -1, 124414), -- Plated Leather Gaiters Material
(21615, 2166, 1, 1, -1, 77327), -- Recipe: Earrings of Binding (100%)
(21615, 57, 900, 1837, 0, 700000), -- Adena
(21615, 227, 1, 1, 1, 22.871476), -- Stiletto
(21615, 2083, 1, 1, 1, 1679.128524), -- Stiletto Edge
(21615, 242, 1, 1, 1, 22.871476), -- Soulfire Dirk
(21615, 2084, 1, 1, 1, 1679.128524), -- Soulfire Dirk Blade
(21615, 1868, 1, 1, 2, 183766.731196), -- Thread
(21615, 1873, 1, 1, 2, 36753.297208), -- Silver Nugget
(21615, 5549, 1, 1, 2, 9188.44688), -- Metallic Thread
(21615, 1889, 1, 1, 2, 6125.467816), -- Compound Braid
(21615, 4044, 1, 1, 2, 3062.733908), -- Thons
(21615, 2229, 1, 1, 2, 1113.743708), -- Recipe: Theca Leather Armor
(21615, 952, 1, 1, 2, 1225.044532), -- Scroll: Enchant Armor (C-Grade)
(21615, 8724, 1, 1, 2, 3062.733908), -- Life Stone - Level 49
(21615, 8734, 1, 1, 2, 765.622188), -- Mid-Grade Life Stone - Level 49
(21615, 8744, 1, 1, 2, 76.488672), -- High-Grade Life Stone - Level 49
(21615, 8754, 1, 1, 2, 15.689984), -- Top-Grade Life Stone - Level 49
-- Gigantic Flyer
(21616, 1873, 1, 3, -1, 832740), -- Silver Nugget
(21616, 1911, 1, 1, -1, 309684), -- Earring of Protection Gemstone
(21616, 1966, 1, 1, -1, 152015), -- Plated Leather Fragment
(21616, 57, 1643, 3353, 0, 700000), -- Adena
(21616, 2496, 1, 1, 1, 512.025192), -- Dwarven Chain Shield
(21616, 2947, 1, 1, 1, 21961.458792), -- Dwarven Chain Shield Fragment
(21616, 632, 1, 1, 1, 472.674552), -- Knight's Shield
(21616, 1972, 1, 1, 1, 24596.81784), -- Knight's Shield Fragment
(21616, 500, 1, 1, 1, 330.945552), -- Great Helmet
(21616, 1971, 1, 1, 1, 18822.078072), -- Great Helmet Material
(21616, 1873, 1, 1, 2, 73793.528028), -- Silver Nugget
(21616, 1868, 1, 3, 2, 184484.179236), -- Thread
(21616, 1876, 1, 1, 2, 36896.764014), -- Mithril Ore
(21616, 1895, 1, 1, 2, 52709.765496), -- Metallic Fiber
(21616, 4042, 1, 1, 2, 3074.820126), -- Enria
(21616, 951, 1, 1, 2, 335.461044), -- Scroll: Enchant Weapon (C-Grade)
(21616, 8724, 1, 1, 2, 6149.640252), -- Life Stone - Level 49
(21616, 8734, 1, 1, 2, 1537.23048), -- Mid-Grade Life Stone - Level 49
(21616, 8744, 1, 1, 2, 153.723048), -- High-Grade Life Stone - Level 49
(21616, 8754, 1, 1, 2, 30.888276), -- Top-Grade Life Stone - Level 49
-- Fiend Archer
(21617, 4438, 1, 1, -1, 11695), -- Knuckle Duster Edge
(21617, 951, 1, 1, -1, 2982), -- Scroll: Enchant Weapon (C-Grade)
(21617, 1911, 1, 1, -1, 121965), -- Earring of Protection Gemstone
(21617, 57, 648, 1318, 0, 700000), -- Adena
(21617, 282, 1, 1, 1, 16.439522), -- Elemental Bow
(21617, 2085, 1, 1, 1, 1256.560478), -- Crossbow Shaft
(21617, 285, 1, 1, 1, 16.439522), -- Noble Elven Bow
(21617, 2086, 1, 1, 1, 1256.560478), -- Noble Elven Bow Shaft
(21617, 1869, 1, 1, 2, 60547.2658), -- Iron Ore
(21617, 1864, 1, 1, 2, 121094.33742), -- Stem
(21617, 1880, 1, 1, 2, 6054.72658), -- Steel
(21617, 5550, 1, 1, 2, 807.20626), -- Durable Metal Plate
(21617, 4043, 1, 1, 2, 2018.30692), -- Asofe
(21617, 2348, 1, 1, 2, 140.7805), -- Recipe: Heathen's Book
(21617, 2351, 1, 1, 2, 126.60536), -- Recipe: Scorpion
(21617, 952, 1, 1, 2, 807.20626), -- Scroll: Enchant Armor (C-Grade)
(21617, 8724, 1, 1, 2, 2018.30692), -- Life Stone - Level 49
(21617, 8734, 1, 1, 2, 504.47964), -- Mid-Grade Life Stone - Level 49
(21617, 8744, 1, 1, 2, 50.4868), -- High-Grade Life Stone - Level 49
(21617, 8754, 1, 1, 2, 10.29154), -- Top-Grade Life Stone - Level 49
-- Fiend Archer
(21618, 4438, 1, 1, -1, 16560), -- Knuckle Duster Edge
(21618, 951, 1, 1, -1, 4222), -- Scroll: Enchant Weapon (C-Grade)
(21618, 1911, 1, 1, -1, 172710), -- Earring of Protection Gemstone
(21618, 57, 918, 1867, 0, 700000), -- Adena
(21618, 282, 1, 1, 1, 23.277485), -- Elemental Bow
(21618, 2085, 1, 1, 1, 1779.222515), -- Crossbow Shaft
(21618, 285, 1, 1, 1, 23.277485), -- Noble Elven Bow
(21618, 2086, 1, 1, 1, 1779.222515), -- Noble Elven Bow Shaft
(21618, 1869, 1, 1, 2, 85738.3957), -- Iron Ore
(21618, 1864, 1, 1, 2, 171476.51643), -- Stem
(21618, 1880, 1, 1, 2, 8573.83957), -- Steel
(21618, 5550, 1, 1, 2, 1143.05029), -- Durable Metal Plate
(21618, 4043, 1, 1, 2, 2858.03818), -- Asofe
(21618, 2348, 1, 1, 2, 199.35325), -- Recipe: Heathen's Book
(21618, 2351, 1, 1, 2, 179.28044), -- Recipe: Scorpion
(21618, 952, 1, 1, 2, 1143.05029), -- Scroll: Enchant Armor (C-Grade)
(21618, 8724, 1, 1, 2, 2858.03818), -- Life Stone - Level 49
(21618, 8734, 1, 1, 2, 714.37206), -- Mid-Grade Life Stone - Level 49
(21618, 8744, 1, 1, 2, 71.4922), -- High-Grade Life Stone - Level 49
(21618, 8754, 1, 1, 2, 14.57341), -- Top-Grade Life Stone - Level 49
-- Pit Archer
(21619, 2166, 1, 1, -1, 143676), -- Recipe: Earrings of Binding (100%)
(21619, 1912, 1, 1, -1, 456727), -- Ring of Protection Gemstone
(21619, 2167, 1, 1, -1, 216246), -- Recipe: Ring of Ages
(21619, 57, 1676, 3407, 0, 700000), -- Adena
(21619, 282, 1, 1, 1, 42.493517), -- Elemental Bow
(21619, 2085, 1, 1, 1, 3248.006483), -- Crossbow Shaft
(21619, 285, 1, 1, 1, 42.493517), -- Noble Elven Bow
(21619, 2086, 1, 1, 1, 3248.006483), -- Noble Elven Bow Shaft
(21619, 1869, 2, 6, 2, 46948.722525), -- Iron Ore
(21619, 1870, 2, 6, 2, 37558.97802), -- Coal
(21619, 1871, 1, 1, 2, 187795.381581), -- Charcoal
(21619, 1872, 1, 3, 2, 125196.921054), -- Animal Bone
(21619, 1867, 1, 3, 2, 83464.777863), -- Animal Skin
(21619, 952, 1, 1, 2, 2504.095695), -- Scroll: Enchant Armor (C-Grade)
(21619, 8724, 1, 1, 2, 6259.993497), -- Life Stone - Level 49
(21619, 8734, 1, 1, 2, 1564.875504), -- Mid-Grade Life Stone - Level 49
(21619, 8744, 1, 1, 2, 156.290958), -- High-Grade Life Stone - Level 49
(21619, 8754, 1, 1, 2, 30.963303), -- Top-Grade Life Stone - Level 49
-- Musveren
(21620, 2335, 1, 1, -1, 3676), -- Recipe: War Axe
(21620, 1976, 1, 1, -1, 96108), -- Rind Leather Gaiters Material
(21620, 2167, 1, 1, -1, 80638), -- Recipe: Ring of Ages
(21620, 57, 624, 1272, 0, 700000), -- Adena
(21620, 853, 1, 1, 1, 155.099014), -- Earring of Protection
(21620, 1911, 1, 1, 1, 8681.3888), -- Earring of Protection Gemstone
(21620, 916, 1, 1, 1, 116.367552), -- Necklace of Protection
(21620, 1913, 1, 1, 1, 7097.670286), -- Necklace of Protection Gemstone
(21620, 884, 1, 1, 1, 232.735104), -- Ring of Protection
(21620, 1912, 1, 1, 1, 12577.739244), -- Ring of Protection Gemstone
(21620, 1870, 1, 1, 2, 70028.1594), -- Coal
(21620, 1865, 1, 1, 2, 70028.1594), -- Varnish
(21620, 1874, 1, 1, 2, 4668.595065), -- Oriharukon Ore
(21620, 4043, 1, 1, 2, 2334.220875), -- Asofe
(21620, 4039, 1, 1, 2, 2334.220875), -- Mold Glue
(21620, 952, 1, 1, 2, 933.68835), -- Scroll: Enchant Armor (C-Grade)
(21620, 8724, 1, 1, 2, 2334.220875), -- Life Stone - Level 49
(21620, 8734, 1, 1, 2, 583.51689), -- Mid-Grade Life Stone - Level 49
(21620, 8744, 1, 1, 2, 58.413015), -- High-Grade Life Stone - Level 49
(21620, 8754, 1, 1, 2, 11.805255), -- Top-Grade Life Stone - Level 49
-- Musveren
(21621, 2335, 1, 1, -1, 5205), -- Recipe: War Axe
(21621, 1976, 1, 1, -1, 136094), -- Rind Leather Gaiters Material
(21621, 2167, 1, 1, -1, 114187), -- Recipe: Ring of Ages
(21621, 57, 883, 1802, 0, 700000), -- Adena
(21621, 853, 1, 1, 1, 219.630006), -- Earring of Protection
(21621, 1911, 1, 1, 1, 12293.3952), -- Earring of Protection Gemstone
(21621, 916, 1, 1, 1, 164.783808), -- Necklace of Protection
(21621, 1913, 1, 1, 1, 10050.749694), -- Necklace of Protection Gemstone
(21621, 884, 1, 1, 1, 329.567616), -- Ring of Protection
(21621, 1912, 1, 1, 1, 17810.873676), -- Ring of Protection Gemstone
(21621, 1870, 1, 1, 2, 99163.96628), -- Coal
(21621, 1865, 1, 1, 2, 99163.96628), -- Varnish
(21621, 1874, 1, 1, 2, 6611.003453); -- Oriharukon Ore

INSERT INTO `droplist` VALUES
(21621, 4043, 1, 1, 2, 3305.393175), -- Asofe
(21621, 4039, 1, 1, 2, 3305.393175), -- Mold Glue
(21621, 952, 1, 1, 2, 1322.15727), -- Scroll: Enchant Armor (C-Grade)
(21621, 8724, 1, 1, 2, 3305.393175), -- Life Stone - Level 49
(21621, 8734, 1, 1, 2, 826.294018), -- Mid-Grade Life Stone - Level 49
(21621, 8744, 1, 1, 2, 82.716243), -- High-Grade Life Stone - Level 49
(21621, 8754, 1, 1, 2, 16.716931), -- Top-Grade Life Stone - Level 49
-- Greater Musveren
(21622, 1913, 1, 1, -1, 248409), -- Necklace of Protection Gemstone
(21622, 951, 1, 1, -1, 7427), -- Scroll: Enchant Weapon (C-Grade)
(21622, 1865, 1, 9, -1, 817018), -- Varnish
(21622, 57, 1612, 3288, 0, 700000), -- Adena
(21622, 853, 1, 1, 1, 400.889652), -- Earring of Protection
(21622, 1911, 1, 1, 1, 22439.0784), -- Earring of Protection Gemstone
(21622, 916, 1, 1, 1, 300.779136), -- Necklace of Protection
(21622, 1913, 1, 1, 1, 18345.587748), -- Necklace of Protection Gemstone
(21622, 884, 1, 1, 1, 601.558272), -- Ring of Protection
(21622, 1912, 1, 1, 1, 32510.106792), -- Ring of Protection Gemstone
(21622, 1864, 5, 15, 2, 32909.279491), -- Stem
(21622, 1865, 3, 9, 2, 27424.326173), -- Varnish
(21622, 1866, 1, 1, 2, 109696.864275), -- Suede
(21622, 1873, 1, 1, 2, 65818.118565), -- Silver Nugget
(21622, 1868, 1, 3, 2, 109696.864275), -- Thread
(21622, 2166, 1, 1, 2, 5577.881305), -- Recipe: Earrings of Binding (100%)
(21622, 8724, 1, 1, 2, 5484.953318), -- Life Stone - Level 49
(21622, 8734, 1, 1, 2, 1371.018121), -- Mid-Grade Life Stone - Level 49
(21622, 8744, 1, 1, 2, 136.969687), -- High-Grade Life Stone - Level 49
(21622, 8754, 1, 1, 2, 27.305854), -- Top-Grade Life Stone - Level 49
(21622, 1342, 40, 120, 2, 82273.418936), -- Steel Arrow
-- Zaken's Guard
(21623, 4601, 1, 1, -1, 4445), -- Greater Dye of STR (Str+3 Con-3)
(21623, 1539, 1, 1, -1, 444475), -- Greater Healing Potion
(21623, 1914, 1, 1, -1, 112367), -- Earring of Seal Gemstone
(21623, 57, 791, 1608, 0, 700000), -- Adena
(21623, 283, 1, 1, 1, 25.03392), -- Akat Long Bow
(21623, 2109, 1, 1, 1, 2318.96608), -- Akat Longbow Shaft
(21623, 1871, 1, 1, 2, 68928.022516), -- Charcoal
(21623, 1866, 1, 1, 2, 45951.932222), -- Suede
(21623, 1877, 1, 1, 2, 2757.110966), -- Adamantite Nugget
(21623, 4041, 1, 1, 2, 599.431341), -- Mold Hardener
(21623, 4040, 1, 1, 2, 1378.555483), -- Mold Lubricant
(21623, 2357, 1, 1, 2, 112.385615), -- Recipe: Crystal Dagger
(21623, 3014, 1, 1, 2, 1925.333232), -- Recipe: Full Plate Boots
(21623, 4188, 1, 1, 2, 79.352937), -- Recipe: Hell Knife (100%)
(21623, 8725, 1, 1, 2, 1914.653494), -- Life Stone - Level 52
(21623, 8735, 1, 1, 2, 478.725465), -- Mid-Grade Life Stone - Level 52
(21623, 8745, 1, 1, 2, 47.810455), -- High-Grade Life Stone - Level 52
(21623, 8755, 1, 1, 2, 9.686274), -- Top-Grade Life Stone - Level 52
-- Zaken's Guard
(21624, 4601, 1, 1, -1, 6294), -- Greater Dye of STR (Str+3 Con-3)
(21624, 1539, 1, 1, -1, 629400), -- Greater Healing Potion
(21624, 1914, 1, 1, -1, 159118), -- Earring of Seal Gemstone
(21624, 57, 1120, 2277, 0, 700000), -- Adena
(21624, 283, 1, 1, 1, 35.44692), -- Akat Long Bow
(21624, 2109, 1, 1, 1, 3283.55308), -- Akat Longbow Shaft
(21624, 1871, 1, 1, 2, 97605.339148), -- Charcoal
(21624, 1866, 1, 1, 2, 65070.108866), -- Suede
(21624, 1877, 1, 1, 2, 3904.199498), -- Adamantite Nugget
(21624, 4041, 1, 1, 2, 848.823123), -- Mold Hardener
(21624, 4040, 1, 1, 2, 1952.099749), -- Mold Lubricant
(21624, 2357, 1, 1, 2, 159.143345), -- Recipe: Crystal Dagger
(21624, 3014, 1, 1, 2, 2726.362896), -- Recipe: Full Plate Boots
(21624, 4188, 1, 1, 2, 112.367511), -- Recipe: Hell Knife (100%)
(21624, 8725, 1, 1, 2, 2711.239882), -- Life Stone - Level 52
(21624, 8735, 1, 1, 2, 677.897895), -- Mid-Grade Life Stone - Level 52
(21624, 8745, 1, 1, 2, 67.701865), -- High-Grade Life Stone - Level 52
(21624, 8755, 1, 1, 2, 13.716222), -- Top-Grade Life Stone - Level 52
-- Kaim Vanul
(21626, 4603, 1, 1, -1, 3968), -- Greater Dye of CON (Con+3 Str-3)
(21626, 1539, 1, 1, -1, 396845), -- Greater Healing Potion
(21626, 4041, 1, 1, -1, 15529), -- Mold Hardener
(21626, 57, 707, 1437, 0, 700000), -- Adena
(21626, 854, 1, 1, 1, 108.633591), -- Earring of Seal
(21626, 1914, 1, 1, 1, 6913.98058), -- Earring of Seal Gemstone
(21626, 917, 1, 1, 1, 81.48103), -- Necklace of Mermaid
(21626, 1916, 1, 1, 1, 5236.96557), -- Necklace of Mermaid Teardrop
(21626, 885, 1, 1, 1, 162.892019), -- Ring of Ages
(21626, 1915, 1, 1, 1, 10843.04721), -- Ring of Ages Gemstone
(21626, 1872, 1, 1, 2, 82055.327472), -- Animal Bone
(21626, 1867, 1, 1, 2, 82055.327472), -- Animal Skin
(21626, 1881, 1, 1, 2, 8205.496844), -- Coarse Bone Powder
(21626, 1875, 1, 1, 2, 4102.83818), -- Stone of Purity
(21626, 4041, 1, 1, 2, 535.137196), -- Mold Hardener
(21626, 4601, 1, 1, 2, 136.791192), -- Greater Dye of STR (Str+3 Con-3)
(21626, 4609, 1, 1, 2, 136.791192), -- Greater Dye of MEN (Men+3 Int-3)
(21626, 2355, 1, 1, 2, 100.349444), -- Recipe: Ghoul's Staff
(21626, 8725, 1, 1, 2, 1709.530868), -- Life Stone - Level 52
(21626, 8735, 1, 1, 2, 427.427596), -- Mid-Grade Life Stone - Level 52
(21626, 8745, 1, 1, 2, 42.724808), -- High-Grade Life Stone - Level 52
(21626, 8755, 1, 1, 2, 8.257736), -- Top-Grade Life Stone - Level 52
-- Kaim Vanul
(21627, 4603, 1, 1, -1, 5620), -- Greater Dye of CON (Con+3 Str-3)
(21627, 1539, 1, 1, -1, 561953), -- Greater Healing Potion
(21627, 4041, 1, 1, -1, 21989), -- Mold Hardener
(21627, 57, 1001, 2034, 0, 700000), -- Adena
(21627, 854, 1, 1, 1, 153.832833), -- Earring of Seal
(21627, 1914, 1, 1, 1, 9790.68454), -- Earring of Seal Gemstone
(21627, 917, 1, 1, 1, 115.38289), -- Necklace of Mermaid
(21627, 1916, 1, 1, 1, 7415.91291), -- Necklace of Mermaid Teardrop
(21627, 885, 1, 1, 1, 230.666597), -- Ring of Ages
(21627, 1915, 1, 1, 1, 15354.52023), -- Ring of Ages Gemstone
(21627, 1872, 1, 1, 2, 116194.614768), -- Animal Bone
(21627, 1867, 1, 1, 2, 116194.614768), -- Animal Skin
(21627, 1881, 1, 1, 2, 11619.410636), -- Coarse Bone Powder
(21627, 1875, 1, 1, 2, 5809.83242), -- Stone of Purity
(21627, 4041, 1, 1, 2, 757.782124), -- Mold Hardener
(21627, 4601, 1, 1, 2, 193.703448), -- Greater Dye of STR (Str+3 Con-3)
(21627, 4609, 1, 1, 2, 193.703448), -- Greater Dye of MEN (Men+3 Int-3)
(21627, 2355, 1, 1, 2, 142.100036), -- Recipe: Ghoul's Staff
(21627, 8725, 1, 1, 2, 2420.784692), -- Life Stone - Level 52
(21627, 8735, 1, 1, 2, 605.259724), -- Mid-Grade Life Stone - Level 52
(21627, 8745, 1, 1, 2, 60.500552), -- High-Grade Life Stone - Level 52
(21627, 8755, 1, 1, 2, 11.693384), -- Top-Grade Life Stone - Level 52
-- Kaim Vanul Lad
(21628, 1874, 1, 1, -1, 307715), -- Oriharukon Ore
(21628, 4604, 1, 1, -1, 10257), -- Greater Dye of CON (Con+3 Dex-3)
(21628, 1539, 1, 3, -1, 512859), -- Greater Healing Potion
(21628, 57, 1828, 3713, 0, 700000), -- Adena
(21628, 162, 1, 1, 1, 7.220367), -- War Axe
(21628, 2097, 1, 1, 1, 638.983884), -- War Axe Blade
(21628, 174, 1, 1, 1, 7.220367), -- Nirvana Axe
(21628, 2098, 1, 1, 1, 638.983884), -- Nirvana Axe Blade
(21628, 196, 1, 1, 1, 7.220367), -- Stick of Eternity
(21628, 2099, 1, 1, 1, 672.482349), -- Stick of Eternity Shaft
(21628, 197, 1, 1, 1, 7.220367), -- Paradia Staff
(21628, 2100, 1, 1, 1, 672.482349), -- Paradia Staff Head
(21628, 199, 1, 1, 1, 7.220367), -- Pa'agrian Hammer
(21628, 2102, 1, 1, 1, 648.361329), -- Pa'agrian Hammer Head
(21628, 200, 1, 1, 1, 7.220367), -- Sage's Staff
(21628, 2103, 1, 1, 1, 672.482349), -- Sage's Staff Head
(21628, 201, 1, 1, 1, 7.220367), -- Club of Nature
(21628, 2104, 1, 1, 1, 672.482349), -- Club of Nature Head
(21628, 202, 1, 1, 1, 7.220367), -- Mace of Underworld
(21628, 2105, 1, 1, 1, 638.978571), -- Mace of Underworld Head
(21628, 1874, 1, 1, 2, 11568.38119), -- Oriharukon Ore
(21628, 1878, 1, 1, 2, 69410.71907), -- Braided Hemp
(21628, 1884, 1, 1, 2, 106785.837935), -- Cord
(21628, 1889, 1, 1, 2, 11568.38119), -- Compound Braid
(21628, 5220, 1, 1, 2, 6941.1151), -- Metal Hardener
(21628, 2356, 1, 1, 2, 283.130115), -- Recipe: Demon's Staff
(21628, 3012, 1, 1, 2, 3237.531315), -- Recipe: Full Plate Helmet
(21628, 8725, 1, 1, 2, 4820.122835), -- Life Stone - Level 52
(21628, 8735, 1, 1, 2, 1205.0847), -- Mid-Grade Life Stone - Level 52
(21628, 8745, 1, 1, 2, 120.50847), -- High-Grade Life Stone - Level 52
(21628, 8755, 1, 1, 2, 24.18808), -- Top-Grade Life Stone - Level 52
-- Pirate Zombie Captain
(21629, 2100, 1, 1, -1, 13718), -- Paradia Staff Head
(21629, 2354, 1, 1, -1, 3970), -- Recipe: Deadman's Staff
(21629, 4042, 1, 1, -1, 40560), -- Enria
(21629, 57, 967, 1954, 0, 700000), -- Adena
(21629, 75, 1, 1, 1, 5.075532), -- Caliburs
(21629, 2089, 1, 1, 1, 456.925392), -- Caliburs Edge
(21629, 76, 1, 1, 1, 5.075532), -- Sword of Delusion
(21629, 2090, 1, 1, 1, 456.925392), -- Delusional Blade
(21629, 77, 1, 1, 1, 5.075532), -- Tsurugi
(21629, 2091, 1, 1, 1, 456.925392), -- Tsurugi Blade
(21629, 84, 1, 1, 1, 5.075532), -- Homunkulus's Sword
(21629, 2092, 1, 1, 1, 456.925392), -- Homunkulus's Sword Blade
(21629, 134, 1, 1, 1, 5.075532), -- Sword of Nightmare
(21629, 2095, 1, 1, 1, 456.925392), -- Sword of Nightmare Blade
(21629, 145, 1, 1, 1, 5.075532), -- Sword of Whispering Death
(21629, 2096, 1, 1, 1, 456.919848), -- Sword of Whispering Death Blade
(21629, 1873, 1, 1, 2, 28754.269544), -- Silver Nugget
(21629, 1868, 1, 1, 2, 143770.883256), -- Thread
(21629, 1876, 1, 1, 2, 14377.018656), -- Mithril Ore
(21629, 1895, 1, 1, 2, 20538.59808), -- Metallic Fiber
(21629, 4042, 1, 1, 2, 1198.084888), -- Enria
(21629, 4608, 1, 1, 2, 159.775616), -- Greater Dye of INT (Int+3 Wit-3)
(21629, 3017, 1, 1, 2, 2007.877872), -- Recipe: Divine Gloves
(21629, 5155, 1, 1, 2, 143.751608), -- Recipe: Soulshot (B) Compressed Package (100%)
(21629, 6669, 1, 1, 2, 16717.452752), -- Deluxe Chest Key - Grade 5
(21629, 8725, 1, 1, 2, 1996.730736), -- Life Stone - Level 52
(21629, 8735, 1, 1, 2, 499.2988), -- Mid-Grade Life Stone - Level 52
(21629, 8745, 1, 1, 2, 49.92988), -- High-Grade Life Stone - Level 52
(21629, 8755, 1, 1, 2, 10.45044), -- Top-Grade Life Stone - Level 52
-- Pirate Zombie Captain
(21630, 2100, 1, 1, -1, 19426), -- Paradia Staff Head
(21630, 2354, 1, 1, -1, 5622), -- Recipe: Deadman's Staff
(21630, 4042, 1, 1, -1, 57436), -- Enria
(21630, 57, 1369, 2766, 0, 700000), -- Adena
(21630, 75, 1, 1, 1, 7.188506), -- Caliburs
(21630, 2089, 1, 1, 1, 647.146136), -- Caliburs Edge
(21630, 76, 1, 1, 1, 7.188506), -- Sword of Delusion
(21630, 2090, 1, 1, 1, 647.146136), -- Delusional Blade
(21630, 77, 1, 1, 1, 7.188506), -- Tsurugi
(21630, 2091, 1, 1, 1, 647.146136), -- Tsurugi Blade
(21630, 84, 1, 1, 1, 7.188506), -- Homunkulus's Sword
(21630, 2092, 1, 1, 1, 647.146136), -- Homunkulus's Sword Blade
(21630, 134, 1, 1, 1, 7.188506), -- Sword of Nightmare
(21630, 2095, 1, 1, 1, 647.146136), -- Sword of Nightmare Blade
(21630, 145, 1, 1, 1, 7.188506), -- Sword of Whispering Death
(21630, 2096, 1, 1, 1, 647.138284), -- Sword of Whispering Death Blade
(21630, 1873, 1, 1, 2, 40717.591901), -- Silver Nugget
(21630, 1868, 1, 1, 2, 203587.301799), -- Thread
(21630, 1876, 1, 1, 2, 20358.631524), -- Mithril Ore
(21630, 1895, 1, 1, 2, 29083.75932), -- Metallic Fiber
(21630, 4042, 1, 1, 2, 1696.552627), -- Enria
(21630, 4608, 1, 1, 2, 226.250864), -- Greater Dye of INT (Int+3 Wit-3)
(21630, 3017, 1, 1, 2, 2843.263038), -- Recipe: Divine Gloves
(21630, 5155, 1, 1, 2, 203.560007), -- Recipe: Soulshot (B) Compressed Package (100%)
(21630, 6669, 1, 1, 2, 23672.812058), -- Deluxe Chest Key - Grade 5
(21630, 8725, 1, 1, 2, 2827.478094), -- Life Stone - Level 52
(21630, 8735, 1, 1, 2, 707.03395), -- Mid-Grade Life Stone - Level 52
(21630, 8745, 1, 1, 2, 70.703395), -- High-Grade Life Stone - Level 52
(21630, 8755, 1, 1, 2, 14.798385), -- Top-Grade Life Stone - Level 52
-- Zombie Captain's Spiritual Body
(21631, 2091, 1, 1, -1, 30793), -- Tsurugi Blade
(21631, 2353, 1, 1, -1, 9218), -- Recipe: Samurai Longsword
(21631, 2092, 1, 1, -1, 30793), -- Homunkulus's Sword Blade
(21631, 57, 2244, 4536, 0, 700000), -- Adena
(21631, 103, 1, 1, 1, 294.589262), -- Tower Shield
(21631, 1978, 1, 1, 1, 18723.076077), -- Tower Shield Fragment
(21631, 107, 1, 1, 1, 294.589262), -- Composite Shield
(21631, 4055, 1, 1, 1, 18723.076077), -- Composite Shield Fragment
(21631, 517, 1, 1, 1, 206.30218), -- Composite Helmet
(21631, 2957, 1, 1, 1, 12810.532481), -- Composite Helmet Design
(21631, 1149, 1, 1, 1, 206.30218), -- Shining Circlet
(21631, 1983, 1, 1, 1, 12810.532481), -- Shining Circlet Pattern
(21631, 1873, 1, 1, 2, 84970.373859), -- Silver Nugget
(21631, 1868, 1, 3, 2, 212425.726659), -- Thread
(21631, 1876, 1, 1, 2, 42484.978941), -- Mithril Ore
(21631, 1895, 1, 1, 2, 60693.124185), -- Metallic Fiber
(21631, 4042, 1, 1, 2, 3540.380247), -- Enria
(21631, 2357, 1, 1, 2, 346.508841), -- Recipe: Crystal Dagger
(21631, 3012, 1, 1, 2, 3963.012879), -- Recipe: Full Plate Helmet
(21631, 8725, 1, 1, 2, 5900.633745), -- Life Stone - Level 52
(21631, 8735, 1, 1, 2, 1475.054442), -- Mid-Grade Life Stone - Level 52
(21631, 8745, 1, 1, 2, 147.671835), -- High-Grade Life Stone - Level 52
(21631, 8755, 1, 1, 2, 29.534367), -- Top-Grade Life Stone - Level 52
-- Doll Blader
(21632, 2955, 1, 1, -1, 135850), -- Theca Leather Gloves Texture
(21632, 4042, 1, 1, -1, 35774), -- Enria
(21632, 1918, 1, 1, -1, 92959), -- Nassen's Earring Gemstone
(21632, 57, 850, 1726, 0, 700000), -- Adena
(21632, 400, 1, 1, 1, 41.603614), -- Theca Leather Armor
(21632, 1984, 1, 1, 1, 2831.361299), -- Theca Leather Armor Pattern
(21632, 401, 1, 1, 1, 19.696443), -- Drake Leather Armor
(21632, 1987, 1, 1, 1, 2015.154804), -- Drake Leather Armor Texture
(21632, 420, 1, 1, 1, 66.588652), -- Theca Leather Gaiters
(21632, 1985, 1, 1, 1, 4554.595188), -- Theca Leather Gaiters Pattern
(21632, 1870, 1, 1, 2, 66044.127513), -- Coal
(21632, 1865, 1, 1, 2, 66044.127513), -- Varnish
(21632, 1874, 1, 1, 2, 4402.970824), -- Oriharukon Ore
(21632, 4043, 1, 1, 2, 2201.485412), -- Asofe
(21632, 4039, 1, 1, 2, 2201.485412), -- Mold Glue
(21632, 4133, 1, 1, 2, 317.583259), -- Recipe: Zubei's Breastplate (100%)
(21632, 4959, 1, 1, 2, 1272.507271), -- Recipe: Sealed Avadon Boots (60%)
(21632, 4941, 1, 1, 2, 508.046245), -- Recipe: Zubei's Gaiters (60%)
(21632, 8726, 1, 1, 2, 1528.777103), -- Life Stone - Level 55
(21632, 8736, 1, 1, 2, 382.230513), -- Mid-Grade Life Stone - Level 55
(21632, 8746, 1, 1, 2, 38.266536), -- High-Grade Life Stone - Level 55
(21632, 8756, 1, 1, 2, 7.392399), -- Top-Grade Life Stone - Level 55
-- Doll Blader
(21633, 2955, 1, 1, -1, 192371), -- Theca Leather Gloves Texture
(21633, 4042, 1, 1, -1, 50658), -- Enria
(21633, 1918, 1, 1, -1, 131635), -- Nassen's Earring Gemstone
(21633, 57, 1203, 2444, 0, 700000), -- Adena
(21633, 400, 1, 1, 1, 58.910438), -- Theca Leather Armor
(21633, 1984, 1, 1, 1, 4009.188583), -- Theca Leather Armor Pattern
(21633, 401, 1, 1, 1, 27.890031), -- Drake Leather Armor
(21633, 1987, 1, 1, 1, 2853.445668), -- Drake Leather Armor Texture
(21633, 420, 1, 1, 1, 94.289084), -- Theca Leather Gaiters
(21633, 1985, 1, 1, 1, 6449.276196), -- Theca Leather Gaiters Pattern
(21633, 1870, 1, 1, 2, 93521.772435), -- Coal
(21633, 1865, 1, 1, 2, 93521.772435), -- Varnish
(21633, 1874, 1, 1, 2, 6234.82588), -- Oriharukon Ore
(21633, 4043, 1, 1, 2, 3117.41294), -- Asofe
(21633, 4039, 1, 1, 2, 3117.41294), -- Mold Glue
(21633, 4133, 1, 1, 2, 449.713705), -- Recipe: Zubei's Breastplate (100%)
(21633, 4959, 1, 1, 2, 1801.933645), -- Recipe: Sealed Avadon Boots (60%)
(21633, 4941, 1, 1, 2, 719.418775), -- Recipe: Zubei's Gaiters (60%)
(21633, 8726, 1, 1, 2, 2164.824485), -- Life Stone - Level 55
(21633, 8736, 1, 1, 2, 541.257435), -- Mid-Grade Life Stone - Level 55
(21633, 8746, 1, 1, 2, 54.18732), -- High-Grade Life Stone - Level 55
(21633, 8756, 1, 1, 2, 10.468005), -- Top-Grade Life Stone - Level 55
-- Crimson Doll Blader
(21634, 1806, 1, 1, -1, 11096), -- Recipe: Soulshot (B-Grade)
(21634, 1918, 1, 1, -1, 240271), -- Nassen's Earring Gemstone
(21634, 4039, 1, 1, -1, 184928), -- Mold Glue
(21634, 57, 2196, 4461, 0, 700000), -- Adena
(21634, 135, 1, 1, 1, 21.728315), -- Samurai Longsword
(21634, 2115, 1, 1, 1, 2346.288378), -- Samurai Longsword Blade
(21634, 5286, 1, 1, 1, 21.728315), -- Berserker Blade
(21634, 5530, 1, 1, 1, 2349.254992), -- Berserker Blade Edge
(21634, 1894, 1, 1, 2, 7187.52632), -- Crafted Leather
(21634, 4039, 1, 1, 2, 6828.17148), -- Mold Glue
(21634, 4041, 1, 1, 2, 1781.25012), -- Mold Hardener
(21634, 4044, 1, 1, 2, 6828.17148), -- Thons
(21634, 1806, 1, 1, 2, 409.70072), -- Recipe: Soulshot (B-Grade)
(21634, 4134, 1, 1, 2, 1575.7248), -- Recipe: Zubei's Gaiters (100%)
(21634, 8726, 1, 1, 2, 4741.77808), -- Life Stone - Level 55
(21634, 8736, 1, 1, 2, 1185.44452), -- Mid-Grade Life Stone - Level 55
(21634, 8746, 1, 1, 2, 118.54752), -- High-Grade Life Stone - Level 55
(21634, 8756, 1, 1, 2, 23.68496), -- Top-Grade Life Stone - Level 55
-- Veil Master
(21635, 1985, 1, 1, -1, 70752), -- Theca Leather Gaiters Pattern
(21635, 4937, 1, 1, -1, 33858), -- Recipe: Adamantite Earrings (70%)
(21635, 1806, 1, 1, -1, 4104), -- Recipe: Soulshot (B-Grade)
(21635, 57, 810, 1651, 0, 700000), -- Adena
(21635, 2436, 1, 1, 1, 51.147582), -- Theca Leather Boots
(21635, 2954, 1, 1, 1, 3425.59672), -- Theca Leather Boots Texture
(21635, 2437, 1, 1, 1, 39.351028), -- Drake Leather Boots
(21635, 2960, 1, 1, 1, 2947.146874), -- Drake Leather Boots Design
(21635, 2438, 1, 1, 1, 39.351028), -- Full Plate Boots
(21635, 2961, 1, 1, 1, 2947.146874), -- Full Plate Boots Part
(21635, 2460, 1, 1, 1, 51.147582), -- Theca Leather Gloves
(21635, 2955, 1, 1, 1, 3425.59672), -- Theca Leather Gloves Texture
(21635, 2461, 1, 1, 1, 39.351028), -- Drake Leather Gloves
(21635, 2962, 1, 1, 1, 2947.146874), -- Drake Leather Gloves Design
(21635, 2462, 1, 1, 1, 39.351028), -- Full Plate Gauntlets
(21635, 2963, 1, 1, 1, 2947.146874), -- Full Plate Gauntlets Part
(21635, 2463, 1, 1, 1, 39.351028), -- Divine Gloves
(21635, 2964, 1, 1, 1, 2947.16876), -- Divine Gloves Pattern
(21635, 1864, 1, 1, 2, 126266.154028), -- Stem
(21635, 1869, 1, 1, 2, 63132.947596), -- Iron Ore
(21635, 1878, 1, 1, 2, 25253.33434), -- Braided Hemp
(21635, 1884, 1, 1, 2, 38851.024764), -- Cord
(21635, 4039, 1, 1, 2, 2104.33668), -- Mold Glue
(21635, 4178, 1, 1, 2, 1158.2911), -- Recipe: Zubei's Shield (100%)
(21635, 4184, 1, 1, 2, 72.732916), -- Recipe: Sprite's Staff (100%)
(21635, 5160, 1, 1, 2, 126.311968), -- Recipe: Spiritshot (B) Compressed Package (100%)
(21635, 8726, 1, 1, 2, 1461.388056), -- Life Stone - Level 55
(21635, 8736, 1, 1, 2, 365.476432), -- Mid-Grade Life Stone - Level 55
(21635, 8746, 1, 1, 2, 36.495876), -- High-Grade Life Stone - Level 55
(21635, 8756, 1, 1, 2, 7.506244), -- Top-Grade Life Stone - Level 55
-- Veil Master
(21636, 1985, 1, 1, -1, 100189), -- Theca Leather Gaiters Pattern
(21636, 4937, 1, 1, -1, 47945), -- Recipe: Adamantite Earrings (70%)
(21636, 1806, 1, 1, -1, 5811), -- Recipe: Soulshot (B-Grade)
(21636, 57, 1148, 2337, 0, 700000), -- Adena
(21636, 2436, 1, 1, 1, 72.428304), -- Theca Leather Boots
(21636, 2954, 1, 1, 1, 4850.86784), -- Theca Leather Boots Texture
(21636, 2437, 1, 1, 1, 55.723616), -- Drake Leather Boots
(21636, 2960, 1, 1, 1, 4173.351728), -- Drake Leather Boots Design
(21636, 2438, 1, 1, 1, 55.723616), -- Full Plate Boots
(21636, 2961, 1, 1, 1, 4173.351728), -- Full Plate Boots Part
(21636, 2460, 1, 1, 1, 72.428304), -- Theca Leather Gloves
(21636, 2955, 1, 1, 1, 4850.86784), -- Theca Leather Gloves Texture
(21636, 2461, 1, 1, 1, 55.723616), -- Drake Leather Gloves
(21636, 2962, 1, 1, 1, 4173.351728), -- Drake Leather Gloves Design
(21636, 2462, 1, 1, 1, 55.723616), -- Full Plate Gauntlets
(21636, 2963, 1, 1, 1, 4173.351728), -- Full Plate Gauntlets Part
(21636, 2463, 1, 1, 1, 55.723616), -- Divine Gloves
(21636, 2964, 1, 1, 1, 4173.38272), -- Divine Gloves Pattern
(21636, 1864, 1, 1, 2, 178799.325075), -- Stem
(21636, 1869, 1, 1, 2, 89399.479275), -- Iron Ore
(21636, 1878, 1, 1, 2, 35760.011625), -- Braided Hemp
(21636, 1884, 1, 1, 2, 55015.035975), -- Cord
(21636, 4039, 1, 1, 2, 2979.84825), -- Mold Glue
(21636, 4178, 1, 1, 2, 1640.199375), -- Recipe: Zubei's Shield (100%)
(21636, 4184, 1, 1, 2, 102.993525), -- Recipe: Sprite's Staff (100%)
(21636, 5160, 1, 1, 2, 178.8642), -- Recipe: Spiritshot (B) Compressed Package (100%)
(21636, 8726, 1, 1, 2, 2069.40015), -- Life Stone - Level 55
(21636, 8736, 1, 1, 2, 517.5333), -- Mid-Grade Life Stone - Level 55
(21636, 8746, 1, 1, 2, 51.680025), -- High-Grade Life Stone - Level 55
(21636, 8756, 1, 1, 2, 10.629225), -- Top-Grade Life Stone - Level 55
-- Crimson Veil Master
(21637, 2115, 1, 1, -1, 24296), -- Samurai Longsword Blade
(21637, 4141, 1, 1, -1, 25497), -- Recipe: Avadon Breastplate (100%)
(21637, 2116, 1, 1, -1, 24951), -- Deadman's Staff Head
(21637, 57, 2095, 4266, 0, 700000), -- Adena
(21637, 135, 1, 1, 1, 20.77005), -- Samurai Longsword
(21637, 2115, 1, 1, 1, 2242.81206), -- Samurai Longsword Blade
(21637, 5286, 1, 1, 1, 20.77005), -- Berserker Blade
(21637, 5530, 1, 1, 1, 2245.64784), -- Berserker Blade Edge
(21637, 1864, 4, 12, 2, 44503.242147), -- Stem
(21637, 1865, 2, 6, 2, 35602.354575), -- Varnish
(21637, 1866, 1, 1, 2, 118674.913821), -- Suede
(21637, 1873, 1, 1, 2, 71205.107721), -- Silver Nugget
(21637, 1868, 1, 3, 2, 118674.913821), -- Thread
(21637, 4142, 1, 1, 2, 1369.489956), -- Recipe: Avadon Gaiters (100%)
(21637, 4936, 1, 1, 2, 3266.289345), -- Recipe: Avadon Shield (60%)
(21637, 8726, 1, 1, 2, 4120.825569), -- Life Stone - Level 55
(21637, 8736, 1, 1, 2, 1030.306035), -- Mid-Grade Life Stone - Level 55
(21637, 8746, 1, 1, 2, 102.831318), -- High-Grade Life Stone - Level 55
(21637, 8756, 1, 1, 2, 20.725692), -- Top-Grade Life Stone - Level 55
-- Dread Wolf
(21638, 2203, 1, 1, -1, 99396), -- Recipe: Reinforced Mithril Boots
(21638, 1935, 1, 1, -1, 25488), -- Scale Mail Fragment
(21638, 1900, 1, 1, -1, 49916), -- Enchanted Necklace Chain
(21638, 57, 193, 384, 0, 700000), -- Adena
(21638, 316, 1, 1, 1, 21.746132), -- Sage's Blood
(21638, 317, 1, 1, 1, 21.746132), -- Tome of Blood
(21638, 2030, 1, 1, 1, 945.507736), -- Tome of Blood Page
(21638, 1874, 1, 1, 2, 2310.220763), -- Oriharukon Ore
(21638, 1878, 1, 1, 2, 13861.222136), -- Braided Hemp
(21638, 1884, 1, 1, 2, 21324.992593), -- Cord
(21638, 1889, 1, 1, 2, 2310.220763), -- Compound Braid
(21638, 5220, 1, 1, 2, 1386.142702), -- Metal Hardener
(21638, 2153, 1, 1, 2, 5389.268736), -- Recipe: Tiger's Eye Earring
(21638, 2977, 1, 1, 2, 4638.932307), -- Recipe: Brigandine Boots
-- Tasaba Lizardman
(21639, 2021, 1, 1, -1, 6804), -- Spinebone Sword Blade
(21639, 2184, 1, 1, -1, 56604), -- Recipe: Mithril Banded Gaiters
(21639, 2153, 1, 1, -1, 83805), -- Recipe: Tiger's Eye Earring
(21639, 57, 227, 455, 0, 700000), -- Adena
(21639, 83, 1, 1, 1, 17.34048), -- Sword of Magic
(21639, 144, 1, 1, 1, 17.34048), -- Sword of Occult
(21639, 124, 1, 1, 1, 12.845952), -- Two-Handed Sword
(21639, 2026, 1, 1, 1, 574.780536), -- Two-Handed Sword Edge
(21639, 127, 1, 1, 1, 12.845952), -- Crimson Sword
(21639, 130, 1, 1, 1, 12.8466), -- Elven Sword
(21639, 1875, 1, 1, 2, 3183.424369), -- Stone of Purity
(21639, 1879, 1, 1, 2, 7958.577158), -- Cokes
(21639, 1885, 1, 1, 2, 3979.288579), -- High-Grade Suede
(21639, 5550, 1, 1, 2, 636.691368), -- Durable Metal Plate
(21639, 5549, 1, 1, 2, 4775.152789), -- Metallic Thread
(21639, 2250, 1, 1, 2, 11937.865737), -- Recipe: Bone Arrow
-- Ogre
(21641, 2302, 1, 1, -1, 3052), -- Recipe: Silver Axe
(21641, 1956, 1, 1, -1, 79338), -- Square Shield Fragment
(21641, 2154, 1, 1, -1, 74836), -- Recipe: Elven Earring
(21641, 57, 296, 590, 0, 700000), -- Adena
(21641, 88, 1, 1, 1, 6.72708), -- Morning Star
(21641, 2031, 1, 1, 1, 365.64681), -- Morning Star Head
(21641, 90, 1, 1, 1, 6.72708), -- Goat Head Staff
(21641, 2032, 1, 1, 1, 333.78285), -- Goat Head Staff Head
(21641, 158, 1, 1, 1, 6.72708), -- Tarbar
(21641, 2035, 1, 1, 1, 365.64681), -- Tarbar Head
(21641, 169, 1, 1, 1, 6.72708), -- Skull Breaker
(21641, 2036, 1, 1, 1, 365.64681), -- Skull Breaker Head
(21641, 172, 1, 1, 1, 6.72708), -- Heavy Bone Club
(21641, 2037, 1, 1, 1, 365.64132), -- Heavy Bone Club Head
(21641, 1874, 1, 1, 2, 3010.925489), -- Oriharukon Ore
(21641, 1878, 1, 1, 2, 18065.345155), -- Braided Hemp
(21641, 1884, 1, 1, 2, 27792.726819), -- Cord
(21641, 1889, 1, 1, 2, 3010.925489), -- Compound Braid
(21641, 5220, 1, 1, 2, 1806.430626), -- Metal Hardener
(21641, 2190, 1, 1, 2, 3225.976754), -- Recipe: Mithril Stockings
(21641, 2279, 1, 1, 2, 322.680787), -- Recipe: War Pick
(21641, 1341, 10, 30, 2, 150543.988881), -- Bone Arrow
-- Tasaba Lizardman Sniper
(21642, 2145, 1, 1, -1, 45818), -- Recipe: Mithril Alloy
(21642, 1904, 1, 1, -1, 59864), -- Elven Necklace Beads
(21642, 1868, 1, 3, -1, 641445), -- Thread
(21642, 57, 271, 541, 0, 700000), -- Adena
(21642, 279, 1, 1, 1, 30.87216), -- Reinforced Long Bow
(21642, 2040, 1, 1, 1, 1918.12784), -- Reinforced Long Bow Shaft
(21642, 1873, 1, 1, 2, 22105.244736), -- Silver Nugget
(21642, 1868, 1, 1, 2, 110526.22368), -- Thread
(21642, 1876, 1, 1, 2, 11052.622368), -- Mithril Ore
(21642, 1895, 1, 1, 2, 15789.437136), -- Metallic Fiber
(21642, 2146, 1, 1, 2, 3947.318352), -- Recipe: Artisan's frame
(21642, 2285, 1, 1, 2, 307.153728), -- Recipe: Claymore
-- Tasaba Lizardman Sniper
(21643, 2145, 1, 1, -1, 58218), -- Recipe: Mithril Alloy
(21643, 1904, 1, 1, -1, 76067), -- Elven Necklace Beads
(21643, 1868, 1, 3, -1, 815056), -- Thread
(21643, 57, 345, 687, 0, 700000), -- Adena
(21643, 279, 1, 1, 1, 39.23568), -- Reinforced Long Bow
(21643, 2040, 1, 1, 1, 2437.76432), -- Reinforced Long Bow Shaft
(21643, 1873, 1, 1, 2, 28088.031492), -- Silver Nugget
(21643, 1868, 1, 1, 2, 140440.15746), -- Thread
(21643, 1876, 1, 1, 2, 14044.015746), -- Mithril Ore
(21643, 1895, 1, 1, 2, 20062.849917), -- Metallic Fiber
(21643, 2146, 1, 1, 2, 5015.660469), -- Recipe: Artisan's frame
(21643, 2285, 1, 1, 2, 390.284916), -- Recipe: Claymore
-- Lienrik
(21644, 2026, 1, 1, -1, 4711), -- Two-Handed Sword Edge
(21644, 2155, 1, 1, -1, 62822), -- Recipe: Elven Ring
(21644, 5550, 1, 1, -1, 5218), -- Durable Metal Plate
(21644, 57, 166, 330, 0, 700000), -- Adena
(21644, 395, 1, 1, 1, 58.81275), -- Manticore Skin Shirt
(21644, 1942, 1, 1, 1, 2579.8905), -- Manticore Skin Shirt Texture
(21644, 417, 1, 1, 1, 93.92625), -- Manticore Skin Gaiters
(21644, 1943, 1, 1, 1, 4017.3705), -- Manticore Skin Gaiters Pattern
(21644, 1875, 1, 1, 2, 1685.957287), -- Stone of Purity
(21644, 1879, 1, 1, 2, 4214.885927), -- Cokes
(21644, 1885, 1, 1, 2, 2107.450254), -- High-Grade Suede
(21644, 5550, 1, 1, 2, 337.185625), -- Durable Metal Plate
(21644, 5549, 1, 1, 2, 2528.92864), -- Metallic Thread
(21644, 2278, 1, 1, 2, 180.644009), -- Recipe: Reinforced Long Bow
(21644, 2286, 1, 1, 2, 140.502516), -- Recipe: Bonebreaker
(21644, 2977, 1, 1, 2, 3385.445742), -- Recipe: Brigandine Boots
-- Lienrik Lad
(21645, 1870, 1, 1, -1, 720648), -- Coal
(21645, 2029, 1, 1, -1, 8596), -- Gastraphetes Shaft
(21645, 5549, 1, 1, -1, 72065), -- Metallic Thread
(21645, 57, 301, 600, 0, 700000), -- Adena
(21645, 850, 1, 1, 1, 172.699016), -- Elven Earring
(21645, 1902, 1, 1, 1, 6290.24193), -- Elven Earring Beads
(21645, 913, 1, 1, 1, 129.61627), -- Elven Necklace
(21645, 1904, 1, 1, 1, 5794.180798), -- Elven Necklace Beads
(21645, 881, 1, 1, 1, 259.23254), -- Elven Ring
(21645, 1903, 1, 1, 1, 10356.029446), -- Elven Ring Piece
(21645, 1875, 1, 1, 2, 2759.404299), -- Stone of Purity
(21645, 1879, 1, 1, 2, 6898.614586), -- Cokes
(21645, 1885, 1, 1, 2, 3449.307293), -- High-Grade Suede
(21645, 5550, 1, 1, 2, 551.797789), -- Durable Metal Plate
(21645, 5549, 1, 1, 2, 4139.210287), -- Metallic Thread
(21645, 2188, 1, 1, 2, 2956.489772), -- Recipe: Manticore Skin Gaiters
(21645, 5473, 1, 1, 2, 2956.489772), -- Recipe: Durable Metal Plate(100%)
(21645, 1832, 1, 1, 2, 45991.317712), -- Greater Antidote
(21645, 1341, 10, 30, 2, 137974.36849), -- Bone Arrow
-- Grave Scarab
(21646, 5508, 1, 1, -1, 80750), -- Sealed Dark Crystal Gloves Design
(21646, 730, 1, 1, -1, 2870), -- Scroll: Enchant Armor (A-Grade)
(21646, 1894, 1, 1, -1, 120842), -- Crafted Leather
(21646, 57, 1701, 3463, 0, 700000), -- Adena
(21646, 12225, 1, 1, 1, 879.400095), -- Common Item - Sealed Dark Crystal Shield
(21646, 5494, 1, 1, 1, 4451.04739), -- Sealed Dark Crystal Shield Fragment
(21646, 12226, 1, 1, 1, 616.09024), -- Common Item - Sealed Dark Crystal Helmet
(21646, 5525, 1, 1, 1, 3276.17946), -- Sealed Dark Crystal Helmet Design
(21646, 12234, 1, 1, 1, 616.09024), -- Common Item - Sealed Tallum Helmet
(21646, 5526, 1, 1, 1, 3276.192575), -- Sealed Tallum Helm Design
(21646, 1867, 1, 1, 2, 154137.061536), -- Animal Skin
(21646, 1872, 1, 1, 2, 154137.061536), -- Animal Bone
(21646, 1882, 1, 1, 2, 25689.510256), -- Leather
(21646, 1894, 1, 1, 2, 4056.059456), -- Crafted Leather
(21646, 4042, 1, 1, 2, 1926.48248), -- Enria
(21646, 5277, 1, 1, 2, 51.502432), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21646, 8731, 1, 1, 2, 1070.376016), -- Life Stone - Level 70
(21646, 8741, 1, 1, 2, 267.715472), -- Mid-Grade Life Stone - Level 70
(21646, 8751, 1, 1, 2, 26.72296), -- High-Grade Life Stone - Level 70
(21646, 8761, 1, 1, 2, 5.344592), -- Top-Grade Life Stone - Level 70
(21646, 1344, 10, 30, 2, 144504.163264), -- Mithril Arrow
-- Scavenger Scarab
(21647, 4044, 1, 1, -1, 96846), -- Thons
(21647, 5509, 1, 1, -1, 68122), -- Sealed Tallum Gloves Design
(21647, 5462, 1, 1, -1, 1076), -- Recipe: Branch of the Mother Tree(60%)
(21647, 57, 1435, 2921, 0, 700000), -- Adena
(21647, 12227, 1, 1, 1, 194.890605), -- Common Item - Sealed Dark Crystal Breastplate
(21647, 5520, 1, 1, 1, 1153.07335), -- Sealed Dark Crystal Breastplate Pattern
(21647, 12233, 1, 1, 1, 120.00638), -- Common Item - Sealed Tallum Plate Armor
(21647, 5521, 1, 1, 1, 813.65336), -- Sealed Tallum Plate Armor Pattern
(21647, 12220, 1, 1, 1, 310.977485), -- Common Item - Sealed Dark Crystal Gaiters
(21647, 5524, 1, 1, 1, 1762.39882), -- Sealed Dark Crystal Gaiters Pattern
(21647, 1868, 1, 1, 2, 214552.24957), -- Thread
(21647, 1873, 1, 1, 2, 42910.449914), -- Silver Nugget
(21647, 5549, 1, 1, 2, 10727.47236), -- Metallic Thread
(21647, 1889, 1, 1, 2, 7151.64824), -- Compound Braid
(21647, 4044, 1, 1, 2, 3575.82412), -- Thons
(21647, 5282, 1, 1, 2, 47.64029), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21647, 8731, 1, 1, 2, 993.159928), -- Life Stone - Level 70
(21647, 8741, 1, 1, 2, 248.289982), -- Mid-Grade Life Stone - Level 70
(21647, 8751, 1, 1, 2, 24.941093), -- High-Grade Life Stone - Level 70
(21647, 8761, 1, 1, 2, 5.324503), -- Top-Grade Life Stone - Level 70
-- Grave Ant
(21648, 5482, 1, 1, -1, 41890), -- Sealed Dark Crystal Leggings Design
(21648, 5464, 1, 1, -1, 1175), -- Recipe: Dark Legion's Edge(60%)
(21648, 5485, 1, 1, -1, 26688), -- Sealed Tallum Tunic Texture
(21648, 57, 1566, 3192, 0, 700000), -- Adena
(21648, 12225, 1, 1, 1, 810.402558), -- Common Item - Sealed Dark Crystal Shield
(21648, 5494, 1, 1, 1, 4101.819196), -- Sealed Dark Crystal Shield Fragment
(21648, 12226, 1, 1, 1, 567.751936), -- Common Item - Sealed Dark Crystal Helmet
(21648, 5525, 1, 1, 1, 3019.131144), -- Sealed Dark Crystal Helmet Design
(21648, 12234, 1, 1, 1, 567.751936), -- Common Item - Sealed Tallum Helmet
(21648, 5526, 1, 1, 1, 3019.14323), -- Sealed Tallum Helm Design
(21648, 1869, 1, 1, 2, 106532.87281), -- Iron Ore
(21648, 1870, 1, 1, 2, 106532.87281), -- Coal
(21648, 1871, 1, 1, 2, 106532.87281), -- Charcoal
(21648, 1872, 1, 3, 2, 71022.07273), -- Animal Bone
(21648, 1867, 1, 3, 2, 47347.73344), -- Animal Skin
(21648, 5167, 1, 1, 2, 47.257), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21648, 8731, 1, 1, 2, 986.25359), -- Life Stone - Level 70
(21648, 8741, 1, 1, 2, 246.68154), -- Mid-Grade Life Stone - Level 70
(21648, 8751, 1, 1, 2, 24.57364), -- High-Grade Life Stone - Level 70
(21648, 8761, 1, 1, 2, 4.7257), -- Top-Grade Life Stone - Level 70
(21648, 1344, 40, 120, 2, 33292.08393), -- Mithril Arrow
-- Scavenger Ant
(21649, 729, 1, 1, -1, 417), -- Scroll: Enchant Weapon (A-Grade)
(21649, 4044, 1, 1, -1, 125138), -- Thons
(21649, 1894, 1, 1, -1, 131724), -- Crafted Leather
(21649, 57, 1853, 3776, 0, 700000), -- Adena
(21649, 12227, 1, 1, 1, 251.813877), -- Common Item - Sealed Dark Crystal Breastplate
(21649, 5520, 1, 1, 1, 1489.86079), -- Sealed Dark Crystal Breastplate Pattern
(21649, 12233, 1, 1, 1, 155.057612), -- Common Item - Sealed Tallum Plate Armor
(21649, 5521, 1, 1, 1, 1051.303664), -- Sealed Tallum Plate Armor Pattern
(21649, 12220, 1, 1, 1, 401.807189), -- Common Item - Sealed Dark Crystal Gaiters
(21649, 5524, 1, 1, 1, 2277.156868), -- Sealed Dark Crystal Gaiters Pattern
(21649, 1894, 1, 1, 2, 5404.10768), -- Crafted Leather
(21649, 4039, 1, 1, 2, 5133.898515), -- Mold Glue
(21649, 4041, 1, 1, 2, 1339.26801), -- Mold Hardener
(21649, 4044, 1, 1, 2, 5133.898515), -- Thons
(21649, 5272, 1, 1, 2, 68.455005), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21649, 8731, 1, 1, 2, 1426.07977), -- Life Stone - Level 70
(21649, 8741, 1, 1, 2, 356.529395), -- Mid-Grade Life Stone - Level 70
(21649, 8751, 1, 1, 2, 35.65483), -- High-Grade Life Stone - Level 70
(21649, 8761, 1, 1, 2, 7.10828), -- Top-Grade Life Stone - Level 70
-- Shrine Knight
(21650, 5162, 1, 1, -1, 1530), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21650, 5514, 1, 1, -1, 58132), -- Sealed Gauntlets of Nightmare Design
(21650, 5167, 1, 1, -1, 1530), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21650, 57, 1698, 3464, 0, 700000), -- Adena
(21650, 11951, 1, 1, 1, 174.943146), -- Common Item - Bloody Orchid
(21650, 5536, 1, 1, 1, 2162.056854), -- Bloody Orchid Head
(21650, 1895, 1, 1, 2, 36310.96792), -- Metallic Fiber
(21650, 4040, 1, 1, 2, 2541.79243), -- Mold Lubricant
(21650, 4042, 1, 1, 2, 2118.19463), -- Enria
(21650, 4043, 1, 1, 2, 4236.18363), -- Asofe
(21650, 3957, 1, 1, 2, 56.54825), -- Recipe: Blessed Spiritshot S
(21650, 8731, 1, 1, 2, 1176.82049), -- Life Stone - Level 70
(21650, 8741, 1, 1, 2, 294.25653), -- Mid-Grade Life Stone - Level 70
(21650, 8751, 1, 1, 2, 29.40509), -- High-Grade Life Stone - Level 70
(21650, 8761, 1, 1, 2, 5.96327), -- Top-Grade Life Stone - Level 70
(21650, 1344, 10, 30, 2, 158859.86776), -- Mithril Arrow
-- Shrine Guard
(21651, 5515, 1, 1, -1, 55534), -- Sealed Majestic Gauntlets Design
(21651, 1889, 1, 1, -1, 219210), -- Compound Braid
(21651, 4044, 1, 1, -1, 109605), -- Thons
(21651, 57, 1622, 3309, 0, 700000), -- Adena
(21651, 11946, 1, 1, 1, 41.771594), -- Common Item - Dasparion's Staff
(21651, 5543, 1, 1, 1, 516.510096), -- Dasparion's Staff Head
(21651, 11949, 1, 1, 1, 41.771594), -- Common Item - Meteor Shower
(21651, 5532, 1, 1, 1, 511.685946), -- Meteor Shower Head
(21651, 11953, 1, 1, 1, 41.771594), -- Common Item - Spiritual Eye
(21651, 8341, 1, 1, 1, 511.031636), -- Spiritual Eye Piece
(21651, 11958, 1, 1, 1, 41.771594), -- Common Item - Destroyer Hammer
(21651, 8346, 1, 1, 1, 511.685946), -- Hammer Piece of Destroyer
(21651, 1868, 1, 1, 2, 242817.03955), -- Thread
(21651, 1873, 1, 1, 2, 48563.40791), -- Silver Nugget
(21651, 5549, 1, 1, 2, 12140.6934), -- Metallic Thread
(21651, 1889, 1, 1, 2, 8093.7956), -- Compound Braid
(21651, 4044, 1, 1, 2, 4046.8978), -- Thons
(21651, 5157, 1, 1, 2, 53.91635), -- Recipe: Soulshot (S) Compressed Package (100%)
(21651, 8731, 1, 1, 2, 1123.99732), -- Life Stone - Level 70
(21651, 8741, 1, 1, 2, 280.99933), -- Mid-Grade Life Stone - Level 70
(21651, 8751, 1, 1, 2, 28.226795), -- High-Grade Life Stone - Level 70
(21651, 8761, 1, 1, 2, 6.025945), -- Top-Grade Life Stone - Level 70
-- Scarlet Stakato Noble
(21652, 5272, 1, 1, -1, 5080), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21652, 5545, 1, 1, -1, 31358), -- Dark Legion's Edge Blade
(21652, 5277, 1, 1, -1, 5080), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21652, 57, 5636, 11501, 0, 700000), -- Adena
(21652, 305, 1, 1, 1, 20.347728), -- Tallum Glaive
(21652, 5541, 1, 1, 1, 5786.652272), -- Tallum Glaive Edge
(21652, 1867, 4, 12, 2, 78154.646772), -- Animal Skin
(21652, 1872, 1, 3, 2, 208412.811436), -- Animal Bone
(21652, 1882, 1, 1, 2, 104206.195696), -- Leather
(21652, 1894, 1, 1, 2, 16453.543524), -- Crafted Leather
(21652, 4042, 1, 1, 2, 7815.338664), -- Enria
(21652, 959, 1, 1, 2, 18.90198), -- Scroll: Enchant Weapon (S-Grade)
(21652, 8732, 1, 1, 2, 3907.669332), -- Life Stone - Level 76
(21652, 8742, 1, 1, 2, 977.022344), -- Mid-Grade Life Stone - Level 76
(21652, 8752, 1, 1, 2, 97.870252), -- High-Grade Life Stone - Level 76
-- Assassin Beetle
(21653, 5544, 1, 1, -1, 26668), -- Branch of the Mother Tree Head
(21653, 5157, 1, 1, -1, 4325), -- Recipe: Soulshot (S) Compressed Package (100%)
(21653, 5545, 1, 1, -1, 26699), -- Dark Legion's Edge Blade
(21653, 57, 4798, 9794, 0, 700000), -- Adena
(21653, 270, 1, 1, 1, 17.325838), -- Dragon Grinder
(21653, 5538, 1, 1, 1, 4928.674162), -- Dragon Grinder Edge
(21653, 1895, 1, 1, 2, 114073.70024), -- Metallic Fiber
(21653, 4040, 1, 1, 2, 7985.32532), -- Mold Lubricant
(21653, 4042, 1, 1, 2, 6654.1078), -- Enria
(21653, 4043, 1, 1, 2, 13308.61156), -- Asofe
(21653, 960, 1, 1, 2, 159.57188), -- Scroll: Enchant Armor (S-Grade)
(21653, 8732, 1, 1, 2, 3327.25188), -- Life Stone - Level 76
(21653, 8742, 1, 1, 2, 831.91196), -- Mid-Grade Life Stone - Level 76
(21653, 8752, 1, 1, 2, 83.1516), -- High-Grade Life Stone - Level 76
(21653, 1344, 20, 60, 2, 249536.36776), -- Mithril Arrow
-- Necromancer of Destruction
(21654, 5167, 1, 1, -1, 4782), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21654, 5488, 1, 1, -1, 48447), -- Sealed Majestic Robe Fabric
(21654, 4042, 1, 1, -1, 179309), -- Enria
(21654, 57, 5293, 10839, 0, 700000), -- Adena
(21654, 81, 1, 1, 1, 6.384495), -- Dragon Slayer
(21654, 5529, 1, 1, 1, 1815.72554), -- Dragon Slayer Edge
(21654, 151, 1, 1, 1, 6.384495), -- Sword of Miracles
(21654, 5546, 1, 1, 1, 1994.40108), -- Sword of Miracles Edge
(21654, 2500, 1, 1, 1, 6.384495), -- Dark Legion's Edge
(21654, 5545, 1, 1, 1, 1815.719895), -- Dark Legion's Edge Blade
(21654, 1867, 5, 15, 2, 52965.127416), -- Animal Skin
(21654, 1872, 1, 3, 2, 176550.891587), -- Animal Bone
(21654, 1882, 1, 1, 2, 88275.21236), -- Leather
(21654, 1894, 1, 1, 2, 13938.314285), -- Crafted Leather
(21654, 4042, 1, 1, 2, 6620.640927), -- Enria
(21654, 960, 1, 1, 2, 158.73478), -- Scroll: Enchant Armor (S-Grade)
(21654, 8732, 1, 1, 2, 3310.553897), -- Life Stone - Level 76
(21654, 8742, 1, 1, 2, 827.755191), -- Mid-Grade Life Stone - Level 76
(21654, 8752, 1, 1, 2, 82.635459), -- High-Grade Life Stone - Level 76
(21654, 1344, 40, 120, 2, 124137.134098), -- Mithril Arrow
-- Arimanes of Destruction
(21655, 6344, 1, 1, -1, 150349), -- Sealed Majestic Necklace Beads
(21655, 6901, 1, 1, -1, 10256), -- Recipe: Shining Arrow (100%)
(21655, 13099, 1, 1, -1, 143031), -- Sealed Arcana Sigil Piece
(21655, 57, 5046, 10335, 0, 700000), -- Adena
(21655, 5311, 1, 1, 1, 21.507996), -- Sealed Armor of Nightmare
(21655, 5522, 1, 1, 1, 3224.492004), -- Sealed Armor of Nightmare Pattern
(21655, 5316, 1, 1, 1, 21.507996), -- Sealed Majestic Plate Armor
(21655, 5523, 1, 1, 1, 3224.492004), -- Sealed Majestic Plate Armor Pattern
(21655, 1865, 1, 3, 2, 126228.542048), -- Varnish
(21655, 1870, 2, 6, 2, 94671.406536), -- Coal
(21655, 1879, 1, 1, 2, 63114.271024), -- Cokes
(21655, 1875, 1, 1, 2, 25245.561072), -- Stone of Purity
(21655, 4040, 1, 1, 2, 7573.889328), -- Mold Lubricant
(21655, 960, 1, 1, 2, 151.389384), -- Scroll: Enchant Armor (S-Grade)
(21655, 8732, 1, 1, 2, 3155.603048), -- Life Stone - Level 76
(21655, 8742, 1, 1, 2, 788.992848), -- Mid-Grade Life Stone - Level 76
(21655, 8752, 1, 1, 2, 78.825616), -- High-Grade Life Stone - Level 76
(21655, 1344, 100, 300, 2, 47335.519096), -- Mithril Arrow
-- Ashuras of Destruction
(21656, 6704, 1, 1, -1, 219330), -- Sealed Imperial Crusader Boots Design
(21656, 6705, 1, 1, -1, 214834), -- Sealed Imperial Crusader Shield Part
(21656, 6706, 1, 1, -1, 249893), -- Sealed Imperial Crusader Helmet Pattern
(21656, 57, 7595, 15500, 0, 700000), -- Adena
(21656, 5315, 1, 1, 1, 133.330893), -- Sealed Shield of Nightmare
(21656, 5495, 1, 1, 1, 14393.419393), -- Sealed Shield of Nightmare Fragment
(21656, 5312, 1, 1, 1, 93.297984), -- Sealed Helm of Nightmare
(21656, 5527, 1, 1, 1, 11332.826873), -- Sealed Helm of Nightmare Design
(21656, 5317, 1, 1, 1, 93.297984), -- Sealed Majestic Circlet
(21656, 5528, 1, 1, 1, 11332.826873), -- Sealed Majestic Circlet Design
(21656, 1872, 5, 15, 2, 75838.20699), -- Animal Bone
(21656, 1867, 9, 27, 2, 42132.1035), -- Animal Skin
(21656, 1881, 1, 1, 2, 75838.20699), -- Coarse Bone Powder
(21656, 1875, 1, 1, 2, 37918.89315), -- Stone of Purity
(21656, 4041, 1, 1, 2, 4946.05233), -- Mold Hardener
(21656, 960, 1, 1, 2, 227.59329), -- Scroll: Enchant Armor (S-Grade)
(21656, 8732, 1, 1, 2, 4739.91423), -- Life Stone - Level 76
(21656, 8742, 1, 1, 2, 1185.08373), -- Mid-Grade Life Stone - Level 76
(21656, 8752, 1, 1, 2, 118.63458), -- High-Grade Life Stone - Level 76
(21656, 1344, 40, 120, 2, 177745.31121), -- Mithril Arrow
-- Magma Drake
(21657, 6688, 1, 1, -1, 31026), -- Forgotten Blade Edge
(21657, 6689, 1, 1, -1, 30442), -- Basalt Battlehammer Head
(21657, 6690, 1, 1, -1, 31085), -- Imperial Staff Head
(21657, 57, 7076, 14446, 0, 700000), -- Adena
(21657, 5320, 1, 1, 1, 40.133496), -- Sealed Leather Armor of Nightmare
(21657, 5480, 1, 1, 1, 5946.366504), -- Sealed Leather Armor of Nightmare Fabric
(21657, 5323, 1, 1, 1, 40.133496), -- Sealed Majestic Leather Armor
(21657, 5481, 1, 1, 1, 5946.366504), -- Sealed Majestic Leather Armor Fabric
(21657, 1865, 9, 27, 2, 29444.351638), -- Varnish
(21657, 1870, 2, 6, 2, 132499.582371), -- Coal
(21657, 1879, 1, 1, 2, 88333.054914), -- Cokes
(21657, 1875, 1, 1, 2, 35333.148305), -- Stone of Purity
(21657, 4040, 1, 1, 2, 10600.128643), -- Mold Lubricant
(21657, 960, 1, 1, 2, 212.142528), -- Scroll: Enchant Armor (S-Grade)
(21657, 8732, 1, 1, 2, 4416.689576), -- Life Stone - Level 76
(21657, 8742, 1, 1, 2, 1104.172394), -- Mid-Grade Life Stone - Level 76
(21657, 8752, 1, 1, 2, 110.4909), -- High-Grade Life Stone - Level 76
(21657, 1344, 100, 300, 2, 66249.238731), -- Mithril Arrow
-- Punishment of Splendor
(21658, 1876, 1, 1, -1, 727098), -- Mithril Ore
(21658, 4052, 1, 1, -1, 128713), -- Earring of Black Ore Piece
(21658, 57, 1443, 2919, 0, 700000), -- Adena
(21658, 11930, 1, 1, 1, 58.453316), -- Common Item - Sword of Damascus
(21658, 4114, 1, 1, 1, 783.318352), -- Sword of Damascus Blade
(21658, 11929, 1, 1, 1, 58.453316), -- Common Item - Guardian Sword
(21658, 8330, 1, 1, 1, 782.000824), -- Guardian Sword Blade
(21658, 11943, 1, 1, 1, 58.453316), -- Common Item - Wizard's Tear
(21658, 8336, 1, 1, 1, 783.320876), -- Blade of the Wizard's Tear
(21658, 1876, 1, 1, 2, 17897.773922), -- Mithril Ore
(21658, 1880, 1, 1, 2, 8948.886961), -- Steel
(21658, 1877, 1, 1, 2, 3579.593285), -- Adamantite Nugget
(21658, 1881, 1, 1, 2, 11931.720946), -- Coarse Bone Powder
(21658, 1882, 1, 1, 2, 19886.329912), -- Leather
(21658, 1807, 1, 1, 2, 119.35186), -- Recipe: Soulshot (A-Grade)
(21658, 5392, 1, 1, 2, 771.359521), -- Recipe: Sealed Dark Crystal Gloves(60%)
(21658, 8729, 1, 1, 2, 1193.133594), -- Life Stone - Level 64
(21658, 8739, 1, 1, 2, 298.37965), -- Mid-Grade Life Stone - Level 64
(21658, 8749, 1, 1, 2, 29.837965), -- High-Grade Life Stone - Level 64
(21658, 8759, 1, 1, 2, 5.967593), -- Top-Grade Life Stone - Level 64
(21658, 1343, 10, 30, 2, 127840.664791), -- Silver Arrow
-- Otherworldly Invader Soldier
(21659, 1869, 1, 3, -1, 635864), -- Iron Ore
(21659, 1061, 1, 1, -1, 770744), -- Greater Healing Potion
(21659, 1900, 1, 1, -1, 139139), -- Enchanted Necklace Chain
(21659, 57, 536, 1073, 0, 700000), -- Adena
(21659, 627, 1, 1, 1, 2583.325615), -- Aspis
(21659, 46, 1, 1, 1, 1809.674385), -- Bronze Helmet
(21659, 1869, 1, 1, 2, 115824.879009), -- Iron Ore
(21659, 1864, 1, 1, 2, 231649.758018), -- Stem
(21659, 1880, 1, 1, 2, 11582.600946), -- Steel
(21659, 5550, 1, 1, 2, 1544.196066), -- Durable Metal Plate
(21659, 737, 1, 1, 2, 11582.600946), -- Scroll of Resurrection
(21659, 6387, 1, 1, 2, 4632.965015), -- Blessed Scroll of Resurrection for Pets
-- Otherworldly Invader Soldier
(21660, 2190, 1, 1, -1, 126744), -- Recipe: Mithril Stockings
(21660, 1940, 1, 1, -1, 264838), -- Iron Boots Design
(21660, 1870, 1, 3, -1, 887208), -- Coal
(21660, 57, 749, 1495, 0, 700000), -- Adena
(21660, 553, 1, 1, 1, 689.387352), -- Iron Boots
(21660, 1940, 1, 1, 1, 20115.675888), -- Iron Boots Design
(21660, 2422, 1, 1, 1, 689.387352), -- Reinforced Leather Boots
(21660, 2423, 1, 1, 1, 689.387352), -- Boots of Knowledge
(21660, 63, 1, 1, 1, 689.387352), -- Gauntlets
(21660, 2446, 1, 1, 1, 689.387352), -- Reinforced Leather Gloves
(21660, 2447, 1, 1, 1, 689.387352), -- Gloves of Knowledge
(21660, 1870, 1, 3, 2, 117930.3516), -- Coal
(21660, 1865, 1, 1, 2, 235861.1028), -- Varnish
(21660, 1874, 1, 1, 2, 15724.26), -- Oriharukon Ore
(21660, 2192, 1, 1, 2, 30084.2856), -- Recipe: Kite Shield
-- Otherworldly Invader Archer
(21661, 1901, 1, 1, -1, 189223), -- Tiger's Eye Earring Stone
(21661, 1875, 1, 1, -1, 91332), -- Stone of Purity
(21661, 1879, 1, 1, -1, 228329), -- Cokes
(21661, 57, 579, 1158, 0, 700000), -- Adena
(21661, 278, 1, 1, 1, 97.963868), -- Gastraphetes
(21661, 2029, 1, 1, 1, 4344.036132), -- Gastraphetes Shaft
(21661, 1875, 1, 1, 2, 8093.3412), -- Stone of Purity
(21661, 1879, 1, 1, 2, 20233.3856), -- Cokes
(21661, 1885, 1, 1, 2, 10116.6928), -- High-Grade Suede
(21661, 5550, 1, 1, 2, 1618.6552), -- Durable Metal Plate
(21661, 5549, 1, 1, 2, 12140.0444), -- Metallic Thread
(21661, 2154, 1, 1, 2, 12997.8808), -- Recipe: Elven Earring
-- Otherworldly Invader Elite Soldier
(21662, 1876, 1, 1, -1, 304870), -- Mithril Ore
(21662, 2026, 1, 1, -1, 18347), -- Two-Handed Sword Edge
(21662, 2191, 1, 1, -1, 204063), -- Recipe: RIP Gauntlets
(21662, 57, 644, 1285, 0, 700000), -- Adena
(21662, 849, 1, 1, 1, 820.320485), -- Tiger's Eye Earring
(21662, 1901, 1, 1, 1, 27985.785794), -- Tiger's Eye Earring Stone
(21662, 912, 1, 1, 1, 614.910887), -- Near Forest Necklace
(21662, 880, 1, 1, 1, 1227.982834), -- Black Pearl Ring
(21662, 1876, 1, 1, 2, 27016.076109), -- Mithril Ore
(21662, 1880, 1, 1, 2, 13508.094074), -- Steel
(21662, 1877, 1, 1, 2, 5403.192814), -- Adamantite Nugget
(21662, 1881, 1, 1, 2, 18010.717406), -- Coarse Bone Powder
(21662, 1882, 1, 1, 2, 30017.824997), -- Leather
(21662, 2193, 1, 1, 2, 18083.0946), -- Recipe: Boots of Power
-- Otherworldly Invader Shaman
(21663, 1938, 1, 1, -1, 100705), -- Mithril Banded Mail Material
(21663, 2154, 1, 1, -1, 160385), -- Recipe: Elven Earring
(21663, 1939, 1, 1, -1, 131576), -- Mithril Banded Gaiters Material
(21663, 57, 633, 1266, 0, 700000), -- Adena
(21663, 849, 1, 1, 1, 806.135035), -- Tiger's Eye Earring
(21663, 1901, 1, 1, 1, 27501.839614), -- Tiger's Eye Earring Stone
(21663, 912, 1, 1, 1, 604.277497), -- Near Forest Necklace
(21663, 880, 1, 1, 1, 1206.747854), -- Black Pearl Ring
(21663, 1874, 1, 1, 2, 8849.658333), -- Oriharukon Ore
(21663, 1878, 1, 1, 2, 53097.770895), -- Braided Hemp
(21663, 1884, 1, 1, 2, 81688.8783), -- Cord
(21663, 1889, 1, 1, 2, 8849.658333), -- Compound Braid
(21663, 5220, 1, 1, 2, 5309.866641), -- Metal Hardener
(21663, 2155, 1, 1, 2, 21307.167498), -- Recipe: Elven Ring
-- Otherworldly Invader Priest
(21664, 2153, 1, 1, -1, 127997), -- Recipe: Tiger's Eye Earring
(21664, 1933, 1, 1, -1, 96826), -- Dark Stockings Fabric
(21664, 2183, 1, 1, -1, 54146), -- Recipe: Mithril Banded Mail
(21664, 57, 347, 694, 0, 700000), -- Adena
(21664, 848, 1, 1, 1, 685.579742), -- Enchanted Earring
(21664, 911, 1, 1, 1, 514.569931), -- Enchanted Necklace
(21664, 1900, 1, 1, 1, 12301.341586), -- Enchanted Necklace Chain
(21664, 879, 1, 1, 1, 1031.508741), -- Enchanted Ring
(21664, 1869, 1, 1, 2, 89949.637161), -- Iron Ore
(21664, 1864, 1, 1, 2, 179899.274322), -- Stem
(21664, 1880, 1, 1, 2, 8995.047837), -- Steel
(21664, 5550, 1, 1, 2, 1199.283631), -- Durable Metal Plate
(21664, 955, 1, 1, 2, 359.757049), -- Scroll: Enchant Weapon (D-Grade)
-- Otherworldly Invader Magus
(21665, 2027, 1, 1, -1, 17685), -- Spiked Club Head
(21665, 2192, 1, 1, -1, 172191), -- Recipe: Kite Shield
(21665, 2028, 1, 1, -1, 16040), -- Shilen Knife Edge
(21665, 57, 570, 1138, 0, 700000), -- Adena
(21665, 436, 1, 1, 1, 613.463652), -- Tunic of Knowledge
(21665, 469, 1, 1, 1, 980.536348), -- Stockings of Knowledge
(21665, 1875, 1, 1, 2, 6835.916625), -- Stone of Purity
(21665, 1879, 1, 1, 2, 17089.984875), -- Cokes
(21665, 1885, 1, 1, 2, 8545.18575), -- High-Grade Suede
(21665, 5550, 1, 1, 2, 1367.106), -- Durable Metal Plate
(21665, 5549, 1, 1, 2, 10254.06825), -- Metallic Thread
(21665, 2269, 1, 1, 2, 732.26775), -- Recipe: Morning Star
(21665, 1341, 10, 30, 2, 341800.47075), -- Bone Arrow
-- Otherworldly Invader Martyrs
(21666, 1935, 1, 1, -1, 57679), -- Scale Mail Fragment
(21666, 955, 1, 1, -1, 4130), -- Scroll: Enchant Weapon (D-Grade)
(21666, 1872, 1, 3, -1, 688304), -- Animal Bone
(21666, 57, 436, 871, 0, 700000), -- Adena
(21666, 69, 1, 1, 1, 45.547201), -- Bastard Sword
(21666, 125, 1, 1, 1, 45.547201), -- Spinebone Sword
(21666, 2021, 1, 1, 1, 1424.807982), -- Spinebone Sword Blade
(21666, 126, 1, 1, 1, 45.547201), -- Artisan's Sword
(21666, 128, 1, 1, 1, 45.550415), -- Knight's Sword
(21666, 1872, 1, 1, 2, 150452.83595), -- Animal Bone
(21666, 1867, 1, 1, 2, 150452.83595), -- Animal Skin
(21666, 1881, 1, 1, 2, 15045.283595), -- Coarse Bone Powder
(21666, 1875, 1, 1, 2, 7522.805415), -- Stone of Purity
(21666, 956, 1, 1, 2, 3761.23909), -- Scroll: Enchant Armor (D-Grade)
-- Otherworldly Invader Warrior
(21667, 2155, 1, 1, -1, 194440), -- Recipe: Elven Ring
(21667, 1940, 1, 1, -1, 180800), -- Iron Boots Design
(21667, 1874, 1, 1, -1, 80757), -- Oriharukon Ore
(21667, 57, 512, 1024, 0, 700000), -- Adena
(21667, 628, 1, 1, 1, 1570.90251), -- Hoplon
(21667, 47, 1, 1, 1, 1099.09749), -- Helmet
(21667, 1874, 1, 1, 2, 7156.344832), -- Oriharukon Ore
(21667, 1878, 1, 1, 2, 42938.477568), -- Braided Hemp
(21667, 1884, 1, 1, 2, 66059.112448), -- Cord
(21667, 1889, 1, 1, 2, 7156.344832), -- Compound Braid
(21667, 5220, 1, 1, 2, 4293.861376), -- Metal Hardener
(21667, 2156, 1, 1, 2, 8587.858944), -- Recipe: Elven Necklace
-- Otherworldly Invader Soldier
(21668, 1864, 1, 5, -1, 724636), -- Stem
(21668, 1832, 1, 3, -1, 603864), -- Greater Antidote
(21668, 1936, 1, 1, -1, 88949), -- White Tunic Pattern
(21668, 57, 459, 917, 0, 700000), -- Adena
(21668, 348, 1, 1, 1, 289.749609), -- Scale Mail
(21668, 1935, 1, 1, 1, 8296.124238), -- Scale Mail Fragment
(21668, 377, 1, 1, 1, 463.333329), -- Scale Gaiters
(21668, 1937, 1, 1, 1, 12757.792824), -- Scale Gaiters Fragment
(21668, 1869, 1, 1, 2, 98996.537724), -- Iron Ore
(21668, 1864, 1, 1, 2, 197993.075448), -- Stem
(21668, 1880, 1, 1, 2, 9899.49065), -- Steel
(21668, 5550, 1, 1, 2, 1320.068022), -- Durable Metal Plate
(21668, 1829, 1, 1, 2, 39598.778212), -- Scroll of Escape: Clan Hall
(21668, 1061, 1, 1, 2, 59998.049944), -- Greater Healing Potion
-- Otherworldly Invader Discipline
(21669, 5550, 1, 1, -1, 17008), -- Durable Metal Plate
(21669, 2026, 1, 1, -1, 15353), -- Two-Handed Sword Edge
(21669, 2156, 1, 1, -1, 102046), -- Recipe: Elven Necklace
(21669, 57, 539, 1078, 0, 700000), -- Adena
(21669, 316, 1, 1, 1, 60.818808), -- Sage's Blood
(21669, 317, 1, 1, 1, 60.818808), -- Tome of Blood
(21669, 2030, 1, 1, 1, 2644.362384), -- Tome of Blood Page
(21669, 1869, 1, 1, 2, 113035.988166), -- Iron Ore
(21669, 1864, 1, 3, 2, 75357.45657), -- Stem
(21669, 1880, 1, 1, 2, 11303.71683), -- Steel
(21669, 5550, 1, 1, 2, 1507.031118), -- Durable Metal Plate
(21669, 2186, 1, 1, 2, 3780.36258), -- Recipe: Brigandine Tunic
(21669, 1341, 20, 60, 2, 188393.444736), -- Bone Arrow
-- Otherworldly Invader Berserker
(21670, 1878, 1, 1, -1, 601988), -- Braided Hemp
(21670, 1884, 1, 1, -1, 926136), -- Cord
(21670, 2029, 1, 1, -1, 17952), -- Gastraphetes Shaft
(21670, 57, 636, 1268, 0, 700000), -- Adena
(21670, 393, 1, 1, 1, 227.975928), -- Mithril Banded Mail
(21670, 1938, 1, 1, 1, 8965.486248), -- Mithril Banded Mail Material
(21670, 394, 1, 1, 1, 227.975928), -- Reinforced Leather Shirt
(21670, 415, 1, 1, 1, 364.385424), -- Mithril Banded Gaiters
(21670, 1939, 1, 1, 1, 11713.812912), -- Mithril Banded Gaiters Material
(21670, 416, 1, 1, 1, 364.36356), -- Reinforced Leather Gaiters
(21670, 1874, 1, 1, 2, 8890.914032), -- Oriharukon Ore
(21670, 1878, 1, 1, 2, 53345.324708), -- Braided Hemp
(21670, 1884, 1, 1, 2, 82069.828464), -- Cord
(21670, 1889, 1, 1, 2, 8890.914032), -- Compound Braid
(21670, 5220, 1, 1, 2, 5334.580316), -- Metal Hardener
(21670, 2270, 1, 1, 2, 952.438448), -- Recipe: Goat Head Staff
-- Otherworldly Invader Food
(21671, 2184, 1, 1, -1, 46479), -- Recipe: Mithril Banded Gaiters
(21671, 1937, 1, 1, -1, 38014), -- Scale Gaiters Fragment
(21671, 2185, 1, 1, -1, 87103), -- Recipe: Iron Boots
(21671, 57, 187, 373, 0, 700000), -- Adena
(21671, 1123, 1, 1, 1, 944.5), -- Blue Buckskin Boots
(21671, 605, 1, 1, 1, 944.5), -- Leather Gauntlets
(21671, 1876, 1, 1, 2, 6908.494544), -- Mithril Ore
(21671, 1880, 1, 1, 2, 3454.247272), -- Steel
(21671, 1877, 1, 1, 2, 1381.675136), -- Adamantite Nugget
(21671, 1881, 1, 1, 2, 4605.623408), -- Coarse Bone Powder
(21671, 1882, 1, 1, 2, 7676.058824), -- Leather
(21671, 1830, 1, 1, 2, 13816.929656), -- Scroll of Escape: Castle
(21671, 6667, 1, 1, 2, 21588.97116), -- Deluxe Chest Key - Grade 3
-- Otherworldly Invader Elite Soldier
(21672, 2193, 1, 1, -1, 424088), -- Recipe: Boots of Power
(21672, 2030, 1, 1, -1, 37052), -- Tome of Blood Page
(21672, 2269, 1, 1, -1, 22628), -- Recipe: Morning Star
(21672, 57, 1338, 2670, 0, 700000), -- Adena
(21672, 157, 1, 1, 1, 151.026668), -- Spiked Club
(21672, 2027, 1, 1, 1, 7354.946664), -- Spiked Club Head
(21672, 186, 1, 1, 1, 151.026668), -- Staff of Magic
(21672, 1864, 4, 12, 2, 70182.020871), -- Stem
(21672, 1865, 2, 6, 2, 56145.43311), -- Varnish
(21672, 1866, 3, 9, 2, 31191.856287), -- Suede
(21672, 1873, 1, 1, 2, 112290.86622), -- Silver Nugget
(21672, 1868, 1, 3, 2, 187151.596689), -- Thread
(21672, 2271, 1, 1, 2, 2005.226823), -- Recipe: Winged Spear
-- Otherworldly Invader Elite Soldier
(21673, 1901, 1, 1, -1, 445848), -- Tiger's Eye Earring Stone
(21673, 1889, 1, 1, -1, 215196), -- Compound Braid
(21673, 5220, 1, 1, -1, 129118), -- Metal Hardener
(21673, 57, 1363, 2720, 0, 700000), -- Adena
(21673, 393, 1, 1, 1, 488.963738), -- Mithril Banded Mail
(21673, 1938, 1, 1, 1, 19229.212958), -- Mithril Banded Mail Material
(21673, 394, 1, 1, 1, 488.963738), -- Reinforced Leather Shirt
(21673, 415, 1, 1, 1, 781.535404), -- Mithril Banded Gaiters
(21673, 1939, 1, 1, 1, 25123.835652), -- Mithril Banded Gaiters Material
(21673, 416, 1, 1, 1, 781.48851), -- Reinforced Leather Gaiters
(21673, 1874, 1, 1, 2, 19069.662612), -- Oriharukon Ore
(21673, 1878, 1, 1, 2, 114417.633603), -- Braided Hemp
(21673, 1884, 1, 1, 2, 176027.339124), -- Cord
(21673, 1889, 1, 1, 2, 19069.662612), -- Compound Braid
(21673, 5220, 1, 1, 2, 11441.865981), -- Metal Hardener
(21673, 2272, 1, 1, 2, 2042.836068), -- Recipe: Sword of Revolution
-- Otherworldly Invader Elite Soldier
(21674, 1938, 1, 1, -1, 8463), -- Mithril Banded Mail Material
(21674, 2270, 1, 1, -1, 899), -- Recipe: Goat Head Staff
(21674, 1939, 1, 1, -1, 11057), -- Mithril Banded Gaiters Material
(21674, 57, 53, 106, 0, 700000), -- Adena
(21674, 260, 1, 1, 1, 18), -- Triple-Edged Jamadhr
(21674, 1875, 1, 1, 2, 637.3666), -- Stone of Purity
(21674, 1879, 1, 1, 2, 1593.420998), -- Cokes
(21674, 1885, 1, 1, 2, 796.712748), -- High-Grade Suede
(21674, 5550, 1, 1, 2, 127.47332), -- Durable Metal Plate
(21674, 5549, 1, 1, 2, 956.054398), -- Metallic Thread
(21674, 2273, 1, 1, 2, 68.288636), -- Recipe: Tarbar
(21674, 6036, 1, 1, 2, 318.6833), -- Greater Magic Haste Potion
-- Otherworldly Invader Elite Soldier
(21675, 2021, 1, 1, -1, 3319), -- Spinebone Sword Blade
(21675, 956, 1, 1, -1, 8761), -- Scroll: Enchant Armor (D-Grade)
(21675, 1880, 1, 1, -1, 26283), -- Steel
(21675, 57, 111, 222, 0, 700000), -- Adena
(21675, 292, 1, 1, 1, 58), -- Pike
(21675, 1869, 1, 1, 2, 28725.7002), -- Iron Ore
(21675, 1864, 1, 1, 2, 57451.3065), -- Stem
(21675, 1880, 1, 1, 2, 2872.5888), -- Steel
(21675, 5550, 1, 1, 2, 383.0181), -- Durable Metal Plate
(21675, 2153, 1, 1, 2, 4467.3864), -- Recipe: Tiger's Eye Earring
-- Otherworldly Invader Warrior
(21676, 1865, 1, 7, -1, 726143), -- Varnish
(21676, 1870, 1, 7, -1, 726143), -- Coal
(21676, 2029, 1, 1, -1, 34646), -- Gastraphetes Shaft
(21676, 57, 1227, 2454, 0, 700000), -- Adena
(21676, 849, 1, 1, 1, 1563.102765), -- Tiger's Eye Earring
(21676, 1901, 1, 1, 1, 53326.303506), -- Tiger's Eye Earring Stone
(21676, 912, 1, 1, 1, 1171.699263), -- Near Forest Necklace
(21676, 880, 1, 1, 1, 2339.894466), -- Black Pearl Ring
(21676, 1865, 1, 3, 2, 154434.072451), -- Varnish
(21676, 1870, 1, 3, 2, 102955.931127), -- Coal
(21676, 1879, 1, 1, 2, 51478.141324), -- Cokes
(21676, 1875, 1, 1, 2, 20591.045617), -- Stone of Purity
(21676, 2188, 1, 1, 2, 22061.809481), -- Recipe: Manticore Skin Gaiters
-- Otherworldly Invader Elite Soldier
(21677, 6667, 1, 3, -1, 738208), -- Deluxe Chest Key - Grade 3
(21677, 2250, 1, 1, -1, 590566), -- Recipe: Bone Arrow
(21677, 1900, 1, 1, -1, 258453), -- Enchanted Necklace Chain
(21677, 57, 996, 1993, 0, 700000), -- Adena
(21677, 6667, 3, 9, 1, 425208), -- Deluxe Chest Key - Grade 3
-- Otherworldly Invader Elite Soldier
(21678, 6667, 1, 3, -1, 880592), -- Deluxe Chest Key - Grade 3
(21678, 2154, 1, 1, -1, 301702), -- Recipe: Elven Earring
(21678, 1901, 1, 1, -1, 389212), -- Tiger's Eye Earring Stone
(21678, 57, 1191, 2381, 0, 700000), -- Adena
(21678, 6667, 12, 36, 1, 125721), -- Deluxe Chest Key - Grade 3
-- Otherworldly Invader Elite Soldier
(21679, 956, 1, 1, -1, 77629), -- Scroll: Enchant Armor (D-Grade)
(21679, 955, 1, 1, -1, 9315), -- Scroll: Enchant Weapon (D-Grade)
(21679, 6387, 1, 1, -1, 93155), -- Blessed Scroll of Resurrection for Pets
(21679, 57, 982, 1965, 0, 700000), -- Adena
(21679, 1123, 1, 1, 1, 4971), -- Blue Buckskin Boots
(21679, 605, 1, 1, 1, 4971), -- Leather Gauntlets
(21679, 956, 1, 1, 2, 21210.710892), -- Scroll: Enchant Armor (D-Grade)
(21679, 955, 1, 1, 2, 2545.289108), -- Scroll: Enchant Weapon (D-Grade)
-- Otherworldly Invader Elite Soldier
(21680, 1938, 1, 1, -1, 208130), -- Mithril Banded Mail Material
(21680, 1901, 1, 1, -1, 427616), -- Tiger's Eye Earring Stone
(21680, 2154, 1, 1, -1, 331471), -- Recipe: Elven Earring
(21680, 57, 1308, 2609, 0, 700000), -- Adena
(21680, 316, 1, 1, 1, 147.605444), -- Sage's Blood
(21680, 317, 1, 1, 1, 147.605444), -- Tome of Blood
(21680, 2030, 1, 1, 1, 6417.789112), -- Tome of Blood Page
(21680, 956, 1, 1, 2, 27434.817039), -- Scroll: Enchant Armor (D-Grade)
(21680, 955, 1, 1, 2, 3292.182961), -- Scroll: Enchant Weapon (D-Grade)
-- Otherworldly Invader Magus
(21681, 2155, 1, 1, -1, 431241), -- Recipe: Elven Ring
(21681, 1939, 1, 1, -1, 235980), -- Mithril Banded Gaiters Material
(21681, 2156, 1, 1, -1, 214931), -- Recipe: Elven Necklace
(21681, 57, 1135, 2270, 0, 700000), -- Adena
(21681, 628, 1, 1, 1, 3484.226466), -- Hoplon
(21681, 47, 1, 1, 1, 2437.773534), -- Helmet
(21681, 956, 1, 1, 2, 23808.031905), -- Scroll: Enchant Armor (D-Grade)
(21681, 955, 1, 1, 2, 2856.968095), -- Scroll: Enchant Weapon (D-Grade)
-- Dimension Invader Soldier
(21682, 6036, 1, 1, -1, 73165), -- Greater Magic Haste Potion
(21682, 1944, 1, 1, -1, 111959), -- Mithril Tunic Fabric
(21682, 2148, 1, 1, -1, 156783), -- Recipe: Crafted Leather
(21682, 57, 916, 1829, 0, 700000), -- Adena
(21682, 437, 1, 1, 1, 329.830615), -- Mithril Tunic
(21682, 1944, 1, 1, 1, 14468.40813), -- Mithril Tunic Fabric
(21682, 470, 1, 1, 1, 526.752325), -- Mithril Stockings
(21682, 1945, 1, 1, 1, 22530.00893), -- Mithril Stocking Design
(21682, 1867, 1, 3, 2, 151283.147256), -- Animal Skin
(21682, 1872, 1, 3, 2, 100855.431504), -- Animal Bone
(21682, 1882, 1, 1, 2, 50427.715752), -- Leather
(21682, 1894, 1, 1, 2, 7962.392223), -- Crafted Leather
(21682, 2157, 1, 1, 2, 18754.313265), -- Recipe: Omen Beast's Eye Earring
-- Dimension Invader Soldier
(21683, 1910, 1, 1, -1, 222740), -- Aquastone Necklace Chain
(21683, 2164, 1, 1, -1, 227537), -- Recipe: Ring of Protection
(21683, 1954, 1, 1, -1, 157256), -- Karmian Stocking Design
(21683, 57, 1170, 2376, 0, 700000), -- Adena
(21683, 263, 1, 1, 1, 79.29713), -- Chakram
(21683, 2073, 1, 1, 1, 5402.70287), -- Chakram Edge
(21683, 1873, 1, 1, 2, 55919.671785), -- Silver Nugget
(21683, 1868, 1, 1, 2, 279597.522399), -- Thread
(21683, 1876, 1, 1, 2, 27959.626761), -- Mithril Ore
(21683, 1895, 1, 1, 2, 39942.443448), -- Metallic Fiber
(21683, 4042, 1, 1, 2, 2330.143173), -- Enria
(21683, 2165, 1, 1, 2, 5356.275978), -- Recipe: Necklace of Protection
(21683, 8723, 1, 1, 2, 5591.758047), -- Life Stone - Level 46
(21683, 8733, 1, 1, 2, 1397.834946), -- Mid-Grade Life Stone - Level 46
(21683, 8743, 1, 1, 2, 139.699842), -- High-Grade Life Stone - Level 46
(21683, 8753, 1, 1, 2, 28.023621), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Archer
(21684, 1906, 1, 1, -1, 319295), -- Mithril Ring Wire
(21684, 2160, 1, 1, -1, 149862), -- Recipe: Moonstone Earring
(21684, 1907, 1, 1, -1, 161591), -- Necklace of Darkness Gem
(21684, 57, 919, 1865, 0, 700000), -- Adena
(21684, 353, 1, 1, 1, 193.89057), -- Half Plate Armor
(21684, 1950, 1, 1, 1, 9465.08433), -- Half Plate Temper
(21684, 380, 1, 1, 1, 310.22985), -- Plate Gaiters
(21684, 1951, 1, 1, 1, 14720.79525), -- Plate Gaiters Part
(21684, 1872, 1, 3, 2, 155525.042959), -- Animal Bone
(21684, 1867, 1, 3, 2, 103683.468945), -- Animal Skin
(21684, 1881, 1, 1, 2, 31104.880225), -- Coarse Bone Powder
(21684, 1875, 1, 1, 2, 15552.600571), -- Stone of Purity
(21684, 2160, 1, 1, 2, 15051.0073), -- Recipe: Moonstone Earring
-- Dimension Invader Elite Soldier
(21685, 2165, 1, 1, -1, 97361), -- Recipe: Necklace of Protection
(21685, 1958, 1, 1, -1, 228416), -- Reinforced Mithril Boots Design
(21685, 1873, 1, 3, -1, 508225), -- Silver Nugget
(21685, 57, 1005, 2042, 0, 700000), -- Adena
(21685, 439, 1, 1, 1, 206.349728), -- Karmian Tunic
(21685, 1962, 1, 1, 1, 9608.237531), -- Karmian Tunic Pattern
(21685, 471, 1, 1, 1, 329.783624), -- Karmian Stockings
(21685, 1954, 1, 1, 1, 15962.629117), -- Karmian Stocking Design
(21685, 1868, 1, 1, 2, 240194.805461), -- Thread
(21685, 1873, 1, 1, 2, 48039.089199), -- Silver Nugget
(21685, 5549, 1, 1, 2, 12009.692233), -- Metallic Thread
(21685, 1889, 1, 1, 2, 8006.354733), -- Compound Braid
(21685, 4044, 1, 1, 2, 4003.3375), -- Thons
(21685, 2213, 1, 1, 2, 1864.914741), -- Recipe: Dwarven Chain Mail Shirt
(21685, 8723, 1, 1, 2, 4804.005), -- Life Stone - Level 46
(21685, 8733, 1, 1, 2, 1201.00125), -- Mid-Grade Life Stone - Level 46
(21685, 8743, 1, 1, 2, 120.100125), -- High-Grade Life Stone - Level 46
(21685, 8753, 1, 1, 2, 23.699758), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Shaman
(21686, 1864, 1, 11, -1, 846642), -- Stem
(21686, 1869, 1, 5, -1, 846642), -- Iron Ore
(21686, 4470, 1, 1, -1, 14514), -- Dye of STR (Str+1 Dex-1)
(21686, 57, 1004, 2040, 0, 700000), -- Adena
(21686, 280, 1, 1, 1, 91.952059), -- Light Crossbow
(21686, 2054, 1, 1, 1, 5427.047941), -- Light Crossbow Shaft
(21686, 1864, 3, 9, 2, 85029.025977), -- Stem
(21686, 1869, 2, 6, 2, 63772.093917), -- Iron Ore
(21686, 1878, 1, 1, 2, 102035.004204), -- Braided Hemp
(21686, 1884, 1, 1, 2, 156976.862994), -- Cord
(21686, 2161, 1, 1, 2, 24766.012908), -- Recipe: Aquastone Ring
-- Dimension Invader Priest
(21687, 1945, 1, 1, -1, 112828), -- Mithril Stocking Design
(21687, 2149, 1, 1, -1, 101464), -- Recipe: Metallic Fiber
(21687, 1946, 1, 1, -1, 191960), -- Rip Gauntlets Pattern
(21687, 57, 593, 1184, 0, 700000), -- Adena
(21687, 1124, 1, 1, 1, 159.905806), -- Boots of Power
(21687, 1948, 1, 1, 1, 6201.719194), -- Boots of Power Pattern
(21687, 2424, 1, 1, 1, 159.905806), -- Manticore Skin Boots
(21687, 2923, 1, 1, 1, 6201.719194), -- Manticore Skin Boot Lining
(21687, 2425, 1, 1, 1, 159.905806), -- Brigandine Boots
(21687, 2924, 1, 1, 1, 6201.719194), -- Brigandine Boots Design
(21687, 2426, 1, 1, 1, 159.905806), -- Elven Mithril Boots
(21687, 2925, 1, 1, 1, 6201.719194), -- Elven Mithril Boots Design
(21687, 606, 1, 1, 1, 159.905806), -- Rip Gauntlets
(21687, 1946, 1, 1, 1, 6201.719194), -- Rip Gauntlets Pattern
(21687, 2448, 1, 1, 1, 159.905806), -- Manticore Skin Gloves
(21687, 2926, 1, 1, 1, 6201.719194), -- Manticore Skin Gloves Lining
(21687, 2449, 1, 1, 1, 159.905806), -- Brigandine Gauntlets
(21687, 2927, 1, 1, 1, 6201.719194), -- Brigandine Gauntlets Pattern
(21687, 2450, 1, 1, 1, 159.905806), -- Mithril Gloves
(21687, 2928, 1, 1, 1, 6201.719194), -- Mithril Gloves Design
(21687, 1872, 1, 1, 2, 163175.610456), -- Animal Bone
(21687, 1867, 1, 1, 2, 163175.610456), -- Animal Skin
(21687, 1881, 1, 1, 2, 16317.487035), -- Coarse Bone Powder
(21687, 1875, 1, 1, 2, 8158.928544), -- Stone of Purity
(21687, 2158, 1, 1, 2, 15146.26929), -- Recipe: Mithril Ring
(21687, 6036, 1, 1, 2, 4079.094219), -- Greater Magic Haste Potion
-- Dimension Invader Magus
(21688, 4042, 1, 1, -1, 37507), -- Enria
(21688, 1959, 1, 1, -1, 60618), -- Chain Mail Shirt Material
(21688, 1908, 1, 1, -1, 213109), -- Moonstone Earring Wire
(21688, 57, 890, 1808, 0, 700000), -- Adena
(21688, 281, 1, 1, 1, 60.332655), -- Crystallized Ice Bow
(21688, 2074, 1, 1, 1, 3766.667345), -- Crystallized Ice Bow Shaft
(21688, 1873, 1, 1, 2, 42543.602178), -- Silver Nugget
(21688, 1868, 1, 1, 2, 212717.377334), -- Thread
(21688, 1876, 1, 1, 2, 21271.6427), -- Mithril Ore
(21688, 1895, 1, 1, 2, 30388.196762), -- Metallic Fiber
(21688, 4042, 1, 1, 2, 1772.689688), -- Enria
(21688, 2214, 1, 1, 2, 2639.077518), -- Recipe: Dwarven Chain Gaiters
(21688, 8723, 1, 1, 2, 4254.32854), -- Life Stone - Level 46
(21688, 8733, 1, 1, 2, 1063.740524), -- Mid-Grade Life Stone - Level 46
(21688, 8743, 1, 1, 2, 106.437408), -- High-Grade Life Stone - Level 46
(21688, 8753, 1, 1, 2, 20.907348), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Martyrs
(21689, 1867, 1, 5, -1, 791992), -- Animal Skin
(21689, 1872, 1, 5, -1, 791992), -- Animal Bone
(21689, 6036, 1, 1, -1, 59399), -- Greater Magic Haste Potion
(21689, 57, 744, 1485, 0, 700000), -- Adena
(21689, 352, 1, 1, 1, 133.671476), -- Brigandine Tunic
(21689, 1941, 1, 1, 1, 6105.317763), -- Brigandine Temper
(21689, 2377, 1, 1, 1, 213.819619), -- Mithril Scale Gaiters
(21689, 2918, 1, 1, 1, 9108.198203), -- Mithril Scale Gaiters Material
(21689, 2378, 1, 1, 1, 213.819619), -- Brigandine Gaiters
(21689, 2919, 1, 1, 1, 9108.17332), -- Brigandine Gaiters Material
(21689, 1867, 1, 3, 2, 122819.6691), -- Animal Skin
(21689, 1872, 1, 1, 2, 245639.765436), -- Animal Bone
(21689, 1882, 1, 1, 2, 40939.8897), -- Leather
(21689, 1894, 1, 1, 2, 6464.08068), -- Crafted Leather
(21689, 2159, 1, 1, 2, 11372.595084), -- Recipe: Necklace of Darkness
-- Dimension Invader Warrior
(21690, 1949, 1, 1, -1, 229233), -- Mithril Gloves Design
(21690, 2161, 1, 1, -1, 199410), -- Recipe: Aquastone Ring
(21690, 1950, 1, 1, -1, 66664), -- Half Plate Temper
(21690, 57, 812, 1649, 0, 700000), -- Adena
(21690, 1125, 1, 1, 1, 228.58947), -- Assault Boots
(21690, 1957, 1, 1, 1, 9593.03791), -- Assault Boots Part
(21690, 2427, 1, 1, 1, 228.58947), -- Salamander Skin Boots
(21690, 2931, 1, 1, 1, 9593.03791), -- Salamander Skin Boot Lining
(21690, 2428, 1, 1, 1, 228.58947), -- Plate Boots
(21690, 2932, 1, 1, 1, 9593.03791), -- Plate Boots Design
(21690, 61, 1, 1, 1, 228.58947), -- Mithril Plate Gloves
(21690, 1949, 1, 1, 1, 9593.03791), -- Mithril Gloves Design
(21690, 607, 1, 1, 1, 228.58947), -- Ogre Power Gauntlets
(21690, 1963, 1, 1, 1, 9593.03791), -- Ogre Power Gauntlets Part
(21690, 2451, 1, 1, 1, 228.58947), -- Sage's Worn Gloves
(21690, 2933, 1, 1, 1, 9593.27363), -- Sage's Worn Gloves Lining
(21690, 1868, 1, 3, 2, 206277.286132), -- Thread
(21690, 1873, 1, 1, 2, 82511.047706), -- Silver Nugget
(21690, 5549, 1, 1, 2, 20627.59536), -- Metallic Thread
(21690, 1889, 1, 1, 2, 13751.73024), -- Compound Braid
(21690, 2162, 1, 1, 2, 9965.340562), -- Recipe: Aquastone Necklace
-- Dimension Invader Soldier
(21691, 1947, 1, 1, -1, 270129), -- Kite Shield Fragment
(21691, 2157, 1, 1, -1, 155045), -- Recipe: Omen Beast's Eye Earring
(21691, 1948, 1, 1, -1, 253520), -- Boots of Power Pattern
(21691, 57, 783, 1563, 0, 700000), -- Adena
(21691, 279, 1, 1, 1, 90.288), -- Reinforced Long Bow
(21691, 2040, 1, 1, 1, 5609.712), -- Reinforced Long Bow Shaft
(21691, 1865, 1, 1, 2, 193954.314364), -- Varnish
(21691, 1870, 1, 1, 2, 193954.314364), -- Coal
(21691, 1879, 1, 1, 2, 32325.79456), -- Cokes
(21691, 1875, 1, 1, 2, 12930.317824), -- Stone of Purity
(21691, 2194, 1, 1, 2, 19831.258888), -- Recipe: Mithril Gloves
-- Dimension Invader Discipline
(21692, 2162, 1, 1, -1, 104484), -- Recipe: Aquastone Necklace
(21692, 1951, 1, 1, -1, 109178), -- Plate Gaiters Part
(21692, 1866, 1, 3, -1, 720938), -- Suede
(21692, 57, 855, 1737, 0, 700000), -- Adena
(21692, 159, 1, 1, 1, 15.659924), -- Bonebreaker
(21692, 2048, 1, 1, 1, 897.876168), -- Bonebreaker Head
(21692, 187, 1, 1, 1, 15.659924), -- Atuba Hammer
(21692, 2049, 1, 1, 1, 897.876168), -- Atuba Hammer Head
(21692, 188, 1, 1, 1, 15.659924), -- Ghost Staff
(21692, 2050, 1, 1, 1, 952.038276), -- Ghost Staff Head
(21692, 189, 1, 1, 1, 15.659924), -- Staff of Life
(21692, 2051, 1, 1, 1, 952.038276), -- Staff of Life Shaft
(21692, 190, 1, 1, 1, 15.659924), -- Atuba Mace
(21692, 2058, 1, 1, 1, 897.871492), -- Atuba Mace Head
(21692, 1866, 1, 1, 2, 144808.707174), -- Suede
(21692, 1871, 1, 1, 2, 217213.458738), -- Charcoal
(21692, 5220, 1, 1, 2, 8688.633864), -- Metal Hardener
(21692, 1885, 1, 1, 2, 18101.187891), -- High-Grade Suede
(21692, 2199, 1, 1, 2, 9165.012333), -- Recipe: Karmian Stockings
-- Dimension Invader Berserker 
(21693, 2213, 1, 1, -1, 38957), -- Recipe: Dwarven Chain Mail Shirt
(21693, 1960, 1, 1, -1, 137469), -- Chain Gaiters Part
(21693, 2214, 1, 1, -1, 62254), -- Recipe: Dwarven Chain Gaiters
(21693, 57, 992, 2016, 0, 700000), -- Adena
(21693, 631, 1, 1, 1, 387.48576), -- Eldarake
(21693, 1964, 1, 1, 1, 15968.259678), -- Eldarake Temper
(21693, 2495, 1, 1, 1, 387.48576), -- Chain Shield
(21693, 2945, 1, 1, 1, 15968.259678), -- Chain Shield Fragment
(21693, 2413, 1, 1, 1, 271.240032), -- Chain Hood
(21693, 2936, 1, 1, 1, 14503.269092), -- Chain Hood Pattern
(21693, 1873, 1, 1, 2, 47428.251993), -- Silver Nugget
(21693, 1868, 1, 1, 2, 237141.611684), -- Thread
(21693, 1876, 1, 1, 2, 23714.301856), -- Mithril Ore
(21693, 1895, 1, 1, 2, 33877.222361), -- Metallic Fiber
(21693, 4042, 1, 1, 2, 1976.309061), -- Enria
(21693, 2215, 1, 1, 2, 1510.281386), -- Recipe: Robe of Seal
(21693, 8723, 1, 1, 2, 4742.930715), -- Life Stone - Level 46
(21693, 8733, 1, 1, 2, 1185.644749), -- Mid-Grade Life Stone - Level 46
(21693, 8743, 1, 1, 2, 118.529303), -- High-Grade Life Stone - Level 46
(21693, 8753, 1, 1, 2, 23.916892), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Food
(21694, 2158, 1, 1, -1, 94518), -- Recipe: Mithril Ring
(21694, 2031, 1, 1, -1, 7731), -- Morning Star Head
(21694, 1895, 1, 1, -1, 218202), -- Metallic Fiber
(21694, 57, 319, 636, 0, 700000), -- Adena
(21694, 88, 1, 1, 1, 7.352), -- Morning Star
(21694, 2031, 1, 1, 1, 399.614), -- Morning Star Head
(21694, 90, 1, 1, 1, 7.352), -- Goat Head Staff
(21694, 2032, 1, 1, 1, 364.79), -- Goat Head Staff Head
(21694, 158, 1, 1, 1, 7.352), -- Tarbar
(21694, 2035, 1, 1, 1, 399.614), -- Tarbar Head
(21694, 169, 1, 1, 1, 7.352), -- Skull Breaker
(21694, 2036, 1, 1, 1, 399.614), -- Skull Breaker Head
(21694, 172, 1, 1, 1, 7.352), -- Heavy Bone Club
(21694, 2037, 1, 1, 1, 399.608), -- Heavy Bone Club Head
(21694, 1895, 1, 1, 2, 28198.35246), -- Metallic Fiber
(21694, 2195, 1, 1, 2, 2524.15536), -- Recipe: Half Plate Armor
(21694, 5473, 1, 1, 2, 7049.56986), -- Recipe: Durable Metal Plate(100%)
(21694, 6668, 1, 1, 2, 35247.92232), -- Deluxe Chest Key - Grade 4
-- Dimension Invader Elite Soldier
(21695, 1961, 1, 1, -1, 168993), -- Mithril Shirt Fabric
(21695, 4041, 1, 1, -1, 45922), -- Mold Hardener
(21695, 1872, 1, 15, -1, 880170), -- Animal Bone
(21695, 57, 2089, 4243, 0, 700000), -- Adena
(21695, 96, 1, 1, 1, 47.192537), -- Scythe
(21695, 2062, 1, 1, 1, 3262.47082), -- Scythe Edge
(21695, 298, 1, 1, 1, 47.192537), -- Orcish Glaive
(21695, 2075, 1, 1, 1, 3262.47082), -- Orcish Glaive Blade
(21695, 302, 1, 1, 1, 47.192537), -- Body Slasher
(21695, 2076, 1, 1, 1, 3262.480749), -- Body Slasher Blade
(21695, 1872, 1, 3, 2, 166392.457034), -- Animal Bone
(21695, 1867, 1, 3, 2, 110928.187189), -- Animal Skin
(21695, 1881, 1, 1, 2, 33278.561907), -- Coarse Bone Powder
(21695, 1875, 1, 1, 2, 16639.104703), -- Stone of Purity
(21695, 4041, 1, 1, 2, 2170.348657), -- Mold Hardener
(21695, 2216, 1, 1, 2, 10313.474258), -- Recipe: Great Helmet
(21695, 8723, 1, 1, 2, 9983.533322), -- Life Stone - Level 46
(21695, 8733, 1, 1, 2, 2496.059581), -- Mid-Grade Life Stone - Level 46
(21695, 8743, 1, 1, 2, 249.570708), -- High-Grade Life Stone - Level 46
(21695, 8753, 1, 1, 2, 49.702641), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Elite Soldier
(21696, 1962, 1, 1, -1, 172193), -- Karmian Tunic Pattern
(21696, 2215, 1, 1, -1, 68548), -- Recipe: Robe of Seal
(21696, 1894, 1, 1, -1, 188808), -- Crafted Leather
(21696, 57, 2128, 4323, 0, 700000), -- Adena
(21696, 281, 1, 1, 1, 144.265515), -- Crystallized Ice Bow
(21696, 2074, 1, 1, 1, 9006.734485), -- Crystallized Ice Bow Shaft
(21696, 1894, 1, 1, 2, 9914.792608), -- Crafted Leather
(21696, 4039, 1, 1, 2, 9419.040498), -- Mold Glue
(21696, 4041, 1, 1, 2, 2457.170842), -- Mold Hardener
(21696, 4044, 1, 1, 2, 9419.040498), -- Thons
(21696, 2217, 1, 1, 2, 16720.230478), -- Recipe: Knight's Shield
(21696, 8723, 1, 1, 2, 11302.898516), -- Life Stone - Level 46
(21696, 8733, 1, 1, 2, 2825.69343), -- Mid-Grade Life Stone - Level 46
(21696, 8743, 1, 1, 2, 282.600542), -- High-Grade Life Stone - Level 46
(21696, 8753, 1, 1, 2, 56.532588), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Elite Soldier
(21697, 1964, 1, 1, -1, 16957), -- Eldarake Temper
(21697, 2216, 1, 1, -1, 8671), -- Recipe: Great Helmet
(21697, 2059, 1, 1, -1, 1559), -- Flamberge Blade
(21697, 57, 83, 169, 0, 700000), -- Adena
(21697, 263, 1, 1, 1, 5.626885), -- Chakram
(21697, 2073, 1, 1, 1, 383.373115), -- Chakram Edge
(21697, 1864, 1, 1, 2, 19835.043195), -- Stem
(21697, 1869, 1, 1, 2, 9917.500959), -- Iron Ore
(21697, 1878, 1, 1, 2, 3967.008639), -- Braided Hemp
(21697, 1884, 1, 1, 2, 6103.093389), -- Cord
(21697, 4039, 1, 1, 2, 330.587493), -- Mold Glue
(21697, 2219, 1, 1, 2, 615.976671), -- Recipe: Crimson Boots
(21697, 8723, 1, 1, 2, 396.713247), -- Life Stone - Level 46
(21697, 8733, 1, 1, 2, 99.188631), -- Mid-Grade Life Stone - Level 46
(21697, 8743, 1, 1, 2, 9.90648), -- High-Grade Life Stone - Level 46
(21697, 8753, 1, 1, 2, 1.981296), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Elite Soldier
(21698, 1871, 1, 1, -1, 453642), -- Charcoal
(21698, 6036, 1, 1, -1, 15121), -- Greater Magic Haste Potion
(21698, 2032, 1, 1, -1, 4192), -- Goat Head Staff Head
(21698, 57, 189, 378, 0, 700000), -- Adena
(21698, 395, 1, 1, 1, 68.170512), -- Manticore Skin Shirt
(21698, 1942, 1, 1, 1, 2990.379744), -- Manticore Skin Shirt Texture
(21698, 417, 1, 1, 1, 108.87096), -- Manticore Skin Gaiters
(21698, 1943, 1, 1, 1, 4656.578784), -- Manticore Skin Gaiters Pattern
(21698, 1871, 1, 1, 2, 46899.512352), -- Charcoal
(21698, 1866, 1, 1, 2, 31266.341568), -- Suede
(21698, 1877, 1, 1, 2, 1875.866112), -- Adamantite Nugget
(21698, 2196, 1, 1, 2, 1922.095536), -- Recipe: Plate Gaiters
(21698, 1341, 10, 30, 2, 156332.184432), -- Bone Arrow
-- Dimension Invader Warrior
(21699, 2199, 1, 1, -1, 207800), -- Recipe: Karmian Stockings
(21699, 1953, 1, 1, -1, 157747), -- Sage's Rag Lining
(21699, 2203, 1, 3, -1, 536477), -- Recipe: Reinforced Mithril Boots
(21699, 57, 1947, 3955, 0, 700000), -- Adena
(21699, 70, 1, 1, 1, 89.149925), -- Claymore
(21699, 2047, 1, 1, 1, 5435.116325), -- Claymore Blade
(21699, 2499, 1, 1, 1, 89.149925), -- Elven Long Sword
(21699, 2967, 1, 1, 1, 5361.583825), -- Elven Long Sword Blade
(21699, 1869, 1, 3, 2, 164869.335895), -- Iron Ore
(21699, 1864, 4, 12, 2, 123652.090514), -- Stem
(21699, 1880, 1, 1, 2, 49460.623583), -- Steel
(21699, 5550, 1, 1, 2, 6594.84431), -- Durable Metal Plate
(21699, 2204, 1, 1, 2, 9794.105698), -- Recipe: Chain Mail Shirt
-- Dimension Invader Elite Soldier
(21700, 6668, 1, 3, -1, 728069), -- Deluxe Chest Key - Grade 4
(21700, 6036, 1, 1, -1, 135906), -- Greater Magic Haste Potion
(21700, 1902, 1, 1, -1, 413089), -- Elven Earring Beads
(21700, 57, 1702, 3397, 0, 700000), -- Adena
(21700, 6668, 3, 9, 1, 412199), -- Deluxe Chest Key - Grade 4
-- Dimension Invader Elite Soldier
(21701, 6668, 1, 3, -1, 853195), -- Deluxe Chest Key - Grade 4
(21701, 1905, 1, 1, -1, 464775), -- Omen Beast's Eye Earring Gemstone
(21701, 2160, 1, 1, -1, 308251), -- Recipe: Moonstone Earring
(21701, 57, 1889, 3837, 0, 700000), -- Adena
(21701, 6668, 3, 9, 1, 478839), -- Deluxe Chest Key - Grade 4
-- Dimension Invader Elite Soldier
(21702, 1902, 1, 1, -1, 407248), -- Elven Earring Beads
(21702, 2157, 1, 1, -1, 332193), -- Recipe: Omen Beast's Eye Earring
(21702, 1903, 1, 1, -1, 670482), -- Elven Ring Piece
(21702, 57, 1678, 3349, 0, 700000), -- Adena
(21702, 395, 1, 1, 1, 604.011299), -- Manticore Skin Shirt
(21702, 1942, 1, 1, 1, 26495.666538), -- Manticore Skin Shirt Texture
(21702, 417, 1, 1, 1, 964.629545), -- Manticore Skin Gaiters
(21702, 1943, 1, 1, 1, 41258.692618), -- Manticore Skin Gaiters Pattern
(21702, 952, 1, 1, 2, 13852.08), -- Scroll: Enchant Armor (C-Grade)
(21702, 951, 1, 1, 2, 1888.92), -- Scroll: Enchant Weapon (C-Grade)
-- Dimension Invader Elite Soldier
(21703, 951, 1, 1, -1, 9384), -- Scroll: Enchant Weapon (C-Grade)
(21703, 952, 1, 1, -1, 68813), -- Scroll: Enchant Armor (C-Grade)
(21703, 2163, 1, 1, -1, 263316), -- Recipe: Earring of Protection
(21703, 57, 2041, 4146, 0, 700000), -- Adena
(21703, 631, 1, 1, 1, 797.1096), -- Eldarake
(21703, 1964, 1, 1, 1, 32848.828005), -- Eldarake Temper
(21703, 2495, 1, 1, 1, 797.1096), -- Chain Shield
(21703, 2945, 1, 1, 1, 32848.828005), -- Chain Shield Fragment
(21703, 2413, 1, 1, 1, 557.97672), -- Chain Hood
(21703, 2936, 1, 1, 1, 29835.14807), -- Chain Hood Pattern
(21703, 951, 1, 1, 2, 739.141548), -- Scroll: Enchant Weapon (C-Grade)
(21703, 952, 1, 1, 2, 5420.4253), -- Scroll: Enchant Armor (C-Grade)
(21703, 8723, 1, 1, 2, 16261.2759), -- Life Stone - Level 46
(21703, 8733, 1, 1, 2, 4065.305488), -- Mid-Grade Life Stone - Level 46
(21703, 8743, 1, 1, 2, 406.525154), -- High-Grade Life Stone - Level 46
(21703, 8753, 1, 1, 2, 81.32661), -- Top-Grade Life Stone - Level 46
-- Dimension Invader Magus
(21704, 951, 1, 1, -1, 8282), -- Scroll: Enchant Weapon (C-Grade)
(21704, 952, 1, 1, -1, 60738), -- Scroll: Enchant Armor (C-Grade)
(21704, 1905, 1, 1, -1, 443126), -- Omen Beast's Eye Earring Gemstone
(21704, 57, 1801, 3658, 0, 700000), -- Adena
(21704, 1125, 1, 1, 1, 506.977542), -- Assault Boots
(21704, 1957, 1, 1, 1, 21275.935326), -- Assault Boots Part
(21704, 2427, 1, 1, 1, 506.977542), -- Salamander Skin Boots
(21704, 2931, 1, 1, 1, 21275.935326), -- Salamander Skin Boot Lining
(21704, 2428, 1, 1, 1, 506.977542), -- Plate Boots
(21704, 2932, 1, 1, 1, 21275.935326), -- Plate Boots Design
(21704, 61, 1, 1, 1, 506.977542), -- Mithril Plate Gloves
(21704, 1949, 1, 1, 1, 21275.935326), -- Mithril Gloves Design
(21704, 607, 1, 1, 1, 506.977542), -- Ogre Power Gauntlets
(21704, 1963, 1, 1, 1, 21275.935326), -- Ogre Power Gauntlets Part
(21704, 2451, 1, 1, 1, 506.977542), -- Sage's Worn Gloves
(21704, 2933, 1, 1, 1, 21276.458118), -- Sage's Worn Gloves Lining
(21704, 951, 1, 1, 2, 2079.48), -- Scroll: Enchant Weapon (C-Grade)
(21704, 952, 1, 1, 2, 15249.52), -- Scroll: Enchant Armor (C-Grade)
-- Purgatory Invader Soldier
(21705, 1914, 1, 1, -1, 195926), -- Earring of Seal Gemstone
(21705, 2169, 1, 1, -1, 61725), -- Recipe: Necklace of Seal
(21705, 1915, 1, 1, -1, 307267), -- Ring of Ages Gemstone
(21705, 57, 1379, 2804, 0, 700000), -- Adena
(21705, 75, 1, 1, 1, 7.274563), -- Caliburs
(21705, 2089, 1, 1, 1, 654.893428), -- Caliburs Edge
(21705, 76, 1, 1, 1, 7.274563), -- Sword of Delusion
(21705, 2090, 1, 1, 1, 654.893428), -- Delusional Blade
(21705, 77, 1, 1, 1, 7.274563), -- Tsurugi
(21705, 2091, 1, 1, 1, 654.893428), -- Tsurugi Blade
(21705, 84, 1, 1, 1, 7.274563), -- Homunkulus's Sword
(21705, 2092, 1, 1, 1, 654.893428), -- Homunkulus's Sword Blade
(21705, 134, 1, 1, 1, 7.274563), -- Sword of Nightmare
(21705, 2095, 1, 1, 1, 654.893428), -- Sword of Nightmare Blade
(21705, 145, 1, 1, 1, 7.274563), -- Sword of Whispering Death
(21705, 2096, 1, 1, 1, 654.885482), -- Sword of Whispering Death Blade
(21705, 1872, 1, 1, 2, 192294.568988), -- Animal Bone
(21705, 1867, 1, 1, 2, 192294.568988), -- Animal Skin
(21705, 1881, 1, 1, 2, 19229.287612), -- Coarse Bone Powder
(21705, 1875, 1, 1, 2, 9614.643806), -- Stone of Purity
(21705, 4041, 1, 1, 2, 1253.991971), -- Mold Hardener
(21705, 2170, 1, 1, 2, 3401.395029), -- Recipe: Nassen's Earring
(21705, 8725, 1, 1, 2, 4006.172122), -- Life Stone - Level 52
(21705, 8735, 1, 1, 2, 1001.331422), -- Mid-Grade Life Stone - Level 52
(21705, 8745, 1, 1, 2, 100.302429), -- High-Grade Life Stone - Level 52
(21705, 8755, 1, 1, 2, 20.737633), -- Top-Grade Life Stone - Level 52
-- Purgatory Invader Soldier
(21706, 4039, 1, 1, -1, 148647), -- Mold Glue
(21706, 1870, 1, 9, -1, 891882), -- Coal
(21706, 2117, 1, 1, -1, 20981), -- Ghoul's Staff Head
(21706, 57, 1762, 3590, 0, 700000), -- Adena
(21706, 135, 1, 1, 1, 17.464265), -- Samurai Longsword
(21706, 2115, 1, 1, 1, 1885.843518), -- Samurai Longsword Blade
(21706, 5286, 1, 1, 1, 17.464265), -- Berserker Blade
(21706, 5530, 1, 1, 1, 1888.227952), -- Berserker Blade Edge
(21706, 1870, 1, 1, 2, 149686.356764), -- Coal
(21706, 1865, 1, 1, 2, 149686.356764), -- Varnish
(21706, 1874, 1, 1, 2, 9979.24207), -- Oriharukon Ore
(21706, 4043, 1, 1, 2, 4989.458586), -- Asofe
(21706, 4039, 1, 1, 2, 4989.458586), -- Mold Glue
(21706, 4143, 1, 1, 2, 959.423794), -- Recipe: Zubei's Leather Shirt (100%)
(21706, 4971, 1, 1, 2, 172.520838), -- Recipe: Dark Elven Long Bow (60%)
(21706, 8726, 1, 1, 2, 3465.03717), -- Life Stone - Level 55
(21706, 8736, 1, 1, 2, 866.178068), -- Mid-Grade Life Stone - Level 55
(21706, 8746, 1, 1, 2, 86.747766), -- High-Grade Life Stone - Level 55
(21706, 8756, 1, 1, 2, 17.219594), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Archer
(21707, 1885, 1, 1, -1, 296029), -- High-Grade Suede
(21707, 1920, 1, 1, -1, 121552), -- Necklace of Seal Chain
(21707, 3034, 1, 1, -1, 7105), -- Recipe: Spiritshot B
(21707, 57, 1406, 2856, 0, 700000), -- Adena
(21707, 286, 1, 1, 1, 27.831292), -- Eminence Bow
(21707, 2121, 1, 1, 1, 3016.168708), -- Eminence Bow Shaft
(21707, 1875, 1, 1, 2, 8744.303472), -- Stone of Purity
(21707, 1879, 1, 1, 2, 21860.728032), -- Cokes
(21707, 1885, 1, 1, 2, 10930.364016), -- High-Grade Suede
(21707, 5550, 1, 1, 2, 1748.836176), -- Durable Metal Plate
(21707, 5549, 1, 1, 2, 13116.42456), -- Metallic Thread
(21707, 4134, 1, 1, 2, 1008.93216), -- Recipe: Zubei's Gaiters (100%)
(21707, 8726, 1, 1, 2, 3036.236064), -- Life Stone - Level 55
(21707, 8736, 1, 1, 2, 759.028368), -- Mid-Grade Life Stone - Level 55
(21707, 8746, 1, 1, 2, 75.884448), -- High-Grade Life Stone - Level 55
(21707, 8756, 1, 1, 2, 15.262704), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Elite Soldier
(21708, 4142, 1, 1, -1, 29469), -- Recipe: Avadon Gaiters (100%)
(21708, 2118, 1, 1, -1, 18024), -- Demon's Staff Head
(21708, 4143, 1, 1, -1, 24557), -- Recipe: Zubei's Leather Shirt (100%)
(21708, 57, 1514, 3084, 0, 700000), -- Adena
(21708, 286, 1, 1, 1, 30.007326), -- Eminence Bow
(21708, 2121, 1, 1, 1, 3251.992674), -- Eminence Bow Shaft
(21708, 1864, 1, 3, 2, 128591.499712), -- Stem
(21708, 1869, 1, 1, 2, 128591.499712), -- Iron Ore
(21708, 1878, 1, 1, 2, 51436.520421), -- Braided Hemp
(21708, 1884, 1, 1, 2, 79133.230592), -- Cord
(21708, 4039, 1, 1, 2, 4286.277372), -- Mold Glue
(21708, 4144, 1, 1, 2, 1321.482994), -- Recipe: Zubei's Leather Gaiters (100%)
(21708, 4972, 1, 1, 2, 148.199987), -- Recipe: Great Axe (60%)
(21708, 8726, 1, 1, 2, 2976.713948), -- Life Stone - Level 55
(21708, 8736, 1, 1, 2, 744.178487), -- Mid-Grade Life Stone - Level 55
(21708, 8746, 1, 1, 2, 74.298653), -- High-Grade Life Stone - Level 55
(21708, 8756, 1, 1, 2, 15.098122), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Shaman
(21709, 1984, 1, 1, -1, 83265), -- Theca Leather Armor Pattern
(21709, 3955, 1, 1, -1, 7769), -- Recipe: Blessed Spiritshot B
(21709, 1985, 1, 1, -1, 133941), -- Theca Leather Gaiters Pattern
(21709, 57, 1538, 3123, 0, 700000), -- Adena
(21709, 203, 1, 1, 1, 7.79848), -- Pa'agrian Axe
(21709, 2112, 1, 1, 1, 694.54632), -- Pa'agrian Axe Blade
(21709, 204, 1, 1, 1, 6.08536), -- Deadman's Staff
(21709, 2116, 1, 1, 1, 674.7904), -- Deadman's Staff Head
(21709, 205, 1, 1, 1, 6.08536), -- Ghoul's Staff
(21709, 2117, 1, 1, 1, 674.7904), -- Ghoul's Staff Head
(21709, 206, 1, 1, 1, 6.08536), -- Demon's Staff
(21709, 2118, 1, 1, 1, 674.7904), -- Demon's Staff Head
(21709, 2503, 1, 1, 1, 6.08536), -- Yaksa Mace
(21709, 2969, 1, 1, 1, 688.94256), -- Yaksa Mace Head
(21709, 1895, 1, 1, 2, 45530.579024), -- Metallic Fiber
(21709, 4040, 1, 1, 2, 3187.160284), -- Mold Lubricant
(21709, 4042, 1, 1, 2, 2655.946328), -- Enria
(21709, 4043, 1, 1, 2, 5311.892656), -- Asofe
(21709, 3955, 1, 1, 2, 318.691338), -- Recipe: Blessed Spiritshot B
(21709, 8726, 1, 1, 2, 3688.807486), -- Life Stone - Level 55
(21709, 8736, 1, 1, 2, 922.18644), -- Mid-Grade Life Stone - Level 55
(21709, 8746, 1, 1, 2, 92.218644), -- High-Grade Life Stone - Level 55
(21709, 8756, 1, 1, 2, 18.5178), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Priest
(21710, 2170, 1, 1, -1, 53231), -- Recipe: Nassen's Earring
(21710, 1916, 1, 1, -1, 96042), -- Necklace of Mermaid Teardrop
(21710, 1866, 1, 3, -1, 752328), -- Suede
(21710, 57, 893, 1815, 0, 700000), -- Adena
(21710, 64, 1, 1, 1, 247.18237), -- Composite Boots
(21710, 2956, 1, 1, 1, 13725.81763), -- Composite Boots Part
(21710, 608, 1, 1, 1, 247.18237), -- Mithril Gauntlets
(21710, 1981, 1, 1, 1, 13725.81763), -- Mithril Gauntlets Design
(21710, 1871, 1, 1, 2, 84850.130792), -- Charcoal
(21710, 1866, 1, 1, 2, 56566.810356), -- Suede
(21710, 1877, 1, 1, 2, 3394.086584), -- Adamantite Nugget
(21710, 4041, 1, 1, 2, 737.763852), -- Mold Hardener
(21710, 4040, 1, 1, 2, 1697.043292), -- Mold Lubricant
(21710, 2231, 1, 1, 2, 365.746472), -- Recipe: Full Plate Armor
(21710, 8725, 1, 1, 2, 2357.013988), -- Life Stone - Level 52
(21710, 8735, 1, 1, 2, 589.295868), -- Mid-Grade Life Stone - Level 52
(21710, 8745, 1, 1, 2, 58.980432), -- High-Grade Life Stone - Level 52
(21710, 8755, 1, 1, 2, 11.86388), -- Top-Grade Life Stone - Level 52
(21710, 1539, 1, 1, 2, 18855.264484), -- Greater Healing Potion
-- Purgatory Invader Magus
(21711, 2119, 1, 1, -1, 15460), -- Crystal Dagger Blade
(21711, 4041, 1, 1, -1, 29502), -- Mold Hardener
(21711, 4040, 1, 1, -1, 67854), -- Mold Lubricant
(21711, 57, 1341, 2731, 0, 700000), -- Adena
(21711, 203, 1, 1, 1, 6.812335), -- Pa'agrian Axe
(21711, 2112, 1, 1, 1, 606.718515), -- Pa'agrian Axe Blade
(21711, 204, 1, 1, 1, 5.315845), -- Deadman's Staff
(21711, 2116, 1, 1, 1, 589.4608), -- Deadman's Staff Head
(21711, 205, 1, 1, 1, 5.315845), -- Ghoul's Staff
(21711, 2117, 1, 1, 1, 589.4608), -- Ghoul's Staff Head
(21711, 206, 1, 1, 1, 5.315845), -- Demon's Staff
(21711, 2118, 1, 1, 1, 589.4608), -- Demon's Staff Head
(21711, 2503, 1, 1, 1, 5.315845), -- Yaksa Mace
(21711, 2969, 1, 1, 1, 601.82337), -- Yaksa Mace Head
(21711, 1871, 1, 1, 2, 113881.22889), -- Charcoal
(21711, 1866, 1, 1, 2, 75920.75205), -- Suede
(21711, 1877, 1, 1, 2, 4555.22496), -- Adamantite Nugget
(21711, 4041, 1, 1, 2, 990.20493), -- Mold Hardener
(21711, 4040, 1, 1, 2, 2277.61248), -- Mold Lubricant
(21711, 4145, 1, 1, 2, 499.43751), -- Recipe: Avadon Leather Armor (100%)
(21711, 4972, 1, 1, 2, 131.26113), -- Recipe: Great Axe (60%)
(21711, 8726, 1, 1, 2, 2636.11062), -- Life Stone - Level 55
(21711, 8736, 1, 1, 2, 659.12847), -- Mid-Grade Life Stone - Level 55
(21711, 8746, 1, 1, 2, 65.93301), -- High-Grade Life Stone - Level 55
(21711, 8756, 1, 1, 2, 13.10595), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Martyrs
(21712, 5549, 1, 1, -1, 283133), -- Metallic Thread
(21712, 4602, 1, 1, -1, 6292), -- Greater Dye of STR (Str+3 Dex-3)
(21712, 1539, 1, 1, -1, 629184), -- Greater Healing Potion
(21712, 57, 1120, 2277, 0, 700000), -- Adena
(21712, 854, 1, 1, 1, 172.235448), -- Earring of Seal
(21712, 1914, 1, 1, 1, 10961.91824), -- Earring of Seal Gemstone
(21712, 917, 1, 1, 1, 129.18584), -- Necklace of Mermaid
(21712, 1916, 1, 1, 1, 8303.05896), -- Necklace of Mermaid Teardrop
(21712, 885, 1, 1, 1, 258.260632), -- Ring of Ages
(21712, 1915, 1, 1, 1, 17191.34088), -- Ring of Ages Gemstone
(21712, 1868, 1, 1, 2, 234172.29052), -- Thread
(21712, 1873, 1, 1, 2, 46834.3344), -- Silver Nugget
(21712, 5549, 1, 1, 2, 11708.5836), -- Metallic Thread
(21712, 1889, 1, 1, 2, 7805.7224), -- Compound Braid
(21712, 4044, 1, 1, 2, 3902.8612), -- Thons
(21712, 2232, 1, 1, 2, 672.94976), -- Recipe: Drake Leather Armor
(21712, 8725, 1, 1, 2, 3252.48742), -- Life Stone - Level 52
(21712, 8735, 1, 1, 2, 813.04454), -- Mid-Grade Life Stone - Level 52
(21712, 8745, 1, 1, 2, 81.33538), -- High-Grade Life Stone - Level 52
(21712, 8755, 1, 1, 2, 16.39078), -- Top-Grade Life Stone - Level 52
-- Purgatory Invader Warrior
(21713, 1874, 1, 1, -1, 209404), -- Oriharukon Ore
(21713, 4043, 1, 1, -1, 104702), -- Asofe
(21713, 1986, 1, 1, -1, 33191), -- Full Plate Armor Temper
(21713, 57, 1243, 2526, 0, 700000), -- Adena
(21713, 135, 1, 1, 1, 12.301555), -- Samurai Longsword
(21713, 2115, 1, 1, 1, 1328.358666), -- Samurai Longsword Blade
(21713, 5286, 1, 1, 1, 12.301555), -- Berserker Blade
(21713, 5530, 1, 1, 1, 1330.038224), -- Berserker Blade Edge
(21713, 1870, 1, 1, 2, 115977.494732), -- Coal
(21713, 1865, 1, 1, 2, 115977.494732), -- Varnish
(21713, 1874, 1, 1, 2, 7731.950941), -- Oriharukon Ore
(21713, 4043, 1, 1, 2, 3865.849086), -- Asofe
(21713, 4039, 1, 1, 2, 3865.849086), -- Mold Glue
(21713, 4126, 1, 1, 2, 1913.714099), -- Recipe: Adamantite Earrings (100%)
(21713, 8726, 1, 1, 2, 2684.659549), -- Life Stone - Level 55
(21713, 8736, 1, 1, 2, 671.101695), -- Mid-Grade Life Stone - Level 55
(21713, 8746, 1, 1, 2, 67.236554), -- High-Grade Life Stone - Level 55
(21713, 8756, 1, 1, 2, 13.649526), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Soldier
(21714, 1977, 1, 1, -1, 44094), -- Composite Armor Temper
(21714, 2231, 1, 1, -1, 12848), -- Recipe: Full Plate Armor
(21714, 1978, 1, 1, -1, 191076), -- Tower Shield Fragment
(21714, 57, 1179, 2397, 0, 700000), -- Adena
(21714, 64, 1, 1, 1, 326.45126), -- Composite Boots
(21714, 2956, 1, 1, 1, 18127.54874), -- Composite Boots Part
(21714, 608, 1, 1, 1, 326.45126), -- Mithril Gauntlets
(21714, 1981, 1, 1, 1, 18127.54874), -- Mithril Gauntlets Design
(21714, 1895, 1, 1, 2, 35219.244522), -- Metallic Fiber
(21714, 4040, 1, 1, 2, 2465.319702), -- Mold Lubricant
(21714, 4042, 1, 1, 2, 2054.47788), -- Enria
(21714, 4043, 1, 1, 2, 4108.902006), -- Asofe
(21714, 2233, 1, 1, 2, 1152.055728), -- Recipe: Divine Tunic
(21714, 2970, 1, 1, 2, 4371.167772), -- Recipe: Ring of Seal
(21714, 8725, 1, 1, 2, 3424.076046), -- Life Stone - Level 52
(21714, 8735, 1, 1, 2, 856.03245), -- Mid-Grade Life Stone - Level 52
(21714, 8745, 1, 1, 2, 85.576368), -- High-Grade Life Stone - Level 52
(21714, 8755, 1, 1, 2, 17.147526), -- Top-Grade Life Stone - Level 52
-- Purgatory Invader Disciples
(21715, 4126, 1, 1, -1, 54581), -- Recipe: Adamantite Earrings (100%)
(21715, 1987, 1, 1, -1, 50463), -- Drake Leather Armor Texture
(21715, 4127, 1, 1, -1, 81871), -- Recipe: Adamantite Ring (100%)
(21715, 57, 1309, 2660, 0, 700000), -- Adena
(21715, 442, 1, 1, 1, 74.01585), -- Divine Tunic
(21715, 1988, 1, 1, 1, 5866.542054), -- Divine Tunic Fabric
(21715, 473, 1, 1, 1, 118.394838), -- Divine Stockings
(21715, 1989, 1, 1, 1, 9202.047258), -- Divine Stocking Pattern
(21715, 1867, 1, 1, 2, 162835.031093), -- Animal Skin
(21715, 1872, 1, 1, 2, 162835.031093), -- Animal Bone
(21715, 1882, 1, 1, 2, 27139.110887), -- Leather
(21715, 1894, 1, 1, 2, 4285.007265), -- Crafted Leather
(21715, 4042, 1, 1, 2, 2035.515615), -- Enria
(21715, 4127, 1, 1, 2, 3023.097315), -- Recipe: Adamantite Ring (100%)
(21715, 8726, 1, 1, 2, 2827.044059), -- Life Stone - Level 55
(21715, 8736, 1, 1, 2, 706.669572), -- Mid-Grade Life Stone - Level 55
(21715, 8746, 1, 1, 2, 70.593803), -- High-Grade Life Stone - Level 55
(21715, 8756, 1, 1, 2, 13.899298), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Berserker
(21716, 2120, 1, 1, -1, 18168), -- Great Pata Blade
(21716, 4144, 1, 1, -1, 38872), -- Recipe: Zubei's Leather Gaiters (100%)
(21716, 2121, 1, 1, -1, 17393), -- Eminence Bow Shaft
(21716, 57, 1495, 3045, 0, 700000), -- Adena
(21716, 135, 1, 1, 1, 14.814135), -- Samurai Longsword
(21716, 2115, 1, 1, 1, 1599.674562), -- Samurai Longsword Blade
(21716, 5286, 1, 1, 1, 14.814135), -- Berserker Blade
(21716, 5530, 1, 1, 1, 1601.697168), -- Berserker Blade Edge
(21716, 1874, 1, 1, 2, 9310.165887), -- Oriharukon Ore
(21716, 1878, 1, 1, 2, 55860.482205), -- Braided Hemp
(21716, 1884, 1, 1, 2, 85939.229706), -- Cord
(21716, 1889, 1, 1, 2, 9310.165887), -- Compound Braid
(21716, 5220, 1, 1, 2, 5586.13374), -- Metal Hardener
(21716, 4146, 1, 1, 2, 895.218126), -- Recipe: Tunic of Zubei (100%)
(21716, 8726, 1, 1, 2, 3232.6371), -- Life Stone - Level 55
(21716, 8736, 1, 1, 2, 808.159275), -- Mid-Grade Life Stone - Level 55
(21716, 8746, 1, 1, 2, 80.901447), -- High-Grade Life Stone - Level 55
(21716, 8756, 1, 1, 2, 15.906627), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Food
(21717, 2232, 1, 1, -1, 6974), -- Recipe: Drake Leather Armor
(21717, 1981, 1, 1, -1, 71378), -- Mithril Gauntlets Design
(21717, 1877, 1, 1, -1, 48537), -- Adamantite Nugget
(21717, 57, 480, 976, 0, 700000), -- Adena
(21717, 103, 1, 1, 1, 63.263882), -- Tower Shield
(21717, 1978, 1, 1, 1, 4020.833847), -- Tower Shield Fragment
(21717, 107, 1, 1, 1, 63.263882), -- Composite Shield
(21717, 4055, 1, 1, 1, 4020.833847), -- Composite Shield Fragment
(21717, 517, 1, 1, 1, 44.30398), -- Composite Helmet
(21717, 2957, 1, 1, 1, 2751.098291), -- Composite Helmet Design
(21717, 1149, 1, 1, 1, 44.30398), -- Shining Circlet
(21717, 1983, 1, 1, 1, 2751.098291), -- Shining Circlet Pattern
(21717, 1871, 1, 1, 2, 38599.778274), -- Charcoal
(21717, 1866, 1, 1, 2, 25733.289402), -- Suede
(21717, 1877, 1, 1, 2, 1543.953732), -- Adamantite Nugget
(21717, 4041, 1, 1, 2, 335.655666), -- Mold Hardener
(21717, 4040, 1, 1, 2, 771.976866), -- Mold Lubricant
(21717, 2234, 1, 1, 2, 575.320668), -- Recipe: Divine Stockings
(21717, 3012, 1, 1, 2, 720.085809), -- Recipe: Full Plate Helmet
(21717, 6669, 1, 1, 2, 8976.685374), -- Deluxe Chest Key - Grade 5
(21717, 8725, 1, 1, 2, 1072.259349), -- Life Stone - Level 52
(21717, 8735, 1, 1, 2, 268.02588), -- Mid-Grade Life Stone - Level 52
(21717, 8745, 1, 1, 2, 26.802588), -- High-Grade Life Stone - Level 52
(21717, 8755, 1, 1, 2, 5.298186), -- Top-Grade Life Stone - Level 52
(21717, 1342, 10, 30, 2, 77199.868206), -- Steel Arrow
-- Purgatory Invader Elite Soldier
(21718, 4145, 1, 1, -1, 34919), -- Recipe: Avadon Leather Armor (100%)
(21718, 2122, 1, 1, -1, 36339), -- Orcish Poleaxe Blade
(21718, 4044, 1, 1, -1, 265386), -- Thons
(21718, 57, 3146, 6410, 0, 700000), -- Adena
(21718, 442, 1, 1, 1, 178.1599), -- Divine Tunic
(21718, 1988, 1, 1, 1, 14121.063876), -- Divine Tunic Fabric
(21718, 473, 1, 1, 1, 284.982372), -- Divine Stockings
(21718, 1989, 1, 1, 1, 22149.793852), -- Divine Stocking Pattern
(21718, 1868, 1, 3, 2, 267241.391685), -- Thread
(21718, 1873, 1, 1, 2, 106896.644365), -- Silver Nugget
(21718, 5549, 1, 1, 2, 26724.270705), -- Metallic Thread
(21718, 1889, 1, 1, 2, 17816.18047), -- Compound Braid
(21718, 4044, 1, 1, 2, 8908.090235), -- Thons
(21718, 4147, 1, 1, 2, 2746.48212), -- Recipe: Stockings of Zubei (100%)
(21718, 8311, 1, 1, 2, 203.881575), -- Recipe: Kaim Vanul's Bones (100%)
(21718, 8726, 1, 1, 2, 6186.161595), -- Life Stone - Level 55
(21718, 8736, 1, 1, 2, 1546.430785), -- Mid-Grade Life Stone - Level 55
(21718, 8746, 1, 1, 2, 154.774615), -- High-Grade Life Stone - Level 55
(21718, 8756, 1, 1, 2, 30.69185), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Elite Soldier
(21719, 1876, 1, 3, -1, 811236), -- Mithril Ore
(21719, 2917, 1, 1, -1, 465960), -- Ring of Seal Gemstone
(21719, 4146, 1, 1, -1, 52002), -- Recipe: Tunic of Zubei (100%)
(21719, 57, 3206, 6531, 0, 700000), -- Adena
(21719, 2436, 1, 1, 1, 202.222947), -- Theca Leather Boots
(21719, 2954, 1, 1, 1, 13543.83212), -- Theca Leather Boots Texture
(21719, 2437, 1, 1, 1, 155.582738), -- Drake Leather Boots
(21719, 2960, 1, 1, 1, 11652.177929), -- Drake Leather Boots Design
(21719, 2438, 1, 1, 1, 155.582738), -- Full Plate Boots
(21719, 2961, 1, 1, 1, 11652.177929), -- Full Plate Boots Part
(21719, 2460, 1, 1, 1, 202.222947), -- Theca Leather Gloves
(21719, 2955, 1, 1, 1, 13543.83212), -- Theca Leather Gloves Texture
(21719, 2461, 1, 1, 1, 155.582738), -- Drake Leather Gloves
(21719, 2962, 1, 1, 1, 11652.177929), -- Drake Leather Gloves Design
(21719, 2462, 1, 1, 1, 155.582738), -- Full Plate Gauntlets
(21719, 2963, 1, 1, 1, 11652.177929), -- Full Plate Gauntlets Part
(21719, 2463, 1, 1, 1, 155.582738), -- Divine Gloves
(21719, 2964, 1, 1, 1, 11652.26446), -- Divine Gloves Pattern
(21719, 1873, 1, 1, 2, 119813.339128), -- Silver Nugget
(21719, 1868, 3, 9, 2, 99844.322498), -- Thread
(21719, 1876, 1, 1, 2, 59906.669564), -- Mithril Ore
(21719, 1895, 1, 1, 2, 85580.95652), -- Metallic Fiber
(21719, 4042, 1, 1, 2, 4992.159076), -- Enria
(21719, 4148, 1, 1, 2, 1313.646004), -- Recipe: Avadon Robe (100%)
(21719, 8726, 1, 1, 2, 6933.723306), -- Life Stone - Level 55
(21719, 8736, 1, 1, 2, 1733.525908), -- Mid-Grade Life Stone - Level 55
(21719, 8746, 1, 1, 2, 173.428656), -- High-Grade Life Stone - Level 55
(21719, 8756, 1, 1, 2, 34.22934), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Elite Soldier
(21720, 2954, 1, 1, -1, 20023), -- Theca Leather Boots Texture
(21720, 4147, 1, 1, -1, 3251), -- Recipe: Stockings of Zubei (100%)
(21720, 2955, 1, 1, -1, 20023), -- Theca Leather Gloves Texture
(21720, 57, 125, 255, 0, 700000), -- Adena
(21720, 301, 1, 1, 1, 1.05728), -- Scorpion
(21720, 2113, 1, 1, 1, 94.157), -- Scorpion Blade
(21720, 303, 1, 1, 1, 1.05728), -- Widow Maker
(21720, 2114, 1, 1, 1, 94.157), -- Widowmaker Head
(21720, 299, 1, 1, 1, 0.82488), -- Orcish Poleaxe
(21720, 2122, 1, 1, 1, 88.74656), -- Orcish Poleaxe Blade
(21720, 1866, 1, 1, 2, 7787.405109), -- Suede
(21720, 1871, 1, 1, 2, 11681.09691), -- Charcoal
(21720, 5220, 1, 1, 2, 467.239575), -- Metal Hardener
(21720, 1885, 1, 1, 2, 973.428327), -- High-Grade Suede
(21720, 4041, 1, 1, 2, 101.577561), -- Mold Hardener
(21720, 4149, 1, 1, 2, 150.140367), -- Recipe: Avadon Circlet (100%)
(21720, 8726, 1, 1, 2, 270.386004), -- Life Stone - Level 55
(21720, 8736, 1, 1, 2, 67.596501), -- Mid-Grade Life Stone - Level 55
(21720, 8746, 1, 1, 2, 6.753198), -- High-Grade Life Stone - Level 55
(21720, 8756, 1, 1, 2, 1.376448), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Elite Soldier
(21721, 1865, 1, 1, -1, 720775), -- Varnish
(21721, 4603, 1, 1, -1, 1602), -- Greater Dye of CON (Con+3 Str-3)
(21721, 1539, 1, 1, -1, 160172), -- Greater Healing Potion
(21721, 57, 285, 580, 0, 700000), -- Adena
(21721, 231, 1, 1, 1, 4.508932), -- Grace Dagger
(21721, 2106, 1, 1, 1, 405.991068), -- Grace Dagger Edge
(21721, 233, 1, 1, 1, 4.508932), -- Dark Screamer
(21721, 2107, 1, 1, 1, 405.991068), -- Dark Screamer Edge
(21721, 1870, 1, 1, 2, 29806.676424), -- Coal
(21721, 1865, 1, 1, 2, 29806.676424), -- Varnish
(21721, 1874, 1, 1, 2, 1987.13764), -- Oriharukon Ore
(21721, 4043, 1, 1, 2, 993.536472), -- Asofe
(21721, 4039, 1, 1, 2, 993.536472), -- Mold Glue
(21721, 2353, 1, 1, 2, 48.651392), -- Recipe: Samurai Longsword
(21721, 8725, 1, 1, 2, 827.979408), -- Life Stone - Level 52
(21721, 8735, 1, 1, 2, 206.962504), -- Mid-Grade Life Stone - Level 52
(21721, 8745, 1, 1, 2, 20.70272), -- High-Grade Life Stone - Level 52
(21721, 8755, 1, 1, 2, 4.140544), -- Top-Grade Life Stone - Level 52
-- Purgatory Invader Warrior
(21722, 1989, 1, 1, -1, 226991), -- Divine Stocking Pattern
(21722, 4128, 1, 1, -1, 93213), -- Recipe: Adamantite Necklace (100%)
(21722, 2112, 1, 1, -1, 36472), -- Pa'agrian Axe Blade
(21722, 57, 2981, 6056, 0, 700000), -- Adena
(21722, 301, 1, 1, 1, 25.2048), -- Scorpion
(21722, 2113, 1, 1, 1, 2244.635625), -- Scorpion Blade
(21722, 303, 1, 1, 1, 25.2048), -- Widow Maker
(21722, 2114, 1, 1, 1, 2244.635625), -- Widowmaker Head
(21722, 299, 1, 1, 1, 19.66455), -- Orcish Poleaxe
(21722, 2122, 1, 1, 1, 2115.6546), -- Orcish Poleaxe Blade
(21722, 1865, 1, 3, 2, 139044.434802), -- Varnish
(21722, 1870, 1, 1, 2, 278088.869604), -- Coal
(21722, 1879, 1, 1, 2, 46348.144934), -- Cokes
(21722, 1875, 1, 1, 2, 18539.05911), -- Stone of Purity
(21722, 4040, 1, 1, 2, 5561.717733), -- Mold Lubricant
(21722, 4133, 1, 1, 2, 1336.860551), -- Recipe: Zubei's Breastplate (100%)
(21722, 8726, 1, 1, 2, 6437.214732), -- Life Stone - Level 55
(21722, 8736, 1, 1, 2, 1609.303683), -- Mid-Grade Life Stone - Level 55
(21722, 8746, 1, 1, 2, 161.079516), -- High-Grade Life Stone - Level 55
(21722, 8756, 1, 1, 2, 32.315335), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Elite Soldier
(21723, 6669, 1, 3, -1, 753266), -- Deluxe Chest Key - Grade 5
(21723, 4601, 1, 1, -1, 14396), -- Greater Dye of STR (Str+3 Con-3)
(21723, 1539, 1, 3, -1, 719788), -- Greater Healing Potion
(21723, 57, 2562, 5209, 0, 700000), -- Adena
(21723, 6669, 1, 3, 1, 240303.493541), -- Deluxe Chest Key - Grade 5
(21723, 8725, 1, 1, 1, 57405.972284), -- Life Stone - Level 52
(21723, 8735, 1, 1, 1, 14351.493071), -- Mid-Grade Life Stone - Level 52
(21723, 8745, 1, 1, 1, 1435.243442), -- High-Grade Life Stone - Level 52
(21723, 8755, 1, 1, 1, 286.797662), -- Top-Grade Life Stone - Level 52
-- Purgatory Invader Elite Soldier
(21724, 6669, 1, 3, -1, 849629), -- Deluxe Chest Key - Grade 5
(21724, 1984, 1, 1, -1, 156630), -- Theca Leather Armor Pattern
(21724, 4126, 1, 1, -1, 120574), -- Recipe: Adamantite Earrings (100%)
(21724, 57, 2892, 5875, 0, 700000), -- Adena
(21724, 6669, 1, 3, 1, 263516.06152), -- Deluxe Chest Key - Grade 5
(21724, 8726, 1, 1, 1, 52459.182272), -- Life Stone - Level 55
(21724, 8736, 1, 1, 1, 13114.795568), -- Mid-Grade Life Stone - Level 55
(21724, 8746, 1, 1, 1, 1311.413424), -- High-Grade Life Stone - Level 55
(21724, 8756, 1, 1, 1, 262.547216), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Elite Soldier
(21725, 951, 1, 1, -1, 11612), -- Scroll: Enchant Weapon (C-Grade)
(21725, 952, 1, 1, -1, 85153), -- Scroll: Enchant Armor (C-Grade)
(21725, 1914, 1, 1, -1, 358792), -- Earring of Seal Gemstone
(21725, 57, 2526, 5135, 0, 700000), -- Adena
(21725, 162, 1, 1, 1, 9.991368), -- War Axe
(21725, 2097, 1, 1, 1, 884.210336), -- War Axe Blade
(21725, 174, 1, 1, 1, 9.991368), -- Nirvana Axe
(21725, 2098, 1, 1, 1, 884.210336), -- Nirvana Axe Blade
(21725, 196, 1, 1, 1, 9.991368), -- Stick of Eternity
(21725, 2099, 1, 1, 1, 930.564696), -- Stick of Eternity Shaft
(21725, 197, 1, 1, 1, 9.991368), -- Paradia Staff
(21725, 2100, 1, 1, 1, 930.564696), -- Paradia Staff Head
(21725, 199, 1, 1, 1, 9.991368), -- Pa'agrian Hammer
(21725, 2102, 1, 1, 1, 897.186616), -- Pa'agrian Hammer Head
(21725, 200, 1, 1, 1, 9.991368), -- Sage's Staff
(21725, 2103, 1, 1, 1, 930.564696), -- Sage's Staff Head
(21725, 201, 1, 1, 1, 9.991368), -- Club of Nature
(21725, 2104, 1, 1, 1, 930.564696), -- Club of Nature Head
(21725, 202, 1, 1, 1, 9.991368), -- Mace of Underworld
(21725, 2105, 1, 1, 1, 884.202984), -- Mace of Underworld Head
(21725, 1894, 1, 1, 2, 9266.986612), -- Crafted Leather
(21725, 4039, 1, 1, 2, 8803.603231), -- Mold Glue
(21725, 4041, 1, 1, 2, 2296.614354), -- Mold Hardener
(21725, 4044, 1, 1, 2, 8803.603231), -- Thons
(21725, 951, 1, 1, 2, 480.195766), -- Scroll: Enchant Weapon (C-Grade)
(21725, 952, 1, 1, 2, 3521.449805), -- Scroll: Enchant Armor (C-Grade)
(21725, 8725, 1, 1, 2, 7336.371495), -- Life Stone - Level 52
(21725, 8735, 1, 1, 2, 1834.082233), -- Mid-Grade Life Stone - Level 52
(21725, 8745, 1, 1, 2, 183.403967), -- High-Grade Life Stone - Level 52
(21725, 8755, 1, 1, 2, 36.689306), -- Top-Grade Life Stone - Level 52
-- Purgatory Invader Elite Soldier
(21726, 951, 1, 1, -1, 14147), -- Scroll: Enchant Weapon (C-Grade)
(21726, 952, 1, 1, -1, 103742), -- Scroll: Enchant Armor (C-Grade)
(21726, 4127, 1, 1, -1, 192590), -- Recipe: Adamantite Ring (100%)
(21726, 57, 3075, 6264, 0, 700000), -- Adena
(21726, 855, 1, 1, 1, 293.92956), -- Nassen's Earring
(21726, 1918, 1, 1, 1, 20737.44528), -- Nassen's Earring Gemstone
(21726, 119, 1, 1, 1, 220.47996), -- Necklace of Seal
(21726, 1920, 1, 1, 1, 16384.1793), -- Necklace of Seal Chain
(21726, 886, 1, 1, 1, 440.89434), -- Ring of Seal
(21726, 2917, 1, 1, 1, 27503.07156), -- Ring of Seal Gemstone
(21726, 951, 1, 1, 2, 870.547482), -- Scroll: Enchant Weapon (C-Grade)
(21726, 952, 1, 1, 2, 6383.929104), -- Scroll: Enchant Armor (C-Grade)
(21726, 8726, 1, 1, 2, 11083.217397), -- Life Stone - Level 55
(21726, 8736, 1, 1, 2, 2770.798989), -- Mid-Grade Life Stone - Level 55
(21726, 8746, 1, 1, 2, 277.082043), -- High-Grade Life Stone - Level 55
(21726, 8756, 1, 1, 2, 55.424985), -- Top-Grade Life Stone - Level 55
-- Purgatory Invader Magus
(21727, 951, 1, 1, -1, 12666), -- Scroll: Enchant Weapon (C-Grade)
(21727, 952, 1, 1, -1, 92886), -- Scroll: Enchant Armor (C-Grade)
(21727, 1984, 1, 1, -1, 149334), -- Theca Leather Armor Pattern
(21727, 57, 2758, 5602, 0, 700000), -- Adena
(21727, 855, 1, 1, 1, 263.169594), -- Nassen's Earring
(21727, 1918, 1, 1, 1, 18567.254872), -- Nassen's Earring Gemstone
(21727, 119, 1, 1, 1, 197.406554), -- Necklace of Seal
(21727, 1920, 1, 1, 1, 14669.561695), -- Necklace of Seal Chain
(21727, 886, 1, 1, 1, 394.754391), -- Ring of Seal
(21727, 2917, 1, 1, 1, 24624.852894), -- Ring of Seal Gemstone
(21727, 951, 1, 1, 2, 779.477196), -- Scroll: Enchant Weapon (C-Grade)
(21727, 952, 1, 1, 2, 5716.089312), -- Scroll: Enchant Armor (C-Grade)
(21727, 8726, 1, 1, 2, 9923.772566), -- Life Stone - Level 55
(21727, 8736, 1, 1, 2, 2480.938342), -- Mid-Grade Life Stone - Level 55
(21727, 8746, 1, 1, 2, 248.095754), -- High-Grade Life Stone - Level 55
(21727, 8756, 1, 1, 2, 49.62683), -- Top-Grade Life Stone - Level 55
-- Forbidden Path Invader Elite Soldier
(21728, 1867, 1, 15, -1, 851364), -- Animal Skin
(21728, 1881, 1, 1, -1, 681091), -- Coarse Bone Powder
(21728, 4614, 1, 1, -1, 7046), -- Greater Dye of STR (Str+4 Dex-4)
(21728, 57, 2020, 4107, 0, 700000), -- Adena
(21728, 357, 1, 1, 1, 23.6358), -- Zubei's Breastplate
(21728, 4056, 1, 1, 1, 3414.917892), -- Zubei's Breastplate Part
(21728, 2376, 1, 1, 1, 23.6358), -- Avadon Breastplate
(21728, 4064, 1, 1, 1, 3414.917892), -- Avadon Breastplate Part
(21728, 383, 1, 1, 1, 37.81728), -- Zubei's Gaiters
(21728, 4057, 1, 1, 1, 5277.61152), -- Zubei's Gaiter Material
(21728, 2379, 1, 1, 1, 37.81728), -- Avadon Gaiters
(21728, 4065, 1, 1, 1, 5277.646536), -- Avadon Gaiters Material
(21728, 1872, 1, 1, 2, 201183.611929), -- Animal Bone
(21728, 1867, 1, 1, 2, 201183.611929), -- Animal Skin
(21728, 1881, 1, 1, 2, 20118.317322), -- Coarse Bone Powder
(21728, 1875, 1, 1, 2, 10059.158661), -- Stone of Purity
(21728, 4041, 1, 1, 2, 1312.178619), -- Mold Hardener
(21728, 4129, 1, 1, 2, 1632.874898), -- Recipe: Earrings of Black Ore (100%)
(21728, 8728, 1, 1, 2, 2514.679988), -- Life Stone - Level 61
(21728, 8738, 1, 1, 2, 628.669997), -- Mid-Grade Life Stone - Level 61
(21728, 8748, 1, 1, 2, 62.735387), -- High-Grade Life Stone - Level 61
(21728, 8758, 1, 1, 2, 13.16127), -- Top-Grade Life Stone - Level 61
-- Forbidden Path Invader Elite Soldier
(21729, 1807, 1, 1, -1, 8500), -- Recipe: Soulshot (A-Grade)
(21729, 4085, 1, 1, -1, 110793), -- Tunic of Doom Pattern
(21729, 3035, 1, 1, -1, 8500), -- Recipe: Spiritshot A
(21729, 57, 2526, 5122, 0, 700000), -- Adena
(21729, 97, 1, 1, 1, 18.661898), -- Lance
(21729, 4115, 1, 1, 1, 4107.338102), -- Lance Blade
(21729, 1874, 1, 1, 2, 12553.916375), -- Oriharukon Ore
(21729, 1878, 1, 1, 2, 75323.270225), -- Braided Hemp
(21729, 1884, 1, 1, 2, 115882.076975), -- Cord
(21729, 1889, 1, 1, 2, 12553.916375), -- Compound Braid
(21729, 5220, 1, 1, 2, 7532.349825), -- Metal Hardener
(21729, 6337, 1, 1, 2, 965.685875), -- Recipe: Sealed Majestic Earring(70%)
(21729, 8729, 1, 1, 2, 2510.783275), -- Life Stone - Level 64
(21729, 8739, 1, 1, 2, 627.752825), -- Mid-Grade Life Stone - Level 64
(21729, 8749, 1, 1, 2, 62.706875), -- High-Grade Life Stone - Level 64
(21729, 8759, 1, 1, 2, 12.541375), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Archer
(21730, 4087, 1, 1, -1, 120236), -- Stockings of Doom Pattern
(21730, 5276, 1, 1, -1, 6832), -- Recipe: Greater Spiritshot (A) Compressed Package(100%)
(21730, 4088, 1, 1, -1, 193646), -- Blue Wolf Helmet Design
(21730, 57, 2032, 4115, 0, 700000), -- Adena
(21730, 287, 1, 1, 1, 14.99883), -- Bow of Peril
(21730, 4121, 1, 1, 1, 3296.00117), -- Bow of Peril Shaft
(21730, 1870, 1, 1, 2, 151351.171776), -- Coal
(21730, 1865, 1, 1, 2, 151351.171776), -- Varnish
(21730, 1874, 1, 1, 2, 10090.034712), -- Oriharukon Ore
(21730, 4043, 1, 1, 2, 5045.017356), -- Asofe
(21730, 4039, 1, 1, 2, 5045.017356), -- Mold Glue
(21730, 5438, 1, 1, 2, 82.689192), -- Recipe: Meteor Shower(60%)
(21730, 8729, 1, 1, 2, 2018.072052), -- Life Stone - Level 64
(21730, 8739, 1, 1, 2, 504.5994), -- Mid-Grade Life Stone - Level 64
(21730, 8749, 1, 1, 2, 50.45994), -- High-Grade Life Stone - Level 64
(21730, 8759, 1, 1, 2, 9.76644), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Elite Soldier
(21731, 4086, 1, 1, -1, 128514), -- Blue Wolf Stockings Pattern
(21731, 1894, 1, 1, -1, 192162), -- Crafted Leather
(21731, 4042, 1, 1, -1, 91277), -- Enria
(21731, 57, 2170, 4400, 0, 700000), -- Adena
(21731, 110, 1, 1, 1, 82.98527), -- Doom Shield
(21731, 4077, 1, 1, 1, 12129.68575), -- Doom Shield Fragment
(21731, 2416, 1, 1, 1, 58.09296), -- Blue Wolf Helmet
(21731, 4088, 1, 1, 1, 10190.57153), -- Blue Wolf Helmet Design
(21731, 2417, 1, 1, 1, 58.09296), -- Doom Helmet
(21731, 4089, 1, 1, 1, 10190.57153), -- Doom Helmet Pattern
(21731, 1867, 1, 3, 2, 65361.890284), -- Animal Skin
(21731, 1872, 1, 1, 2, 196086.08128), -- Animal Bone
(21731, 1882, 1, 1, 2, 32681.150356), -- Leather
(21731, 1894, 1, 1, 2, 5160.311244), -- Crafted Leather
(21731, 4042, 1, 1, 2, 2451.076016), -- Enria
(21731, 6339, 1, 1, 2, 1131.139568), -- Recipe: Sealed Majestic Ring(70%)
(21731, 8729, 1, 1, 2, 1961.024984), -- Life Stone - Level 64
(21731, 8739, 1, 1, 2, 490.051032), -- Mid-Grade Life Stone - Level 64
(21731, 8749, 1, 1, 2, 48.840932), -- High-Grade Life Stone - Level 64
(21731, 8759, 1, 1, 2, 9.850272), -- Top-Grade Life Stone - Level 64
(21731, 1343, 20, 60, 2, 105046.584032), -- Silver Arrow
-- Forbidden Path Invader Shaman
(21732, 5281, 1, 1, -1, 7470), -- Recipe: Greater Blessed Spiritshot (A) Compressed Package(100%)
(21732, 4089, 1, 1, -1, 211741), -- Doom Helmet Pattern
(21732, 4039, 1, 1, -1, 186755), -- Mold Glue
(21732, 57, 2222, 4499, 0, 700000), -- Adena
(21732, 234, 1, 1, 1, 16.400973), -- Demon's Dagger
(21732, 4119, 1, 1, 1, 3622.599027), -- Demon's Dagger Edge
(21732, 1864, 4, 12, 2, 37612.227775), -- Stem
(21732, 1869, 1, 1, 2, 150448.490969), -- Iron Ore
(21732, 1878, 1, 1, 2, 60179.56444), -- Braided Hemp
(21732, 1884, 1, 1, 2, 92583.848339), -- Cord
(21732, 4039, 1, 1, 2, 5015.103747), -- Mold Glue
(21732, 5444, 1, 1, 2, 82.345676), -- Recipe: Carnage Bow(60%)
(21732, 8729, 1, 1, 2, 2006.125525), -- Life Stone - Level 64
(21732, 8739, 1, 1, 2, 501.636414), -- Mid-Grade Life Stone - Level 64
(21732, 8749, 1, 1, 2, 49.995589), -- High-Grade Life Stone - Level 64
(21732, 8759, 1, 1, 2, 10.083144), -- Top-Grade Life Stone - Level 64
(21732, 1343, 30, 90, 2, 71641.578382), -- Silver Arrow
-- Forbidden Path Invader Priest
(21733, 4056, 1, 1, -1, 59834), -- Zubei's Breastplate Part
(21733, 4131, 1, 1, -1, 26877), -- Recipe: Necklace of Black Ore (100%)
(21733, 4057, 1, 1, -1, 92471), -- Zubei's Gaiter Material
(21733, 57, 1308, 2658, 0, 700000), -- Adena
(21733, 91, 1, 1, 1, 7.30784), -- Heavy War Axe
(21733, 4105, 1, 1, 1, 1396.64965), -- Heavy War Axe Head
(21733, 92, 1, 1, 1, 7.30784), -- Sprite's Staff
(21733, 4106, 1, 1, 1, 1373.73467), -- Sprite's Staff Head
(21733, 1872, 1, 1, 2, 118363.192878), -- Animal Bone
(21733, 1867, 1, 1, 2, 118363.192878), -- Animal Skin
(21733, 1881, 1, 1, 2, 11836.203666), -- Coarse Bone Powder
(21733, 1875, 1, 1, 2, 5918.294536), -- Stone of Purity
(21733, 4041, 1, 1, 2, 771.968218), -- Mold Hardener
(21733, 4130, 1, 1, 2, 1441.033034), -- Recipe: Ring of Black Ore (100%)
(21733, 8728, 1, 1, 2, 1479.573634), -- Life Stone - Level 61
(21733, 8738, 1, 1, 2, 369.98976), -- Mid-Grade Life Stone - Level 61
(21733, 8748, 1, 1, 2, 36.998976), -- High-Grade Life Stone - Level 61
(21733, 8758, 1, 1, 2, 7.322714), -- Top-Grade Life Stone - Level 61
(21733, 1343, 10, 30, 2, 126818.229706), -- Silver Arrow
-- Forbidden Path Invader Magus
(21734, 4087, 1, 1, -1, 113812), -- Stockings of Doom Pattern
(21734, 3956, 1, 1, -1, 6467), -- Recipe: Blessed Spiritshot A
(21734, 4088, 1, 1, -1, 183300), -- Blue Wolf Helmet Design
(21734, 57, 1922, 3897, 0, 700000), -- Adena
(21734, 2391, 1, 1, 1, 23.742072), -- Blue Wolf Leather Armor
(21734, 4082, 1, 1, 1, 4047.257928), -- Blue Wolf Leather Armor Texture
(21734, 2392, 1, 1, 1, 23.742072), -- Leather Armor of Doom
(21734, 4083, 1, 1, 1, 4047.257928), -- Leather Armor of Doom Design
(21734, 1864, 1, 3, 2, 143264.840715), -- Stem
(21734, 1869, 1, 1, 2, 143264.840715), -- Iron Ore
(21734, 1878, 1, 1, 2, 57306.11198), -- Braided Hemp
(21734, 1884, 1, 1, 2, 88162.809965), -- Cord
(21734, 4039, 1, 1, 2, 4775.36292), -- Mold Glue
(21734, 729, 1, 1, 2, 15.81246), -- Scroll: Enchant Weapon (A-Grade)
(21734, 8729, 1, 1, 2, 1910.233015), -- Life Stone - Level 64
(21734, 8739, 1, 1, 2, 477.448445), -- Mid-Grade Life Stone - Level 64
(21734, 8749, 1, 1, 2, 47.876615), -- High-Grade Life Stone - Level 64
(21734, 8759, 1, 1, 2, 9.66317), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Martyrs
(21735, 4154, 1, 1, -1, 49078), -- Recipe: Doom Shield (100%)
(21735, 4064, 1, 1, -1, 75061), -- Avadon Breastplate Part
(21735, 948, 1, 1, -1, 10368), -- Scroll: Enchant Armor (B-Grade)
(21735, 57, 1640, 3334, 0, 700000), -- Adena
(21735, 300, 1, 1, 1, 18.33528), -- Great Axe
(21735, 4113, 1, 1, 1, 3151.66472), -- Great Axe Head
(21735, 1894, 1, 1, 2, 4775.892408), -- Crafted Leather
(21735, 4039, 1, 1, 2, 4537.099692), -- Mold Glue
(21735, 4041, 1, 1, 2, 1183.5846), -- Mold Hardener
(21735, 4044, 1, 1, 2, 4537.099692), -- Thons
(21735, 4131, 1, 1, 2, 1106.608752), -- Recipe: Necklace of Black Ore (100%)
(21735, 8728, 1, 1, 2, 2268.540324), -- Life Stone - Level 61
(21735, 8738, 1, 1, 2, 567.13032), -- Mid-Grade Life Stone - Level 61
(21735, 8748, 1, 1, 2, 56.713032), -- High-Grade Life Stone - Level 61
(21735, 8758, 1, 1, 2, 11.33118), -- Top-Grade Life Stone - Level 61
-- Forbidden Path Invader Warrior
(21736, 5220, 1, 1, -1, 181225), -- Metal Hardener
(21736, 4090, 1, 1, -1, 203395), -- Sealed Blue Wolf Boots Design
(21736, 5438, 1, 1, -1, 2476), -- Recipe: Meteor Shower(60%)
(21736, 57, 1797, 3638, 0, 700000), -- Adena
(21736, 97, 1, 1, 1, 13.261436), -- Lance
(21736, 4115, 1, 1, 1, 2918.738564), -- Lance Blade
(21736, 1866, 1, 1, 2, 89218.36224), -- Suede
(21736, 1871, 1, 1, 2, 133827.421824), -- Charcoal
(21736, 5220, 1, 1, 2, 5353.174656), -- Metal Hardener
(21736, 1885, 1, 1, 2, 11152.386432), -- High-Grade Suede
(21736, 4041, 1, 1, 2, 1163.828736), -- Mold Hardener
(21736, 5446, 1, 1, 2, 73.164672), -- Recipe: Bloody Orchid(60%)
(21736, 8729, 1, 1, 2, 1784.391552), -- Life Stone - Level 64
(21736, 8739, 1, 1, 2, 446.03712), -- Mid-Grade Life Stone - Level 64
(21736, 8749, 1, 1, 2, 44.725248), -- High-Grade Life Stone - Level 64
(21736, 8759, 1, 1, 2, 8.50752), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Soldier
(21737, 1880, 1, 1, -1, 436600), -- Steel
(21737, 5550, 1, 1, -1, 58213), -- Durable Metal Plate
(21737, 4615, 1, 1, -1, 6022), -- Greater Dye of CON (Con+4 Str-4)
(21737, 57, 1727, 3510, 0, 700000), -- Adena
(21737, 229, 1, 1, 1, 9.652236), -- Kris
(21737, 4109, 1, 1, 1, 1816.347764), -- Kris Edge
(21737, 243, 1, 1, 1, 9.652236), -- Hell Knife
(21737, 4110, 1, 1, 1, 1816.347764), -- Hell Knife Edge
(21737, 1869, 1, 1, 2, 117240.823812), -- Iron Ore
(21737, 1864, 1, 3, 2, 117240.823812), -- Stem
(21737, 1880, 1, 1, 2, 11724.040076), -- Steel
(21737, 5550, 1, 1, 2, 1563.17714), -- Durable Metal Plate
(21737, 4043, 1, 1, 2, 3908.154376), -- Asofe
(21737, 4154, 1, 1, 2, 1387.61056), -- Recipe: Doom Shield (100%)
(21737, 8728, 1, 1, 2, 1954.077188), -- Life Stone - Level 61
(21737, 8738, 1, 1, 2, 488.62506), -- Mid-Grade Life Stone - Level 61
(21737, 8748, 1, 1, 2, 48.65098), -- High-Grade Life Stone - Level 61
(21737, 8758, 1, 1, 2, 9.730196), -- Top-Grade Life Stone - Level 61
(21737, 1343, 10, 30, 2, 167486.2868), -- Silver Arrow
-- Forbidden Path Invader Disciple
(21738, 4091, 1, 1, -1, 214178), -- Sealed Doom Gloves Part
(21738, 5444, 1, 1, -1, 2607), -- Recipe: Carnage Bow(60%)
(21738, 4096, 1, 1, -1, 214178), -- Sealed Blue Wolf Gloves Fabric
(21738, 57, 1892, 3831, 0, 700000), -- Adena
(21738, 79, 1, 1, 1, 4.654791), -- Sword of Damascus
(21738, 4114, 1, 1, 1, 1028.253552), -- Sword of Damascus Blade
(21738, 7883, 1, 1, 1, 4.654791), -- Guardian Sword
(21738, 8330, 1, 1, 1, 1026.525426), -- Guardian Sword Blade
(21738, 7889, 1, 1, 1, 4.654791), -- Wizard's Tear
(21738, 8336, 1, 1, 1, 1028.256649), -- Blade of the Wizard's Tear
(21738, 1865, 1, 1, 2, 128111.325055), -- Varnish
(21738, 1870, 1, 1, 2, 128111.325055), -- Coal
(21738, 1879, 1, 1, 2, 21351.966501), -- Cokes
(21738, 1875, 1, 1, 2, 8540.59702), -- Stone of Purity
(21738, 4040, 1, 1, 2, 2562.179106), -- Mold Lubricant
(21738, 5452, 1, 1, 2, 70.144748), -- Recipe: Blood Tornado(60%)
(21738, 8729, 1, 1, 2, 1708.119404), -- Life Stone - Level 64
(21738, 8739, 1, 1, 2, 427.029851), -- Mid-Grade Life Stone - Level 64
(21738, 8749, 1, 1, 2, 42.65559), -- High-Grade Life Stone - Level 64
(21738, 8759, 1, 1, 2, 8.531118), -- Top-Grade Life Stone - Level 64
(21738, 1343, 10, 30, 2, 183017.126552), -- Silver Arrow
-- Forbidden Path Invader Berserker
(21739, 5156, 1, 1, -1, 7209), -- Recipe: Soulshot (A) Compressed Package (100%)
(21739, 4089, 1, 1, -1, 204345), -- Doom Helmet Pattern
(21739, 5220, 1, 1, -1, 216279), -- Metal Hardener
(21739, 57, 2143, 4344, 0, 700000), -- Adena
(21739, 864, 1, 1, 1, 74.877555), -- Earring of Black Ore
(21739, 4052, 1, 1, 1, 9423.78114), -- Earring of Black Ore Piece
(21739, 926, 1, 1, 1, 56.164746), -- Necklace of Black Ore
(21739, 4054, 1, 1, 1, 5242.7448), -- Necklace of Black Ore Beads
(21739, 895, 1, 1, 1, 112.303173), -- Ring of Black Ore
(21739, 4053, 1, 1, 1, 11409.128586), -- Ring of Black Ore Gemstone
(21739, 1866, 1, 1, 2, 96796.186686), -- Suede
(21739, 1871, 1, 1, 2, 145194.280029), -- Charcoal
(21739, 5220, 1, 1, 2, 5807.752354), -- Metal Hardener
(21739, 1885, 1, 1, 2, 12099.405541), -- High-Grade Suede
(21739, 4041, 1, 1, 2, 1262.75972); -- Mold Hardener

INSERT INTO `droplist` VALUES
(21739, 730, 1, 1, 2, 121.093003), -- Scroll: Enchant Armor (A-Grade)
(21739, 8729, 1, 1, 2, 1936.074511), -- Life Stone - Level 64
(21739, 8739, 1, 1, 2, 483.900833), -- Mid-Grade Life Stone - Level 64
(21739, 8749, 1, 1, 2, 48.531437), -- High-Grade Life Stone - Level 64
(21739, 8759, 1, 1, 2, 9.894759), -- Top-Grade Life Stone - Level 64
(21739, 1343, 10, 30, 2, 207419.121127), -- Silver Arrow
-- Forbidden Path Invader Food
(21740, 4065, 1, 1, -1, 49715), -- Avadon Gaiters Material
(21740, 4155, 1, 1, -1, 5520), -- Recipe: Blue Wolf Breastplate (100%)
(21740, 4066, 1, 1, -1, 41903), -- Zubei's Leather Shirt Fabric
(21740, 57, 703, 1429, 0, 700000), -- Adena
(21740, 357, 1, 1, 1, 8.2242), -- Zubei's Breastplate
(21740, 4056, 1, 1, 1, 1188.238508), -- Zubei's Breastplate Part
(21740, 2376, 1, 1, 1, 8.2242), -- Avadon Breastplate
(21740, 4064, 1, 1, 1, 1188.238508), -- Avadon Breastplate Part
(21740, 383, 1, 1, 1, 13.15872), -- Zubei's Gaiters
(21740, 4057, 1, 1, 1, 1836.37248), -- Zubei's Gaiter Material
(21740, 2379, 1, 1, 1, 13.15872), -- Avadon Gaiters
(21740, 4065, 1, 1, 1, 1836.384664), -- Avadon Gaiters Material
(21740, 1895, 1, 1, 2, 14999.987416), -- Metallic Fiber
(21740, 4040, 1, 1, 2, 1049.9951), -- Mold Lubricant
(21740, 4042, 1, 1, 2, 874.991132), -- Enria
(21740, 4043, 1, 1, 2, 1750.010972), -- Asofe
(21740, 4155, 1, 1, 2, 163.032732), -- Recipe: Blue Wolf Breastplate (100%)
(21740, 6670, 1, 1, 2, 8749.997444), -- Deluxe Chest Key - Grade 6
(21740, 8728, 1, 1, 2, 874.991132), -- Life Stone - Level 61
(21740, 8738, 1, 1, 2, 218.75496), -- Mid-Grade Life Stone - Level 61
(21740, 8748, 1, 1, 2, 21.875496), -- High-Grade Life Stone - Level 61
(21740, 8758, 1, 1, 2, 4.363616), -- Top-Grade Life Stone - Level 61
-- Forbidden Path Invader Elite Soldier
(21741, 4040, 1, 1, -1, 227632), -- Mold Lubricant
(21741, 4090, 1, 1, -1, 510958), -- Sealed Blue Wolf Boots Design
(21741, 5161, 1, 1, -1, 15175), -- Recipe: Spiritshot (A) Compressed Package (100%)
(21741, 57, 4510, 9145, 0, 700000), -- Adena
(21741, 79, 1, 1, 1, 11.105667), -- Sword of Damascus
(21741, 4114, 1, 1, 1, 2453.266224), -- Sword of Damascus Blade
(21741, 7883, 1, 1, 1, 11.105667), -- Guardian Sword
(21741, 8330, 1, 1, 1, 2449.143162), -- Guardian Sword Blade
(21741, 7889, 1, 1, 1, 11.105667), -- Wizard's Tear
(21741, 8336, 1, 1, 1, 2453.273613), -- Blade of the Wizard's Tear
(21741, 1871, 1, 3, 2, 168097.46061), -- Charcoal
(21741, 1866, 1, 1, 2, 224130.22827), -- Suede
(21741, 1877, 1, 1, 2, 13447.59468), -- Adamantite Nugget
(21741, 4041, 1, 1, 2, 2923.445085), -- Mold Hardener
(21741, 4040, 1, 1, 2, 6723.79734), -- Mold Lubricant
(21741, 5434, 1, 1, 2, 124.67076), -- Recipe: Dragon Slayer(60%)
(21741, 8729, 1, 1, 2, 4482.671955), -- Life Stone - Level 64
(21741, 8739, 1, 1, 2, 1120.773285), -- Mid-Grade Life Stone - Level 64
(21741, 8749, 1, 1, 2, 112.03521), -- High-Grade Life Stone - Level 64
(21741, 8759, 1, 1, 2, 22.322805), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Elite Soldier
(21742, 4091, 1, 1, -1, 520636), -- Sealed Doom Gloves Part
(21742, 5166, 1, 1, -1, 15463), -- Recipe: Blessed Spiritshot (A) Compressed Package (100%)
(21742, 4096, 1, 1, -1, 520636), -- Sealed Blue Wolf Gloves Fabric
(21742, 57, 4596, 9318, 0, 700000), -- Adena
(21742, 234, 1, 1, 1, 33.946724), -- Demon's Dagger
(21742, 4119, 1, 1, 1, 7498.053276), -- Demon's Dagger Edge
(21742, 1867, 1, 3, 2, 138408.963184), -- Animal Skin
(21742, 1872, 2, 6, 2, 103806.439296), -- Animal Bone
(21742, 1882, 1, 1, 2, 69204.292864), -- Leather
(21742, 1894, 1, 1, 2, 10926.973744), -- Crafted Leather
(21742, 4042, 1, 1, 2, 5190.397456), -- Enria
(21742, 5440, 1, 1, 2, 115.501536), -- Recipe: Elysian(60%)
(21742, 8729, 1, 1, 2, 4152.393456), -- Life Stone - Level 64
(21742, 8739, 1, 1, 2, 1038.004), -- Mid-Grade Life Stone - Level 64
(21742, 8749, 1, 1, 2, 103.8004), -- High-Grade Life Stone - Level 64
(21742, 8759, 1, 1, 2, 20.76008), -- Top-Grade Life Stone - Level 64
(21742, 1343, 100, 300, 2, 44488.473984), -- Silver Arrow
-- Forbidden Path Invader Elite Soldier
(21743, 1877, 1, 1, -1, 18090), -- Adamantite Nugget
(21743, 4041, 1, 1, -1, 3933), -- Mold Hardener
(21743, 4099, 1, 1, -1, 20303), -- Sealed Doom Boots Part
(21743, 57, 179, 363, 0, 700000), -- Adena
(21743, 358, 1, 1, 1, 1.800056), -- Blue Wolf Breastplate
(21743, 4078, 1, 1, 1, 325.405527), -- Blue Wolf Breastplate Part
(21743, 2381, 1, 1, 1, 1.107882), -- Doom Plate Armor
(21743, 4081, 1, 1, 1, 219.567481), -- Doom Plate Armor Temper
(21743, 2380, 1, 1, 1, 2.879686), -- Blue Wolf Gaiters
(21743, 4080, 1, 1, 1, 458.239368), -- Blue Wolf Gaiters Material
(21743, 1871, 1, 1, 2, 13358.63214), -- Charcoal
(21743, 1866, 1, 1, 2, 8905.75476), -- Suede
(21743, 1877, 1, 1, 2, 534.353715), -- Adamantite Nugget
(21743, 4041, 1, 1, 2, 116.161815), -- Mold Hardener
(21743, 4040, 1, 1, 2, 267.16515), -- Mold Lubricant
(21743, 5442, 1, 1, 2, 4.940565), -- Recipe: Soul Bow(60%)
(21743, 8729, 1, 1, 2, 178.117905), -- Life Stone - Level 64
(21743, 8739, 1, 1, 2, 44.53533), -- Mid-Grade Life Stone - Level 64
(21743, 8749, 1, 1, 2, 4.44885), -- High-Grade Life Stone - Level 64
(21743, 8759, 1, 1, 2, 0.88977), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Elite Soldier
(21744, 4157, 1, 1, -1, 5252), -- Recipe: Blue Wolf Gaiters (100%)
(21744, 4067, 1, 1, -1, 37792), -- Zubei's Leather Gaiter Texture
(21744, 947, 1, 1, -1, 422), -- Scroll: Enchant Weapon (B-Grade)
(21744, 57, 418, 849, 0, 700000), -- Adena
(21744, 2397, 1, 1, 1, 8.683896), -- Tunic of Zubei
(21744, 4069, 1, 1, 1, 1225.609632), -- Tunic of Zubei Fabric
(21744, 2406, 1, 1, 1, 5.341752), -- Avadon Robe
(21744, 4071, 1, 1, 1, 941.572008), -- Avadon Robe Fabric
(21744, 2402, 1, 1, 1, 13.895856), -- Stockings of Zubei
(21744, 4070, 1, 1, 1, 1860.896856), -- Stockings of Zubei Fabric
(21744, 1868, 1, 1, 2, 56699.599515), -- Thread
(21744, 1873, 1, 1, 2, 11339.965885), -- Silver Nugget
(21744, 5549, 1, 1, 2, 2835.02021), -- Metallic Thread
(21744, 1889, 1, 1, 2, 1889.975155), -- Compound Braid
(21744, 4044, 1, 1, 2, 945.045055), -- Thons
(21744, 4157, 1, 1, 2, 141.049785), -- Recipe: Blue Wolf Gaiters (100%)
(21744, 8728, 1, 1, 2, 472.46505), -- Life Stone - Level 61
(21744, 8738, 1, 1, 2, 118.17374), -- Mid-Grade Life Stone - Level 61
(21744, 8748, 1, 1, 2, 11.840365), -- High-Grade Life Stone - Level 61
(21744, 8758, 1, 1, 2, 2.414055), -- Top-Grade Life Stone - Level 61
(21744, 1343, 10, 30, 2, 40499.451185), -- Silver Arrow
-- Forbidden Path Invader Warrior
(21745, 5446, 1, 1, -1, 5936), -- Recipe: Bloody Orchid(60%)
(21745, 4114, 1, 1, -1, 47551), -- Sword of Damascus Blade
(21745, 5452, 1, 1, -1, 5936), -- Recipe: Blood Tornado(60%)
(21745, 57, 4309, 8724, 0, 700000), -- Adena
(21745, 268, 1, 1, 1, 31.799145), -- Bellion Cestus
(21745, 4120, 1, 1, 1, 7011.200855), -- Bellion Cestus Edge
(21745, 1871, 1, 3, 2, 97239.14411), -- Charcoal
(21745, 1866, 1, 1, 2, 194477.919233), -- Suede
(21745, 1877, 1, 1, 2, 11668.844888), -- Adamantite Nugget
(21745, 4041, 1, 1, 2, 2536.785625), -- Mold Hardener
(21745, 4040, 1, 1, 2, 5834.422444), -- Mold Lubricant
(21745, 5460, 1, 1, 2, 159.402384), -- Recipe: Dasparion's Staff(60%)
(21745, 8729, 1, 1, 2, 3889.491967), -- Life Stone - Level 64
(21745, 8739, 1, 1, 2, 972.280745), -- Mid-Grade Life Stone - Level 64
(21745, 8749, 1, 1, 2, 97.412568), -- High-Grade Life Stone - Level 64
(21745, 8759, 1, 1, 2, 19.556311), -- Top-Grade Life Stone - Level 64
(21745, 1343, 80, 240, 2, 52091.739725), -- Silver Arrow
-- Forbidden Path Invader Elite Soldier
(21746, 6670, 1, 3, -1, 790715), -- Deluxe Chest Key - Grade 6
(21746, 947, 1, 1, -1, 3795), -- Scroll: Enchant Weapon (B-Grade)
(21746, 57, 3753, 7629, 0, 700000), -- Adena
(21746, 6670, 1, 3, 1, 233565.185724), -- Deluxe Chest Key - Grade 6
(21746, 8728, 1, 1, 1, 46713.154488), -- Life Stone - Level 61
(21746, 8738, 1, 1, 1, 11678.288622), -- Mid-Grade Life Stone - Level 61
(21746, 8748, 1, 1, 1, 1167.858198), -- High-Grade Life Stone - Level 61
(21746, 8758, 1, 1, 1, 233.512968), -- Top-Grade Life Stone - Level 61
-- Forbidden Path Invader Elite Soldier
(21747, 6670, 1, 3, -1, 878270), -- Deluxe Chest Key - Grade 6
(21747, 1894, 1, 1, -1, 369798), -- Crafted Leather
(21747, 4052, 1, 1, -1, 373136), -- Earring of Black Ore Piece
(21747, 57, 4180, 8463, 0, 700000), -- Adena
(21747, 6670, 1, 3, 1, 259427.203254), -- Deluxe Chest Key - Grade 6
(21747, 8729, 1, 1, 1, 41508.327516), -- Life Stone - Level 64
(21747, 8739, 1, 1, 1, 10377.238158), -- Mid-Grade Life Stone - Level 64
(21747, 8749, 1, 1, 1, 1037.69256), -- High-Grade Life Stone - Level 64
(21747, 8759, 1, 1, 1, 207.538512), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Elite Soldier
(21748, 947, 1, 1, -1, 3742), -- Scroll: Enchant Weapon (B-Grade)
(21748, 948, 1, 1, -1, 23386), -- Scroll: Enchant Armor (B-Grade)
(21748, 4129, 1, 1, -1, 101238), -- Recipe: Earrings of Black Ore (100%)
(21748, 57, 3700, 7521, 0, 700000), -- Adena
(21748, 267, 1, 1, 1, 41.361392), -- Arthro Nail
(21748, 4111, 1, 1, 1, 7906.638608), -- Arthro Nail Blade
(21748, 1872, 1, 3, 2, 167463.771489), -- Animal Bone
(21748, 1867, 1, 3, 2, 111642.514326), -- Animal Skin
(21748, 1881, 1, 1, 2, 33492.619251), -- Coarse Bone Powder
(21748, 1875, 1, 1, 2, 16746.478434), -- Stone of Purity
(21748, 4041, 1, 1, 2, 2184.38199), -- Mold Hardener
(21748, 947, 1, 1, 2, 100.609866), -- Scroll: Enchant Weapon (B-Grade)
(21748, 948, 1, 1, 2, 627.96762), -- Scroll: Enchant Armor (B-Grade)
(21748, 8728, 1, 1, 2, 4186.4508), -- Life Stone - Level 61
(21748, 8738, 1, 1, 2, 1046.6127), -- Mid-Grade Life Stone - Level 61
(21748, 8748, 1, 1, 2, 104.66127), -- High-Grade Life Stone - Level 61
(21748, 8758, 1, 1, 2, 20.932254), -- Top-Grade Life Stone - Level 61
-- Forbidden Path Invader Elite Soldier
(21749, 947, 1, 1, -1, 4449), -- Scroll: Enchant Weapon (B-Grade)
(21749, 948, 1, 1, -1, 27807), -- Scroll: Enchant Armor (B-Grade)
(21749, 4053, 1, 1, -1, 476765), -- Ring of Black Ore Gemstone
(21749, 57, 4408, 8937, 0, 700000), -- Adena
(21749, 601, 1, 1, 1, 132.73836), -- Sealed Doom Boots
(21749, 4099, 1, 1, 1, 18437.26164), -- Sealed Doom Boots Part
(21749, 2439, 1, 1, 1, 132.73836), -- Sealed Blue Wolf Boots
(21749, 4090, 1, 1, 1, 18437.26164), -- Sealed Blue Wolf Boots Design
(21749, 2475, 1, 1, 1, 132.73836), -- Sealed Doom Gloves
(21749, 4091, 1, 1, 1, 18437.26164), -- Sealed Doom Gloves Part
(21749, 2487, 1, 1, 1, 132.73836), -- Sealed Blue Wolf Gloves
(21749, 4096, 1, 1, 1, 18437.26164), -- Sealed Blue Wolf Gloves Fabric
(21749, 947, 1, 1, 2, 219.040822), -- Scroll: Enchant Weapon (B-Grade)
(21749, 948, 1, 1, 2, 1369.035206), -- Scroll: Enchant Armor (B-Grade)
(21749, 8729, 1, 1, 2, 7301.50652), -- Life Stone - Level 64
(21749, 8739, 1, 1, 2, 1825.37663), -- Mid-Grade Life Stone - Level 64
(21749, 8749, 1, 1, 2, 182.532196), -- High-Grade Life Stone - Level 64
(21749, 8759, 1, 1, 2, 36.508626), -- Top-Grade Life Stone - Level 64
-- Forbidden Path Invader Magus
(21750, 947, 1, 1, -1, 4019), -- Scroll: Enchant Weapon (B-Grade)
(21750, 948, 1, 1, -1, 25121), -- Scroll: Enchant Armor (B-Grade)
(21750, 5230, 1, 1, -1, 13398), -- Recipe: Mithril Arrow (100%)
(21750, 57, 3985, 8069, 0, 700000), -- Adena
(21750, 110, 1, 1, 1, 152.258055), -- Doom Shield
(21750, 4077, 1, 1, 1, 22255.062375), -- Doom Shield Fragment
(21750, 2416, 1, 1, 1, 106.58664), -- Blue Wolf Helmet
(21750, 4088, 1, 1, 1, 18697.253145), -- Blue Wolf Helmet Design
(21750, 2417, 1, 1, 1, 106.58664), -- Doom Helmet
(21750, 4089, 1, 1, 1, 18697.253145), -- Doom Helmet Pattern
(21750, 947, 1, 1, 2, 197.865941), -- Scroll: Enchant Weapon (B-Grade)
(21750, 948, 1, 1, 2, 1236.689293), -- Scroll: Enchant Armor (B-Grade)
(21750, 8729, 1, 1, 2, 6595.66306), -- Life Stone - Level 64
(21750, 8739, 1, 1, 2, 1648.915765), -- Mid-Grade Life Stone - Level 64
(21750, 8749, 1, 1, 2, 164.886638), -- High-Grade Life Stone - Level 64
(21750, 8759, 1, 1, 2, 32.979303), -- Top-Grade Life Stone - Level 64
-- Dark Omen Invader Soldier
(21751, 729, 1, 1, -1, 794), -- Scroll: Enchant Weapon (A-Grade)
(21751, 1876, 1, 3, -1, 714323), -- Mithril Ore
(21751, 1895, 1, 5, -1, 680308), -- Metallic Fiber
(21751, 57, 2825, 5748, 0, 700000), -- Adena
(21751, 269, 1, 1, 1, 14.967297), -- Blood Tornado
(21751, 5539, 1, 1, 1, 3558.032703), -- Blood Tornado Edge
(21751, 1873, 1, 1, 2, 76727.328436), -- Silver Nugget
(21751, 1868, 1, 3, 2, 191818.091564), -- Thread
(21751, 1876, 1, 1, 2, 38363.434692), -- Mithril Ore
(21751, 1895, 1, 1, 2, 54805.300176), -- Metallic Fiber
(21751, 4042, 1, 1, 2, 3196.838128), -- Enria
(21751, 5434, 1, 1, 2, 71.15306), -- Recipe: Dragon Slayer(60%)
(21751, 8730, 1, 1, 2, 2131.378436), -- Life Stone - Level 67
(21751, 8740, 1, 1, 2, 532.959372), -- Mid-Grade Life Stone - Level 67
(21751, 8750, 1, 1, 2, 53.250032), -- High-Grade Life Stone - Level 67
(21751, 8760, 1, 1, 2, 10.558196), -- Top-Grade Life Stone - Level 67
(21751, 1343, 30, 90, 2, 91341.707908), -- Silver Arrow
-- Dark Omen Invader Soldier
(21752, 5522, 1, 1, -1, 23752), -- Sealed Armor of Nightmare Pattern
(21752, 5272, 1, 1, -1, 3100), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21752, 5523, 1, 1, -1, 23752), -- Sealed Majestic Plate Armor Pattern
(21752, 57, 3440, 7020, 0, 700000), -- Adena
(21752, 269, 1, 1, 1, 18.268229), -- Blood Tornado
(21752, 5539, 1, 1, 1, 4342.731771), -- Blood Tornado Edge
(21752, 1872, 1, 3, 2, 156071.585124), -- Animal Bone
(21752, 1867, 1, 3, 2, 104047.723416), -- Animal Skin
(21752, 1881, 1, 1, 2, 31214.240022), -- Coarse Bone Powder
(21752, 1875, 1, 1, 2, 15607.312518), -- Stone of Purity
(21752, 4041, 1, 1, 2, 2035.569018), -- Mold Hardener
(21752, 5162, 1, 1, 2, 103.95378), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21752, 8731, 1, 1, 2, 2167.62882), -- Life Stone - Level 70
(21752, 8741, 1, 1, 2, 542.099712), -- Mid-Grade Life Stone - Level 70
(21752, 8751, 1, 1, 2, 54.286974), -- High-Grade Life Stone - Level 70
(21752, 8761, 1, 1, 2, 10.780392), -- Top-Grade Life Stone - Level 70
(21752, 1344, 40, 120, 2, 73158.820224), -- Mithril Arrow
-- Dark Omen Invader Archer
(21753, 5520, 1, 1, -1, 36478), -- Sealed Dark Crystal Breastplate Pattern
(21753, 5464, 1, 1, -1, 2095), -- Recipe: Dark Legion's Edge(60%)
(21753, 5521, 1, 1, -1, 25740), -- Sealed Tallum Plate Armor Pattern
(21753, 57, 2793, 5688, 0, 700000), -- Adena
(21753, 5287, 1, 1, 1, 19.545087), -- Sealed Dark Crystal breastplate
(21753, 5520, 1, 1, 1, 2244.887619), -- Sealed Dark Crystal Breastplate Pattern
(21753, 5293, 1, 1, 1, 12.031689), -- Sealed Tallum Plate Armor
(21753, 5521, 1, 1, 1, 1584.082068), -- Sealed Tallum Plate Armor Pattern
(21753, 5288, 1, 1, 1, 31.276533), -- Sealed Dark Crystal Gaiters
(21753, 5524, 1, 1, 1, 3431.177004), -- Sealed Dark Crystal Gaiters Pattern
(21753, 1869, 1, 1, 2, 189880.055386), -- Iron Ore
(21753, 1864, 1, 3, 2, 189880.055386), -- Stem
(21753, 1880, 1, 1, 2, 18987.956622), -- Steel
(21753, 5550, 1, 1, 2, 2531.923216), -- Durable Metal Plate
(21753, 4043, 1, 1, 2, 6329.318874), -- Asofe
(21753, 6901, 1, 1, 2, 189.796408), -- Recipe: Shining Arrow (100%)
(21753, 8731, 1, 1, 2, 1758.062604), -- Life Stone - Level 70
(21753, 8741, 1, 1, 2, 439.760234), -- Mid-Grade Life Stone - Level 70
(21753, 8751, 1, 1, 2, 44.02494), -- High-Grade Life Stone - Level 70
(21753, 8761, 1, 1, 2, 8.804988), -- Top-Grade Life Stone - Level 70
(21753, 1344, 30, 90, 2, 79116.241342), -- Mithril Arrow
-- Dark Omen Invader Elite Soldier
(21754, 5277, 1, 1, -1, 2663), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21754, 5527, 1, 1, -1, 71635), -- Sealed Helm of Nightmare Design
(21754, 4042, 1, 1, -1, 99859), -- Enria
(21754, 57, 2956, 6030, 0, 700000), -- Adena
(21754, 288, 1, 1, 1, 15.6906), -- Carnage Bow
(21754, 5535, 1, 1, 1, 3774.3094), -- Carnage Bow Stave
(21754, 1873, 1, 1, 2, 88490.527136), -- Silver Nugget
(21754, 1868, 1, 3, 2, 221226.741418), -- Thread
(21754, 1876, 1, 1, 2, 44245.263568), -- Mithril Ore
(21754, 1895, 1, 1, 2, 63207.579894), -- Metallic Fiber
(21754, 4042, 1, 1, 2, 3687.24649), -- Enria
(21754, 5167, 1, 1, 2, 98.270096), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21754, 8731, 1, 1, 2, 2048.423208), -- Life Stone - Level 70
(21754, 8741, 1, 1, 2, 512.105802), -- Mid-Grade Life Stone - Level 70
(21754, 8751, 1, 1, 2, 51.252938), -- High-Grade Life Stone - Level 70
(21754, 8761, 1, 1, 2, 10.58945), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Shaman
(21755, 729, 1, 1, -1, 687), -- Scroll: Enchant Weapon (A-Grade)
(21755, 1874, 1, 1, -1, 412363), -- Oriharukon Ore
(21755, 4043, 1, 1, -1, 206181), -- Asofe
(21755, 57, 3054, 6219, 0, 700000), -- Adena
(21755, 6324, 1, 1, 1, 75.749399), -- Sealed Phoenix Earring
(21755, 6341, 1, 1, 1, 10527.59323), -- Sealed Phoenix Earring Gemstone
(21755, 6323, 1, 1, 1, 56.803681), -- Sealed Phoenix Necklace
(21755, 6343, 1, 1, 1, 8138.223544), -- Sealed Phoenix Necklace Beads
(21755, 6325, 1, 1, 1, 113.607362), -- Sealed Phoenix Ring
(21755, 6345, 1, 1, 1, 14561.022784), -- Sealed Phoenix Ring Gemstone
(21755, 1870, 1, 1, 2, 228385.807984), -- Coal
(21755, 1865, 1, 1, 2, 228385.807984), -- Varnish
(21755, 1874, 1, 1, 2, 15225.753201), -- Oriharukon Ore
(21755, 4043, 1, 1, 2, 7612.631585), -- Asofe
(21755, 4039, 1, 1, 2, 7612.631585), -- Mold Glue
(21755, 1808, 1, 1, 2, 101.436417), -- Recipe: Soulshot (S-Grade)
(21755, 8731, 1, 1, 2, 2114.483765), -- Life Stone - Level 70
(21755, 8741, 1, 1, 2, 528.743449), -- Mid-Grade Life Stone - Level 70
(21755, 8751, 1, 1, 2, 52.923348), -- High-Grade Life Stone - Level 70
(21755, 8761, 1, 1, 2, 10.780682), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Priest
(21756, 5524, 1, 1, -1, 45563), -- Sealed Dark Crystal Gaiters Pattern
(21756, 5466, 1, 1, -1, 1712), -- Recipe: Sword of Miracles(60%)
(21756, 5525, 1, 1, -1, 71462), -- Sealed Dark Crystal Helmet Design
(21756, 57, 1828, 3720, 0, 700000), -- Adena
(21756, 288, 1, 1, 1, 9.6876), -- Carnage Bow
(21756, 5535, 1, 1, 1, 2330.3124), -- Carnage Bow Stave
(21756, 1873, 1, 1, 2, 54620.82496), -- Silver Nugget
(21756, 1868, 1, 1, 2, 273104.92144), -- Thread
(21756, 1876, 1, 1, 2, 27310.41248), -- Mithril Ore
(21756, 1895, 1, 1, 2, 39015.04568), -- Metallic Fiber
(21756, 4042, 1, 1, 2, 2276.00048), -- Enria
(21756, 5440, 1, 1, 2, 50.58664), -- Recipe: Elysian(60%)
(21756, 8730, 1, 1, 2, 1517.20088), -- Life Stone - Level 67
(21756, 8740, 1, 1, 2, 379.20064), -- Mid-Grade Life Stone - Level 67
(21756, 8750, 1, 1, 2, 37.8404), -- High-Grade Life Stone - Level 67
(21756, 8760, 1, 1, 2, 7.9664), -- Top-Grade Life Stone - Level 67
-- Dark Omen Invader Magus
(21757, 4041, 1, 1, -1, 46140), -- Mold Hardener
(21757, 5528, 1, 1, -1, 63440), -- Sealed Majestic Circlet Design
(21757, 5282, 1, 1, -1, 2358), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21757, 57, 2617, 5341, 0, 700000), -- Adena
(21757, 235, 1, 1, 1, 13.896744), -- Bloody Orchid
(21757, 5536, 1, 1, 1, 3333.103256), -- Bloody Orchid Head
(21757, 1871, 1, 1, 2, 178108.583588), -- Charcoal
(21757, 1866, 1, 1, 2, 118739.196589), -- Suede
(21757, 1877, 1, 1, 2, 7124.461669), -- Adamantite Nugget
(21757, 4041, 1, 1, 2, 1548.796015), -- Mold Hardener
(21757, 4040, 1, 1, 2, 3562.019539), -- Mold Lubricant
(21757, 5272, 1, 1, 2, 79.024517), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21757, 8731, 1, 1, 2, 1648.950082), -- Life Stone - Level 70
(21757, 8741, 1, 1, 2, 412.448816), -- Mid-Grade Life Stone - Level 70
(21757, 8751, 1, 1, 2, 41.413918), -- High-Grade Life Stone - Level 70
(21757, 8761, 1, 1, 2, 8.45182), -- Top-Grade Life Stone - Level 70
(21757, 1344, 20, 60, 2, 111317.653447), -- Mithril Arrow
-- Dark Omen Invader Martyrs
(21758, 6335, 1, 1, -1, 22305), -- Recipe: Sealed Majestic Necklace(70%)
(21758, 5526, 1, 1, -1, 89647), -- Sealed Tallum Helm Design
(21758, 730, 1, 1, -1, 4833), -- Scroll: Enchant Armor (A-Grade)
(21758, 57, 2294, 4666, 0, 700000), -- Adena
(21758, 235, 1, 1, 1, 12.148752), -- Bloody Orchid
(21758, 5536, 1, 1, 1, 2913.851248), -- Bloody Orchid Head
(21758, 1865, 1, 1, 2, 155728.231308), -- Varnish
(21758, 1870, 1, 1, 2, 155728.231308), -- Coal
(21758, 1879, 1, 1, 2, 25954.705218), -- Cokes
(21758, 1875, 1, 1, 2, 10381.97497), -- Stone of Purity
(21758, 4040, 1, 1, 2, 3114.360284), -- Mold Lubricant
(21758, 5442, 1, 1, 2, 57.587336), -- Recipe: Soul Bow(60%)
(21758, 8730, 1, 1, 2, 1730.406564), -- Life Stone - Level 67
(21758, 8740, 1, 1, 2, 432.369434), -- Mid-Grade Life Stone - Level 67
(21758, 8750, 1, 1, 2, 43.190502), -- High-Grade Life Stone - Level 67
(21758, 8760, 1, 1, 2, 8.823866), -- Top-Grade Life Stone - Level 67
(21758, 1343, 20, 60, 2, 111234.11921), -- Silver Arrow
-- Dark Omen Invader Warrior
(21759, 5524, 1, 1, -1, 49299), -- Sealed Dark Crystal Gaiters Pattern
(21759, 5466, 1, 1, -1, 1853), -- Recipe: Sword of Miracles(60%)
(21759, 5525, 1, 1, -1, 77321), -- Sealed Dark Crystal Helmet Design
(21759, 57, 2470, 5029, 0, 700000), -- Adena
(21759, 212, 1, 1, 1, 3.27503), -- Dasparion's Staff
(21759, 5543, 1, 1, 1, 785.978994), -- Dasparion's Staff Head
(21759, 2504, 1, 1, 1, 3.27503), -- Meteor Shower
(21759, 5532, 1, 1, 1, 778.639166), -- Meteor Shower Head
(21759, 7894, 1, 1, 1, 3.27503), -- Spiritual Eye
(21759, 8341, 1, 1, 1, 777.642554), -- Spiritual Eye Piece
(21759, 7899, 1, 1, 1, 3.27503), -- Destroyer Hammer
(21759, 8346, 1, 1, 1, 778.639166), -- Hammer Piece of Destroyer
(21759, 1871, 1, 1, 2, 167895.571012), -- Charcoal
(21759, 1866, 1, 1, 2, 111930.513461), -- Suede
(21759, 1877, 1, 1, 2, 6715.934381), -- Adamantite Nugget
(21759, 4041, 1, 1, 2, 1459.985735), -- Mold Hardener
(21759, 4040, 1, 1, 2, 3357.768011), -- Mold Lubricant
(21759, 3036, 1, 1, 2, 74.493133), -- Recipe: Spiritshot S
(21759, 8731, 1, 1, 2, 1554.396818), -- Life Stone - Level 70
(21759, 8741, 1, 1, 2, 388.798384), -- Mid-Grade Life Stone - Level 70
(21759, 8751, 1, 1, 2, 39.039182), -- High-Grade Life Stone - Level 70
(21759, 8761, 1, 1, 2, 7.96718), -- Top-Grade Life Stone - Level 70
(21759, 1344, 20, 60, 2, 104934.532703), -- Mithril Arrow
-- Dark Omen Invader Soldier
(21760, 5220, 1, 1, -1, 244215), -- Metal Hardener
(21760, 1885, 1, 1, -1, 508781), -- High-Grade Suede
(21760, 5532, 1, 1, -1, 20589), -- Meteor Shower Head
(21760, 57, 2415, 4913, 0, 700000), -- Adena
(21760, 5291, 1, 1, 1, 50.658804), -- Sealed Dark Crystal Boots
(21760, 5496, 1, 1, 1, 5286.341196), -- Sealed Dark Crystal Boots Lining
(21760, 5296, 1, 1, 1, 50.658804), -- Sealed Tallum Boots
(21760, 5497, 1, 1, 1, 5286.341196), -- Sealed Tallum Boots Lining
(21760, 5290, 1, 1, 1, 50.658804), -- Sealed Dark Crystal Gloves
(21760, 5508, 1, 1, 1, 5286.341196), -- Sealed Dark Crystal Gloves Design
(21760, 5295, 1, 1, 1, 50.658804), -- Sealed Tallum Gloves
(21760, 5509, 1, 1, 1, 5286.341196), -- Sealed Tallum Gloves Design
(21760, 1866, 1, 1, 2, 120228.659184), -- Suede
(21760, 1871, 1, 1, 2, 180342.988776), -- Charcoal
(21760, 5220, 1, 1, 2, 7213.601826), -- Metal Hardener
(21760, 1885, 1, 1, 2, 15028.582398), -- High-Grade Suede
(21760, 4041, 1, 1, 2, 1568.359144), -- Mold Hardener
(21760, 5448, 1, 1, 2, 66.710856), -- Recipe: Soul Separator(60%)
(21760, 8730, 1, 1, 2, 2003.941792), -- Life Stone - Level 67
(21760, 8740, 1, 1, 2, 500.985448), -- Mid-Grade Life Stone - Level 67
(21760, 8750, 1, 1, 2, 50.033142), -- High-Grade Life Stone - Level 67
(21760, 8760, 1, 1, 2, 10.137434), -- Top-Grade Life Stone - Level 67
-- Dark Omen Invader Disciple
(21761, 6335, 1, 1, -1, 20258), -- Recipe: Sealed Majestic Necklace(70%)
(21761, 5526, 1, 1, -1, 81420), -- Sealed Tallum Helm Design
(21761, 730, 1, 1, -1, 4389), -- Scroll: Enchant Armor (A-Grade)
(21761, 57, 2601, 5296, 0, 700000), -- Adena
(21761, 269, 1, 1, 1, 13.794377), -- Blood Tornado
(21761, 5539, 1, 1, 1, 3279.205623), -- Blood Tornado Edge
(21761, 1872, 1, 3, 2, 129650.70038), -- Animal Bone
(21761, 1867, 1, 1, 2, 259301.40076), -- Animal Skin
(21761, 1881, 1, 1, 2, 25930.05369), -- Coarse Bone Powder
(21761, 1875, 1, 1, 2, 12965.24281), -- Stone of Purity
(21761, 4041, 1, 1, 2, 1691.00595), -- Mold Hardener
(21761, 3957, 1, 1, 2, 86.386), -- Recipe: Blessed Spiritshot S
(21761, 8731, 1, 1, 2, 1800.71617), -- Life Stone - Level 70
(21761, 8741, 1, 1, 2, 450.07106), -- Mid-Grade Life Stone - Level 70
(21761, 8751, 1, 1, 2, 44.92072), -- High-Grade Life Stone - Level 70
(21761, 8761, 1, 1, 2, 9.50246), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Berserker
(21762, 5529, 1, 1, -1, 16229), -- Dragon Slayer Edge
(21762, 6901, 1, 1, -1, 5915), -- Recipe: Shining Arrow (100%)
(21762, 5533, 1, 1, -1, 16226), -- Elysian Head
(21762, 57, 2918, 5954, 0, 700000), -- Adena
(21762, 269, 1, 1, 1, 15.490922), -- Blood Tornado
(21762, 5539, 1, 1, 1, 3682.509078), -- Blood Tornado Edge
(21762, 1867, 1, 3, 2, 145609.12963), -- Animal Skin
(21762, 1872, 1, 1, 2, 291218.758614), -- Animal Bone
(21762, 1882, 1, 1, 2, 48536.210092), -- Leather
(21762, 1894, 1, 1, 2, 7663.585838), -- Crafted Leather
(21762, 4042, 1, 1, 2, 3640.29066), -- Enria
(21762, 5277, 1, 1, 2, 96.874676), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21762, 8731, 1, 1, 2, 2022.3837), -- Life Stone - Level 70
(21762, 8741, 1, 1, 2, 505.346248), -- Mid-Grade Life Stone - Level 70
(21762, 8751, 1, 1, 2, 50.434754), -- High-Grade Life Stone - Level 70
(21762, 8761, 1, 1, 2, 10.985788), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Food
(21763, 6337, 1, 1, -1, 12746), -- Recipe: Sealed Majestic Earring(70%)
(21763, 5535, 1, 1, -1, 8480), -- Carnage Bow Stave
(21763, 6339, 1, 1, -1, 19118), -- Recipe: Sealed Majestic Ring(70%)
(21763, 57, 983, 2000, 0, 700000), -- Adena
(21763, 212, 1, 1, 1, 1.30207), -- Dasparion's Staff
(21763, 5543, 1, 1, 1, 312.485586), -- Dasparion's Staff Head
(21763, 2504, 1, 1, 1, 1.30207), -- Meteor Shower
(21763, 5532, 1, 1, 1, 309.567454), -- Meteor Shower Head
(21763, 7894, 1, 1, 1, 1.30207), -- Spiritual Eye
(21763, 8341, 1, 1, 1, 309.171226), -- Spiritual Eye Piece
(21763, 7899, 1, 1, 1, 1.30207), -- Destroyer Hammer
(21763, 8346, 1, 1, 1, 309.567454), -- Hammer Piece of Destroyer
(21763, 1867, 1, 1, 2, 81572.041845), -- Animal Skin
(21763, 1872, 1, 1, 2, 81572.041845), -- Animal Bone
(21763, 1882, 1, 1, 2, 13595.477805), -- Leather
(21763, 1894, 1, 1, 2, 2146.61097), -- Crafted Leather
(21763, 4042, 1, 1, 2, 1019.68146), -- Enria
(21763, 5450, 1, 1, 2, 22.54959), -- Recipe: Dragon Grinder(60%)
(21763, 6671, 1, 1, 2, 6797.601405), -- Deluxe Chest Key - Grade 7
(21763, 8730, 1, 1, 2, 679.78764), -- Life Stone - Level 67
(21763, 8740, 1, 1, 2, 169.94691), -- Mid-Grade Life Stone - Level 67
(21763, 8750, 1, 1, 2, 17.04969), -- High-Grade Life Stone - Level 67
(21763, 8760, 1, 1, 2, 3.29994), -- Top-Grade Life Stone - Level 67
(21763, 1343, 10, 30, 2, 87398.9109), -- Silver Arrow
-- Dark Omen Invader Elite Soldier
(21764, 4040, 1, 1, -1, 249035), -- Mold Lubricant
(21764, 4042, 1, 1, -1, 207529), -- Enria
(21764, 5534, 1, 1, -1, 34185), -- Soul Bow Stave
(21764, 57, 6142, 12533, 0, 700000), -- Adena
(21764, 269, 1, 1, 1, 32.611365), -- Blood Tornado
(21764, 5539, 1, 1, 1, 7752.388635), -- Blood Tornado Edge
(21764, 1895, 1, 1, 2, 131359.410125), -- Metallic Fiber
(21764, 4040, 1, 1, 2, 9195.272845), -- Mold Lubricant
(21764, 4042, 1, 1, 2, 7662.65128), -- Enria
(21764, 4043, 1, 1, 2, 15325.30256), -- Asofe
(21764, 5282, 1, 1, 2, 204.53216), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21764, 8731, 1, 1, 2, 4256.82558), -- Life Stone - Level 70
(21764, 8741, 1, 1, 2, 1064.206395), -- Mid-Grade Life Stone - Level 70
(21764, 8751, 1, 1, 2, 106.374985), -- High-Grade Life Stone - Level 70
(21764, 8761, 1, 1, 2, 21.457615), -- Top-Grade Life Stone - Level 70
(21764, 1344, 20, 60, 2, 287348.966455), -- Mithril Arrow
-- Dark Omen Invader Elite Soldier
(21765, 1808, 1, 1, -1, 5639), -- Recipe: Soulshot (S-Grade)
(21765, 5537, 1, 1, -1, 34808), -- Soul Separator Head
(21765, 3036, 1, 1, -1, 5639), -- Recipe: Spiritshot S
(21765, 57, 6259, 12770, 0, 700000), -- Adena
(21765, 288, 1, 1, 1, 33.22764), -- Carnage Bow
(21765, 5535, 1, 1, 1, 7992.77236), -- Carnage Bow Stave
(21765, 1868, 3, 9, 2, 156155.19046), -- Thread
(21765, 1873, 1, 1, 2, 187386.05125), -- Silver Nugget
(21765, 5549, 1, 1, 2, 46846.73444), -- Metallic Thread
(21765, 1889, 1, 1, 2, 31230.86079), -- Compound Braid
(21765, 4044, 1, 1, 2, 15615.430395), -- Thons
(21765, 6901, 1, 1, 2, 468.520535), -- Recipe: Shining Arrow (100%)
(21765, 8731, 1, 1, 2, 4337.69343), -- Life Stone - Level 70
(21765, 8741, 1, 1, 2, 1084.20173), -- Mid-Grade Life Stone - Level 70
(21765, 8751, 1, 1, 2, 108.597475), -- High-Grade Life Stone - Level 70
(21765, 8761, 1, 1, 2, 21.719495), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Elite Soldier
(21766, 5538, 1, 1, -1, 1357), -- Dragon Grinder Edge
(21766, 4041, 1, 1, -1, 4302), -- Mold Hardener
(21766, 1875, 1, 1, -1, 32985), -- Stone of Purity
(21766, 57, 244, 498, 0, 700000), -- Adena
(21766, 235, 1, 1, 1, 1.295424), -- Bloody Orchid
(21766, 5536, 1, 1, 1, 310.704576), -- Bloody Orchid Head
(21766, 1872, 1, 1, 2, 22143.894474), -- Animal Bone
(21766, 1867, 1, 1, 2, 22143.894474), -- Animal Skin
(21766, 1881, 1, 1, 2, 2214.368832), -- Coarse Bone Powder
(21766, 1875, 1, 1, 2, 1107.184416), -- Stone of Purity
(21766, 4041, 1, 1, 2, 144.445236), -- Mold Hardener
(21766, 1808, 1, 1, 2, 7.352826), -- Recipe: Soulshot (S-Grade)
(21766, 8731, 1, 1, 2, 153.790884), -- Life Stone - Level 70
(21766, 8741, 1, 1, 2, 38.413362), -- Mid-Grade Life Stone - Level 70
(21766, 8751, 1, 1, 2, 3.848208), -- High-Grade Life Stone - Level 70
(21766, 8761, 1, 1, 2, 0.755898), -- Top-Grade Life Stone - Level 70
(21766, 1344, 10, 30, 2, 20760.05139), -- Mithril Arrow
-- Dark Omen Invader Elite Soldier
(21767, 5536, 1, 1, -1, 5023), -- Bloody Orchid Head
(21767, 729, 1, 1, -1, 164), -- Scroll: Enchant Weapon (A-Grade)
(21767, 4044, 1, 1, -1, 49211), -- Thons
(21767, 57, 584, 1188, 0, 700000), -- Adena
(21767, 269, 1, 1, 1, 3.091482), -- Blood Tornado
(21767, 5539, 1, 1, 1, 734.908518), -- Blood Tornado Edge
(21767, 1868, 1, 1, 2, 87216.700884), -- Thread
(21767, 1873, 1, 1, 2, 17443.385784), -- Silver Nugget
(21767, 5549, 1, 1, 2, 4360.846446), -- Metallic Thread
(21767, 1889, 1, 1, 2, 2907.230964), -- Compound Braid
(21767, 4044, 1, 1, 2, 1453.615482), -- Thons
(21767, 5456, 1, 1, 2, 16.190556), -- Recipe: Tallum Glaive(60%)
(21767, 8730, 1, 1, 2, 484.5765), -- Life Stone - Level 67
(21767, 8740, 1, 1, 2, 121.087116), -- Mid-Grade Life Stone - Level 67
(21767, 8750, 1, 1, 2, 12.085908), -- High-Grade Life Stone - Level 67
(21767, 8760, 1, 1, 2, 2.28036), -- Top-Grade Life Stone - Level 67
-- Dark Omen Invader Warrior
(21768, 6337, 1, 1, -1, 61505), -- Recipe: Sealed Majestic Earring(70%)
(21768, 5535, 1, 1, -1, 40923), -- Carnage Bow Stave
(21768, 6339, 1, 1, -1, 92257), -- Recipe: Sealed Majestic Ring(70%)
(21768, 57, 5923, 12058, 0, 700000), -- Adena
(21768, 235, 1, 1, 1, 31.40988), -- Bloody Orchid
(21768, 5536, 1, 1, 1, 7533.59012), -- Bloody Orchid Head
(21768, 1871, 1, 3, 2, 221417.291809), -- Charcoal
(21768, 1866, 1, 3, 2, 98407.606206), -- Suede
(21768, 1877, 1, 1, 2, 17713.4118), -- Adamantite Nugget
(21768, 4041, 1, 1, 2, 3850.710766), -- Mold Hardener
(21768, 4040, 1, 1, 2, 8856.7059), -- Mold Lubricant
(21768, 5162, 1, 1, 2, 196.697123), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21768, 8731, 1, 1, 2, 4100.405848), -- Life Stone - Level 70
(21768, 8741, 1, 1, 2, 1025.101462), -- Mid-Grade Life Stone - Level 70
(21768, 8751, 1, 1, 2, 102.439008), -- High-Grade Life Stone - Level 70
(21768, 8761, 1, 1, 2, 20.630078), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Elite Soldier
(21769, 6671, 1, 3, -1, 737151), -- Deluxe Chest Key - Grade 7
(21769, 5478, 1, 1, -1, 111577), -- Sealed Dark Crystal Leather Armor Pattern
(21769, 729, 1, 1, -1, 1474), -- Scroll: Enchant Weapon (A-Grade)
(21769, 57, 5248, 10676, 0, 700000), -- Adena
(21769, 6671, 1, 1, 1, 435485.9027), -- Deluxe Chest Key - Grade 7
(21769, 8730, 1, 1, 1, 43548.344656), -- Life Stone - Level 67
(21769, 8740, 1, 1, 1, 10887.086164), -- Mid-Grade Life Stone - Level 67
(21769, 8750, 1, 1, 1, 1088.561248), -- High-Grade Life Stone - Level 67
(21769, 8760, 1, 1, 1, 218.105232), -- Top-Grade Life Stone - Level 67
-- Dark Omen Invader Elite Soldier
(21770, 6671, 1, 3, -1, 646418), -- Deluxe Chest Key - Grade 7
(21770, 1894, 1, 1, -1, 408264), -- Crafted Leather
(21770, 57, 5746, 11699, 0, 700000), -- Adena
(21770, 6671, 1, 3, 1, 238677.24872), -- Deluxe Chest Key - Grade 7
(21770, 8731, 1, 1, 1, 39779.637985), -- Life Stone - Level 70
(21770, 8741, 1, 1, 1, 9944.981895), -- Mid-Grade Life Stone - Level 70
(21770, 8751, 1, 1, 1, 994.46923), -- High-Grade Life Stone - Level 70
(21770, 8761, 1, 1, 1, 198.66217), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Elite Soldier
(21771, 729, 1, 1, -1, 1453), -- Scroll: Enchant Weapon (A-Grade)
(21771, 730, 1, 1, -1, 10901), -- Scroll: Enchant Armor (A-Grade)
(21771, 5479, 1, 1, -1, 77403), -- Sealed Tallum Leather Armor Pattern
(21771, 57, 5173, 10525, 0, 700000), -- Adena
(21771, 235, 1, 1, 1, 27.407352), -- Bloody Orchid
(21771, 5536, 1, 1, 1, 6573.592648), -- Bloody Orchid Head
(21771, 729, 1, 1, 2, 71.553042), -- Scroll: Enchant Weapon (A-Grade)
(21771, 730, 1, 1, 2, 536.647815), -- Scroll: Enchant Armor (A-Grade)
(21771, 8730, 1, 1, 2, 7155.313967), -- Life Stone - Level 67
(21771, 8740, 1, 1, 2, 1788.82605), -- Mid-Grade Life Stone - Level 67
(21771, 8750, 1, 1, 2, 178.882605), -- High-Grade Life Stone - Level 67
(21771, 8760, 1, 1, 2, 35.776521), -- Top-Grade Life Stone - Level 67
-- Dark Omen Invader Elite Soldier
(21772, 729, 1, 1, -1, 1352), -- Scroll: Enchant Weapon (A-Grade)
(21772, 730, 1, 1, -1, 10141), -- Scroll: Enchant Armor (A-Grade)
(21772, 6901, 1, 1, -1, 12169), -- Recipe: Shining Arrow (100%)
(21772, 57, 6003, 12248, 0, 700000), -- Adena
(21772, 212, 1, 1, 1, 7.96708), -- Dasparion's Staff
(21772, 5543, 1, 1, 1, 1912.030584), -- Dasparion's Staff Head
(21772, 2504, 1, 1, 1, 7.96708), -- Meteor Shower
(21772, 5532, 1, 1, 1, 1894.175176), -- Meteor Shower Head
(21772, 7894, 1, 1, 1, 7.96708), -- Spiritual Eye
(21772, 8341, 1, 1, 1, 1891.750744), -- Spiritual Eye Piece
(21772, 7899, 1, 1, 1, 7.96708), -- Destroyer Hammer
(21772, 8346, 1, 1, 1, 1894.175176), -- Hammer Piece of Destroyer
(21772, 729, 1, 1, 2, 83.209189), -- Scroll: Enchant Weapon (A-Grade)
(21772, 730, 1, 1, 2, 624.073709), -- Scroll: Enchant Armor (A-Grade)
(21772, 8731, 1, 1, 2, 6934.153387), -- Life Stone - Level 70
(21772, 8741, 1, 1, 2, 1733.535951), -- Mid-Grade Life Stone - Level 70
(21772, 8751, 1, 1, 2, 173.35647), -- High-Grade Life Stone - Level 70
(21772, 8761, 1, 1, 2, 34.671294), -- Top-Grade Life Stone - Level 70
-- Dark Omen Invader Magus
(21773, 729, 1, 1, -1, 1233), -- Scroll: Enchant Weapon (A-Grade)
(21773, 730, 1, 1, -1, 9245), -- Scroll: Enchant Armor (A-Grade)
(21773, 5482, 1, 1, -1, 146420), -- Sealed Dark Crystal Leggings Design
(21773, 57, 5478, 11154, 0, 700000), -- Adena
(21773, 288, 1, 1, 1, 29.05452), -- Carnage Bow
(21773, 5535, 1, 1, 1, 6988.94548), -- Carnage Bow Stave
(21773, 729, 1, 1, 2, 75.854688), -- Scroll: Enchant Weapon (A-Grade)
(21773, 730, 1, 1, 2, 568.914528), -- Scroll: Enchant Armor (A-Grade)
(21773, 8731, 1, 1, 2, 6321.273504), -- Life Stone - Level 70
(21773, 8741, 1, 1, 2, 1580.316192), -- Mid-Grade Life Stone - Level 70
(21773, 8751, 1, 1, 2, 158.03424), -- High-Grade Life Stone - Level 70
(21773, 8761, 1, 1, 2, 31.606848), -- Top-Grade Life Stone - Level 70
-- Messenger Invader Soldier
(21774, 1876, 1, 3, -1, 765263), -- Mithril Ore
(21774, 1895, 1, 5, -1, 728822), -- Metallic Fiber
(21774, 5546, 1, 1, -1, 23061), -- Sword of Miracles Edge
(21774, 57, 3773, 7702, 0, 700000), -- Adena
(21774, 305, 1, 1, 1, 13.623552), -- Tallum Glaive
(21774, 5541, 1, 1, 1, 3874.376448), -- Tallum Glaive Edge
(21774, 1873, 1, 1, 2, 125581.51365), -- Silver Nugget
(21774, 1868, 3, 9, 2, 104651.000505), -- Thread
(21774, 1876, 1, 1, 2, 62790.756825), -- Mithril Ore
(21774, 1895, 1, 1, 2, 89700.801675), -- Metallic Fiber
(21774, 4042, 1, 1, 2, 5232.53046), -- Enria
(21774, 959, 1, 1, 2, 12.52176), -- Scroll: Enchant Weapon (S-Grade)
(21774, 8732, 1, 1, 2, 2616.26523), -- Life Stone - Level 76
(21774, 8742, 1, 1, 2, 654.26196), -- Mid-Grade Life Stone - Level 76
(21774, 8752, 1, 1, 2, 65.347935), -- High-Grade Life Stone - Level 76
-- Messenger Invader Soldier
(21775, 960, 1, 1, -1, 3646), -- Scroll: Enchant Armor (S-Grade)
(21775, 4041, 1, 1, -1, 79260), -- Mold Hardener
(21775, 5220, 1, 1, -1, 364595), -- Metal Hardener
(21775, 57, 4493, 9173, 0, 700000), -- Adena
(21775, 5311, 1, 1, 1, 19.112697), -- Sealed Armor of Nightmare
(21775, 5522, 1, 1, 1, 2865.387303), -- Sealed Armor of Nightmare Pattern
(21775, 5316, 1, 1, 1, 19.112697), -- Sealed Majestic Plate Armor
(21775, 5523, 1, 1, 1, 2865.387303), -- Sealed Majestic Plate Armor Pattern
(21775, 1866, 1, 1, 2, 249295.545558), -- Suede
(21775, 1871, 1, 3, 2, 186971.903982), -- Charcoal
(21775, 5220, 1, 1, 2, 14957.615223), -- Metal Hardener
(21775, 1885, 1, 1, 2, 31161.820788), -- High-Grade Suede
(21775, 4041, 1, 1, 2, 3251.612907), -- Mold Hardener
(21775, 959, 1, 1, 2, 15.178437), -- Scroll: Enchant Weapon (S-Grade)
(21775, 8732, 1, 1, 2, 3115.986228), -- Life Stone - Level 76
(21775, 8742, 1, 1, 2, 778.996557), -- Mid-Grade Life Stone - Level 76
(21775, 8752, 1, 1, 2, 78.34032), -- High-Grade Life Stone - Level 76
-- Messenger Invader Archer
(21776, 6707, 1, 1, -1, 37008), -- Sealed Draconic Leather Armor Part
(21776, 6708, 1, 1, -1, 106346), -- Sealed Draconic Leather Gloves Fabric
(21776, 6709, 1, 1, -1, 106346), -- Sealed Draconic Leather Boots Design
(21776, 57, 3684, 7518, 0, 700000), -- Adena
(21776, 5326, 1, 1, 1, 20.884591), -- Sealed Robe of Nightmare
(21776, 5487, 1, 1, 1, 3104.615409), -- Sealed Robe of Nightmare Fabric
(21776, 5329, 1, 1, 1, 20.884591), -- Sealed Majestic Robe
(21776, 5488, 1, 1, 1, 3104.615409), -- Sealed Majestic Robe Fabric
(21776, 1867, 1, 3, 2, 183857.10798), -- Animal Skin
(21776, 1872, 1, 3, 2, 122571.40532), -- Animal Bone
(21776, 1882, 1, 1, 2, 61285.70266), -- Leather
(21776, 1894, 1, 1, 2, 9676.789096), -- Crafted Leather
(21776, 4042, 1, 1, 2, 4596.663305), -- Enria
(21776, 960, 1, 1, 2, 110.263374), -- Scroll: Enchant Armor (S-Grade)
(21776, 8732, 1, 1, 2, 2298.096047), -- Life Stone - Level 76
(21776, 8742, 1, 1, 2, 574.406209), -- Mid-Grade Life Stone - Level 76
(21776, 8752, 1, 1, 2, 57.487742), -- High-Grade Life Stone - Level 76
(21776, 1344, 40, 120, 2, 86183.078267), -- Mithril Arrow
-- Messenger Invader Elite Soldier
(21777, 6691, 1, 1, -1, 16925), -- Angel Slayer Blade
(21777, 6693, 1, 1, -1, 17232), -- Dragon Hunter Axe Blade
(21777, 6694, 1, 1, -1, 17232), -- Saint Spear Blade
(21777, 57, 3860, 7880, 0, 700000), -- Adena
(21777, 5326, 1, 1, 1, 21.893573), -- Sealed Robe of Nightmare
(21777, 5487, 1, 1, 1, 3254.606427), -- Sealed Robe of Nightmare Fabric
(21777, 5329, 1, 1, 1, 21.893573), -- Sealed Majestic Robe
(21777, 5488, 1, 1, 1, 3254.606427), -- Sealed Majestic Robe Fabric
(21777, 1869, 2, 6, 2, 72280.060965), -- Iron Ore
(21777, 1864, 5, 15, 2, 57824.048772), -- Stem
(21777, 1880, 1, 1, 2, 28912.024386), -- Steel
(21777, 5550, 1, 1, 2, 3854.857608), -- Durable Metal Plate
(21777, 4043, 1, 1, 2, 9637.440183), -- Asofe
(21777, 960, 1, 1, 2, 115.50357), -- Scroll: Enchant Armor (S-Grade)
(21777, 8732, 1, 1, 2, 2409.286005), -- Life Stone - Level 76
(21777, 8742, 1, 1, 2, 602.395542), -- Mid-Grade Life Stone - Level 76
(21777, 8752, 1, 1, 2, 60.121089), -- High-Grade Life Stone - Level 76
(21777, 1344, 30, 90, 2, 120467.26188), -- Mithril Arrow
-- Messenger Invader Shaman
(21778, 960, 1, 1, -1, 3267), -- Scroll: Enchant Armor (S-Grade)
(21778, 4042, 1, 1, -1, 136119), -- Enria
(21778, 4043, 1, 1, -1, 272238), -- Asofe
(21778, 57, 4028, 8221, 0, 700000), -- Adena
(21778, 6327, 1, 1, 1, 67.101165), -- Sealed Majestic Earring
(21778, 6342, 1, 1, 1, 11385.396355), -- Sealed Majestic Earring Gemstone
(21778, 6326, 1, 1, 1, 50.31704), -- Sealed Majestic Necklace
(21778, 6344, 1, 1, 1, 7367.98353), -- Sealed Majestic Necklace Beads
(21778, 6328, 1, 1, 1, 100.63408), -- Sealed Majestic Ring
(21778, 6346, 1, 1, 1, 16363.56783), -- Sealed Majestic Ring Gemstone
(21778, 1895, 1, 1, 2, 107698.69836), -- Metallic Fiber
(21778, 4040, 1, 1, 2, 7538.87574), -- Mold Lubricant
(21778, 4042, 1, 1, 2, 6282.39645), -- Enria
(21778, 4043, 1, 1, 2, 12564.7929), -- Asofe
(21778, 959, 1, 1, 2, 15.053445), -- Scroll: Enchant Weapon (S-Grade)
(21778, 8732, 1, 1, 2, 3141.198225), -- Life Stone - Level 76
(21778, 8742, 1, 1, 2, 785.26503), -- Mid-Grade Life Stone - Level 76
(21778, 8752, 1, 1, 2, 78.71985), -- High-Grade Life Stone - Level 76
-- Messenger Invader Priest
(21779, 5162, 1, 1, -1, 2201), -- Recipe: Spiritshot (S) Compressed Package (100%)
(21779, 6342, 1, 1, -1, 112188), -- Sealed Majestic Earring Gemstone
(21779, 5167, 1, 1, -1, 2201), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21779, 57, 2441, 4984, 0, 700000), -- Adena
(21779, 5320, 1, 1, 1, 13.847112), -- Sealed Leather Armor of Nightmare
(21779, 5480, 1, 1, 1, 2051.652888), -- Sealed Leather Armor of Nightmare Fabric
(21779, 5323, 1, 1, 1, 13.847112), -- Sealed Majestic Leather Armor
(21779, 5481, 1, 1, 1, 2051.652888), -- Sealed Majestic Leather Armor Fabric
(21779, 1894, 1, 1, 2, 7129.135104), -- Crafted Leather
(21779, 4039, 1, 1, 2, 6772.73408), -- Mold Glue
(21779, 4041, 1, 1, 2, 1766.67904), -- Mold Hardener
(21779, 4044, 1, 1, 2, 6772.73408), -- Thons
(21779, 960, 1, 1, 2, 81.367552), -- Scroll: Enchant Armor (S-Grade)
(21779, 8732, 1, 1, 2, 1693.113856), -- Life Stone - Level 76
(21779, 8742, 1, 1, 2, 423.278464), -- Mid-Grade Life Stone - Level 76
(21779, 8752, 1, 1, 2, 42.355712), -- High-Grade Life Stone - Level 76
(21779, 1344, 10, 30, 2, 253974.602112), -- Mithril Arrow
-- Messenger Invader Magus
(21780, 959, 1, 1, -1, 277), -- Scroll: Enchant Weapon (S-Grade)
(21780, 1894, 1, 1, -1, 243319), -- Crafted Leather
(21780, 4042, 1, 1, -1, 115576), -- Enria
(21780, 57, 3419, 6979, 0, 700000), -- Adena
(21780, 6327, 1, 1, 1, 56.975697), -- Sealed Majestic Earring
(21780, 6342, 1, 1, 1, 9667.356639), -- Sealed Majestic Earring Gemstone
(21780, 6326, 1, 1, 1, 42.724272), -- Sealed Majestic Necklace
(21780, 6344, 1, 1, 1, 6256.165554), -- Sealed Majestic Necklace Beads
(21780, 6328, 1, 1, 1, 85.448544), -- Sealed Majestic Ring
(21780, 6346, 1, 1, 1, 13894.329294), -- Sealed Majestic Ring Gemstone
(21780, 1867, 1, 3, 2, 189664.15704), -- Animal Skin
(21780, 1872, 1, 3, 2, 126442.506636), -- Animal Bone
(21780, 1882, 1, 1, 2, 63221.253318), -- Leather
(21780, 1894, 1, 1, 2, 9982.344954), -- Crafted Leather
(21780, 4042, 1, 1, 2, 4741.603926), -- Enria
(21780, 959, 1, 1, 2, 11.515494), -- Scroll: Enchant Weapon (S-Grade)
(21780, 8732, 1, 1, 2, 2370.60342), -- Life Stone - Level 76
(21780, 8742, 1, 1, 2, 592.849398), -- Mid-Grade Life Stone - Level 76
(21780, 8752, 1, 1, 2, 59.165814), -- High-Grade Life Stone - Level 76
-- Messenger Invader Martyrs
(21781, 6344, 1, 1, -1, 91077), -- Sealed Majestic Necklace Beads
(21781, 4041, 1, 1, -1, 54024), -- Mold Hardener
(21781, 4040, 1, 1, -1, 124256), -- Mold Lubricant
(21781, 57, 3063, 6253, 0, 700000), -- Adena
(21781, 5311, 1, 1, 1, 13.026716), -- Sealed Armor of Nightmare
(21781, 5522, 1, 1, 1, 1952.973284), -- Sealed Armor of Nightmare Pattern
(21781, 5316, 1, 1, 1, 13.026716), -- Sealed Majestic Plate Armor
(21781, 5523, 1, 1, 1, 1952.973284), -- Sealed Majestic Plate Armor Pattern
(21781, 1871, 1, 1, 2, 254884.450515), -- Charcoal
(21781, 1866, 1, 1, 2, 169922.818665), -- Suede
(21781, 1877, 1, 1, 2, 10195.306815), -- Adamantite Nugget
(21781, 4041, 1, 1, 2, 2216.2743), -- Mold Hardener
(21781, 4040, 1, 1, 2, 5097.875925), -- Mold Lubricant
(21781, 959, 1, 1, 2, 10.235805), -- Scroll: Enchant Weapon (S-Grade)
(21781, 8732, 1, 1, 2, 2124.152055), -- Life Stone - Level 76
(21781, 8742, 1, 1, 2, 530.926755), -- Mid-Grade Life Stone - Level 76
(21781, 8752, 1, 1, 2, 52.959165), -- High-Grade Life Stone - Level 76
-- Messenger Invader Warrior
(21782, 6710, 1, 1, -1, 107136), -- Sealed Draconic Leather Helmet Pattern
(21782, 6711, 1, 1, -1, 32723), -- Sealed Major Arcana Robe Part
(21782, 6712, 1, 1, -1, 94033), -- Sealed Major Arcana Gloves fabric
(21782, 57, 3257, 6648, 0, 700000), -- Adena
(21782, 5314, 1, 1, 1, 44.992152), -- Sealed Boots of Nightmare
(21782, 5502, 1, 1, 1, 5148.007848), -- Sealed Boots of Nightmare Lining
(21782, 5319, 1, 1, 1, 44.992152), -- Sealed Majestic Boots
(21782, 5503, 1, 1, 1, 5148.007848), -- Sealed Majestic Boots Lining
(21782, 5313, 1, 1, 1, 44.992152), -- Sealed Gauntlets of Nightmare
(21782, 5514, 1, 1, 1, 5148.007848), -- Sealed Gauntlets of Nightmare Design
(21782, 5318, 1, 1, 1, 44.992152), -- Sealed Majestic Gauntlets
(21782, 5515, 1, 1, 1, 5148.007848), -- Sealed Majestic Gauntlets Design
(21782, 1873, 1, 1, 2, 97542.129277), -- Silver Nugget
(21782, 1868, 4, 12, 2, 60963.975289), -- Thread
(21782, 1876, 1, 1, 2, 48770.871984), -- Mithril Ore
(21782, 1895, 1, 1, 2, 69673.114616), -- Metallic Fiber
(21782, 4042, 1, 1, 2, 4064.239332), -- Enria
(21782, 960, 1, 1, 2, 97.483177), -- Scroll: Enchant Armor (S-Grade)
(21782, 8732, 1, 1, 2, 2032.119666), -- Life Stone - Level 76
(21782, 8742, 1, 1, 2, 508.222571), -- Mid-Grade Life Stone - Level 76
(21782, 8752, 1, 1, 2, 50.860788), -- High-Grade Life Stone - Level 76
(21782, 1344, 30, 90, 2, 101605.9833), -- Mithril Arrow
-- Messenger Invader Soldier
(21783, 6346, 1, 1, -1, 212950), -- Sealed Majestic Ring Gemstone
(21783, 5272, 1, 1, -1, 2907), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21783, 5480, 1, 1, -1, 29350), -- Sealed Leather Armor of Nightmare Fabric
(21783, 57, 3224, 6583, 0, 700000), -- Adena
(21783, 5326, 1, 1, 1, 18.288634), -- Sealed Robe of Nightmare
(21783, 5487, 1, 1, 1, 2718.711366), -- Sealed Robe of Nightmare Fabric
(21783, 5329, 1, 1, 1, 18.288634), -- Sealed Majestic Robe
(21783, 5488, 1, 1, 1, 2718.711366), -- Sealed Majestic Robe Fabric
(21783, 1865, 1, 3, 2, 80501.604066), -- Varnish
(21783, 1870, 2, 6, 2, 60376.114134), -- Coal
(21783, 1879, 1, 1, 2, 40250.624202), -- Cokes
(21783, 1875, 1, 1, 2, 16100.463078), -- Stone of Purity
(21783, 4040, 1, 1, 2, 4830.245622), -- Mold Lubricant
(21783, 960, 1, 1, 2, 96.740064), -- Scroll: Enchant Armor (S-Grade)
(21783, 8732, 1, 1, 2, 2012.691258), -- Life Stone - Level 76
(21783, 8742, 1, 1, 2, 503.26173), -- Mid-Grade Life Stone - Level 76
(21783, 8752, 1, 1, 2, 50.148342), -- High-Grade Life Stone - Level 76
(21783, 1344, 20, 60, 2, 150940.107504), -- Mithril Arrow
-- Messenger Invader Disciple
(21784, 959, 1, 1, -1, 278), -- Scroll: Enchant Weapon (S-Grade)
(21784, 4041, 1, 1, -1, 60474), -- Mold Hardener
(21784, 4044, 1, 1, -1, 231818), -- Thons
(21784, 57, 3430, 7000, 0, 700000), -- Adena
(21784, 5315, 1, 1, 1, 60.193125), -- Sealed Shield of Nightmare
(21784, 5495, 1, 1, 1, 6498.005625), -- Sealed Shield of Nightmare Fragment
(21784, 5312, 1, 1, 1, 42.12), -- Sealed Helm of Nightmare
(21784, 5527, 1, 1, 1, 5116.280625), -- Sealed Helm of Nightmare Design
(21784, 5317, 1, 1, 1, 42.12), -- Sealed Majestic Circlet
(21784, 5528, 1, 1, 1, 5116.280625), -- Sealed Majestic Circlet Design
(21784, 1894, 1, 1, 2, 11262.32075), -- Crafted Leather
(21784, 4039, 1, 1, 2, 10699.1775), -- Mold Glue
(21784, 4041, 1, 1, 2, 2791.108375), -- Mold Hardener
(21784, 4044, 1, 1, 2, 10699.1775), -- Thons
(21784, 959, 1, 1, 2, 12.82875), -- Scroll: Enchant Weapon (S-Grade)
(21784, 8732, 1, 1, 2, 2674.794375), -- Life Stone - Level 76
(21784, 8742, 1, 1, 2, 668.688875), -- Mid-Grade Life Stone - Level 76
(21784, 8752, 1, 1, 2, 66.903875), -- High-Grade Life Stone - Level 76
-- Messenger Invader Berserker
(21785, 6695, 1, 1, -1, 16395), -- Demon Splinter Blade
(21785, 6696, 1, 1, -1, 16975), -- Heavens Divider Edge
(21785, 6697, 1, 1, -1, 16395), -- Arcana Mace Head
(21785, 57, 3811, 7780, 0, 700000), -- Adena
(21785, 5314, 1, 1, 1, 52.664124), -- Sealed Boots of Nightmare
(21785, 5502, 1, 1, 1, 6025.835876), -- Sealed Boots of Nightmare Lining
(21785, 5319, 1, 1, 1, 52.664124), -- Sealed Majestic Boots
(21785, 5503, 1, 1, 1, 6025.835876), -- Sealed Majestic Boots Lining
(21785, 5313, 1, 1, 1, 52.664124), -- Sealed Gauntlets of Nightmare
(21785, 5514, 1, 1, 1, 6025.835876), -- Sealed Gauntlets of Nightmare Design
(21785, 5318, 1, 1, 1, 52.664124), -- Sealed Majestic Gauntlets
(21785, 5515, 1, 1, 1, 6025.835876), -- Sealed Majestic Gauntlets Design
(21785, 1868, 4, 12, 2, 71360.98215), -- Thread
(21785, 1873, 1, 1, 2, 114177.93615), -- Silver Nugget
(21785, 5549, 1, 1, 2, 28544.39286), -- Metallic Thread
(21785, 1889, 1, 1, 2, 19029.47367), -- Compound Braid
(21785, 4044, 1, 1, 2, 9514.91919), -- Thons
(21785, 960, 1, 1, 2, 114.15423), -- Scroll: Enchant Armor (S-Grade)
(21785, 8732, 1, 1, 2, 2378.63862), -- Life Stone - Level 76
(21785, 8742, 1, 1, 2, 594.84201), -- Mid-Grade Life Stone - Level 76
(21785, 8752, 1, 1, 2, 59.44773), -- High-Grade Life Stone - Level 76
(21785, 1344, 30, 90, 2, 118935.21339), -- Mithril Arrow
-- Messenger Invader Food
(21786, 5277, 1, 1, -1, 1183), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(21786, 5481, 1, 1, -1, 11948), -- Sealed Majestic Leather Armor Fabric
(21786, 5220, 1, 1, -1, 106505), -- Metal Hardener
(21786, 57, 1313, 2680, 0, 700000), -- Adena
(21786, 6327, 1, 1, 1, 21.87648), -- Sealed Majestic Earring
(21786, 6342, 1, 1, 1, 3711.89376), -- Sealed Majestic Earring Gemstone
(21786, 6326, 1, 1, 1, 16.40448), -- Sealed Majestic Necklace
(21786, 6344, 1, 1, 1, 2402.12736), -- Sealed Majestic Necklace Beads
(21786, 6328, 1, 1, 1, 32.80896), -- Sealed Majestic Ring
(21786, 6346, 1, 1, 1, 5334.88896), -- Sealed Majestic Ring Gemstone
(21786, 1866, 1, 1, 2, 72824.004294), -- Suede
(21786, 1871, 1, 1, 2, 109236.109814), -- Charcoal
(21786, 5220, 1, 1, 2, 4369.369964), -- Metal Hardener
(21786, 1885, 1, 1, 2, 9103.02638), -- High-Grade Suede
(21786, 4041, 1, 1, 2, 949.791124), -- Mold Hardener
(21786, 6672, 1, 1, 2, 9103.02638), -- Deluxe Chest Key - Grade 8
(21786, 8732, 1, 1, 2, 910.302638), -- Life Stone - Level 76
(21786, 8742, 1, 1, 2, 227.627346), -- Mid-Grade Life Stone - Level 76
(21786, 8752, 1, 1, 2, 22.74206), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21787, 960, 1, 1, -1, 6509), -- Scroll: Enchant Armor (S-Grade)
(21787, 6688, 1, 1, -1, 35174), -- Forgotten Blade Edge
(21787, 959, 1, 1, -1, 651), -- Scroll: Enchant Weapon (S-Grade)
(21787, 57, 8022, 16377, 0, 700000), -- Adena
(21787, 5315, 1, 1, 1, 140.846562), -- Sealed Shield of Nightmare
(21787, 5495, 1, 1, 1, 15204.755562), -- Sealed Shield of Nightmare Fragment
(21787, 5312, 1, 1, 1, 98.557056), -- Sealed Helm of Nightmare
(21787, 5527, 1, 1, 1, 11971.641882), -- Sealed Helm of Nightmare Design
(21787, 5317, 1, 1, 1, 98.557056), -- Sealed Majestic Circlet
(21787, 5528, 1, 1, 1, 11971.641882), -- Sealed Majestic Circlet Design
(21787, 1864, 4, 12, 2, 166904.233588), -- Stem
(21787, 1865, 2, 6, 2, 133523.674085), -- Varnish
(21787, 1866, 3, 9, 2, 74179.872124), -- Suede
(21787, 1873, 4, 12, 2, 33381.038194), -- Silver Nugget
(21787, 1868, 10, 30, 2, 63582.610766), -- Thread
(21787, 959, 1, 1, 2, 26.806696), -- Scroll: Enchant Weapon (S-Grade)
(21787, 8732, 1, 1, 2, 5563.346802), -- Life Stone - Level 76
(21787, 8742, 1, 1, 2, 1391.076046), -- Mid-Grade Life Stone - Level 76
(21787, 8752, 1, 1, 2, 138.341699), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21788, 6698, 1, 1, -1, 325700), -- Sealed Tateossian Earring Part
(21788, 6699, 1, 1, -1, 361407), -- Sealed Tateossian Ring Gem
(21788, 6700, 1, 1, -1, 198508), -- Sealed Tateossian Necklace Chain
(21788, 57, 8174, 16687, 0, 700000), -- Adena
(21788, 81, 1, 1, 1, 9.8397), -- Dragon Slayer
(21788, 5529, 1, 1, 1, 2798.3724), -- Dragon Slayer Edge
(21788, 151, 1, 1, 1, 9.8397), -- Sword of Miracles
(21788, 5546, 1, 1, 1, 3073.7448), -- Sword of Miracles Edge
(21788, 2500, 1, 1, 1, 9.8397), -- Dark Legion's Edge
(21788, 5545, 1, 1, 1, 2798.3637), -- Dark Legion's Edge Blade
(21788, 1869, 2, 6, 2, 122447.124952), -- Iron Ore
(21788, 1870, 3, 9, 2, 102038.991404), -- Coal
(21788, 1871, 3, 9, 2, 87461.992632), -- Charcoal
(21788, 1872, 8, 24, 2, 51019.705244), -- Animal Bone
(21788, 1867, 13, 39, 2, 30233.977012), -- Animal Skin
(21788, 960, 1, 1, 2, 244.745056), -- Scroll: Enchant Armor (S-Grade)
(21788, 8732, 1, 1, 2, 5101.928616), -- Life Stone - Level 76
(21788, 8742, 1, 1, 2, 1275.691696), -- Mid-Grade Life Stone - Level 76
(21788, 8752, 1, 1, 2, 127.401536), -- High-Grade Life Stone - Level 76
(21788, 1344, 400, 1200, 2, 19132.441852), -- Mithril Arrow
-- Messenger Invader Elite Soldier
(21789, 959, 1, 1, -1, 26), -- Scroll: Enchant Weapon (S-Grade)
(21789, 1894, 1, 1, -1, 22689), -- Crafted Leather
(21789, 4039, 1, 1, -1, 21554), -- Mold Glue
(21789, 57, 319, 651, 0, 700000), -- Adena
(21789, 164, 1, 1, 1, 0.288204), -- Elysian
(21789, 5533, 1, 1, 1, 81.986142), -- Elysian Head
(21789, 213, 1, 1, 1, 0.288204), -- Branch of the Mother Tree
(21789, 5544, 1, 1, 1, 81.905208), -- Branch of the Mother Tree Head
(21789, 7895, 1, 1, 1, 0.288204), -- Flaming Dragon Skull
(21789, 8342, 1, 1, 1, 81.986142), -- Flaming Dragon Skull Piece
(21789, 7902, 1, 1, 1, 0.288204), -- Doom Crusher
(21789, 8349, 1, 1, 1, 81.969692), -- Doom Crusher Head
(21789, 1894, 1, 1, 2, 1047.28719), -- Crafted Leather
(21789, 4039, 1, 1, 2, 994.9203), -- Mold Glue
(21789, 4041, 1, 1, 2, 259.546155), -- Mold Hardener
(21789, 4044, 1, 1, 2, 994.9203), -- Thons
(21789, 959, 1, 1, 2, 1.19295), -- Scroll: Enchant Weapon (S-Grade)
(21789, 8732, 1, 1, 2, 248.730075), -- Life Stone - Level 76
(21789, 8742, 1, 1, 2, 62.181615), -- Mid-Grade Life Stone - Level 76
(21789, 8752, 1, 1, 2, 6.221415), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21790, 5550, 1, 1, -1, 21088), -- Durable Metal Plate
(21790, 5487, 1, 1, -1, 7122), -- Sealed Robe of Nightmare Fabric
(21790, 5282, 1, 1, -1, 703), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21790, 57, 780, 1592, 0, 700000), -- Adena
(21790, 5314, 1, 1, 1, 10.773684), -- Sealed Boots of Nightmare
(21790, 5502, 1, 1, 1, 1232.726316), -- Sealed Boots of Nightmare Lining
(21790, 5319, 1, 1, 1, 10.773684), -- Sealed Majestic Boots
(21790, 5503, 1, 1, 1, 1232.726316), -- Sealed Majestic Boots Lining
(21790, 5313, 1, 1, 1, 10.773684), -- Sealed Gauntlets of Nightmare
(21790, 5514, 1, 1, 1, 1232.726316), -- Sealed Gauntlets of Nightmare Design
(21790, 5318, 1, 1, 1, 10.773684), -- Sealed Majestic Gauntlets
(21790, 5515, 1, 1, 1, 1232.726316), -- Sealed Majestic Gauntlets Design
(21790, 1869, 1, 1, 2, 58397.655524), -- Iron Ore
(21790, 1864, 1, 1, 2, 116795.311048), -- Stem
(21790, 1880, 1, 1, 2, 5839.868512), -- Steel
(21790, 5550, 1, 1, 2, 778.631975), -- Durable Metal Plate
(21790, 4043, 1, 1, 2, 1946.708637), -- Asofe
(21790, 960, 1, 1, 2, 23.423309), -- Scroll: Enchant Armor (S-Grade)
(21790, 8732, 1, 1, 2, 486.741509), -- Life Stone - Level 76
(21790, 8742, 1, 1, 2, 121.749727), -- Mid-Grade Life Stone - Level 76
(21790, 8752, 1, 1, 2, 12.097753), -- High-Grade Life Stone - Level 76
(21790, 1344, 10, 30, 2, 72996.812006), -- Mithril Arrow
-- Messenger Invader Warrior
(21791, 960, 1, 1, -1, 6334), -- Scroll: Enchant Armor (S-Grade)
(21791, 1875, 1, 3, -1, 527864), -- Stone of Purity
(21791, 4040, 1, 1, -1, 316718), -- Mold Lubricant
(21791, 57, 7810, 15940, 0, 700000), -- Adena
(21791, 164, 1, 1, 1, 7.04742), -- Elysian
(21791, 5533, 1, 1, 1, 2004.79791), -- Elysian Head
(21791, 213, 1, 1, 1, 7.04742), -- Branch of the Mother Tree
(21791, 5544, 1, 1, 1, 2002.81884), -- Branch of the Mother Tree Head
(21791, 7895, 1, 1, 1, 7.04742), -- Flaming Dragon Skull
(21791, 8342, 1, 1, 1, 2004.79791), -- Flaming Dragon Skull Piece
(21791, 7902, 1, 1, 1, 7.04742), -- Doom Crusher
(21791, 8349, 1, 1, 1, 2004.39566), -- Doom Crusher Head
(21791, 1865, 4, 12, 2, 81209.892433), -- Varnish
(21791, 1870, 1, 3, 2, 216559.556727), -- Coal
(21791, 1879, 1, 1, 2, 108279.543722), -- Cokes
(21791, 1875, 1, 1, 2, 43312.005202), -- Stone of Purity
(21791, 4040, 1, 1, 2, 12993.507704), -- Mold Lubricant
(21791, 959, 1, 1, 2, 25.810565), -- Scroll: Enchant Weapon (S-Grade)
(21791, 8732, 1, 1, 2, 5414.117971), -- Life Stone - Level 76
(21791, 8742, 1, 1, 2, 1353.412172), -- Mid-Grade Life Stone - Level 76
(21791, 8752, 1, 1, 2, 135.153504), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21792, 6672, 1, 3, -1, 592289), -- Deluxe Chest Key - Grade 8
(21792, 1894, 1, 1, -1, 498770), -- Crafted Leather
(21792, 57, 7008, 14306, 0, 700000), -- Adena
(21792, 6672, 1, 3, 1, 273364.229536), -- Deluxe Chest Key - Grade 8
(21792, 8732, 1, 1, 1, 54672.983136), -- Life Stone - Level 76
(21792, 8742, 1, 1, 1, 13668.331552), -- Mid-Grade Life Stone - Level 76
(21792, 8752, 1, 1, 1, 1366.455776), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21793, 6672, 1, 3, -1, 640139), -- Deluxe Chest Key - Grade 8
(21793, 6689, 1, 1, -1, 32582), -- Basalt Battlehammer Head
(21793, 6690, 1, 1, -1, 33271), -- Imperial Staff Head
(21793, 57, 7577, 15464, 0, 700000), -- Adena
(21793, 6672, 1, 3, 1, 295448.698644), -- Deluxe Chest Key - Grade 8
(21793, 8732, 1, 1, 1, 59089.888044), -- Life Stone - Level 76
(21793, 8742, 1, 1, 1, 14772.564708), -- Mid-Grade Life Stone - Level 76
(21793, 8752, 1, 1, 1, 1476.848604), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21794, 959, 1, 1, -1, 561), -- Scroll: Enchant Weapon (S-Grade)
(21794, 960, 1, 1, -1, 5606), -- Scroll: Enchant Armor (S-Grade)
(21794, 1808, 1, 1, -1, 6228), -- Recipe: Soulshot (S-Grade)
(21794, 57, 6908, 14104, 0, 700000), -- Adena
(21794, 81, 1, 1, 1, 8.316243), -- Dragon Slayer
(21794, 5529, 1, 1, 1, 2365.107156), -- Dragon Slayer Edge
(21794, 151, 1, 1, 1, 8.316243), -- Sword of Miracles
(21794, 5546, 1, 1, 1, 2597.844312), -- Sword of Miracles Edge
(21794, 2500, 1, 1, 1, 8.316243), -- Dark Legion's Edge
(21794, 5545, 1, 1, 1, 2365.099803), -- Dark Legion's Edge Blade
(21794, 959, 1, 1, 2, 41.395365), -- Scroll: Enchant Weapon (S-Grade)
(21794, 960, 1, 1, 2, 413.95365), -- Scroll: Enchant Armor (S-Grade)
(21794, 8732, 1, 1, 2, 8624.034375), -- Life Stone - Level 76
(21794, 8742, 1, 1, 2, 2156.005731), -- Mid-Grade Life Stone - Level 76
(21794, 8752, 1, 1, 2, 215.610879), -- High-Grade Life Stone - Level 76
-- Messenger Invader Elite Soldier
(21795, 959, 1, 1, -1, 636), -- Scroll: Enchant Weapon (S-Grade)
(21795, 960, 1, 1, -1, 6361), -- Scroll: Enchant Armor (S-Grade)
(21795, 6691, 1, 1, -1, 34375), -- Angel Slayer Blade
(21795, 57, 7840, 16005, 0, 700000), -- Adena
(21795, 289, 1, 1, 1, 28.3115), -- Soul Bow
(21795, 5534, 1, 1, 1, 8060.6885), -- Soul Bow Stave
(21795, 959, 1, 1, 2, 46.976925), -- Scroll: Enchant Weapon (S-Grade)
(21795, 960, 1, 1, 2, 469.76925), -- Scroll: Enchant Armor (S-Grade)
(21795, 8732, 1, 1, 2, 9786.859375), -- Life Stone - Level 76
(21795, 8742, 1, 1, 2, 2446.711595), -- Mid-Grade Life Stone - Level 76
(21795, 8752, 1, 1, 2, 244.682855), -- High-Grade Life Stone - Level 76
-- Messenger Invader Magus
(21796, 959, 1, 1, -1, 586), -- Scroll: Enchant Weapon (S-Grade)
(21796, 960, 1, 1, -1, 5859), -- Scroll: Enchant Armor (S-Grade)
(21796, 57, 7224, 14744, 0, 700000), -- Adena
(21796, 289, 1, 1, 1, 26.075), -- Soul Bow
(21796, 5534, 1, 1, 1, 7423.925), -- Soul Bow Stave
(21796, 959, 1, 1, 2, 43.267935), -- Scroll: Enchant Weapon (S-Grade)
(21796, 960, 1, 1, 2, 432.67935), -- Scroll: Enchant Armor (S-Grade)
(21796, 8732, 1, 1, 2, 9014.153125), -- Life Stone - Level 76
(21796, 8742, 1, 1, 2, 2253.535289), -- Mid-Grade Life Stone - Level 76
(21796, 8752, 1, 1, 2, 225.364301), -- High-Grade Life Stone - Level 76
-- Spirit of Timiniel
(21797, 2961, 1, 1, -1, 43468), -- Full Plate Boots Part
(21797, 1867, 1, 3, -1, 532190), -- Animal Skin
(21797, 1869, 1, 1, -1, 798286), -- Iron Ore
(21797, 57, 315, 643, 0, 700000), -- Adena
(21797, 2497, 1, 1, 1, 51.030204), -- Full Plate Shield
(21797, 2966, 1, 1, 1, 4032.292964), -- Full Plate Shield Fragment
(21797, 2414, 1, 1, 1, 35.720476), -- Full Plate Helmet
(21797, 2959, 1, 1, 1, 2548.956356), -- Full Plate Helmet Design
(21797, 1869, 1, 1, 2, 26795.514532), -- Iron Ore
(21797, 1870, 1, 1, 2, 26795.514532), -- Coal
(21797, 1871, 1, 1, 2, 26795.514532), -- Charcoal
(21797, 1872, 1, 1, 2, 35727.250588), -- Animal Bone
(21797, 1867, 1, 1, 2, 35727.250588), -- Animal Skin
(21797, 4175, 1, 1, 2, 516.22334), -- Recipe: Sealed Avadon Boots (100%)
(21797, 4972, 1, 1, 2, 30.942764), -- Recipe: Great Axe (60%)
(21797, 8726, 1, 1, 2, 620.233918), -- Life Stone - Level 55
(21797, 8736, 1, 1, 2, 155.020184), -- Mid-Grade Life Stone - Level 55
(21797, 8746, 1, 1, 2, 15.471382), -- High-Grade Life Stone - Level 55
(21797, 8756, 1, 1, 2, 3.06364), -- Top-Grade Life Stone - Level 55
-- Ghost of a Doorman
(21798, 5487, 1, 1, -1, 18126), -- Sealed Robe of Nightmare Fabric
(21798, 5282, 1, 1, -1, 1789), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21798, 5488, 1, 1, -1, 18126), -- Sealed Majestic Robe Fabric
(21798, 57, 1980, 4055, 0, 700000), -- Adena
(21798, 12222, 1, 1, 1, 359.776175), -- Common Item - Sealed Dark Crystal Leather Armor
(21798, 5478, 1, 1, 1, 2082.9424), -- Sealed Dark Crystal Leather Armor Pattern
(21798, 12230, 1, 1, 1, 221.1627), -- Common Item - Sealed Tallum Leather Armor
(21798, 5479, 1, 1, 1, 1465.701325), -- Sealed Tallum Leather Armor Pattern
(21798, 12228, 1, 1, 1, 576.058175), -- Common Item - Sealed Dark Crystal Leggings
(21798, 5482, 1, 1, 1, 3269.359225), -- Sealed Dark Crystal Leggings Design
(21798, 1895, 1, 1, 2, 42463.885912), -- Metallic Fiber
(21798, 4040, 1, 1, 2, 2972.492228), -- Mold Lubricant
(21798, 4042, 1, 1, 2, 2476.992631), -- Enria
(21798, 4043, 1, 1, 2, 4953.985262), -- Asofe
(21798, 5282, 1, 1, 2, 65.948697), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(21798, 6672, 1, 1, 2, 12385.215832), -- Deluxe Chest Key - Grade 8
(21798, 8732, 1, 1, 2, 1238.622654), -- Life Stone - Level 76
(21798, 8742, 1, 1, 2, 309.529325), -- Mid-Grade Life Stone - Level 76
(21798, 8752, 1, 1, 2, 31.079271), -- High-Grade Life Stone - Level 76
(21798, 1344, 10, 30, 2, 185779.248188), -- Mithril Arrow
-- Ghost of a Doorman
(21799, 6901, 1, 1, -1, 7403), -- Recipe: Shining Arrow (100%)
(21799, 5495, 1, 1, -1, 112412), -- Sealed Shield of Nightmare Fragment
(21799, 1894, 1, 1, -1, 259750), -- Crafted Leather
(21799, 57, 3642, 7457, 0, 700000), -- Adena
(21799, 11946, 1, 1, 1, 94.052002), -- Common Item - Dasparion's Staff
(21799, 5543, 1, 1, 1, 1162.962768), -- Dasparion's Staff Head
(21799, 11949, 1, 1, 1, 94.052002), -- Common Item - Meteor Shower
(21799, 5532, 1, 1, 1, 1152.100818), -- Meteor Shower Head
(21799, 11953, 1, 1, 1, 94.052002), -- Common Item - Spiritual Eye
(21799, 8341, 1, 1, 1, 1150.627588), -- Spiritual Eye Piece
(21799, 11958, 1, 1, 1, 94.052002), -- Common Item - Destroyer Hammer
(21799, 8346, 1, 1, 1, 1152.100818), -- Hammer Piece of Destroyer
(21799, 6901, 1, 1, 2, 683.358768), -- Recipe: Shining Arrow (100%)
(21799, 8732, 1, 1, 2, 5694.624624), -- Life Stone - Level 76
(21799, 8742, 1, 1, 2, 1423.652184), -- Mid-Grade Life Stone - Level 76
(21799, 8752, 1, 1, 2, 142.364424), -- High-Grade Life Stone - Level 76
-- Vassal Ghost
(21800, 5167, 1, 1, -1, 1670), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(21800, 5529, 1, 1, -1, 10311), -- Dragon Slayer Edge
(21800, 4042, 1, 1, -1, 62641), -- Enria
(21800, 57, 1853, 3785, 0, 700000), -- Adena
(21800, 11946, 1, 1, 1, 47.760488), -- Common Item - Dasparion's Staff
(21800, 5543, 1, 1, 1, 590.563392), -- Dasparion's Staff Head
(21800, 11949, 1, 1, 1, 47.760488), -- Common Item - Meteor Shower
(21800, 5532, 1, 1, 1, 585.047592), -- Meteor Shower Head
(21800, 11953, 1, 1, 1, 47.760488), -- Common Item - Spiritual Eye
(21800, 8341, 1, 1, 1, 584.299472), -- Spiritual Eye Piece
(21800, 11958, 1, 1, 1, 47.760488), -- Common Item - Destroyer Hammer
(21800, 8346, 1, 1, 1, 585.047592), -- Hammer Piece of Destroyer
(21800, 1867, 1, 3, 2, 92515.426572), -- Animal Skin
(21800, 1872, 1, 1, 2, 185030.853144), -- Animal Bone
(21800, 1882, 1, 1, 2, 30838.639047), -- Leather
(21800, 1894, 1, 1, 2, 4869.387894), -- Crafted Leather
(21800, 4042, 1, 1, 2, 2313.032835), -- Enria
(21800, 5272, 1, 1, 2, 61.811694), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(21800, 8732, 1, 1, 2, 1156.271133), -- Life Stone - Level 76
(21800, 8742, 1, 1, 2, 288.945141), -- Mid-Grade Life Stone - Level 76
(21800, 8752, 1, 1, 2, 28.943571), -- High-Grade Life Stone - Level 76
(21800, 1344, 10, 30, 2, 173465.688969), -- Mithril Arrow
-- Treasure Chest
(21801, 1864, 1, 1, -1, 469914), -- Stem
(21801, 1869, 1, 1, -1, 234957), -- Iron Ore
(21801, 1926, 1, 1, -1, 23733), -- Piece Bone Breastplate Fragment
(21801, 57, 107, 191, 0, 700000), -- Adena
(21801, 39, 1, 1, 1, 974.077488), -- Boots
(21801, 1930, 1, 1, 1, 11863.831212), -- Boot Lining
(21801, 51, 1, 1, 1, 974.0913), -- Bracer
(21801, 1864, 1, 1, 2, 69402.827492), -- Stem
(21801, 1869, 1, 1, 2, 34701.413746), -- Iron Ore
(21801, 1878, 1, 1, 2, 13880.514438), -- Braided Hemp
(21801, 2151, 1, 1, 2, 9666.244324), -- Recipe: Necklace of Devotion
-- Treasure Chest
(21802, 2151, 1, 1, -1, 76492), -- Recipe: Necklace of Devotion
(21802, 1928, 1, 1, -1, 40001), -- Piece Bone Gaiters Fragment
(21802, 2176, 1, 1, -1, 131391), -- Recipe: Leather Boots
(21802, 57, 122, 225, 0, 700000), -- Adena
(21802, 625, 1, 1, 1, 1638.598572), -- Bone Shield
(21802, 1148, 1, 1, 1, 1142.401428), -- Hard Leather Helmet
(21802, 1865, 1, 1, 2, 40557.41856), -- Varnish
(21802, 1870, 1, 1, 2, 40557.41856), -- Coal
(21802, 1879, 1, 1, 2, 6759.60552), -- Cokes
(21802, 2176, 1, 1, 2, 19405.55736), -- Recipe: Leather Boots
-- Treasure Chest
(21803, 1899, 1, 1, -1, 49588), -- Necklace of Devotion Chain
(21803, 1871, 1, 1, -1, 317362), -- Charcoal
(21803, 5220, 1, 1, -1, 12695), -- Metal Hardener
(21803, 57, 137, 264, 0, 700000), -- Adena
(21803, 40, 1, 1, 1, 553.161216), -- Leather Boots
(21803, 1931, 1, 1, 1, 5820.838784), -- Leather Boots Lining
(21803, 604, 1, 1, 1, 553.161216), -- Crafted Leather Gloves
(21803, 1934, 1, 1, 1, 5820.838784), -- Crafted Leather Gloves Lining
(21803, 1866, 1, 1, 2, 23748.367168), -- Suede
(21803, 1871, 1, 1, 2, 35622.550752), -- Charcoal
(21803, 5220, 1, 1, 2, 1424.88242), -- Metal Hardener
(21803, 1885, 1, 1, 2, 2968.545896), -- High-Grade Suede
(21803, 2152, 1, 1, 2, 6271.653764), -- Recipe: Enchanted Necklace
-- Treasure Chest
(21804, 1061, 1, 1, -1, 221263), -- Greater Healing Potion
(21804, 1900, 1, 1, -1, 39943), -- Enchanted Necklace Chain
(21804, 2250, 1, 1, -1, 91271), -- Recipe: Bone Arrow
(21804, 57, 154, 308, 0, 700000), -- Adena
(21804, 627, 1, 1, 1, 741.537355), -- Aspis
(21804, 46, 1, 1, 1, 519.462645), -- Bronze Helmet
(21804, 1867, 1, 1, 2, 66501.276345), -- Animal Skin
(21804, 1872, 1, 1, 2, 66501.276345), -- Animal Bone
(21804, 1882, 1, 1, 2, 11083.46778), -- Leather
(21804, 2250, 1, 1, 2, 12468.97953), -- Recipe: Bone Arrow
-- Treasure Chest
(21805, 1901, 1, 1, -1, 60152), -- Tiger's Eye Earring Stone
(21805, 2154, 1, 1, -1, 46627), -- Recipe: Elven Earring
(21805, 1938, 1, 1, -1, 29277), -- Mithril Banded Mail Material
(21805, 57, 184, 368, 0, 700000), -- Adena
(21805, 553, 1, 1, 1, 169.191552), -- Iron Boots
(21805, 1940, 1, 1, 1, 4936.850688), -- Iron Boots Design
(21805, 2422, 1, 1, 1, 169.191552), -- Reinforced Leather Boots
(21805, 2423, 1, 1, 1, 169.191552), -- Boots of Knowledge
(21805, 63, 1, 1, 1, 169.191552), -- Gauntlets
(21805, 2446, 1, 1, 1, 169.191552), -- Reinforced Leather Gloves
(21805, 2447, 1, 1, 1, 169.191552), -- Gloves of Knowledge
(21805, 1868, 1, 1, 2, 92621.084796), -- Thread
(21805, 1873, 1, 1, 2, 18524.266488), -- Silver Nugget
(21805, 5549, 1, 1, 2, 4631.066622), -- Metallic Thread
(21805, 1889, 1, 1, 2, 3087.377748), -- Compound Braid
(21805, 2154, 1, 1, 2, 4958.204346), -- Recipe: Elven Earring
-- Treasure Chest
(21806, 1864, 1, 3, -1, 512417), -- Stem
(21806, 1880, 1, 1, -1, 51242), -- Steel
(21806, 1939, 1, 1, -1, 45008), -- Mithril Banded Gaiters Material
(21806, 57, 216, 433, 0, 700000), -- Adena
(21806, 628, 1, 1, 1, 664.250537), -- Hoplon
(21806, 47, 1, 1, 1, 464.749463), -- Helmet
(21806, 1869, 1, 1, 2, 54489.709341), -- Iron Ore
(21806, 1864, 1, 1, 2, 108979.418682), -- Stem
(21806, 1880, 1, 1, 2, 5448.953095), -- Steel
(21806, 5550, 1, 1, 2, 726.586543), -- Durable Metal Plate
(21806, 2155, 1, 1, 2, 8746.332339), -- Recipe: Elven Ring
-- Treasure Chest
(21807, 2157, 1, 1, -1, 49421), -- Recipe: Omen Beast's Eye Earring
(21807, 1902, 1, 1, -1, 60588), -- Elven Earring Beads
(21807, 2158, 1, 1, -1, 74010), -- Recipe: Mithril Ring
(21807, 57, 253, 504, 0, 700000), -- Adena
(21807, 1124, 1, 1, 1, 67.31735), -- Boots of Power
(21807, 1948, 1, 1, 1, 2610.80765), -- Boots of Power Pattern
(21807, 2424, 1, 1, 1, 67.31735), -- Manticore Skin Boots
(21807, 2923, 1, 1, 1, 2610.80765), -- Manticore Skin Boot Lining
(21807, 2425, 1, 1, 1, 67.31735), -- Brigandine Boots
(21807, 2924, 1, 1, 1, 2610.80765), -- Brigandine Boots Design
(21807, 2426, 1, 1, 1, 67.31735), -- Elven Mithril Boots
(21807, 2925, 1, 1, 1, 2610.80765), -- Elven Mithril Boots Design
(21807, 606, 1, 1, 1, 67.31735), -- Rip Gauntlets
(21807, 1946, 1, 1, 1, 2610.80765), -- Rip Gauntlets Pattern
(21807, 2448, 1, 1, 1, 67.31735), -- Manticore Skin Gloves
(21807, 2926, 1, 1, 1, 2610.80765), -- Manticore Skin Gloves Lining
(21807, 2449, 1, 1, 1, 67.31735), -- Brigandine Gauntlets
(21807, 2927, 1, 1, 1, 2610.80765), -- Brigandine Gauntlets Pattern
(21807, 2450, 1, 1, 1, 67.31735), -- Mithril Gloves
(21807, 2928, 1, 1, 1, 2610.80765), -- Mithril Gloves Design
(21807, 1870, 1, 1, 2, 77280.051235), -- Coal
(21807, 1865, 1, 1, 2, 77280.051235), -- Varnish
(21807, 1874, 1, 1, 2, 5152.058782), -- Oriharukon Ore
(21807, 2157, 1, 1, 2, 6386.838748), -- Recipe: Omen Beast's Eye Earring
-- Treasure Chest
(21808, 1905, 1, 1, -1, 68125), -- Omen Beast's Eye Earring Gemstone
(21808, 1871, 1, 1, -1, 700321), -- Charcoal
(21808, 1866, 1, 1, -1, 466881), -- Suede
(21808, 57, 282, 570, 0, 700000), -- Adena
(21808, 630, 1, 1, 1, 148.37993), -- Square Shield
(21808, 1956, 1, 1, 1, 6652.40065), -- Square Shield Fragment
(21808, 2494, 1, 1, 1, 148.37993), -- Plate Shield
(21808, 2934, 1, 1, 1, 6652.40065), -- Plate Shield Fragment
(21808, 2412, 1, 1, 1, 103.90834), -- Plate Helmet
(21808, 2930, 1, 1, 1, 4724.5305), -- Plate Helmet Design
(21808, 1871, 1, 1, 2, 87917.448492), -- Charcoal
(21808, 1866, 1, 1, 2, 58611.632328), -- Suede
(21808, 1877, 1, 1, 2, 3516.735312), -- Adamantite Nugget
(21808, 2160, 1, 1, 2, 5672.183868), -- Recipe: Moonstone Earring
-- Treasure Chest
(21809, 4553, 1, 1, -1, 3236), -- Greater Dye of STR (Str+1 Con-1)
(21809, 1908, 1, 1, -1, 76616), -- Moonstone Earring Wire
(21809, 2163, 1, 1, -1, 41279), -- Recipe: Earring of Protection
(21809, 57, 320, 650, 0, 700000), -- Adena
(21809, 62, 1, 1, 1, 43.754131), -- Reinforced Mithril Boots
(21809, 1958, 1, 1, 1, 1909.466138), -- Reinforced Mithril Boots Design
(21809, 2429, 1, 1, 1, 43.754131), -- Chain Boots
(21809, 2937, 1, 1, 1, 1909.466138), -- Chain Boots Part
(21809, 2430, 1, 1, 1, 43.754131), -- Karmian Boots
(21809, 2938, 1, 1, 1, 1909.466138), -- Karmian Boots Fabric
(21809, 2431, 1, 1, 1, 43.754131), -- Plated Leather Boots
(21809, 2939, 1, 1, 1, 1909.466138), -- Plate Leather Boots Lining
(21809, 2432, 1, 1, 1, 43.754131), -- Dwarven Chain Boots
(21809, 2940, 1, 1, 1, 1909.466138), -- Dwarven Chain Boots Part
(21809, 2433, 1, 1, 1, 43.754131), -- Boots of Seal
(21809, 2941, 1, 1, 1, 1909.466138), -- Boots of Seal Pattern
(21809, 2452, 1, 1, 1, 43.754131), -- Reinforced Mithril Gloves
(21809, 2942, 1, 1, 1, 1909.466138), -- Reinforced Mithril Gloves Design
(21809, 2453, 1, 1, 1, 43.754131), -- Chain Gloves
(21809, 2943, 1, 1, 1, 1909.466138), -- Chain Gloves Design
(21809, 2454, 1, 1, 1, 43.754131), -- Karmian Gloves
(21809, 2944, 1, 1, 1, 1909.483717), -- Karmian Gloves Fabric
(21809, 1872, 1, 1, 2, 50983.244305), -- Animal Bone
(21809, 1867, 1, 1, 2, 50983.244305), -- Animal Skin
(21809, 1881, 1, 1, 2, 5098.313045), -- Coarse Bone Powder
(21809, 1875, 1, 1, 2, 2549.21345), -- Stone of Purity
(21809, 4041, 1, 1, 2, 332.4566), -- Mold Hardener
(21809, 2163, 1, 1, 2, 1950.905425), -- Recipe: Earring of Protection
(21809, 8723, 1, 1, 2, 1529.52807), -- Life Stone - Level 46
(21809, 8733, 1, 1, 2, 382.32509), -- Mid-Grade Life Stone - Level 46
(21809, 8743, 1, 1, 2, 38.25528), -- High-Grade Life Stone - Level 46
(21809, 8753, 1, 1, 2, 7.51443), -- Top-Grade Life Stone - Level 46
-- Treasure Chest
(21810, 1966, 1, 1, -1, 33611), -- Plated Leather Fragment
(21810, 2166, 1, 1, -1, 31207), -- Recipe: Earrings of Binding (100%)
(21810, 1967, 1, 1, -1, 50211), -- Plated Leather Gaiters Material
(21810, 57, 364, 740, 0, 700000), -- Adena
(21810, 2496, 1, 1, 1, 113.212719), -- Dwarven Chain Shield
(21810, 2947, 1, 1, 1, 4855.847919), -- Dwarven Chain Shield Fragment
(21810, 632, 1, 1, 1, 104.511989), -- Knight's Shield
(21810, 1972, 1, 1, 1, 5438.54613), -- Knight's Shield Fragment
(21810, 500, 1, 1, 1, 73.174614), -- Great Helmet
(21810, 1971, 1, 1, 1, 4161.706629), -- Great Helmet Material
(21810, 1873, 1, 1, 2, 16316.145312), -- Silver Nugget
(21810, 1868, 1, 1, 2, 81580.483536), -- Thread
(21810, 1876, 1, 1, 2, 8158.072656), -- Mithril Ore
(21810, 1895, 1, 1, 2, 11654.337432), -- Metallic Fiber
(21810, 4042, 1, 1, 2, 679.85964), -- Enria
(21810, 2166, 1, 1, 2, 1382.685048), -- Recipe: Earrings of Binding (100%)
(21810, 8724, 1, 1, 2, 1359.71928), -- Life Stone - Level 49
(21810, 8734, 1, 1, 2, 339.869064), -- Mid-Grade Life Stone - Level 49
(21810, 8744, 1, 1, 2, 34.02336), -- High-Grade Life Stone - Level 49
(21810, 8754, 1, 1, 2, 6.804672), -- Top-Grade Life Stone - Level 49
-- Treasure Chest
(21811, 1878, 1, 1, -1, 417148), -- Braided Hemp
(21811, 1884, 1, 1, -1, 641767), -- Cord
(21811, 4601, 1, 1, -1, 2317), -- Greater Dye of STR (Str+3 Con-3)
(21811, 57, 413, 839, 0, 700000), -- Adena
(21811, 64, 1, 1, 1, 114.215485), -- Composite Boots
(21811, 2956, 1, 1, 1, 6342.284515), -- Composite Boots Part
(21811, 608, 1, 1, 1, 114.215485), -- Mithril Gauntlets
(21811, 1981, 1, 1, 1, 6342.284515), -- Mithril Gauntlets Design
(21811, 1864, 1, 1, 2, 86253.57085), -- Stem
(21811, 1869, 1, 1, 2, 43126.785425), -- Iron Ore
(21811, 1878, 1, 1, 2, 17250.71417), -- Braided Hemp
(21811, 1884, 1, 1, 2, 26539.64191), -- Cord
(21811, 4039, 1, 1, 2, 1437.53003), -- Mold Glue
(21811, 2169, 1, 1, 2, 763.345075), -- Recipe: Necklace of Seal
(21811, 8725, 1, 1, 2, 1198.00066), -- Life Stone - Level 52
(21811, 8735, 1, 1, 2, 299.500165), -- Mid-Grade Life Stone - Level 52
(21811, 8745, 1, 1, 2, 29.896945), -- High-Grade Life Stone - Level 52
(21811, 8755, 1, 1, 2, 6.01477), -- Top-Grade Life Stone - Level 52
-- Treasure Chest
(21812, 1984, 1, 1, -1, 25182), -- Theca Leather Armor Pattern
(21812, 4126, 1, 1, -1, 19385), -- Recipe: Adamantite Earrings (100%)
(21812, 1985, 1, 1, -1, 40508), -- Theca Leather Gaiters Pattern
(21812, 57, 464, 945, 0, 700000), -- Adena
(21812, 2497, 1, 1, 1, 75.091236), -- Full Plate Shield
(21812, 2966, 1, 1, 1, 5933.542076), -- Full Plate Shield Fragment
(21812, 2414, 1, 1, 1, 52.562884), -- Full Plate Helmet
(21812, 2959, 1, 1, 1, 3750.803804), -- Full Plate Helmet Design
(21812, 1865, 1, 1, 2, 43374.460392), -- Varnish
(21812, 1870, 1, 1, 2, 43374.460392), -- Coal
(21812, 1879, 1, 1, 2, 7229.109978), -- Cokes
(21812, 1875, 1, 1, 2, 2891.604096), -- Stone of Purity
(21812, 4040, 1, 1, 2, 867.521124), -- Mold Lubricant
(21812, 4126, 1, 1, 2, 715.719888), -- Recipe: Adamantite Earrings (100%)
(21812, 8726, 1, 1, 2, 1004.062446), -- Life Stone - Level 55
(21812, 8736, 1, 1, 2, 251.040546), -- Mid-Grade Life Stone - Level 55
(21812, 8746, 1, 1, 2, 25.133976), -- High-Grade Life Stone - Level 55
(21812, 8756, 1, 1, 2, 4.887162), -- Top-Grade Life Stone - Level 55
-- Treasure Chest
(21813, 4129, 1, 1, -1, 14243), -- Recipe: Earrings of Black Ore (100%)
(21813, 4049, 1, 1, -1, 69028), -- Adamantite Earring Gemstone
(21813, 947, 1, 1, -1, 526), -- Scroll: Enchant Weapon (B-Grade)
(21813, 57, 519, 1060, 0, 700000), -- Adena
(21813, 12147, 1, 1, 1, 464.977275), -- Common Item - Sealed Zubei's Boots
(21813, 4097, 1, 1, 1, 2528.772725), -- Sealed Zubei's Boots Design
(21813, 12149, 1, 1, 1, 464.977275), -- Common Item - Sealed Avadon Boots
(21813, 4098, 1, 1, 1, 2528.772725), -- Sealed Avadon Boots Design
(21813, 12146, 1, 1, 1, 464.977275), -- Common Item - Sealed Zubei's Gauntlet
(21813, 4100, 1, 1, 1, 2528.772725), -- Sealed Zubei's Gauntlets Part
(21813, 12148, 1, 1, 1, 464.977275), -- Common Item - Sealed Avadon Gloves
(21813, 4073, 1, 1, 1, 2528.772725), -- Sealed Avadon Gloves Part
(21813, 1866, 1, 1, 2, 25915.519371), -- Suede
(21813, 1871, 1, 1, 2, 38873.243388), -- Charcoal
(21813, 5220, 1, 1, 2, 1554.932589), -- Metal Hardener
(21813, 1885, 1, 1, 2, 3239.41317), -- High-Grade Suede
(21813, 4041, 1, 1, 2, 337.994706), -- Mold Hardener
(21813, 4129, 1, 1, 2, 420.674289), -- Recipe: Earrings of Black Ore (100%)
(21813, 8727, 1, 1, 2, 777.430626), -- Life Stone - Level 58
(21813, 8737, 1, 1, 2, 194.393325), -- Mid-Grade Life Stone - Level 58
(21813, 8747, 1, 1, 2, 19.403664), -- High-Grade Life Stone - Level 58
(21813, 8757, 1, 1, 2, 3.994872), -- Top-Grade Life Stone - Level 58
-- Treasure Chest
(21814, 1867, 1, 5, -1, 651751), -- Animal Skin
(21814, 1872, 1, 5, -1, 651751), -- Animal Bone
(21814, 4613, 1, 1, -1, 2023), -- Greater Dye of STR (Str+4 Con-4)
(21814, 57, 580, 1179, 0, 700000), -- Adena
(21814, 12159, 1, 1, 1, 494.493554), -- Common Item - Zubei's Shield
(21814, 4101, 1, 1, 1, 3138.93983), -- Zubei's Shield Fragment
(21814, 12171, 1, 1, 1, 494.493554), -- Common Item - Avadon Shield
(21814, 4439, 1, 1, 1, 3734.256236), -- Avadon Shield Fragment
(21814, 12160, 1, 1, 1, 345.98313), -- Common Item - Zubei's Helmet
(21814, 4102, 1, 1, 1, 2431.918574), -- Zubei's Helmet Design
(21814, 12170, 1, 1, 1, 345.98313), -- Common Item - Avadon Circlet
(21814, 4072, 1, 1, 1, 2431.931992), -- Avadon Circlet Pattern
(21814, 1867, 1, 1, 2, 57755.02248), -- Animal Skin
(21814, 1872, 1, 1, 2, 57755.02248), -- Animal Bone
(21814, 1882, 1, 1, 2, 9625.83708), -- Leather
(21814, 1894, 1, 1, 2, 1519.807905), -- Crafted Leather
(21814, 4042, 1, 1, 2, 721.91198), -- Enria
(21814, 4130, 1, 1, 2, 703.206255), -- Recipe: Ring of Black Ore (100%)
(21814, 8728, 1, 1, 2, 721.91198), -- Life Stone - Level 61
(21814, 8738, 1, 1, 2, 180.477995), -- Mid-Grade Life Stone - Level 61
(21814, 8748, 1, 1, 2, 18.0607), -- High-Grade Life Stone - Level 61
(21814, 8758, 1, 1, 2, 3.741145), -- Top-Grade Life Stone - Level 61
-- Treasure Chest
(21815, 4052, 1, 1, -1, 57668), -- Earring of Black Ore Piece
(21815, 5230, 1, 1, -1, 2172), -- Recipe: Mithril Arrow (100%)
(21815, 4053, 1, 1, -1, 69816), -- Ring of Black Ore Gemstone
(21815, 57, 646, 1308, 0, 700000), -- Adena
(21815, 12188, 1, 1, 1, 319.888157), -- Common Item - Sealed Doom Boots
(21815, 4099, 1, 1, 1, 2699.861843), -- Sealed Doom Boots Part
(21815, 12189, 1, 1, 1, 319.888157), -- Common Item - Sealed Blue Wolf Boots
(21815, 4090, 1, 1, 1, 2699.861843), -- Sealed Blue Wolf Boots Design
(21815, 12187, 1, 1, 1, 319.888157), -- Common Item - Sealed Doom Gloves
(21815, 4091, 1, 1, 1, 2699.861843), -- Sealed Doom Gloves Part
(21815, 12190, 1, 1, 1, 319.888157), -- Common Item - Sealed Blue Wolf Gloves
(21815, 4096, 1, 1, 1, 2699.861843), -- Sealed Blue Wolf Gloves Fabric
(21815, 1868, 1, 1, 2, 96225.909675), -- Thread
(21815, 1873, 1, 1, 2, 19245.181935), -- Silver Nugget
(21815, 5549, 1, 1, 2, 4811.263989), -- Metallic Thread
(21815, 1889, 1, 1, 2, 3207.551319), -- Compound Braid
(21815, 4044, 1, 1, 2, 1603.71267), -- Thons
(21815, 5230, 1, 1, 2, 64.123311), -- Recipe: Mithril Arrow (100%)
(21815, 8729, 1, 1, 2, 641.485068), -- Life Stone - Level 64
(21815, 8739, 1, 1, 2, 160.371267), -- Mid-Grade Life Stone - Level 64
(21815, 8749, 1, 1, 2, 15.999333), -- High-Grade Life Stone - Level 64
(21815, 8759, 1, 1, 2, 3.401433), -- Top-Grade Life Stone - Level 64
-- Treasure Chest
(21816, 5438, 1, 1, -1, 985), -- Recipe: Meteor Shower(60%)
(21816, 4054, 1, 1, -1, 35501), -- Necklace of Black Ore Beads
(21816, 5550, 1, 1, -1, 24032), -- Durable Metal Plate
(21816, 57, 714, 1448, 0, 700000), -- Adena
(21816, 12183, 1, 1, 1, 450.405402), -- Common Item - Doom Shield
(21816, 4077, 1, 1, 1, 3991.455498), -- Doom Shield Fragment
(21816, 12202, 1, 1, 1, 315.20604), -- Common Item - Blue Wolf Helmet
(21816, 4088, 1, 1, 1, 3353.36351), -- Blue Wolf Helmet Design
(21816, 12185, 1, 1, 1, 315.20604), -- Common Item - Doom Helmet
(21816, 4089, 1, 1, 1, 3353.36351), -- Doom Helmet Pattern
(21816, 1869, 1, 1, 2, 53239.04443), -- Iron Ore
(21816, 1864, 1, 1, 2, 106478.257314), -- Stem
(21816, 1880, 1, 1, 2, 5323.98867), -- Steel
(21816, 5550, 1, 1, 2, 709.865156), -- Durable Metal Plate
(21816, 4043, 1, 1, 2, 1774.66289), -- Asofe
(21816, 5434, 1, 1, 2, 19.709118), -- Recipe: Dragon Slayer(60%)
(21816, 8729, 1, 1, 2, 709.865156), -- Life Stone - Level 64
(21816, 8739, 1, 1, 2, 177.382062), -- Mid-Grade Life Stone - Level 64
(21816, 8749, 1, 1, 2, 17.68767), -- High-Grade Life Stone - Level 64
(21816, 8759, 1, 1, 2, 3.537534), -- Top-Grade Life Stone - Level 64
-- Treasure Chest
(21817, 1874, 1, 1, -1, 132389), -- Oriharukon Ore
(21817, 5478, 1, 1, -1, 16699), -- Sealed Dark Crystal Leather Armor Pattern
(21817, 5434, 1, 1, -1, 735), -- Recipe: Dragon Slayer(60%)
(21817, 57, 786, 1596, 0, 700000), -- Adena
(21817, 12224, 1, 1, 1, 319.504745), -- Common Item - Sealed Dark Crystal Boots
(21817, 5496, 1, 1, 1, 1719.245255), -- Sealed Dark Crystal Boots Lining
(21817, 12231, 1, 1, 1, 319.504745), -- Common Item - Sealed Tallum Boots
(21817, 5497, 1, 1, 1, 1719.245255), -- Sealed Tallum Boots Lining
(21817, 12221, 1, 1, 1, 319.504745), -- Common Item - Sealed Dark Crystal Gloves
(21817, 5508, 1, 1, 1, 1719.245255), -- Sealed Dark Crystal Gloves Design
(21817, 12229, 1, 1, 1, 319.504745), -- Common Item - Sealed Tallum Gloves
(21817, 5509, 1, 1, 1, 1719.245255), -- Sealed Tallum Gloves Design
(21817, 1870, 1, 1, 2, 58658.39661), -- Coal
(21817, 1865, 1, 1, 2, 58658.39661), -- Varnish
(21817, 1874, 1, 1, 2, 3910.601772), -- Oriharukon Ore
(21817, 4043, 1, 1, 2, 1955.300886), -- Asofe
(21817, 4039, 1, 1, 2, 1955.300886), -- Mold Glue
(21817, 5440, 1, 1, 2, 21.670968), -- Recipe: Elysian(60%)
(21817, 8730, 1, 1, 2, 651.766962), -- Life Stone - Level 67
(21817, 8740, 1, 1, 2, 162.910242), -- Mid-Grade Life Stone - Level 67
(21817, 8750, 1, 1, 2, 16.253226), -- High-Grade Life Stone - Level 67
(21817, 8760, 1, 1, 2, 3.401838), -- Top-Grade Life Stone - Level 67
-- Treasure Chest
(21818, 5479, 1, 1, -1, 10319), -- Sealed Tallum Leather Armor Pattern
(21818, 5440, 1, 1, -1, 646), -- Recipe: Elysian(60%)
(21818, 5482, 1, 1, -1, 23018), -- Sealed Dark Crystal Leggings Design
(21818, 57, 860, 1756, 0, 700000), -- Adena
(21818, 12225, 1, 1, 1, 445.298973), -- Common Item - Sealed Dark Crystal Shield
(21818, 5494, 1, 1, 1, 2253.862426), -- Sealed Dark Crystal Shield Fragment
(21818, 12226, 1, 1, 1, 311.967616), -- Common Item - Sealed Dark Crystal Helmet
(21818, 5525, 1, 1, 1, 1658.948364), -- Sealed Dark Crystal Helmet Design
(21818, 12234, 1, 1, 1, 311.967616), -- Common Item - Sealed Tallum Helmet
(21818, 5526, 1, 1, 1, 1658.955005), -- Sealed Tallum Helm Design
(21818, 1871, 1, 1, 2, 64393.374788), -- Charcoal
(21818, 1866, 1, 1, 2, 42928.87895), -- Suede
(21818, 1877, 1, 1, 2, 2575.7891), -- Adamantite Nugget
(21818, 4041, 1, 1, 2, 559.910042), -- Mold Hardener
(21818, 4040, 1, 1, 2, 1287.89455), -- Mold Lubricant
(21818, 6901, 1, 1, 2, 64.366546), -- Recipe: Shining Arrow (100%)
(21818, 8730, 1, 1, 2, 715.471922), -- Life Stone - Level 67
(21818, 8740, 1, 1, 2, 178.896162), -- Mid-Grade Life Stone - Level 67
(21818, 8750, 1, 1, 2, 17.923434), -- High-Grade Life Stone - Level 67
(21818, 8760, 1, 1, 2, 3.494506), -- Top-Grade Life Stone - Level 67
-- Treasure Chest
(21819, 1875, 1, 1, -1, 127175), -- Stone of Purity
(21819, 4041, 1, 1, -1, 16588), -- Mold Hardener
(21819, 5480, 1, 1, -1, 8560), -- Sealed Leather Armor of Nightmare Fabric
(21819, 57, 941, 1920, 0, 700000), -- Adena
(21819, 12224, 1, 1, 1, 383.640768), -- Common Item - Sealed Dark Crystal Boots
(21819, 5496, 1, 1, 1, 2064.359232), -- Sealed Dark Crystal Boots Lining
(21819, 12231, 1, 1, 1, 383.640768), -- Common Item - Sealed Tallum Boots
(21819, 5497, 1, 1, 1, 2064.359232), -- Sealed Tallum Boots Lining
(21819, 12221, 1, 1, 1, 383.640768), -- Common Item - Sealed Dark Crystal Gloves
(21819, 5508, 1, 1, 1, 2064.359232), -- Sealed Dark Crystal Gloves Design
(21819, 12229, 1, 1, 1, 383.640768), -- Common Item - Sealed Tallum Gloves
(21819, 5509, 1, 1, 1, 2064.359232), -- Sealed Tallum Gloves Design
(21819, 1872, 1, 1, 2, 93914.12859), -- Animal Bone
(21819, 1867, 1, 1, 2, 93914.12859), -- Animal Skin
(21819, 1881, 1, 1, 2, 9391.514556), -- Coarse Bone Powder
(21819, 1875, 1, 1, 2, 4695.757278), -- Stone of Purity
(21819, 4041, 1, 1, 2, 612.419334), -- Mold Hardener
(21819, 1808, 1, 1, 2, 31.322676), -- Recipe: Soulshot (S-Grade)
(21819, 8731, 1, 1, 2, 652.081164), -- Life Stone - Level 70
(21819, 8741, 1, 1, 2, 163.121988), -- Mid-Grade Life Stone - Level 70
(21819, 8751, 1, 1, 2, 16.27152), -- High-Grade Life Stone - Level 70
(21819, 8761, 1, 1, 2, 3.254304), -- Top-Grade Life Stone - Level 70
-- Treasure Chest
(21820, 6901, 1, 1, -1, 2078), -- Recipe: Shining Arrow (100%)
(21820, 5481, 1, 1, -1, 9325), -- Sealed Majestic Leather Armor Fabric
(21820, 1808, 1, 1, -1, 924), -- Recipe: Soulshot (S-Grade)
(21820, 57, 1025, 2092, 0, 700000), -- Adena
(21820, 12225, 1, 1, 1, 530.657442), -- Common Item - Sealed Dark Crystal Shield
(21820, 5494, 1, 1, 1, 2685.900804), -- Sealed Dark Crystal Shield Fragment
(21820, 12226, 1, 1, 1, 371.768064), -- Common Item - Sealed Dark Crystal Helmet
(21820, 5525, 1, 1, 1, 1976.948856), -- Sealed Dark Crystal Helmet Design
(21820, 12234, 1, 1, 1, 371.768064), -- Common Item - Sealed Tallum Helmet
(21820, 5526, 1, 1, 1, 1976.95677), -- Sealed Tallum Helm Design
(21820, 1873, 1, 1, 2, 30693.24115), -- Silver Nugget
(21820, 1868, 1, 1, 2, 153466.525225), -- Thread
(21820, 1876, 1, 1, 2, 15346.620575), -- Mithril Ore
(21820, 1895, 1, 1, 2, 21923.6524), -- Metallic Fiber
(21820, 4042, 1, 1, 2, 1278.858425), -- Enria
(21820, 3036, 1, 1, 2, 34.183825), -- Recipe: Spiritshot S
(21820, 8732, 1, 1, 2, 639.58895), -- Life Stone - Level 76
(21820, 8742, 1, 1, 2, 159.7375), -- Mid-Grade Life Stone - Level 76
(21820, 8752, 1, 1, 2, 15.97375), -- High-Grade Life Stone - Level 76
(21820, 1344, 10, 30, 2, 95916.6182), -- Mithril Arrow
-- Treasure Chest
(21821, 5487, 1, 1, -1, 10159), -- Sealed Robe of Nightmare Fabric
(21821, 4039, 1, 1, -1, 75202), -- Mold Glue
(21821, 4041, 1, 1, -1, 19618), -- Mold Hardener
(21821, 57, 1110, 2273, 0, 700000), -- Adena
(21821, 12267, 1, 1, 1, 283.34792), -- Common Item - Sealed Boots of Nightmare
(21821, 5502, 1, 1, 1, 1758.65208), -- Sealed Boots of Nightmare Lining
(21821, 12260, 1, 1, 1, 283.34792), -- Common Item - Sealed Majestic Boots
(21821, 5503, 1, 1, 1, 1758.65208), -- Sealed Majestic Boots Lining
(21821, 12264, 1, 1, 1, 283.34792), -- Common Item - Sealed Gauntlet of Nightmare
(21821, 5514, 1, 1, 1, 1758.65208), -- Sealed Gauntlets of Nightmare Design
(21821, 12257, 1, 1, 1, 283.34792), -- Common Item - Sealed Majestic Gauntlet
(21821, 5515, 1, 1, 1, 1758.65208), -- Sealed Majestic Gauntlets Design
(21821, 1894, 1, 1, 2, 3653.482366), -- Crafted Leather
(21821, 4039, 1, 1, 2, 3470.79942), -- Mold Glue
(21821, 4041, 1, 1, 2, 905.431967), -- Mold Hardener
(21821, 4044, 1, 1, 2, 3470.79942), -- Thons
(21821, 959, 1, 1, 2, 4.16163), -- Scroll: Enchant Weapon (S-Grade)
(21821, 8732, 1, 1, 2, 867.699855), -- Life Stone - Level 76
(21821, 8742, 1, 1, 2, 216.921811), -- Mid-Grade Life Stone - Level 76
(21821, 8752, 1, 1, 2, 21.703531), -- High-Grade Life Stone - Level 76
-- Treasure Chest
(21822, 6688, 1, 1, -1, 5261), -- Forgotten Blade Edge
(21822, 6689, 1, 1, -1, 5162), -- Basalt Battlehammer Head
(21822, 6690, 1, 1, -1, 5271), -- Imperial Staff Head
(21822, 57, 1200, 2449, 0, 700000), -- Adena
(21822, 12268, 1, 1, 1, 388.524756), -- Common Item - Sealed Shield of Nightmare
(21822, 5495, 1, 1, 1, 2274.346552), -- Sealed Shield of Nightmare Fragment
(21822, 12269, 1, 1, 1, 271.82546), -- Common Item - Sealed Helm of Nightmare
(21822, 5527, 1, 1, 1, 1790.735492), -- Sealed Helm of Nightmare Design
(21822, 12261, 1, 1, 1, 271.82546), -- Common Item - Sealed Majestic Circlet
(21822, 5528, 1, 1, 1, 1790.74228), -- Sealed Majestic Circlet Design
(21822, 1895, 1, 1, 2, 32095.182002), -- Metallic Fiber
(21822, 4040, 1, 1, 2, 2246.678395), -- Mold Lubricant
(21822, 4042, 1, 1, 2, 1872.238862), -- Enria
(21822, 4043, 1, 1, 2, 3744.436527), -- Asofe
(21822, 960, 1, 1, 2, 44.945927), -- Scroll: Enchant Armor (S-Grade)
(21822, 8732, 1, 1, 2, 936.119431), -- Life Stone - Level 76
(21822, 8742, 1, 1, 2, 234.040157), -- Mid-Grade Life Stone - Level 76
(21822, 8752, 1, 1, 2, 23.358699), -- High-Grade Life Stone - Level 76
-- Executor of Offerings
(21823, 1894, 1, 1, -1, 725194), -- Crafted Leather
(21823, 4039, 1, 1, -1, 688934), -- Mold Glue
(21823, 5480, 1, 1, -1, 92742), -- Sealed Leather Armor of Nightmare Fabric
(21823, 57, 10189, 20801, 0, 700000), -- Adena
(21823, 11975, 1, 1, 1, 678.352818), -- Common Item - Soul Bow
(21823, 5534, 1, 1, 1, 10475.647182), -- Soul Bow Stave
(21823, 1894, 1, 1, 2, 33470.603298), -- Crafted Leather
(21823, 4039, 1, 1, 2, 31796.99226), -- Mold Glue
(21823, 4041, 1, 1, 2, 8294.922801), -- Mold Hardener
(21823, 4044, 1, 1, 2, 31796.99226), -- Thons
(21823, 959, 1, 1, 2, 38.12589), -- Scroll: Enchant Weapon (S-Grade)
(21823, 8732, 1, 1, 2, 7949.248065), -- Life Stone - Level 76
(21823, 8742, 1, 1, 2, 1987.283133), -- Mid-Grade Life Stone - Level 76
(21823, 8752, 1, 1, 2, 198.832293), -- High-Grade Life Stone - Level 76
-- Alpine Kookaburra
(21824, 1894, 1, 1, -1, 374050), -- Crafted Leather
(21824, 4052, 1, 1, -1, 377427), -- Earring of Black Ore Piece
(21824, 1807, 1, 1, -1, 14214), -- Recipe: Soulshot (A-Grade)
(21824, 171, 1, 1, 0, 6.240355), -- Deadman's Glory
(21824, 4116, 1, 1, 0, 1375.68045), -- Deadman's Glory Stone
(21824, 175, 1, 1, 0, 6.240355), -- Art of Battle Axe
(21824, 4117, 1, 1, 0, 1375.68045), -- Art of Battle Axe Blade
(21824, 210, 1, 1, 0, 6.240355), -- Staff of Evil Spirits
(21824, 4118, 1, 1, 0, 1303.37982), -- Evil Spirit Head
(21824, 7893, 1, 1, 0, 6.240355), -- Kaim Vanul's Bones
(21824, 8340, 1, 1, 0, 1375.68045), -- Bones Head of Kaim Vanul
(21824, 7901, 1, 1, 0, 6.240355), -- Star Buster
(21824, 8348, 1, 1, 0, 1373.377055), -- Star Buster Head
(21824, 1894, 1, 1, 1, 12276.64191), -- Crafted Leather
(21824, 4039, 1, 1, 1, 11662.81428), -- Mold Glue
(21824, 4041, 1, 1, 1, 3042.479115), -- Mold Hardener
(21824, 4044, 1, 1, 1, 11662.81428), -- Thons
(21824, 729, 1, 1, 1, 38.894505), -- Scroll: Enchant Weapon (A-Grade)
(21824, 8729, 1, 1, 1, 4665.10785), -- Life Stone - Level 64
(21824, 8739, 1, 1, 1, 1166.29929), -- Mid-Grade Life Stone - Level 64
(21824, 8749, 1, 1, 1, 116.63886), -- High-Grade Life Stone - Level 64
(21824, 8759, 1, 1, 1, 23.30991), -- Top-Grade Life Stone - Level 64
-- Alpine Kookaburra
(21825, 4053, 1, 1, -1, 435874), -- Ring of Black Ore Gemstone
(21825, 3035, 1, 1, -1, 13559), -- Recipe: Spiritshot A
(21825, 4054, 1, 1, -1, 200294), -- Necklace of Black Ore Beads
(21825, 358, 1, 1, 0, 40.453984), -- Blue Wolf Breastplate
(21825, 4078, 1, 1, 0, 7313.078028), -- Blue Wolf Breastplate Part
(21825, 2380, 1, 1, 0, 64.717304), -- Blue Wolf Gaiters
(21825, 4080, 1, 1, 0, 10298.350752), -- Blue Wolf Gaiters Material
(21825, 2381, 1, 1, 0, 24.898248), -- Doom Plate Armor
(21825, 4081, 1, 1, 0, 4934.501684), -- Doom Plate Armor Temper
(21825, 1869, 2, 6, 1, 68266.92215), -- Iron Ore
(21825, 1864, 5, 15, 1, 54613.47815), -- Stem
(21825, 1880, 1, 1, 1, 27306.59015), -- Steel
(21825, 5550, 1, 1, 1, 3640.9184), -- Durable Metal Plate
(21825, 4043, 1, 1, 1, 9102.296), -- Asofe
(21825, 730, 1, 1, 1, 227.5574), -- Scroll: Enchant Armor (A-Grade)
(21825, 8729, 1, 1, 1, 3640.9184), -- Life Stone - Level 64
(21825, 8739, 1, 1, 1, 910.2296), -- Mid-Grade Life Stone - Level 64
(21825, 8749, 1, 1, 1, 91.1421), -- High-Grade Life Stone - Level 64
(21825, 8759, 1, 1, 1, 18.16885), -- Top-Grade Life Stone - Level 64
(21825, 1343, 30, 90, 1, 130031.7788), -- Silver Arrow
-- Alpine Buffalo
(21826, 1874, 1, 1, -1, 758857), -- Oriharukon Ore
(21826, 4043, 1, 1, -1, 379428), -- Asofe
(21826, 4077, 1, 1, -1, 512049), -- Doom Shield Fragment
(21826, 358, 1, 1, 0, 45.283272), -- Blue Wolf Breastplate
(21826, 4078, 1, 1, 0, 8186.093649), -- Blue Wolf Breastplate Part
(21826, 2380, 1, 1, 0, 72.443082), -- Blue Wolf Gaiters
(21826, 4080, 1, 1, 0, 11527.740216), -- Blue Wolf Gaiters Material
(21826, 2381, 1, 1, 0, 27.870534), -- Doom Plate Armor
(21826, 4081, 1, 1, 0, 5523.569247), -- Doom Plate Armor Temper
(21826, 1870, 1, 3, 1, 168116.069575), -- Coal
(21826, 1865, 1, 3, 1, 112077.601312), -- Varnish
(21826, 1874, 1, 1, 1, 22415.586741), -- Oriharukon Ore
(21826, 4043, 1, 1, 1, 11207.627174), -- Asofe
(21826, 4039, 1, 1, 1, 11207.627174), -- Mold Glue
(21826, 6339, 1, 1, 1, 2586.349933), -- Recipe: Sealed Majestic Ring(70%)
(21826, 8730, 1, 1, 1, 3735.764927), -- Life Stone - Level 67
(21826, 8740, 1, 1, 1, 934.02433), -- Mid-Grade Life Stone - Level 67
(21826, 8750, 1, 1, 1, 93.402433), -- High-Grade Life Stone - Level 67
(21826, 8760, 1, 1, 1, 18.946401), -- Top-Grade Life Stone - Level 67
-- Alpine Buffalo
(21827, 3956, 1, 1, -1, 14477), -- Recipe: Blessed Spiritshot A
(21827, 4078, 1, 1, -1, 158605), -- Blue Wolf Breastplate Part
(21827, 5156, 1, 1, -1, 14477), -- Recipe: Soulshot (A) Compressed Package (100%)
(21827, 79, 1, 1, 0, 10.594647), -- Sword of Damascus
(21827, 4114, 1, 1, 0, 2340.380784), -- Sword of Damascus Blade
(21827, 7883, 1, 1, 0, 10.594647), -- Guardian Sword
(21827, 8330, 1, 1, 0, 2336.447442), -- Guardian Sword Blade
(21827, 7889, 1, 1, 0, 10.594647), -- Wizard's Tear
(21827, 8336, 1, 1, 0, 2340.387833), -- Blade of the Wizard's Tear
(21827, 1871, 1, 3, 1, 97191.068), -- Charcoal
(21827, 1866, 1, 1, 1, 194382.503925), -- Suede
(21827, 1877, 1, 1, 1, 11662.854575), -- Adamantite Nugget
(21827, 4041, 1, 1, 1, 2535.371175), -- Mold Hardener
(21827, 4040, 1, 1, 1, 5831.61125), -- Mold Lubricant
(21827, 5456, 1, 1, 1, 108.16995), -- Recipe: Tallum Glaive(60%)
(21827, 8730, 1, 1, 1, 3239.579625), -- Life Stone - Level 67
(21827, 8740, 1, 1, 1, 809.802925), -- Mid-Grade Life Stone - Level 67
(21827, 8750, 1, 1, 1, 80.9435), -- High-Grade Life Stone - Level 67
(21827, 8760, 1, 1, 1, 16.1887), -- Top-Grade Life Stone - Level 67
(21827, 1343, 80, 240, 1, 52066.906375), -- Silver Arrow
-- Alpine Cougar
(21828, 5478, 1, 1, -1, 102093), -- Sealed Dark Crystal Leather Armor Pattern
(21828, 729, 1, 1, -1, 1349), -- Scroll: Enchant Weapon (A-Grade)
(21828, 1875, 1, 1, -1, 809392), -- Stone of Purity
(21828, 212, 1, 1, 0, 6.35987), -- Dasparion's Staff
(21828, 5543, 1, 1, 0, 1526.314026), -- Dasparion's Staff Head
(21828, 2504, 1, 1, 0, 6.35987), -- Meteor Shower
(21828, 5532, 1, 1, 0, 1512.060614), -- Meteor Shower Head
(21828, 7894, 1, 1, 0, 6.35987), -- Spiritual Eye
(21828, 8341, 1, 1, 0, 1510.125266), -- Spiritual Eye Piece
(21828, 7899, 1, 1, 0, 6.35987), -- Destroyer Hammer
(21828, 8346, 1, 1, 0, 1512.060614), -- Hammer Piece of Destroyer
(21828, 1865, 1, 3, 1, 179311.212336), -- Varnish
(21828, 1870, 1, 3, 1, 119540.808224), -- Coal
(21828, 1879, 1, 1, 1, 59770.404112), -- Cokes
(21828, 1875, 1, 1, 1, 23908.240632), -- Stone of Purity
(21828, 4040, 1, 1, 1, 7172.432696), -- Mold Lubricant
(21828, 5450, 1, 1, 1, 132.698496), -- Recipe: Dragon Grinder(60%)
(21828, 8730, 1, 1, 1, 3984.509304), -- Life Stone - Level 67
(21828, 8740, 1, 1, 1, 996.028592), -- Mid-Grade Life Stone - Level 67
(21828, 8750, 1, 1, 1, 99.523872), -- High-Grade Life Stone - Level 67
(21828, 8760, 1, 1, 1, 20.141736), -- Top-Grade Life Stone - Level 67
-- Alpine Cougar
(21829, 4053, 1, 1, -1, 496406), -- Ring of Black Ore Gemstone
(21829, 3035, 1, 1, -1, 15442), -- Recipe: Spiritshot A
(21829, 4054, 1, 1, -1, 228110), -- Necklace of Black Ore Beads
(21829, 5304, 1, 1, 0, 42.690813), -- Sealed Tallum Tunic
(21829, 5485, 1, 1, 0, 4793.923453), -- Sealed Tallum Tunic Texture
(21829, 5305, 1, 1, 0, 68.270477), -- Sealed Tallum Stockings
(21829, 5489, 1, 1, 0, 7524.505098), -- Sealed Tallum Stockings Fabric
(21829, 5308, 1, 1, 0, 26.260311), -- Sealed Dark Crystal Robe
(21829, 5486, 1, 1, 0, 3373.349848), -- Sealed Dark Crystal Robe Fabric
(21829, 1869, 2, 6, 1, 77747.608656), -- Iron Ore
(21829, 1864, 5, 15, 1, 62198.154562), -- Stem
(21829, 1880, 1, 1, 1, 31098.908188), -- Steel
(21829, 5550, 1, 1, 1, 4146.498546), -- Durable Metal Plate
(21829, 4043, 1, 1, 1, 10366.415458), -- Asofe
(21829, 5448, 1, 1, 1, 115.321426), -- Recipe: Soul Separator(60%)
(21829, 8730, 1, 1, 1, 3455.584548), -- Life Stone - Level 67
(21829, 8740, 1, 1, 1, 863.727044), -- Mid-Grade Life Stone - Level 67
(21829, 8750, 1, 1, 1, 86.23743), -- High-Grade Life Stone - Level 67
(21829, 8760, 1, 1, 1, 17.247486), -- Top-Grade Life Stone - Level 67
(21829, 1343, 30, 90, 1, 148090.296656), -- Silver Arrow
-- Grim Wolf
(22001, 1867, 1, 1, -1, 494275), -- Animal Skin
(22001, 1899, 1, 1, -1, 57923), -- Necklace of Devotion Chain
(22001, 2152, 1, 1, -1, 65265), -- Recipe: Enchanted Necklace
(22001, 57, 163, 306, 0, 700000), -- Adena
(22001, 391, 1, 1, 1, 431.702537), -- Puma Skin Shirt
(22001, 413, 1, 1, 1, 691.297463), -- Puma Skin Gaiters
(22001, 1867, 1, 1, 2, 69350.699259), -- Animal Skin
(22001, 1872, 1, 1, 2, 69350.699259), -- Animal Bone
(22001, 1882, 1, 1, 2, 11558.370168), -- Leather
(22001, 2152, 1, 1, 2, 9157.231314), -- Recipe: Enchanted Necklace
-- Grim Grizzly
(22002, 1931, 1, 1, -1, 51043), -- Leather Boots Lining
(22002, 2178, 1, 1, -1, 62477), -- Recipe: Dark Stockings
(22002, 1932, 1, 1, -1, 61981), -- Bone Helmet Design
(22002, 57, 170, 324, 0, 700000), -- Adena
(22002, 258, 1, 1, 1, 139), -- Bagh-Nakh
(22002, 1872, 1, 1, 2, 58439.726211), -- Animal Bone
(22002, 1867, 1, 1, 2, 58439.726211), -- Animal Skin
(22002, 1881, 1, 1, 2, 5843.934606), -- Coarse Bone Powder
(22002, 1875, 1, 1, 2, 2921.967303), -- Stone of Purity
(22002, 8301, 1, 1, 2, 1071.645669), -- Recipe: Priest Sword (100%)
-- Grave Robber Scout
(22003, 1874, 1, 1, -1, 32142), -- Oriharukon Ore
(22003, 1878, 1, 1, -1, 192855), -- Braided Hemp
(22003, 1934, 1, 1, -1, 63024), -- Crafted Leather Gloves Lining
(22003, 57, 208, 401, 0, 700000), -- Adena
(22003, 274, 1, 1, 1, 172), -- Reinforced Bow
(22003, 1874, 1, 1, 2, 3006.579), -- Oriharukon Ore
(22003, 1878, 1, 1, 2, 18039.303), -- Braided Hemp
(22003, 1884, 1, 1, 2, 27752.787), -- Cord
(22003, 1889, 1, 1, 2, 3006.579), -- Compound Braid
(22003, 5220, 1, 1, 2, 1803.936), -- Metal Hardener
(22003, 2180, 1, 1, 2, 3390.816), -- Recipe: Scale Mail
-- Grave Robber Lookout
(22004, 2180, 1, 1, -1, 43085), -- Recipe: Scale Mail
(22004, 2017, 1, 1, -1, 7615), -- Saber Blade
(22004, 2181, 1, 1, -1, 57361), -- Recipe: White Tunic
(22004, 57, 247, 477, 0, 700000), -- Adena
(22004, 123, 1, 1, 1, 25.523518), -- Saber
(22004, 2017, 1, 1, 1, 534.189158), -- Saber Blade
(22004, 5285, 1, 1, 1, 25.523518), -- Heavy Sword
(22004, 5531, 1, 1, 1, 674.909546), -- Heavy Sword Edge
(22004, 7880, 1, 1, 1, 25.523518), -- Steel Sword
(22004, 8327, 1, 1, 1, 674.909546), -- Steel Sword Blade
(22004, 7885, 1, 1, 1, 25.523518), -- Priest Sword
(22004, 8332, 1, 1, 1, 667.897678), -- Priest Sword Blade
(22004, 1875, 1, 1, 2, 3062.880723), -- Stone of Purity
(22004, 1879, 1, 1, 2, 7657.227907), -- Cokes
(22004, 1885, 1, 1, 2, 3828.587854), -- High-Grade Suede
(22004, 5550, 1, 1, 2, 612.555265), -- Durable Metal Plate
(22004, 5549, 1, 1, 2, 4594.347184), -- Metallic Thread
(22004, 2181, 1, 1, 2, 4598.940696), -- Recipe: White Tunic
(22004, 1061, 1, 1, 2, 27844.460371), -- Greater Healing Potion
-- Grave Robber Ranger
(22005, 2018, 1, 1, -1, 6735), -- Assassin Knife Edge
(22005, 1876, 1, 1, -1, 101359), -- Mithril Ore
(22005, 1880, 1, 1, -1, 50680), -- Steel
(22005, 57, 217, 425, 0, 700000), -- Adena
(22005, 220, 1, 1, 1, 181), -- Crafted Dagger
(22005, 1876, 1, 1, 2, 9481.070088), -- Mithril Ore
(22005, 1880, 1, 1, 2, 4740.554376), -- Steel
(22005, 1877, 1, 1, 2, 1896.198552), -- Adamantite Nugget
(22005, 1881, 1, 1, 2, 6320.713392), -- Coarse Bone Powder
(22005, 1882, 1, 1, 2, 10534.548096), -- Leather
(22005, 2182, 1, 1, 2, 5690.915496), -- Recipe: Scale Gaiters
-- Grave Robber Guard
(22006, 1061, 1, 1, -1, 321463), -- Greater Healing Potion
(22006, 1900, 1, 1, -1, 58032), -- Enchanted Necklace Chain
(22006, 2153, 1, 1, -1, 82490), -- Recipe: Tiger's Eye Earring
(22006, 57, 225, 445, 0, 700000), -- Adena
(22006, 292, 1, 1, 1, 117), -- Pike
(22006, 1874, 1, 1, 2, 3220.565136), -- Oriharukon Ore
(22006, 1878, 1, 1, 2, 19323.390816), -- Braided Hemp
(22006, 1884, 1, 1, 2, 29728.298352), -- Cord
(22006, 1889, 1, 1, 2, 3220.565136), -- Compound Braid
(22006, 5220, 1, 1, 2, 1932.363984), -- Metal Hardener
(22006, 737, 1, 1, 2, 4830.816576), -- Scroll of Resurrection
-- Ghost of a Soldier
(22007, 1933, 1, 1, -1, 68021), -- Dark Stockings Fabric
(22007, 2183, 1, 1, -1, 38038), -- Recipe: Mithril Banded Mail
(22007, 1935, 1, 1, -1, 32300), -- Scale Mail Fragment
(22007, 57, 245, 485, 0, 700000), -- Adena
(22007, 86, 1, 1, 1, 12.756868), -- Tomahawk
(22007, 179, 1, 1, 1, 12.756868), -- Mace of Prayer
(22007, 180, 1, 1, 1, 12.756868), -- Mace of Judgment
(22007, 2022, 1, 1, 1, 492.29994), -- Mace of Judgment Head
(22007, 181, 1, 1, 1, 12.756868), -- Mace of Miracle
(22007, 182, 1, 1, 1, 12.756868), -- Doom Hammer
(22007, 183, 1, 1, 1, 12.756868), -- Mystic Staff
(22007, 184, 1, 1, 1, 12.756868), -- Conjuror's Staff
(22007, 2023, 1, 1, 1, 391.64413), -- Conjuror's Staff Head
(22007, 185, 1, 1, 1, 12.757854), -- Staff of Mana
(22007, 1876, 1, 1, 2, 10531.836848), -- Mithril Ore
(22007, 1880, 1, 1, 2, 5265.918424), -- Steel
(22007, 1877, 1, 1, 2, 2106.360002), -- Adamantite Nugget
(22007, 1881, 1, 1, 2, 7021.212286), -- Coarse Bone Powder
(22007, 1882, 1, 1, 2, 11702.032756), -- Leather
(22007, 955, 1, 1, 2, 210.639684), -- Scroll: Enchant Weapon (D-Grade)
-- Grave Robber Fighter
(22008, 955, 1, 1, -1, 2219), -- Scroll: Enchant Weapon (D-Grade)
(22008, 1877, 1, 1, -1, 22185), -- Adamantite Nugget
(22008, 1881, 1, 1, -1, 73951), -- Coarse Bone Powder
(22008, 57, 234, 468, 0, 700000), -- Adena
(22008, 348, 1, 1, 1, 147.844449), -- Scale Mail
(22008, 1935, 1, 1, 1, 4233.089118), -- Scale Mail Fragment
(22008, 377, 1, 1, 1, 236.415369), -- Scale Gaiters
(22008, 1937, 1, 1, 1, 6509.651064), -- Scale Gaiters Fragment
(22008, 1876, 1, 1, 2, 10102.76541), -- Mithril Ore
(22008, 1880, 1, 1, 2, 5051.382705), -- Steel
(22008, 1877, 1, 1, 2, 2020.553082), -- Adamantite Nugget
(22008, 1881, 1, 1, 2, 6735.189213), -- Coarse Bone Powder
(22008, 1882, 1, 1, 2, 11225.303082), -- Leather
(22008, 956, 1, 1, 2, 1683.806508), -- Scroll: Enchant Armor (D-Grade)
-- Ghost of a Loyal Vassal
(22009, 1832, 1, 1, -1, 713613), -- Greater Antidote
(22009, 1936, 1, 1, -1, 52557), -- White Tunic Pattern
(22009, 2184, 1, 1, -1, 67463), -- Recipe: Mithril Banded Gaiters
(22009, 57, 272, 542, 0, 700000), -- Adena
(22009, 848, 1, 1, 1, 535.000334), -- Enchanted Earring
(22009, 879, 1, 1, 1, 804.950157), -- Enchanted Ring
(22009, 911, 1, 1, 1, 401.550787), -- Enchanted Necklace
(22009, 1900, 1, 1, 1, 9599.498722), -- Enchanted Necklace Chain
(22009, 1875, 1, 1, 2, 3342.52409), -- Stone of Purity
(22009, 1879, 1, 1, 2, 8356.164242), -- Cokes
(22009, 1885, 1, 1, 2, 4178.130782), -- High-Grade Suede
(22009, 5550, 1, 1, 2, 668.504818), -- Durable Metal Plate
(22009, 5549, 1, 1, 2, 5013.737474), -- Metallic Thread
(22009, 1829, 1, 1, 2, 20054.949896), -- Scroll of Escape: Clan Hall
(22009, 1832, 1, 1, 2, 55707.988698), -- Greater Antidote
-- Ghost of a General
(22010, 1937, 1, 1, -1, 58413), -- Scale Gaiters Fragment
(22010, 2185, 1, 1, -1, 133844), -- Recipe: Iron Boots
(22010, 2021, 1, 1, -1, 8585), -- Spinebone Sword Blade
(22010, 57, 286, 575, 0, 700000), -- Adena
(22010, 46, 1, 1, 1, 967.658805), -- Bronze Helmet
(22010, 627, 1, 1, 1, 1381.341195), -- Aspis
(22010, 1868, 1, 1, 2, 148621.281435), -- Thread
(22010, 1873, 1, 1, 2, 29724.168105), -- Silver Nugget
(22010, 5549, 1, 1, 2, 7431.09714), -- Metallic Thread
(22010, 1889, 1, 1, 2, 4954.06476), -- Compound Braid
(22010, 1830, 1, 1, 2, 29724.38856), -- Scroll of Escape: Castle
-- Ghost of a Batur Chief
(22011, 1871, 1, 1, -1, 778674), -- Charcoal
(22011, 1866, 1, 1, -1, 519116), -- Suede
(22011, 1901, 1, 1, -1, 107552), -- Tiger's Eye Earring Stone
(22011, 57, 329, 658, 0, 700000), -- Adena
(22011, 58, 1, 1, 1, 83.854923), -- Mithril Breastplate
(22011, 59, 1, 1, 1, 121.22904), -- Mithril Gaiters
(22011, 349, 1, 1, 1, 83.854923), -- Compound Scale Mail
(22011, 350, 1, 1, 1, 83.854923), -- Dwarven Scale Mail
(22011, 351, 1, 1, 1, 75.748802), -- Blast Plate
(22011, 378, 1, 1, 1, 121.22904), -- Compound Scale Gaiters
(22011, 379, 1, 1, 1, 121.228349), -- Dwarven Scale Gaiters
(22011, 1871, 1, 1, 2, 103503.645072), -- Charcoal
(22011, 1866, 1, 1, 2, 69002.430048), -- Suede
(22011, 1877, 1, 1, 2, 4140.153312), -- Adamantite Nugget
(22011, 2154, 1, 1, 2, 11081.771568), -- Recipe: Elven Earring
-- Ghost of a Batur Chief
(22012, 2154, 1, 1, -1, 83370), -- Recipe: Elven Earring
(22012, 1938, 1, 1, -1, 52348), -- Mithril Banded Mail Material
(22012, 2155, 1, 1, -1, 124988), -- Recipe: Elven Ring
(22012, 57, 329, 658, 0, 700000), -- Adena
(22012, 58, 1, 1, 1, 83.854923), -- Mithril Breastplate
(22012, 59, 1, 1, 1, 121.22904), -- Mithril Gaiters
(22012, 349, 1, 1, 1, 83.854923), -- Compound Scale Mail
(22012, 350, 1, 1, 1, 83.854923), -- Dwarven Scale Mail
(22012, 351, 1, 1, 1, 75.748802), -- Blast Plate
(22012, 378, 1, 1, 1, 121.22904), -- Compound Scale Gaiters
(22012, 379, 1, 1, 1, 121.228349), -- Dwarven Scale Gaiters
(22012, 1871, 1, 1, 2, 103503.67842), -- Charcoal
(22012, 1866, 1, 1, 2, 69002.5167), -- Suede
(22012, 1877, 1, 1, 2, 4140.20898), -- Adamantite Nugget
(22012, 2155, 1, 1, 2, 16613.5959), -- Recipe: Elven Ring
-- Ghost of a Morek Chief
(22013, 1939, 1, 1, -1, 68395), -- Mithril Banded Gaiters Material
(22013, 1865, 1, 1, -1, 778674), -- Varnish
(22013, 1870, 1, 1, -1, 778674), -- Coal
(22013, 57, 329, 658, 0, 700000), -- Adena
(22013, 83, 1, 1, 1, 25.04736), -- Sword of Magic
(22013, 124, 1, 1, 1, 18.555264), -- Two-Handed Sword
(22013, 2026, 1, 1, 1, 830.238552), -- Two-Handed Sword Edge
(22013, 127, 1, 1, 1, 18.555264), -- Crimson Sword
(22013, 130, 1, 1, 1, 18.555264), -- Elven Sword
(22013, 144, 1, 1, 1, 25.048296), -- Sword of Occult
(22013, 1865, 1, 1, 2, 82803.091627), -- Varnish
(22013, 1870, 1, 1, 2, 82803.091627), -- Coal
(22013, 1879, 1, 1, 2, 13800.483346), -- Cokes
(22013, 1875, 1, 1, 2, 5520.116718), -- Stone of Purity
(22013, 2156, 1, 1, 2, 6624.216682), -- Recipe: Elven Necklace
-- Ghost of a Morek Chief
(22014, 1940, 1, 1, -1, 116220), -- Iron Boots Design
(22014, 2156, 1, 1, -1, 62294), -- Recipe: Elven Necklace
(22014, 2026, 1, 1, -1, 9372), -- Two-Handed Sword Edge
(22014, 57, 329, 658, 0, 700000), -- Adena
(22014, 83, 1, 1, 1, 25.04736), -- Sword of Magic
(22014, 124, 1, 1, 1, 18.555264), -- Two-Handed Sword
(22014, 2026, 1, 1, 1, 830.238552), -- Two-Handed Sword Edge
(22014, 127, 1, 1, 1, 18.555264), -- Crimson Sword
(22014, 130, 1, 1, 1, 18.555264), -- Elven Sword
(22014, 144, 1, 1, 1, 25.048296), -- Sword of Occult
(22014, 1865, 1, 1, 2, 69002.425128), -- Varnish
(22014, 1870, 1, 1, 2, 69002.425128), -- Coal
(22014, 1879, 1, 1, 2, 11500.275381), -- Cokes
(22014, 1875, 1, 1, 2, 4600.342005), -- Stone of Purity
(22014, 2186, 1, 1, 2, 2307.706212), -- Recipe: Brigandine Tunic
(22014, 1341, 10, 30, 2, 230007.826146), -- Bone Arrow
-- Ghost of a Turka Chief
(22015, 2186, 1, 1, -1, 26043), -- Recipe: Brigandine Tunic
(22015, 2027, 1, 1, -1, 10201), -- Spiked Club Head
(22015, 1884, 1, 1, -1, 479184), -- Cord
(22015, 57, 329, 658, 0, 700000), -- Adena
(22015, 260, 1, 1, 1, 111), -- Triple-Edged Jamadhr
(22015, 1874, 1, 1, 2, 4600.180565), -- Oriharukon Ore
(22015, 1878, 1, 1, 2, 27600.998285), -- Braided Hemp
(22015, 1884, 1, 1, 2, 42463.054645), -- Cord
(22015, 1889, 1, 1, 2, 4600.180565), -- Compound Braid
(22015, 5220, 1, 1, 2, 2760.12536), -- Metal Hardener
(22015, 2187, 1, 1, 2, 3080.46058), -- Recipe: Manticore Skin Shirt
-- Ghost of a Turka Chief
(22016, 1889, 1, 1, -1, 51912), -- Compound Braid
(22016, 2028, 1, 1, -1, 9252), -- Shilen Knife Edge
(22016, 2187, 1, 1, -1, 34762), -- Recipe: Manticore Skin Shirt
(22016, 57, 329, 658, 0, 700000), -- Adena
(22016, 260, 1, 1, 1, 111), -- Triple-Edged Jamadhr
(22016, 1874, 1, 1, 2, 4600.161512), -- Oriharukon Ore
(22016, 1878, 1, 1, 2, 27600.882119), -- Braided Hemp
(22016, 1884, 1, 1, 2, 42462.975832), -- Cord
(22016, 1889, 1, 1, 2, 4600.161512), -- Compound Braid
(22016, 5220, 1, 1, 2, 2760.062126), -- Metal Hardener
(22016, 2188, 1, 1, 2, 4928.756899), -- Recipe: Manticore Skin Gaiters
-- Bandit Sweeper
(22017, 1900, 1, 1, -1, 64708), -- Enchanted Necklace Chain
(22017, 2153, 1, 1, -1, 91981), -- Recipe: Tiger's Eye Earring
(22017, 1933, 1, 1, -1, 69581), -- Dark Stockings Fabric
(22017, 57, 249, 499, 0, 700000), -- Adena
(22017, 69, 1, 1, 1, 26.103903), -- Bastard Sword
(22017, 125, 1, 1, 1, 26.103903), -- Spinebone Sword
(22017, 2021, 1, 1, 1, 816.582546), -- Spinebone Sword Blade
(22017, 126, 1, 1, 1, 26.103903), -- Artisan's Sword
(22017, 128, 1, 1, 1, 26.105745), -- Knight's Sword
(22017, 1869, 1, 1, 2, 64639.352724), -- Iron Ore
(22017, 1864, 1, 1, 2, 129278.913156), -- Stem
(22017, 1880, 1, 1, 2, 6463.87296), -- Steel
(22017, 5550, 1, 1, 2, 861.780492), -- Durable Metal Plate
(22017, 737, 1, 1, 2, 6464.080668), -- Scroll of Resurrection
-- Bandit Hound
(22018, 956, 1, 1, -1, 16825), -- Scroll: Enchant Armor (D-Grade)
(22018, 1872, 1, 1, -1, 672999), -- Animal Bone
(22018, 1882, 1, 1, -1, 112167), -- Leather
(22018, 57, 213, 426, 0, 700000), -- Adena
(22018, 392, 1, 1, 1, 358.558431), -- Lion Skin Shirt
(22018, 414, 1, 1, 1, 574.441569), -- Lion Skin Gaiters
(22018, 1867, 1, 1, 2, 91942.1756), -- Animal Skin
(22018, 1872, 1, 1, 2, 91942.1756), -- Animal Bone
(22018, 1882, 1, 1, 2, 15323.762428), -- Leather
(22018, 955, 1, 1, 2, 275.886372), -- Scroll: Enchant Weapon (D-Grade)
-- Bandit Watchman
(22019, 1834, 1, 1, -1, 763138), -- Emergency Dressing
(22019, 1935, 1, 1, -1, 38370), -- Scale Mail Fragment
(22019, 2183, 1, 1, -1, 45186), -- Recipe: Mithril Banded Mail
(22019, 57, 289, 580, 0, 700000), -- Adena
(22019, 433, 1, 1, 1, 122.021896), -- Elven Tunic
(22019, 434, 1, 1, 1, 122.021896), -- White Tunic
(22019, 1936, 1, 1, 1, 3839.539144), -- White Tunic Pattern
(22019, 435, 1, 1, 1, 122.021896), -- Mystic's Tunic
(22019, 466, 1, 1, 1, 195.494896), -- Elven Stockings
(22019, 467, 1, 1, 1, 195.494896), -- Dark Stockings
(22019, 1933, 1, 1, 1, 5519.900168), -- Dark Stockings Fabric
(22019, 468, 1, 1, 1, 195.505208), -- Mystic's Stockings
(22019, 1869, 1, 1, 2, 62553.737331), -- Iron Ore
(22019, 1864, 1, 1, 2, 125107.474662), -- Stem
(22019, 1880, 1, 1, 2, 6255.303309), -- Steel
(22019, 5550, 1, 1, 2, 834.056091), -- Durable Metal Plate
(22019, 956, 1, 1, 2, 2085.022854), -- Scroll: Enchant Armor (D-Grade)
(22019, 1061, 1, 1, 2, 37911.405753), -- Greater Healing Potion
-- Snow Lynx
(22020, 1901, 1, 1, -1, 78285), -- Tiger's Eye Earring Stone
(22020, 2154, 1, 1, -1, 60684), -- Recipe: Elven Earring
(22020, 1938, 1, 1, -1, 38103), -- Mithril Banded Mail Material
(22020, 57, 239, 479, 0, 700000), -- Adena
(22020, 58, 1, 1, 1, 61.040559), -- Mithril Breastplate
(22020, 59, 1, 1, 1, 88.24632), -- Mithril Gaiters
(22020, 349, 1, 1, 1, 61.040559), -- Compound Scale Mail
(22020, 350, 1, 1, 1, 61.040559), -- Dwarven Scale Mail
(22020, 351, 1, 1, 1, 55.139866), -- Blast Plate
(22020, 378, 1, 1, 1, 88.24632), -- Compound Scale Gaiters
(22020, 379, 1, 1, 1, 88.245817), -- Dwarven Scale Gaiters
(22020, 1872, 1, 1, 2, 80361.58368), -- Animal Bone
(22020, 1867, 1, 1, 2, 80361.58368), -- Animal Skin
(22020, 1881, 1, 1, 2, 8036.158368), -- Coarse Bone Powder
(22020, 1875, 1, 1, 2, 4018.079184), -- Stone of Purity
(22020, 8302, 1, 1, 2, 430.595088), -- Recipe: Sword of Magic Fog (100%)
-- Bandit Undertaker
(22021, 5220, 1, 1, -1, 27560), -- Metal Hardener
(22021, 1874, 1, 1, -1, 45933), -- Oriharukon Ore
(22021, 1939, 1, 1, -1, 60518), -- Mithril Banded Gaiters Material
(22021, 57, 291, 580, 0, 700000), -- Adena
(22021, 157, 1, 1, 1, 32.84046), -- Spiked Club
(22021, 2027, 1, 1, 1, 1599.31908), -- Spiked Club Head
(22021, 186, 1, 1, 1, 32.84046), -- Staff of Magic
(22021, 1874, 1, 1, 2, 3488.918165), -- Oriharukon Ore
(22021, 1878, 1, 1, 2, 20933.98306), -- Braided Hemp
(22021, 1884, 1, 1, 2, 32206.182485), -- Cord
(22021, 1889, 1, 1, 2, 3488.918165), -- Compound Braid
(22021, 5220, 1, 1, 2, 2093.49312), -- Metal Hardener
(22021, 8295, 1, 1, 2, 373.804195), -- Recipe: Titan Sword (100%)
(22021, 1341, 10, 30, 2, 174449.70081), -- Bone Arrow
-- Bandit Assassin
(22022, 2155, 1, 1, -1, 130876), -- Recipe: Elven Ring
(22022, 1940, 1, 1, -1, 121696), -- Iron Boots Design
(22022, 2156, 1, 1, -1, 65229), -- Recipe: Elven Necklace
(22022, 57, 344, 687, 0, 700000), -- Adena
(22022, 223, 1, 1, 1, 23.31348), -- Kukuri
(22022, 238, 1, 1, 1, 23.31348), -- Dagger of Mana
(22022, 239, 1, 1, 1, 23.31348), -- Mystic Knife
(22022, 241, 1, 1, 1, 23.31348), -- Shilen Knife
(22022, 2028, 1, 1, 1, 1029.74608), -- Shilen Knife Edge
(22022, 1872, 1, 1, 2, 115605.509632), -- Animal Bone
(22022, 1867, 1, 1, 2, 115605.509632), -- Animal Skin
(22022, 1881, 1, 1, 2, 11560.576512), -- Coarse Bone Powder
(22022, 1875, 1, 1, 2, 5780.160512), -- Stone of Purity
(22022, 2156, 1, 1, 2, 6936.243712), -- Recipe: Elven Necklace
-- Bandit Warrior
(22023, 2026, 1, 1, -1, 11205), -- Two-Handed Sword Edge
(22023, 1868, 1, 3, -1, 930959), -- Thread
(22023, 1873, 1, 1, -1, 372383), -- Silver Nugget
(22023, 57, 392, 787, 0, 700000), -- Adena
(22023, 83, 1, 1, 1, 29.94444), -- Sword of Magic
(22023, 124, 1, 1, 1, 22.183056), -- Two-Handed Sword
(22023, 2026, 1, 1, 1, 992.560833), -- Two-Handed Sword Edge
(22023, 127, 1, 1, 1, 22.183056), -- Crimson Sword
(22023, 130, 1, 1, 1, 22.183056), -- Elven Sword
(22023, 144, 1, 1, 1, 29.945559), -- Sword of Occult
(22023, 1868, 1, 1, 2, 197993.601342), -- Thread
(22023, 1873, 1, 1, 2, 39598.822188), -- Silver Nugget
(22023, 5549, 1, 1, 2, 9899.705547), -- Metallic Thread
(22023, 1889, 1, 1, 2, 6599.803698), -- Compound Braid
(22023, 8295, 1, 1, 2, 707.067225), -- Recipe: Titan Sword (100%)
-- Bandit Inspector
(22024, 6036, 1, 1, -1, 29133), -- Greater Magic Haste Potion
(22024, 1902, 1, 1, -1, 88550), -- Elven Earring Beads
(22024, 1825, 1, 1, -1, 62428), -- Recipe: Oriharukon
(22024, 57, 369, 737, 0, 700000), -- Adena
(22024, 395, 1, 1, 1, 131.331049), -- Manticore Skin Shirt
(22024, 1942, 1, 1, 1, 5760.991038), -- Manticore Skin Shirt Texture
(22024, 417, 1, 1, 1, 209.740795), -- Manticore Skin Gaiters
(22024, 1943, 1, 1, 1, 8970.937118), -- Manticore Skin Gaiters Pattern
(22024, 1872, 1, 1, 2, 120476.305702), -- Animal Bone
(22024, 1867, 1, 1, 2, 120476.305702), -- Animal Skin
(22024, 1881, 1, 1, 2, 12047.657118), -- Coarse Bone Powder
(22024, 1875, 1, 1, 2, 6023.69582), -- Stone of Purity
(22024, 1825, 1, 1, 2, 6454.035658), -- Recipe: Oriharukon
-- Frozen Wasteland Werewolf
(22025, 1903, 1, 1, -1, 145444), -- Elven Ring Piece
(22025, 2145, 1, 1, -1, 62281), -- Recipe: Mithril Alloy
(22025, 1904, 1, 1, -1, 81375), -- Elven Necklace Beads
(22025, 57, 369, 736, 0, 700000), -- Adena
(22025, 352, 1, 1, 1, 65.409472), -- Brigandine Tunic
(22025, 1941, 1, 1, 1, 2987.515536), -- Brigandine Temper
(22025, 2377, 1, 1, 1, 104.628368), -- Mithril Scale Gaiters
(22025, 2918, 1, 1, 1, 4456.915216), -- Mithril Scale Gaiters Material
(22025, 2378, 1, 1, 1, 104.628368), -- Brigandine Gaiters
(22025, 2919, 1, 1, 1, 4456.90304), -- Brigandine Gaiters Material
(22025, 1867, 1, 1, 2, 120192.92252), -- Animal Skin
(22025, 1872, 1, 1, 2, 120192.92252), -- Animal Bone
(22025, 1882, 1, 1, 2, 20032.24376), -- Leather
(22025, 1894, 1, 1, 2, 3163.01428), -- Crafted Leather
(22025, 2145, 1, 1, 2, 6438.89692), -- Recipe: Mithril Alloy
-- Bandit Captain
(22026, 1864, 1, 5, -1, 763202), -- Stem
(22026, 1869, 1, 3, -1, 572402), -- Iron Ore
(22026, 6036, 1, 1, -1, 38160), -- Greater Magic Haste Potion
(22026, 57, 478, 954, 0, 700000), -- Adena
(22026, 129, 1, 1, 1, 18.36401), -- Sword of Revolution
(22026, 2034, 1, 1, 1, 1041.92956), -- Sword of Revolution Blade
(22026, 7881, 1, 1, 1, 18.36401), -- Titan Sword
(22026, 8328, 1, 1, 1, 941.41663), -- Titan Sword Blade
(22026, 7886, 1, 1, 1, 18.36401), -- Sword of Magic Fog
(22026, 8333, 1, 1, 1, 971.56178), -- Sword of Magic Fog Blade
(22026, 1864, 1, 1, 2, 236710.175405), -- Stem
(22026, 1869, 1, 1, 2, 118354.845855), -- Iron Ore
(22026, 1878, 1, 1, 2, 47342.13182), -- Braided Hemp
(22026, 1884, 1, 1, 2, 72833.82571), -- Cord
(22026, 2146, 1, 1, 2, 8454.02121), -- Recipe: Artisan's frame
-- Forgotten Crewman
(22027, 1941, 1, 1, -1, 87978), -- Brigandine Temper
(22027, 2146, 1, 1, -1, 158015), -- Recipe: Artisan's frame
(22027, 1942, 1, 1, -1, 112839), -- Manticore Skin Shirt Texture
(22027, 57, 936, 1864, 0, 700000), -- Adena
(22027, 279, 1, 1, 1, 106.47648), -- Reinforced Long Bow
(22027, 2040, 1, 1, 1, 6615.52352), -- Reinforced Long Bow Shaft
(22027, 1870, 1, 1, 2, 228708.264224), -- Coal
(22027, 1865, 1, 1, 2, 228708.264224), -- Varnish
(22027, 1874, 1, 1, 2, 15247.350048), -- Oriharukon Ore
(22027, 2147, 1, 1, 2, 16336.44648), -- Recipe: Blacksmith's frame
(22027, 6036, 1, 1, 2, 7623.675024), -- Greater Magic Haste Potion
-- Vagabond of the Ruins
(22028, 2147, 1, 1, -1, 142506), -- Recipe: Blacksmith's frame
(22028, 1943, 1, 1, -1, 158466), -- Manticore Skin Gaiters Pattern
(22028, 1878, 1, 1, -1, 798035), -- Braided Hemp
(22028, 57, 833, 1662, 0, 700000), -- Adena
(22028, 129, 1, 1, 1, 32.005846), -- Sword of Revolution
(22028, 2034, 1, 1, 1, 1815.934376), -- Sword of Revolution Blade
(22028, 7881, 1, 1, 1, 32.005846), -- Titan Sword
(22028, 8328, 1, 1, 1, 1640.754698), -- Titan Sword Blade
(22028, 7886, 1, 1, 1, 32.005846), -- Sword of Magic Fog
(22028, 8333, 1, 1, 1, 1693.293388), -- Sword of Magic Fog Blade
(22028, 1864, 3, 9, 2, 68753.834406), -- Stem
(22028, 1869, 1, 1, 2, 206261.004036), -- Iron Ore
(22028, 1878, 1, 1, 2, 82504.301778), -- Braided Hemp
(22028, 1884, 1, 1, 2, 126930.002232), -- Cord
(22028, 2148, 1, 1, 2, 14732.857548), -- Recipe: Crafted Leather
-- Ragna Orc
(22029, 5549, 1, 1, -1, 118798), -- Metallic Thread
(22029, 6036, 1, 1, -1, 39599), -- Greater Magic Haste Potion
(22029, 1944, 1, 1, -1, 60596), -- Mithril Tunic Fabric
(22029, 57, 496, 990, 0, 700000), -- Adena
(22029, 88, 1, 1, 1, 8.167724), -- Morning Star
(22029, 2031, 1, 1, 1, 444.074651), -- Morning Star Head
(22029, 90, 1, 1, 1, 8.167724), -- Goat Head Staff
(22029, 2032, 1, 1, 1, 405.374899), -- Goat Head Staff Head
(22029, 158, 1, 1, 1, 8.167724), -- Tarbar
(22029, 2035, 1, 1, 1, 444.074651), -- Tarbar Head
(22029, 169, 1, 1, 1, 8.167724), -- Skull Breaker
(22029, 2036, 1, 1, 1, 444.074651), -- Skull Breaker Head
(22029, 172, 1, 1, 1, 8.167724), -- Heavy Bone Club
(22029, 2037, 1, 1, 1, 444.074651), -- Heavy Bone Club Head
(22029, 7890, 1, 1, 1, 8.167724), -- Priest Mace
(22029, 8337, 1, 1, 1, 444.074651), -- Priest Mace Head
(22029, 7896, 1, 1, 1, 8.167724), -- Titan Hammer
(22029, 8343, 1, 1, 1, 444.077778), -- Titan Hammer Piece
(22029, 1868, 1, 1, 2, 245637.916984), -- Thread
(22029, 1873, 1, 1, 2, 49127.713), -- Silver Nugget
(22029, 5549, 1, 1, 2, 12281.847248), -- Metallic Thread
(22029, 1889, 1, 1, 2, 8188.006168), -- Compound Braid
(22029, 2149, 1, 1, 2, 8772.5166), -- Recipe: Metallic Fiber
-- Ragna Orc Shaman
(22030, 1805, 1, 1, -1, 4171), -- Recipe: Soulshot (C-Grade)
(22030, 1905, 1, 1, -1, 121725), -- Omen Beast's Eye Earring Gemstone
(22030, 2160, 1, 1, -1, 80731), -- Recipe: Moonstone Earring
(22030, 57, 504, 1018, 0, 700000), -- Adena
(22030, 438, 1, 1, 1, 171.405545), -- Sage's Rag
(22030, 1953, 1, 1, 1, 10063.594455), -- Sage's Rag Lining
(22030, 1873, 1, 1, 2, 50268.909142), -- Silver Nugget
(22030, 1868, 1, 1, 2, 251344.54571), -- Thread
(22030, 1876, 1, 1, 2, 25134.454571), -- Mithril Ore
(22030, 1895, 1, 1, 2, 35906.467408), -- Metallic Fiber
(22030, 1805, 1, 1, 2, 418.623169), -- Recipe: Soulshot (C-Grade)
-- Ragna Orc Archer
(22031, 1906, 1, 1, -1, 160045); -- Mithril Ring Wire

INSERT INTO `droplist` VALUES
(22031, 1873, 1, 1, -1, 465732), -- Silver Nugget
(22031, 1868, 1, 5, -1, 776220), -- Thread
(22031, 57, 460, 935, 0, 700000), -- Adena
(22031, 280, 1, 1, 1, 42.15233), -- Light Crossbow
(22031, 2054, 1, 1, 1, 2487.84767), -- Light Crossbow Shaft
(22031, 1873, 1, 1, 2, 46773.908608), -- Silver Nugget
(22031, 1868, 1, 1, 2, 233870.218944), -- Thread
(22031, 1876, 1, 1, 2, 23386.954304), -- Mithril Ore
(22031, 1895, 1, 1, 2, 33409.93472), -- Metallic Fiber
(22031, 8303, 1, 1, 2, 510.983424), -- Recipe: Mysterious Sword (100%)
-- Ragna Orc Warrior
(22032, 4553, 1, 1, -1, 5824), -- Greater Dye of STR (Str+1 Con-1)
(22032, 1908, 1, 1, -1, 137871), -- Moonstone Earring Wire
(22032, 2163, 1, 1, -1, 74282), -- Recipe: Earring of Protection
(22032, 57, 573, 1175, 0, 700000), -- Adena
(22032, 71, 1, 1, 1, 13.009464), -- Flamberge
(22032, 2059, 1, 1, 1, 851.817504), -- Flamberge Blade
(22032, 72, 1, 1, 1, 13.009464), -- Stormbringer
(22032, 2060, 1, 1, 1, 910.559424), -- Stormbringer Blade
(22032, 7887, 1, 1, 1, 13.009464), -- Mysterious Sword
(22032, 8334, 1, 1, 1, 910.59468), -- Mysterious Sword Blade
(22032, 1868, 1, 1, 2, 152908.674048), -- Thread
(22032, 1873, 1, 1, 2, 30581.694), -- Silver Nugget
(22032, 5549, 1, 1, 2, 7645.474512), -- Metallic Thread
(22032, 1889, 1, 1, 2, 5096.914992), -- Compound Braid
(22032, 2163, 1, 1, 2, 3900.785616), -- Recipe: Earring of Protection
(22032, 8723, 1, 1, 2, 3058.271424), -- Life Stone - Level 46
(22032, 8733, 1, 1, 2, 764.567856), -- Mid-Grade Life Stone - Level 46
(22032, 8743, 1, 1, 2, 76.518), -- High-Grade Life Stone - Level 46
(22032, 8753, 1, 1, 2, 15.099552), -- Top-Grade Life Stone - Level 46
-- Ragna Orc Mage
(22033, 1909, 1, 1, -1, 252912), -- Aquastone Ring Wire
(22033, 2164, 1, 1, -1, 144063), -- Recipe: Ring of Protection
(22033, 1910, 1, 1, -1, 141025), -- Aquastone Necklace Chain
(22033, 57, 741, 1505, 0, 700000), -- Adena
(22033, 439, 1, 1, 1, 152.080864), -- Karmian Tunic
(22033, 1962, 1, 1, 1, 7081.322953), -- Karmian Tunic Pattern
(22033, 471, 1, 1, 1, 243.052312), -- Karmian Stockings
(22033, 1954, 1, 1, 1, 11764.543871), -- Karmian Stocking Design
(22033, 1872, 1, 1, 2, 118015.861076), -- Animal Bone
(22033, 1867, 1, 1, 2, 118015.861076), -- Animal Skin
(22033, 1881, 1, 1, 2, 11801.612692), -- Coarse Bone Powder
(22033, 1875, 1, 1, 2, 5900.673424), -- Stone of Purity
(22033, 4041, 1, 1, 2, 769.61838), -- Mold Hardener
(22033, 2164, 1, 1, 2, 6808.530684), -- Recipe: Ring of Protection
(22033, 8723, 1, 1, 2, 3540.510392), -- Life Stone - Level 46
(22033, 8733, 1, 1, 2, 884.994676), -- Mid-Grade Life Stone - Level 46
(22033, 8743, 1, 1, 2, 88.526052), -- High-Grade Life Stone - Level 46
(22033, 8753, 1, 1, 2, 17.811548), -- Top-Grade Life Stone - Level 46
-- Ragna Orc Mage
(22034, 1909, 1, 1, -1, 231934), -- Aquastone Ring Wire
(22034, 2164, 1, 1, -1, 132113), -- Recipe: Ring of Protection
(22034, 1910, 1, 1, -1, 129328), -- Aquastone Necklace Chain
(22034, 57, 679, 1380, 0, 700000), -- Adena
(22034, 439, 1, 1, 1, 139.46608), -- Karmian Tunic
(22034, 1962, 1, 1, 1, 6493.942285), -- Karmian Tunic Pattern
(22034, 471, 1, 1, 1, 222.89164), -- Karmian Stockings
(22034, 1954, 1, 1, 1, 10788.699995), -- Karmian Stocking Design
(22034, 1872, 1, 1, 2, 108227.113665), -- Animal Bone
(22034, 1867, 1, 1, 2, 108227.113665), -- Animal Skin
(22034, 1881, 1, 1, 2, 10822.830236), -- Coarse Bone Powder
(22034, 1875, 1, 1, 2, 5411.415118), -- Stone of Purity
(22034, 4041, 1, 1, 2, 705.847091), -- Mold Hardener
(22034, 8319, 1, 1, 2, 188.764766), -- Recipe: Karik Horn (100%)
(22034, 8723, 1, 1, 2, 3246.801523), -- Life Stone - Level 46
(22034, 8733, 1, 1, 2, 811.640946), -- Mid-Grade Life Stone - Level 46
(22034, 8743, 1, 1, 2, 81.068999), -- High-Grade Life Stone - Level 46
(22034, 8753, 1, 1, 2, 16.403991), -- Top-Grade Life Stone - Level 46
-- Ragna Orc Mage
(22035, 1909, 1, 1, -1, 252912), -- Aquastone Ring Wire
(22035, 2164, 1, 1, -1, 144063), -- Recipe: Ring of Protection
(22035, 1910, 1, 1, -1, 141025), -- Aquastone Necklace Chain
(22035, 57, 741, 1505, 0, 700000), -- Adena
(22035, 439, 1, 1, 1, 152.080864), -- Karmian Tunic
(22035, 1962, 1, 1, 1, 7081.322953), -- Karmian Tunic Pattern
(22035, 471, 1, 1, 1, 243.052312), -- Karmian Stockings
(22035, 1954, 1, 1, 1, 11764.543871), -- Karmian Stocking Design
(22035, 1872, 1, 1, 2, 118015.98913), -- Animal Bone
(22035, 1867, 1, 1, 2, 118015.98913), -- Animal Skin
(22035, 1881, 1, 1, 2, 11801.52079), -- Coarse Bone Powder
(22035, 1875, 1, 1, 2, 5900.8906), -- Stone of Purity
(22035, 4041, 1, 1, 2, 769.77196), -- Mold Hardener
(22035, 2213, 1, 1, 2, 1374.44398), -- Recipe: Dwarven Chain Mail Shirt
(22035, 8723, 1, 1, 2, 3540.53436), -- Life Stone - Level 46
(22035, 8733, 1, 1, 2, 885.13359), -- Mid-Grade Life Stone - Level 46
(22035, 8743, 1, 1, 2, 88.5394), -- High-Grade Life Stone - Level 46
(22035, 8753, 1, 1, 2, 17.18706), -- Top-Grade Life Stone - Level 46
-- Ragna Orc Mage
(22036, 1909, 1, 1, -1, 178179), -- Aquastone Ring Wire
(22036, 2164, 1, 1, -1, 101494), -- Recipe: Ring of Protection
(22036, 1910, 1, 1, -1, 99354), -- Aquastone Necklace Chain
(22036, 57, 522, 1060, 0, 700000), -- Adena
(22036, 439, 1, 1, 1, 107.146624), -- Karmian Tunic
(22036, 1962, 1, 1, 1, 4989.055348), -- Karmian Tunic Pattern
(22036, 471, 1, 1, 1, 171.239392), -- Karmian Stockings
(22036, 1954, 1, 1, 1, 8288.558636), -- Karmian Stocking Design
(22036, 1872, 1, 1, 2, 83143.650447), -- Animal Bone
(22036, 1867, 1, 1, 2, 83143.650447), -- Animal Skin
(22036, 1881, 1, 1, 2, 8314.420257), -- Coarse Bone Powder
(22036, 1875, 1, 1, 2, 4157.118108), -- Stone of Purity
(22036, 4041, 1, 1, 2, 542.184786), -- Mold Hardener
(22036, 2214, 1, 1, 2, 1547.416728), -- Recipe: Dwarven Chain Gaiters
(22036, 8723, 1, 1, 2, 2494.307673), -- Life Stone - Level 46
(22036, 8733, 1, 1, 2, 623.530908), -- Mid-Grade Life Stone - Level 46
(22036, 8743, 1, 1, 2, 62.389899), -- High-Grade Life Stone - Level 46
(22036, 8753, 1, 1, 2, 12.330747), -- Top-Grade Life Stone - Level 46
-- Ragna Orc Healer
(22037, 1875, 1, 1, -1, 96375), -- Stone of Purity
(22037, 4555, 1, 1, -1, 5783), -- Greater Dye of CON (Con+1 Str-1)
(22037, 1960, 1, 1, -1, 79213), -- Chain Gaiters Part
(22037, 57, 572, 1161, 0, 700000), -- Adena
(22037, 439, 1, 1, 1, 117.390208), -- Karmian Tunic
(22037, 1962, 1, 1, 1, 5466.026116), -- Karmian Tunic Pattern
(22037, 471, 1, 1, 1, 187.610464), -- Karmian Stockings
(22037, 1954, 1, 1, 1, 9080.973212), -- Karmian Stocking Design
(22037, 1872, 1, 1, 2, 91097.024483), -- Animal Bone
(22037, 1867, 1, 1, 2, 91097.024483), -- Animal Skin
(22037, 1881, 1, 1, 2, 9109.642202), -- Coarse Bone Powder
(22037, 1875, 1, 1, 2, 4554.821101), -- Stone of Purity
(22037, 4041, 1, 1, 2, 594.028518), -- Mold Hardener
(22037, 2215, 1, 1, 2, 870.358214), -- Recipe: Robe of Seal
(22037, 8723, 1, 1, 2, 2732.972989), -- Life Stone - Level 46
(22037, 8733, 1, 1, 2, 683.193042), -- Mid-Grade Life Stone - Level 46
(22037, 8743, 1, 1, 2, 68.27914), -- High-Grade Life Stone - Level 46
(22037, 8753, 1, 1, 2, 13.655828), -- Top-Grade Life Stone - Level 46
-- Ragna Orc Hero
(22038, 2166, 1, 1, -1, 58836), -- Recipe: Earrings of Binding (100%)
(22038, 1911, 1, 1, -1, 129093), -- Earring of Protection Gemstone
(22038, 2167, 1, 1, -1, 88554), -- Recipe: Ring of Ages
(22038, 57, 686, 1395, 0, 700000), -- Adena
(22038, 355, 1, 1, 1, 77.59934), -- Dwarven Chain Mail Shirt
(22038, 1968, 1, 1, 1, 4632.57096), -- Dwarven Chain Mail Shirt Material
(22038, 382, 1, 1, 1, 124.158944), -- Dwarven Chain Gaiters
(22038, 1969, 1, 1, 1, 7347.670756), -- Dwarven Chain Gaiters Material
(22038, 1871, 1, 1, 2, 76903.233096), -- Charcoal
(22038, 1866, 1, 1, 2, 51268.822064), -- Suede
(22038, 1877, 1, 1, 2, 3076.151224), -- Adamantite Nugget
(22038, 4041, 1, 1, 2, 668.776136), -- Mold Hardener
(22038, 4040, 1, 1, 2, 1538.075612), -- Mold Lubricant
(22038, 951, 1, 1, 2, 139.887272), -- Scroll: Enchant Weapon (C-Grade)
(22038, 8724, 1, 1, 2, 2563.413728), -- Life Stone - Level 49
(22038, 8734, 1, 1, 2, 640.853432), -- Mid-Grade Life Stone - Level 49
(22038, 8744, 1, 1, 2, 64.057968), -- High-Grade Life Stone - Level 49
(22038, 8754, 1, 1, 2, 12.729468), -- Top-Grade Life Stone - Level 49
-- Ragna Orc Commander
(22039, 1912, 1, 1, -1, 195087), -- Ring of Protection Gemstone
(22039, 951, 1, 1, -1, 3292), -- Scroll: Enchant Weapon (C-Grade)
(22039, 1877, 1, 1, -1, 72416), -- Adamantite Nugget
(22039, 57, 715, 1457, 0, 700000), -- Adena
(22039, 73, 1, 1, 1, 9.07536), -- Shamshir
(22039, 2077, 1, 1, 1, 666.17464), -- Shamshir Blade
(22039, 74, 1, 1, 1, 9.07536), -- Katana
(22039, 2078, 1, 1, 1, 666.17464), -- Katana Blade
(22039, 131, 1, 1, 1, 9.07536), -- Spirit Sword
(22039, 2080, 1, 1, 1, 666.17464), -- Spirit Sword Blade
(22039, 133, 1, 1, 1, 9.07536), -- Raid Sword
(22039, 2081, 1, 1, 1, 666.17464), -- Raid Sword Blade
(22039, 1871, 1, 1, 2, 72922.6745), -- Charcoal
(22039, 1866, 1, 1, 2, 48615.2035), -- Suede
(22039, 1877, 1, 1, 2, 2916.90175), -- Adamantite Nugget
(22039, 4041, 1, 1, 2, 634.1375), -- Mold Hardener
(22039, 4040, 1, 1, 2, 1458.51625), -- Mold Lubricant
(22039, 952, 1, 1, 2, 972.257), -- Scroll: Enchant Armor (C-Grade)
(22039, 8318, 1, 1, 2, 118.9825), -- Recipe: Dwarven Hammer (100%)
(22039, 8724, 1, 1, 2, 2430.77325), -- Life Stone - Level 49
(22039, 8734, 1, 1, 2, 607.726), -- Mid-Grade Life Stone - Level 49
(22039, 8744, 1, 1, 2, 60.79875), -- High-Grade Life Stone - Level 49
(22039, 8754, 1, 1, 2, 12.029), -- Top-Grade Life Stone - Level 49
-- Ragna Orc Sniper
(22040, 4041, 1, 1, -1, 12090), -- Mold Hardener
(22040, 4589, 1, 1, -1, 4634), -- Greater Dye of STR (Str+2 Con-2)
(22040, 1913, 1, 1, -1, 84545), -- Necklace of Protection Gemstone
(22040, 57, 549, 1120, 0, 700000), -- Adena
(22040, 282, 1, 1, 1, 13.940663), -- Elemental Bow
(22040, 2085, 1, 1, 1, 1065.559337), -- Crossbow Shaft
(22040, 285, 1, 1, 1, 13.940663), -- Noble Elven Bow
(22040, 2086, 1, 1, 1, 1065.559337), -- Noble Elven Bow Shaft
(22040, 1872, 1, 1, 2, 74670.33511), -- Animal Bone
(22040, 1867, 1, 1, 2, 74670.33511), -- Animal Skin
(22040, 1881, 1, 1, 2, 7467.172172), -- Coarse Bone Powder
(22040, 1875, 1, 1, 2, 3733.586086), -- Stone of Purity
(22040, 4041, 1, 1, 2, 486.977432), -- Mold Hardener
(22040, 2166, 1, 1, 2, 1898.26909), -- Recipe: Earrings of Binding (100%)
(22040, 8724, 1, 1, 2, 1866.654382), -- Life Stone - Level 49
(22040, 8734, 1, 1, 2, 466.732926), -- Mid-Grade Life Stone - Level 49
(22040, 8744, 1, 1, 2, 46.590096), -- High-Grade Life Stone - Level 49
(22040, 8754, 1, 1, 2, 9.428948), -- Top-Grade Life Stone - Level 49
(22040, 1342, 10, 30, 2, 112005.918648), -- Steel Arrow
-- Ragna Orc Sorcerer
(22041, 4041, 1, 1, -1, 20152), -- Mold Hardener
(22041, 4589, 1, 1, -1, 7725), -- Greater Dye of STR (Str+2 Con-2)
(22041, 1913, 1, 1, -1, 140926), -- Necklace of Protection Gemstone
(22041, 57, 917, 1863, 0, 700000), -- Adena
(22041, 162, 1, 1, 1, 3.625812), -- War Axe
(22041, 2097, 1, 1, 1, 320.875024), -- War Axe Blade
(22041, 174, 1, 1, 1, 3.625812), -- Nirvana Axe
(22041, 2098, 1, 1, 1, 320.875024), -- Nirvana Axe Blade
(22041, 196, 1, 1, 1, 3.625812), -- Stick of Eternity
(22041, 2099, 1, 1, 1, 337.696764), -- Stick of Eternity Shaft
(22041, 197, 1, 1, 1, 3.625812), -- Paradia Staff
(22041, 2100, 1, 1, 1, 337.696764), -- Paradia Staff Head
(22041, 199, 1, 1, 1, 3.625812), -- Pa'agrian Hammer
(22041, 2102, 1, 1, 1, 325.584044), -- Pa'agrian Hammer Head
(22041, 200, 1, 1, 1, 3.625812), -- Sage's Staff
(22041, 2103, 1, 1, 1, 337.696764), -- Sage's Staff Head
(22041, 201, 1, 1, 1, 3.625812), -- Club of Nature
(22041, 2104, 1, 1, 1, 337.696764), -- Club of Nature Head
(22041, 202, 1, 1, 1, 3.625812), -- Mace of Underworld
(22041, 2105, 1, 1, 1, 320.872356), -- Mace of Underworld Head
(22041, 1872, 1, 1, 2, 127784.765471), -- Animal Bone
(22041, 1867, 1, 1, 2, 127784.765471), -- Animal Skin
(22041, 1881, 1, 1, 2, 12778.391879), -- Coarse Bone Powder
(22041, 1875, 1, 1, 2, 6389.337053), -- Stone of Purity
(22041, 4041, 1, 1, 2, 833.416331), -- Mold Hardener
(22041, 2166, 1, 1, 2, 3248.714997), -- Recipe: Earrings of Binding (100%)
(22041, 8725, 1, 1, 2, 2662.247291), -- Life Stone - Level 52
(22041, 8735, 1, 1, 2, 665.491266), -- Mid-Grade Life Stone - Level 52
(22041, 8745, 1, 1, 2, 66.605572), -- High-Grade Life Stone - Level 52
(22041, 8755, 1, 1, 2, 13.264669), -- Top-Grade Life Stone - Level 52
-- Ragna Orc Sorcerer
(22042, 4041, 1, 1, -1, 18481), -- Mold Hardener
(22042, 4589, 1, 1, -1, 7084), -- Greater Dye of STR (Str+2 Con-2)
(22042, 1913, 1, 1, -1, 129237), -- Necklace of Protection Gemstone
(22042, 57, 841, 1709, 0, 700000), -- Adena
(22042, 162, 1, 1, 1, 3.325473), -- War Axe
(22042, 2097, 1, 1, 1, 294.295796), -- War Axe Blade
(22042, 174, 1, 1, 1, 3.325473), -- Nirvana Axe
(22042, 2098, 1, 1, 1, 294.295796), -- Nirvana Axe Blade
(22042, 196, 1, 1, 1, 3.325473), -- Stick of Eternity
(22042, 2099, 1, 1, 1, 309.724131), -- Stick of Eternity Shaft
(22042, 197, 1, 1, 1, 3.325473), -- Paradia Staff
(22042, 2100, 1, 1, 1, 309.724131), -- Paradia Staff Head
(22042, 199, 1, 1, 1, 3.325473), -- Pa'agrian Hammer
(22042, 2102, 1, 1, 1, 298.614751), -- Pa'agrian Hammer Head
(22042, 200, 1, 1, 1, 3.325473), -- Sage's Staff
(22042, 2103, 1, 1, 1, 309.724131), -- Sage's Staff Head
(22042, 201, 1, 1, 1, 3.325473), -- Club of Nature
(22042, 2104, 1, 1, 1, 309.724131), -- Club of Nature Head
(22042, 202, 1, 1, 1, 3.325473), -- Mace of Underworld
(22042, 2105, 1, 1, 1, 294.293349), -- Mace of Underworld Head
(22042, 1872, 1, 1, 2, 117185.802314), -- Animal Bone
(22042, 1867, 1, 1, 2, 117185.802314), -- Animal Skin
(22042, 1881, 1, 1, 2, 11718.502586), -- Coarse Bone Powder
(22042, 1875, 1, 1, 2, 5859.380702), -- Stone of Purity
(22042, 4041, 1, 1, 2, 764.289554), -- Mold Hardener
(22042, 2166, 1, 1, 2, 2979.253998), -- Recipe: Earrings of Binding (100%)
(22042, 8725, 1, 1, 2, 2441.430194), -- Life Stone - Level 52
(22042, 8735, 1, 1, 2, 610.292844), -- Mid-Grade Life Stone - Level 52
(22042, 8745, 1, 1, 2, 61.081048), -- High-Grade Life Stone - Level 52
(22042, 8755, 1, 1, 2, 12.164446), -- Top-Grade Life Stone - Level 52
-- Ragna Orc Sorcerer
(22043, 4041, 1, 1, -1, 20152), -- Mold Hardener
(22043, 4589, 1, 1, -1, 7725), -- Greater Dye of STR (Str+2 Con-2)
(22043, 1913, 1, 1, -1, 140926), -- Necklace of Protection Gemstone
(22043, 57, 917, 1863, 0, 700000), -- Adena
(22043, 162, 1, 1, 1, 3.625812), -- War Axe
(22043, 2097, 1, 1, 1, 320.875024), -- War Axe Blade
(22043, 174, 1, 1, 1, 3.625812), -- Nirvana Axe
(22043, 2098, 1, 1, 1, 320.875024), -- Nirvana Axe Blade
(22043, 196, 1, 1, 1, 3.625812), -- Stick of Eternity
(22043, 2099, 1, 1, 1, 337.696764), -- Stick of Eternity Shaft
(22043, 197, 1, 1, 1, 3.625812), -- Paradia Staff
(22043, 2100, 1, 1, 1, 337.696764), -- Paradia Staff Head
(22043, 199, 1, 1, 1, 3.625812), -- Pa'agrian Hammer
(22043, 2102, 1, 1, 1, 325.584044), -- Pa'agrian Hammer Head
(22043, 200, 1, 1, 1, 3.625812), -- Sage's Staff
(22043, 2103, 1, 1, 1, 337.696764), -- Sage's Staff Head
(22043, 201, 1, 1, 1, 3.625812), -- Club of Nature
(22043, 2104, 1, 1, 1, 337.696764), -- Club of Nature Head
(22043, 202, 1, 1, 1, 3.625812), -- Mace of Underworld
(22043, 2105, 1, 1, 1, 320.872356), -- Mace of Underworld Head
(22043, 1872, 1, 1, 2, 116167.778793), -- Animal Bone
(22043, 1867, 1, 1, 2, 116167.778793), -- Animal Skin
(22043, 1881, 1, 1, 2, 11616.6951), -- Coarse Bone Powder
(22043, 1875, 1, 1, 2, 5808.34755), -- Stone of Purity
(22043, 4041, 1, 1, 2, 757.706526), -- Mold Hardener
(22043, 2166, 1, 1, 2, 2953.289493), -- Recipe: Earrings of Binding (100%)
(22043, 8725, 1, 1, 2, 2420.190801), -- Life Stone - Level 52
(22043, 8735, 1, 1, 2, 605.116683), -- Mid-Grade Life Stone - Level 52
(22043, 8745, 1, 1, 2, 60.428889), -- High-Grade Life Stone - Level 52
(22043, 8755, 1, 1, 2, 12.140964), -- Top-Grade Life Stone - Level 52
(22043, 1539, 1, 1, 2, 19361.526408), -- Greater Healing Potion
-- Ragna Orc Sorcerer
(22044, 4041, 1, 1, -1, 14198), -- Mold Hardener
(22044, 4589, 1, 1, -1, 5442), -- Greater Dye of STR (Str+2 Con-2)
(22044, 1913, 1, 1, -1, 99284), -- Necklace of Protection Gemstone
(22044, 57, 646, 1313, 0, 700000), -- Adena
(22044, 162, 1, 1, 1, 2.553561), -- War Axe
(22044, 2097, 1, 1, 1, 225.983572), -- War Axe Blade
(22044, 174, 1, 1, 1, 2.553561), -- Nirvana Axe
(22044, 2098, 1, 1, 1, 225.983572), -- Nirvana Axe Blade
(22044, 196, 1, 1, 1, 2.553561), -- Stick of Eternity
(22044, 2099, 1, 1, 1, 237.830667), -- Stick of Eternity Shaft
(22044, 197, 1, 1, 1, 2.553561), -- Paradia Staff
(22044, 2100, 1, 1, 1, 237.830667), -- Paradia Staff Head
(22044, 199, 1, 1, 1, 2.553561), -- Pa'agrian Hammer
(22044, 2102, 1, 1, 1, 229.300007), -- Pa'agrian Hammer Head
(22044, 200, 1, 1, 1, 2.553561), -- Sage's Staff
(22044, 2103, 1, 1, 1, 237.830667), -- Sage's Staff Head
(22044, 201, 1, 1, 1, 2.553561), -- Club of Nature
(22044, 2104, 1, 1, 1, 237.830667), -- Club of Nature Head
(22044, 202, 1, 1, 1, 2.553561), -- Mace of Underworld
(22044, 2105, 1, 1, 1, 225.981693), -- Mace of Underworld Head
(22044, 1872, 1, 1, 2, 90025.761136), -- Animal Bone
(22044, 1867, 1, 1, 2, 90025.761136), -- Animal Skin
(22044, 1881, 1, 1, 2, 9002.516464), -- Coarse Bone Powder
(22044, 1875, 1, 1, 2, 4501.357648), -- Stone of Purity
(22044, 4041, 1, 1, 2, 587.150896), -- Mold Hardener
(22044, 2166, 1, 1, 2, 2288.755152), -- Recipe: Earrings of Binding (100%)
(22044, 8725, 1, 1, 2, 1875.582256), -- Life Stone - Level 52
(22044, 8735, 1, 1, 2, 468.845856), -- Mid-Grade Life Stone - Level 52
(22044, 8745, 1, 1, 2, 46.924352), -- High-Grade Life Stone - Level 52
(22044, 8755, 1, 1, 2, 9.345104), -- Top-Grade Life Stone - Level 52
-- Dark Corpse
(22045, 1902, 1, 1, -1, 49514), -- Elven Earring Beads
(22045, 1879, 1, 1, -1, 81451), -- Cokes
(22045, 1875, 1, 1, -1, 32580), -- Stone of Purity
(22045, 57, 204, 407, 0, 700000), -- Adena
(22045, 606, 1, 1, 1, 55.013278), -- Rip Gauntlets
(22045, 1946, 1, 1, 1, 2133.611722), -- Rip Gauntlets Pattern
(22045, 1124, 1, 1, 1, 55.013278), -- Boots of Power
(22045, 1948, 1, 1, 1, 2133.611722), -- Boots of Power Pattern
(22045, 2424, 1, 1, 1, 55.013278), -- Manticore Skin Boots
(22045, 2923, 1, 1, 1, 2133.611722), -- Manticore Skin Boot Lining
(22045, 2425, 1, 1, 1, 55.013278), -- Brigandine Boots
(22045, 2924, 1, 1, 1, 2133.611722), -- Brigandine Boots Design
(22045, 2426, 1, 1, 1, 55.013278), -- Elven Mithril Boots
(22045, 2925, 1, 1, 1, 2133.611722), -- Elven Mithril Boots Design
(22045, 2448, 1, 1, 1, 55.013278), -- Manticore Skin Gloves
(22045, 2926, 1, 1, 1, 2133.611722), -- Manticore Skin Gloves Lining
(22045, 2449, 1, 1, 1, 55.013278), -- Brigandine Gauntlets
(22045, 2927, 1, 1, 1, 2133.611722), -- Brigandine Gauntlets Pattern
(22045, 2450, 1, 1, 1, 55.013278), -- Mithril Gloves
(22045, 2928, 1, 1, 1, 2133.611722), -- Mithril Gloves Design
(22045, 1865, 1, 1, 2, 50524.490148), -- Varnish
(22045, 1870, 1, 1, 2, 50524.490148), -- Coal
(22045, 1879, 1, 1, 2, 8420.748358), -- Cokes
(22045, 1875, 1, 1, 2, 3368.345922), -- Stone of Purity
(22045, 1825, 1, 1, 2, 3608.925424), -- Recipe: Oriharukon
-- Varangka's Dre Vanul
(22046, 4553, 1, 1, -1, 2196), -- Greater Dye of STR (Str+1 Con-1)
(22046, 1908, 1, 1, -1, 51995), -- Moonstone Earring Wire
(22046, 2163, 1, 1, -1, 28014), -- Recipe: Earring of Protection
(22046, 57, 216, 442, 0, 700000), -- Adena
(22046, 96, 1, 1, 1, 4.905096), -- Scythe
(22046, 2062, 1, 1, 1, 339.09456), -- Scythe Edge
(22046, 298, 1, 1, 1, 4.905096), -- Orcish Glaive
(22046, 2075, 1, 1, 1, 339.09456), -- Orcish Glaive Blade
(22046, 302, 1, 1, 1, 4.905096), -- Body Slasher
(22046, 2076, 1, 1, 1, 339.095592), -- Body Slasher Blade
(22046, 1866, 1, 1, 2, 17300.074932), -- Suede
(22046, 1871, 1, 1, 2, 25950.112398), -- Charcoal
(22046, 5220, 1, 1, 2, 1037.980818), -- Metal Hardener
(22046, 1885, 1, 1, 2, 2162.534031), -- High-Grade Suede
(22046, 4041, 1, 1, 2, 225.630846), -- Mold Hardener
(22046, 2163, 1, 1, 2, 1323.99036), -- Recipe: Earring of Protection
(22046, 8723, 1, 1, 2, 1037.980818), -- Life Stone - Level 46
(22046, 8733, 1, 1, 2, 259.519869), -- Mid-Grade Life Stone - Level 46
(22046, 8743, 1, 1, 2, 25.947054), -- High-Grade Life Stone - Level 46
(22046, 8753, 1, 1, 2, 5.228874), -- Top-Grade Life Stone - Level 46
-- Guardian of the Ghost Town
(22047, 1909, 1, 1, -1, 64552), -- Aquastone Ring Wire
(22047, 2164, 1, 1, -1, 36770), -- Recipe: Ring of Protection
(22047, 1910, 1, 1, -1, 35994), -- Aquastone Necklace Chain
(22047, 57, 188, 386, 0, 700000), -- Adena
(22047, 439, 1, 1, 1, 38.816544), -- Karmian Tunic
(22047, 1962, 1, 1, 1, 1807.410063), -- Karmian Tunic Pattern
(22047, 471, 1, 1, 1, 62.035752), -- Karmian Stockings
(22047, 1954, 1, 1, 1, 3002.737641), -- Karmian Stocking Design
(22047, 1895, 1, 1, 2, 10757.843964), -- Metallic Fiber
(22047, 2164, 1, 1, 2, 2896.350996), -- Recipe: Ring of Protection
(22047, 8723, 1, 1, 2, 1506.093792), -- Life Stone - Level 46
(22047, 8733, 1, 1, 2, 376.523448), -- Mid-Grade Life Stone - Level 46
(22047, 8743, 1, 1, 2, 37.646112), -- High-Grade Life Stone - Level 46
(22047, 8753, 1, 1, 2, 7.541688), -- Top-Grade Life Stone - Level 46
-- Dark Spider
(22048, 1875, 1, 1, -1, 30323), -- Stone of Purity
(22048, 1879, 1, 1, -1, 75807), -- Cokes
(22048, 4469, 1, 1, -1, 2599), -- Dye of STR (Str+1 Con-1)
(22048, 57, 183, 370, 0, 700000), -- Adena
(22048, 851, 1, 1, 1, 81.604063), -- Omen Beast's Eye Earring
(22048, 1905, 1, 1, 1, 3703.037631), -- Omen Beast's Eye Earring Gemstone
(22048, 882, 1, 1, 1, 122.40017), -- Mithril Ring
(22048, 1906, 1, 1, 1, 5232.601343), -- Mithril Ring Wire
(22048, 914, 1, 1, 1, 61.200085), -- Necklace of Darkness
(22048, 1907, 1, 1, 1, 2648.156708), -- Necklace of Darkness Gem
(22048, 1875, 1, 1, 2, 2537.843616), -- Stone of Purity
(22048, 1879, 1, 1, 2, 6344.60904), -- Cokes
(22048, 1885, 1, 1, 2, 3172.312768), -- High-Grade Suede
(22048, 5550, 1, 1, 2, 507.565424), -- Durable Metal Plate
(22048, 5549, 1, 1, 2, 3806.765424), -- Metallic Thread
(22048, 1805, 1, 1, 2, 126.903728), -- Recipe: Soulshot (C-Grade)
-- Varangka's Succubus
(22049, 1911, 1, 1, -1, 46387), -- Earring of Protection Gemstone
(22049, 2166, 1, 1, -1, 21141), -- Recipe: Earrings of Binding (100%)
(22049, 1912, 1, 1, -1, 67206), -- Ring of Protection Gemstone
(22049, 57, 246, 502, 0, 700000), -- Adena
(22049, 500, 1, 1, 1, 49.575342), -- Great Helmet
(22049, 1971, 1, 1, 1, 2819.540128), -- Great Helmet Material
(22049, 632, 1, 1, 1, 70.806217), -- Knight's Shield
(22049, 1972, 1, 1, 1, 3684.58089), -- Knight's Shield Fragment
(22049, 2496, 1, 1, 1, 76.700907), -- Dwarven Chain Shield
(22049, 2947, 1, 1, 1, 3289.796516), -- Dwarven Chain Shield Fragment
(22049, 1872, 1, 1, 2, 36844.401825), -- Animal Bone
(22049, 1867, 1, 1, 2, 36844.401825), -- Animal Skin
(22049, 1881, 1, 1, 2, 3684.39984), -- Coarse Bone Powder
(22049, 1875, 1, 1, 2, 1842.19992), -- Stone of Purity
(22049, 4041, 1, 1, 2, 240.27993), -- Mold Hardener
(22049, 951, 1, 1, 2, 50.266755), -- Scroll: Enchant Weapon (C-Grade)
(22049, 8724, 1, 1, 2, 921.09996), -- Life Stone - Level 49
(22049, 8734, 1, 1, 2, 230.27499), -- Mid-Grade Life Stone - Level 49
(22049, 8744, 1, 1, 2, 22.995225), -- High-Grade Life Stone - Level 49
(22049, 8754, 1, 1, 2, 4.67973), -- Top-Grade Life Stone - Level 49
-- Probe Golem Prodigy IV
(22050, 2163, 1, 1, -1, 81320), -- Recipe: Earring of Protection
(22050, 1908, 1, 1, -1, 150934), -- Moonstone Earring Wire
(22050, 1881, 1, 1, -1, 212515), -- Coarse Bone Powder
(22050, 57, 628, 1284, 0, 700000), -- Adena
(22050, 226, 1, 1, 1, 21.361419), -- Cursed Dagger
(22050, 2070, 1, 1, 1, 1495.138581), -- Cursed Dagger Blade
(22050, 232, 1, 1, 1, 21.361419), -- Dark Elven Dagger
(22050, 2072, 1, 1, 1, 1495.138581), -- Dark Elven Dagger Edge
(22050, 1872, 1, 1, 2, 100437.730136), -- Animal Bone
(22050, 1867, 1, 1, 2, 100437.730136), -- Animal Skin
(22050, 1881, 1, 1, 2, 10043.750584), -- Coarse Bone Powder
(22050, 1875, 1, 1, 2, 5021.98744), -- Stone of Purity
(22050, 4041, 1, 1, 2, 654.94432), -- Mold Hardener
(22050, 2163, 1, 1, 2, 3843.31196), -- Recipe: Earring of Protection
(22050, 8723, 1, 1, 2, 3013.192464), -- Life Stone - Level 46
(22050, 8733, 1, 1, 2, 753.185968), -- Mid-Grade Life Stone - Level 46
(22050, 8743, 1, 1, 2, 75.363456), -- High-Grade Life Stone - Level 46
(22050, 8753, 1, 1, 2, 14.803536), -- Top-Grade Life Stone - Level 46
-- Spelunking Spider
(22051, 1894, 1, 1, -1, 42869), -- Crafted Leather
(22051, 4589, 1, 1, -1, 4073), -- Greater Dye of STR (Str+2 Con-2)
(22051, 1911, 1, 1, -1, 90871), -- Earring of Protection Gemstone
(22051, 57, 482, 984, 0, 700000), -- Adena
(22051, 1126, 1, 1, 1, 72.81756), -- Crimson Boots
(22051, 1974, 1, 1, 1, 3793.729077), -- Crimson Boot Fabric
(22051, 2434, 1, 1, 1, 72.81756), -- Rind Leather Boots
(22051, 2948, 1, 1, 1, 3793.729077), -- Rind Leather Boots Lining
(22051, 2455, 1, 1, 1, 78.849135), -- Plated Leather Gloves
(22051, 2946, 1, 1, 1, 2521.373814), -- Plate Leather Gloves Design
(22051, 2456, 1, 1, 1, 72.81756), -- Dwarven Chain Gloves
(22051, 2949, 1, 1, 1, 3793.729077), -- Dwarven Chain Gloves Design
(22051, 2457, 1, 1, 1, 72.81756), -- Gloves of Seal
(22051, 2950, 1, 1, 1, 3793.729077), -- Gloves of Seal Pattern
(22051, 2458, 1, 1, 1, 72.81756), -- Rind Leather Gloves
(22051, 2951, 1, 1, 1, 3793.772943), -- Rind Leather Gloves Design
(22051, 1894, 1, 1, 2, 2110.455292), -- Crafted Leather
(22051, 4039, 1, 1, 2, 2004.926936), -- Mold Glue
(22051, 4041, 1, 1, 2, 523.028875), -- Mold Hardener
(22051, 4044, 1, 1, 2, 2004.926936), -- Thons
(22051, 951, 1, 1, 2, 109.358465), -- Scroll: Enchant Weapon (C-Grade)
(22051, 8724, 1, 1, 2, 2004.926936), -- Life Stone - Level 49
(22051, 8734, 1, 1, 2, 501.231734), -- Mid-Grade Life Stone - Level 49
(22051, 8744, 1, 1, 2, 50.126901), -- High-Grade Life Stone - Level 49
(22051, 8754, 1, 1, 2, 10.017925), -- Top-Grade Life Stone - Level 49
-- Menacing Jackhammer Golem
(22052, 2166, 1, 1, -1, 60728), -- Recipe: Earrings of Binding (100%)
(22052, 1912, 1, 1, -1, 193047), -- Ring of Protection Gemstone
(22052, 2167, 1, 1, -1, 91402), -- Recipe: Ring of Ages
(22052, 57, 707, 1443, 0, 700000), -- Adena
(22052, 355, 1, 1, 1, 80.09638), -- Dwarven Chain Mail Shirt
(22052, 1968, 1, 1, 1, 4781.64072), -- Dwarven Chain Mail Shirt Material
(22052, 382, 1, 1, 1, 128.154208), -- Dwarven Chain Gaiters
(22052, 1969, 1, 1, 1, 7584.108692), -- Dwarven Chain Gaiters Material
(22052, 1873, 1, 1, 2, 28864.080435), -- Silver Nugget
(22052, 1876, 1, 1, 2, 14431.933395), -- Mithril Ore
(22052, 1895, 1, 1, 2, 20617.16979), -- Metallic Fiber
(22052, 4042, 1, 1, 2, 1202.607705), -- Enria
(22052, 952, 1, 1, 2, 962.043435), -- Scroll: Enchant Armor (C-Grade)
(22052, 8296, 1, 1, 2, 167.711325), -- Recipe: Pa'agrian Sword (100%)
(22052, 8724, 1, 1, 2, 2405.429055), -- Life Stone - Level 49
(22052, 8734, 1, 1, 2, 601.410675), -- Mid-Grade Life Stone - Level 49
(22052, 8744, 1, 1, 2, 60.034245), -- High-Grade Life Stone - Level 49
(22052, 8754, 1, 1, 2, 11.96412), -- Top-Grade Life Stone - Level 49
(22052, 1342, 10, 30, 2, 144320.61582), -- Steel Arrow
-- Horrifying Cannon Golem I
(22053, 1913, 1, 1, -1, 107021), -- Necklace of Protection Gemstone
(22053, 952, 1, 1, -1, 23466), -- Scroll: Enchant Armor (C-Grade)
(22053, 1866, 1, 3, -1, 586654), -- Suede
(22053, 57, 696, 1415, 0, 700000), -- Adena
(22053, 500, 1, 1, 1, 139.898628), -- Great Helmet
(22053, 1971, 1, 1, 1, 7956.572352), -- Great Helmet Material
(22053, 632, 1, 1, 1, 199.810878), -- Knight's Shield
(22053, 1972, 1, 1, 1, 10397.66526), -- Knight's Shield Fragment
(22053, 2496, 1, 1, 1, 216.445338), -- Dwarven Chain Shield
(22053, 2947, 1, 1, 1, 9283.607544), -- Dwarven Chain Shield Fragment
(22053, 1866, 1, 1, 2, 51986.708898), -- Suede
(22053, 1871, 1, 1, 2, 77980.063347), -- Charcoal
(22053, 5220, 1, 1, 2, 3119.14989), -- Metal Hardener
(22053, 1885, 1, 1, 2, 6498.302054), -- High-Grade Suede
(22053, 4041, 1, 1, 2, 678.082421), -- Mold Hardener
(22053, 2166, 1, 1, 2, 2643.453941), -- Recipe: Earrings of Binding (100%)
(22053, 8724, 1, 1, 2, 2599.291575), -- Life Stone - Level 49
(22053, 8734, 1, 1, 2, 649.859452), -- Mid-Grade Life Stone - Level 49
(22053, 8744, 1, 1, 2, 64.927452), -- High-Grade Life Stone - Level 49
(22053, 8754, 1, 1, 2, 13.16097), -- Top-Grade Life Stone - Level 49
-- Horrifying Cannon Golem IV
(22054, 1884, 1, 3, -1, 558523), -- Cord
(22054, 4590, 1, 1, -1, 6051), -- Greater Dye of STR (Str+2 Dex-2)
(22054, 1966, 1, 1, -1, 66272), -- Plated Leather Fragment
(22054, 57, 718, 1459, 0, 700000), -- Adena
(22054, 1126, 1, 1, 1, 108.18884), -- Crimson Boots
(22054, 1974, 1, 1, 1, 5636.540803), -- Crimson Boot Fabric
(22054, 2434, 1, 1, 1, 108.18884), -- Rind Leather Boots
(22054, 2948, 1, 1, 1, 5636.540803), -- Rind Leather Boots Lining
(22054, 2455, 1, 1, 1, 117.150265), -- Plated Leather Gloves
(22054, 2946, 1, 1, 1, 3746.136346), -- Plate Leather Gloves Design
(22054, 2456, 1, 1, 1, 108.18884), -- Dwarven Chain Gloves
(22054, 2949, 1, 1, 1, 5636.540803), -- Dwarven Chain Gloves Design
(22054, 2457, 1, 1, 1, 108.18884), -- Gloves of Seal
(22054, 2950, 1, 1, 1, 5636.540803), -- Gloves of Seal Pattern
(22054, 2458, 1, 1, 1, 108.18884), -- Rind Leather Gloves
(22054, 2951, 1, 1, 1, 5636.605977), -- Rind Leather Gloves Design
(22054, 1864, 1, 1, 2, 160854.761193), -- Stem
(22054, 1869, 1, 1, 2, 80427.547178), -- Iron Ore
(22054, 1878, 1, 1, 2, 32170.885606), -- Braided Hemp
(22054, 1884, 1, 1, 2, 49493.695791), -- Cord
(22054, 4039, 1, 1, 2, 2680.962661), -- Mold Glue
(22054, 2167, 1, 1, 2, 4103.568671), -- Recipe: Ring of Ages
(22054, 8724, 1, 1, 2, 2680.962661), -- Life Stone - Level 49
(22054, 8734, 1, 1, 2, 670.323956), -- Mid-Grade Life Stone - Level 49
(22054, 8744, 1, 1, 2, 66.965763), -- High-Grade Life Stone - Level 49
(22054, 8754, 1, 1, 2, 13.32652), -- Top-Grade Life Stone - Level 49
-- Cruel Vice Golem
(22055, 2168, 1, 1, -1, 49644), -- Recipe: Necklace of Mermaid
(22055, 1967, 1, 1, -1, 106408), -- Plated Leather Gaiters Material
(22055, 2222, 1, 1, -1, 12194), -- Recipe: Composite Armor
(22055, 57, 770, 1571, 0, 700000), -- Adena
(22055, 500, 1, 1, 1, 155.082348), -- Great Helmet
(22055, 1971, 1, 1, 1, 8820.128832), -- Great Helmet Material
(22055, 632, 1, 1, 1, 221.497098), -- Knight's Shield
(22055, 1972, 1, 1, 1, 11526.16266), -- Knight's Shield Fragment
(22055, 2496, 1, 1, 1, 239.936958), -- Dwarven Chain Shield
(22055, 2947, 1, 1, 1, 10291.192104), -- Dwarven Chain Shield Fragment
(22055, 1865, 1, 1, 2, 78585.428352), -- Varnish
(22055, 1870, 1, 1, 2, 78585.428352), -- Coal
(22055, 1879, 1, 1, 2, 13097.505384), -- Cokes
(22055, 1875, 1, 1, 2, 5239.120968), -- Stone of Purity
(22055, 4040, 1, 1, 2, 1571.716488), -- Mold Lubricant
(22055, 8318, 1, 1, 2, 128.121528), -- Recipe: Dwarven Hammer (100%)
(22055, 8724, 1, 1, 2, 2619.461472), -- Life Stone - Level 49
(22055, 8734, 1, 1, 2, 654.865368), -- Mid-Grade Life Stone - Level 49
(22055, 8744, 1, 1, 2, 65.545944), -- High-Grade Life Stone - Level 49
(22055, 8754, 1, 1, 2, 13.069584), -- Top-Grade Life Stone - Level 49
(22055, 1539, 1, 1, 2, 17463.73656), -- Greater Healing Potion
-- Probe Golem Champion I
(22056, 1968, 1, 1, -1, 42292), -- Dwarven Chain Mail Shirt Material
(22056, 951, 1, 1, -1, 3191), -- Scroll: Enchant Weapon (C-Grade)
(22056, 1876, 1, 1, -1, 351020), -- Mithril Ore
(22056, 57, 693, 1413, 0, 700000), -- Adena
(22056, 355, 1, 1, 1, 78.47203), -- Dwarven Chain Mail Shirt
(22056, 1968, 1, 1, 1, 4684.66932), -- Dwarven Chain Mail Shirt Material
(22056, 382, 1, 1, 1, 125.555248), -- Dwarven Chain Gaiters
(22056, 1969, 1, 1, 1, 7430.303402), -- Dwarven Chain Gaiters Material
(22056, 1873, 1, 1, 2, 34562.030166), -- Silver Nugget
(22056, 1876, 1, 1, 2, 17281.015083), -- Mithril Ore
(22056, 1895, 1, 1, 2, 24687.211374), -- Metallic Fiber
(22056, 4042, 1, 1, 2, 1440.09144), -- Enria
(22056, 2222, 1, 1, 2, 540.03429), -- Recipe: Composite Armor
(22056, 8724, 1, 1, 2, 2880.18288), -- Life Stone - Level 49
(22056, 8734, 1, 1, 2, 720.04572), -- Mid-Grade Life Stone - Level 49
(22056, 8744, 1, 1, 2, 72.004572), -- High-Grade Life Stone - Level 49
(22056, 8754, 1, 1, 2, 14.384475), -- Top-Grade Life Stone - Level 49
-- Spelunking Ant
(22057, 1875, 1, 1, -1, 92483), -- Stone of Purity
(22057, 4601, 1, 1, -1, 3083), -- Greater Dye of STR (Str+3 Con-3)
(22057, 1539, 1, 1, -1, 308276), -- Greater Healing Potion
(22057, 57, 549, 1115, 0, 700000), -- Adena
(22057, 854, 1, 1, 1, 84.391461), -- Earring of Seal
(22057, 1914, 1, 1, 1, 5371.09118), -- Earring of Seal Gemstone
(22057, 885, 1, 1, 1, 126.541849), -- Ring of Ages
(22057, 1915, 1, 1, 1, 8423.385047), -- Ring of Ages Gemstone
(22057, 917, 1, 1, 1, 63.29813), -- Necklace of Mermaid
(22057, 1916, 1, 1, 1, 4068.292333), -- Necklace of Mermaid Teardrop
(22057, 1872, 1, 1, 2, 76490.633493), -- Animal Bone
(22057, 1867, 1, 1, 2, 76490.633493), -- Animal Skin
(22057, 1881, 1, 1, 2, 7649.113752), -- Coarse Bone Powder
(22057, 1875, 1, 1, 2, 3824.556876), -- Stone of Purity
(22057, 4041, 1, 1, 2, 498.818721), -- Mold Hardener
(22057, 2169, 1, 1, 2, 1015.446396), -- Recipe: Necklace of Seal
(22057, 8725, 1, 1, 2, 1593.565365), -- Life Stone - Level 52
(22057, 8735, 1, 1, 2, 398.349339), -- Mid-Grade Life Stone - Level 52
(22057, 8745, 1, 1, 2, 39.818133), -- High-Grade Life Stone - Level 52
(22057, 8755, 1, 1, 2, 8.064432), -- Top-Grade Life Stone - Level 52
-- Horrifying Excavator Golem III
(22058, 1914, 1, 1, -1, 119035), -- Earring of Seal Gemstone
(22058, 2169, 1, 1, -1, 37501), -- Recipe: Necklace of Seal
(22058, 1915, 1, 1, -1, 186681), -- Ring of Ages Gemstone
(22058, 57, 839, 1705, 0, 700000), -- Adena
(22058, 854, 1, 1, 1, 128.892753), -- Earring of Seal
(22058, 1914, 1, 1, 1, 8203.37414), -- Earring of Seal Gemstone
(22058, 885, 1, 1, 1, 193.269877), -- Ring of Ages
(22058, 1915, 1, 1, 1, 12865.203131), -- Ring of Ages Gemstone
(22058, 917, 1, 1, 1, 96.67649), -- Necklace of Mermaid
(22058, 1916, 1, 1, 1, 6213.583609), -- Necklace of Mermaid Teardrop
(22058, 1869, 1, 1, 2, 79655.972682), -- Iron Ore
(22058, 1864, 1, 1, 2, 159311.945364), -- Stem
(22058, 1880, 1, 1, 2, 7965.472866), -- Steel
(22058, 5550, 1, 1, 2, 1061.980114), -- Durable Metal Plate
(22058, 4043, 1, 1, 2, 2655.157622), -- Asofe
(22058, 2170, 1, 1, 2, 1878.47322), -- Recipe: Nassen's Earring
(22058, 8725, 1, 1, 2, 2212.700464), -- Life Stone - Level 52
(22058, 8735, 1, 1, 2, 553.175116), -- Mid-Grade Life Stone - Level 52
(22058, 8745, 1, 1, 2, 55.151642), -- High-Grade Life Stone - Level 52
(22058, 8755, 1, 1, 2, 11.196198), -- Top-Grade Life Stone - Level 52
(22058, 1342, 10, 30, 2, 159312.774712), -- Steel Arrow
-- Bloodthirsty Ginzu Golem VII
(22059, 2170, 1, 1, -1, 130904), -- Recipe: Nassen's Earring
(22059, 1916, 1, 1, -1, 236183), -- Necklace of Mermaid Teardrop
(22059, 1869, 1, 11, -1, 925052), -- Iron Ore
(22059, 57, 2198, 4465, 0, 700000), -- Adena
(22059, 265, 1, 1, 1, 69.457584), -- Fisted Blade
(22059, 2108, 1, 1, 1, 6146.542416), -- Fisted Blade Piece
(22059, 1869, 1, 3, 2, 76508.864982), -- Iron Ore
(22059, 1864, 1, 3, 2, 229526.246097), -- Stem
(22059, 1880, 1, 1, 2, 22952.519955), -- Steel
(22059, 5550, 1, 1, 2, 3060.452277), -- Durable Metal Plate
(22059, 4043, 1, 1, 2, 7650.956268), -- Asofe
(22059, 2231, 1, 1, 2, 989.335764), -- Recipe: Full Plate Armor
(22059, 8725, 1, 1, 2, 6375.564324), -- Life Stone - Level 52
(22059, 8735, 1, 1, 2, 1593.891081), -- Mid-Grade Life Stone - Level 52
(22059, 8745, 1, 1, 2, 159.423993), -- High-Grade Life Stone - Level 52
(22059, 8755, 1, 1, 2, 31.745259), -- Top-Grade Life Stone - Level 52
-- Horrifying Cannon Golem
(22060, 1870, 1, 11, -1, 820524), -- Coal
(22060, 4602, 1, 1, -1, 10940), -- Greater Dye of STR (Str+3 Dex-3)
(22060, 1539, 1, 3, -1, 547016), -- Greater Healing Potion
(22060, 57, 1956, 3952, 0, 700000), -- Adena
(22060, 75, 1, 1, 1, 8.801346), -- Caliburs
(22060, 2089, 1, 1, 1, 792.550338), -- Caliburs Edge
(22060, 76, 1, 1, 1, 8.801346), -- Sword of Delusion
(22060, 2090, 1, 1, 1, 792.550338), -- Delusional Blade
(22060, 77, 1, 1, 1, 8.801346), -- Tsurugi
(22060, 2091, 1, 1, 1, 792.550338), -- Tsurugi Blade
(22060, 84, 1, 1, 1, 8.801346), -- Homunkulus's Sword
(22060, 2092, 1, 1, 1, 792.550338), -- Homunkulus's Sword Blade
(22060, 134, 1, 1, 1, 8.801346), -- Sword of Nightmare
(22060, 2095, 1, 1, 1, 792.550338), -- Sword of Nightmare Blade
(22060, 145, 1, 1, 1, 8.801346), -- Sword of Whispering Death
(22060, 2096, 1, 1, 1, 792.550338), -- Sword of Whispering Death Blade
(22060, 7882, 1, 1, 1, 8.801346), -- Pa'agrian Sword
(22060, 8329, 1, 1, 1, 757.08855), -- Pa'agrian Sword Blade
(22060, 1870, 1, 1, 2, 203591.265381), -- Coal
(22060, 1865, 1, 1, 2, 203591.265381), -- Varnish
(22060, 1874, 1, 1, 2, 13572.927785), -- Oriharukon Ore
(22060, 4043, 1, 1, 2, 6786.242943), -- Asofe
(22060, 4039, 1, 1, 2, 6786.242943), -- Mold Glue
(22060, 8304, 1, 1, 2, 332.308048), -- Recipe: Ecliptic Sword (100%)
(22060, 8725, 1, 1, 2, 5655.423402), -- Life Stone - Level 52
(22060, 8735, 1, 1, 2, 1413.634901), -- Mid-Grade Life Stone - Level 52
(22060, 8745, 1, 1, 2, 141.40768), -- High-Grade Life Stone - Level 52
(22060, 8755, 1, 1, 2, 28.281536), -- Top-Grade Life Stone - Level 52
-- Horrifying Cannon Golem III
(22061, 1977, 1, 1, -1, 46483), -- Composite Armor Temper
(22061, 2231, 1, 1, -1, 13544), -- Recipe: Full Plate Armor
(22061, 1978, 1, 1, -1, 201428), -- Tower Shield Fragment
(22061, 57, 1244, 2528, 0, 700000), -- Adena
(22061, 326, 1, 1, 1, 39.326346), -- Heathen's Book
(22061, 2110, 1, 1, 1, 3662.673654), -- Heathen's Book Page
(22061, 1871, 1, 1, 2, 118131.931906), -- Charcoal
(22061, 1866, 1, 1, 2, 78754.542722), -- Suede
(22061, 1877, 1, 1, 2, 4725.173592), -- Adamantite Nugget
(22061, 4041, 1, 1, 2, 1027.180914), -- Mold Hardener
(22061, 4040, 1, 1, 2, 2362.586796), -- Mold Lubricant
(22061, 8308, 1, 1, 2, 192.758428), -- Recipe: Ecliptic Axe (100%)
(22061, 8725, 1, 1, 2, 3281.37055), -- Life Stone - Level 52
(22061, 8735, 1, 1, 2, 820.283726), -- Mid-Grade Life Stone - Level 52
(22061, 8745, 1, 1, 2, 82.004808), -- High-Grade Life Stone - Level 52
(22061, 8755, 1, 1, 2, 16.49522), -- Top-Grade Life Stone - Level 52
(22061, 1539, 1, 1, 2, 26251.671338), -- Greater Healing Potion
-- Horrifying Jackhammer Golem
(22062, 2232, 1, 1, -1, 26234), -- Recipe: Drake Leather Armor
(22062, 1981, 1, 1, -1, 268514), -- Mithril Gauntlets Design
(22062, 1894, 1, 1, -1, 160166), -- Crafted Leather
(22062, 57, 1813, 3664, 0, 700000), -- Adena
(22062, 231, 1, 1, 1, 28.563892), -- Grace Dagger
(22062, 2106, 1, 1, 1, 2571.936108), -- Grace Dagger Edge
(22062, 233, 1, 1, 1, 28.563892), -- Dark Screamer
(22062, 2107, 1, 1, 1, 2571.936108), -- Dark Screamer Edge
(22062, 1867, 1, 3, 2, 125846.187856), -- Animal Skin
(22062, 1872, 1, 1, 2, 251692.375712), -- Animal Bone
(22062, 1882, 1, 1, 2, 41948.875546), -- Leather
(22062, 1894, 1, 1, 2, 6623.41429), -- Crafted Leather
(22062, 4042, 1, 1, 2, 3146.06694), -- Enria
(22062, 2234, 1, 1, 2, 2813.470184), -- Recipe: Divine Stockings
(22062, 8725, 1, 1, 2, 5243.4449), -- Life Stone - Level 52
(22062, 8735, 1, 1, 2, 1311.080616), -- Mid-Grade Life Stone - Level 52
(22062, 8745, 1, 1, 2, 131.195818), -- High-Grade Life Stone - Level 52
(22062, 8755, 1, 1, 2, 25.888138), -- Top-Grade Life Stone - Level 52
-- Ginzu Golem Prodigy X
(22063, 1864, 1, 25, -1, 944873), -- Stem
(22063, 4603, 1, 1, -1, 13648), -- Greater Dye of CON (Con+3 Str-3)
(22063, 1539, 1, 3, -1, 682408), -- Greater Healing Potion
(22063, 57, 2440, 4930, 0, 700000), -- Adena
(22063, 75, 1, 1, 1, 10.980366), -- Caliburs
(22063, 2089, 1, 1, 1, 988.768398), -- Caliburs Edge
(22063, 76, 1, 1, 1, 10.980366), -- Sword of Delusion
(22063, 2090, 1, 1, 1, 988.768398), -- Delusional Blade
(22063, 77, 1, 1, 1, 10.980366), -- Tsurugi
(22063, 2091, 1, 1, 1, 988.768398), -- Tsurugi Blade
(22063, 84, 1, 1, 1, 10.980366), -- Homunkulus's Sword
(22063, 2092, 1, 1, 1, 988.768398), -- Homunkulus's Sword Blade
(22063, 134, 1, 1, 1, 10.980366), -- Sword of Nightmare
(22063, 2095, 1, 1, 1, 988.768398), -- Sword of Nightmare Blade
(22063, 145, 1, 1, 1, 10.980366), -- Sword of Whispering Death
(22063, 2096, 1, 1, 1, 988.768398), -- Sword of Whispering Death Blade
(22063, 7882, 1, 1, 1, 10.980366), -- Pa'agrian Sword
(22063, 8329, 1, 1, 1, 944.52705), -- Pa'agrian Sword Blade
(22063, 1864, 3, 9, 2, 94067.459136), -- Stem
(22063, 1865, 2, 6, 2, 70550.594352), -- Varnish
(22063, 1866, 1, 1, 2, 188134.442145), -- Suede
(22063, 1873, 1, 1, 2, 112880.665287), -- Silver Nugget
(22063, 2353, 1, 1, 2, 460.414809), -- Recipe: Samurai Longsword
(22063, 8725, 1, 1, 2, 7838.954928), -- Life Stone - Level 52
(22063, 8735, 1, 1, 2, 1959.738732), -- Mid-Grade Life Stone - Level 52
(22063, 8745, 1, 1, 2, 196.164324), -- High-Grade Life Stone - Level 52
(22063, 8755, 1, 1, 2, 38.566287), -- Top-Grade Life Stone - Level 52
-- Bloodthirsty Ginzu Golem II
(22064, 1983, 1, 1, -1, 253278), -- Shining Circlet Pattern
(22064, 2233, 1, 1, -1, 53970), -- Recipe: Divine Tunic
(22064, 2089, 1, 1, -1, 31470), -- Caliburs Edge
(22064, 57, 2294, 4636, 0, 700000), -- Adena
(22064, 265, 1, 1, 1, 72.273432), -- Fisted Blade
(22064, 2108, 1, 1, 1, 6395.726568), -- Fisted Blade Piece
(22064, 1868, 4, 12, 2, 54274.47171), -- Thread
(22064, 1873, 1, 1, 2, 86839.492075), -- Silver Nugget
(22064, 5549, 1, 1, 2, 21709.788684), -- Metallic Thread
(22064, 1889, 1, 1, 2, 14473.192456), -- Compound Braid
(22064, 4044, 1, 1, 2, 7236.596228), -- Thons
(22064, 8308, 1, 1, 2, 354.20595), -- Recipe: Ecliptic Axe (100%)
(22064, 8725, 1, 1, 2, 6030.609303), -- Life Stone - Level 52
(22064, 8735, 1, 1, 2, 1507.567991), -- Mid-Grade Life Stone - Level 52
(22064, 8745, 1, 1, 2, 150.790533), -- High-Grade Life Stone - Level 52
(22064, 8755, 1, 1, 2, 30.023171), -- Top-Grade Life Stone - Level 52
(22064, 1342, 30, 90, 2, 144732.261899), -- Steel Arrow
-- Horrifying Ginzu Golem V
(22065, 1806, 1, 1, -1, 12020), -- Recipe: Soulshot (B-Grade)
(22065, 1918, 1, 1, -1, 260288), -- Nassen's Earring Gemstone
(22065, 1895, 1, 3, -1, 858579), -- Metallic Fiber
(22065, 57, 2379, 4833, 0, 700000), -- Adena
(22065, 266, 1, 1, 1, 47.081012), -- Great Pata
(22065, 2120, 1, 1, 1, 5329.918988), -- Great Pata Blade
(22065, 1873, 1, 1, 2, 98626.366995), -- Silver Nugget
(22065, 1876, 1, 1, 2, 49313.06835), -- Mithril Ore
(22065, 1895, 1, 1, 2, 70447.2405), -- Metallic Fiber
(22065, 4042, 1, 1, 2, 4109.38398), -- Enria
(22065, 1806, 1, 1, 2, 493.061595), -- Recipe: Soulshot (B-Grade)
(22065, 8726, 1, 1, 2, 5707.63128), -- Life Stone - Level 55
(22065, 8736, 1, 1, 2, 1426.90782), -- Mid-Grade Life Stone - Level 55
(22065, 8746, 1, 1, 2, 142.7829), -- High-Grade Life Stone - Level 55
(22065, 8756, 1, 1, 2, 28.55658), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22066, 4042, 1, 1, -1, 54680), -- Enria
(22066, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22066, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22066, 57, 1299, 2638, 0, 700000), -- Adena
(22066, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22066, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22066, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22066, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22066, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22066, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22066, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22066, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22066, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22066, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22066, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22066, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22066, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22066, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22066, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22066, 1864, 1, 1, 2, 242275.731216), -- Stem
(22066, 1880, 1, 1, 2, 12113.632556), -- Steel
(22066, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22066, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22066, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22066, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22066, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22066, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22066, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22067, 4042, 1, 1, -1, 54680), -- Enria
(22067, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22067, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22067, 57, 1299, 2638, 0, 700000), -- Adena
(22067, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22067, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22067, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22067, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22067, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22067, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22067, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22067, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22067, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22067, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22067, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22067, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22067, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22067, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22067, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22067, 1864, 1, 1, 2, 242275.731216), -- Stem
(22067, 1880, 1, 1, 2, 12113.632556), -- Steel
(22067, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22067, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22067, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22067, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22067, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22067, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22067, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22068, 4042, 1, 1, -1, 54680), -- Enria
(22068, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22068, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22068, 57, 1299, 2638, 0, 700000), -- Adena
(22068, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22068, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22068, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22068, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22068, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22068, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22068, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22068, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22068, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22068, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22068, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22068, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22068, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22068, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22068, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22068, 1864, 1, 1, 2, 242275.731216), -- Stem
(22068, 1880, 1, 1, 2, 12113.632556), -- Steel
(22068, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22068, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22068, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22068, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22068, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22068, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22068, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22069, 4042, 1, 1, -1, 54680), -- Enria
(22069, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22069, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22069, 57, 1299, 2638, 0, 700000), -- Adena
(22069, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22069, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22069, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22069, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22069, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22069, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22069, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22069, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22069, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22069, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22069, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22069, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22069, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22069, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22069, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22069, 1864, 1, 1, 2, 242275.731216), -- Stem
(22069, 1880, 1, 1, 2, 12113.632556), -- Steel
(22069, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22069, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22069, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22069, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22069, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22069, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22069, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22070, 4042, 1, 1, -1, 54680), -- Enria
(22070, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22070, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22070, 57, 1299, 2638, 0, 700000), -- Adena
(22070, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22070, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22070, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22070, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22070, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22070, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22070, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22070, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22070, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22070, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22070, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22070, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22070, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22070, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22070, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22070, 1864, 1, 1, 2, 242275.731216), -- Stem
(22070, 1880, 1, 1, 2, 12113.632556), -- Steel
(22070, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22070, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22070, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22070, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22070, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22070, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22070, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22071, 4042, 1, 1, -1, 54680), -- Enria
(22071, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22071, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22071, 57, 1299, 2638, 0, 700000), -- Adena
(22071, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22071, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22071, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22071, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22071, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22071, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22071, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22071, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22071, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22071, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22071, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22071, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22071, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22071, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22071, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22071, 1864, 1, 1, 2, 242275.731216), -- Stem
(22071, 1880, 1, 1, 2, 12113.632556), -- Steel
(22071, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22071, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22071, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22071, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22071, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22071, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22071, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22072, 4042, 1, 1, -1, 54680), -- Enria
(22072, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22072, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22072, 57, 1299, 2638, 0, 700000), -- Adena
(22072, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22072, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22072, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22072, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22072, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22072, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22072, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22072, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22072, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22072, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22072, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22072, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22072, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22072, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22072, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22072, 1864, 1, 1, 2, 242275.731216), -- Stem
(22072, 1880, 1, 1, 2, 12113.632556), -- Steel
(22072, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22072, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22072, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22072, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22072, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22072, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22072, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Horrifying Cannon Golem VI
(22073, 4042, 1, 1, -1, 54680), -- Enria
(22073, 1920, 1, 1, -1, 112261), -- Necklace of Seal Chain
(22073, 3034, 1, 1, -1, 6562), -- Recipe: Spiritshot B
(22073, 57, 1299, 2638, 0, 700000), -- Adena
(22073, 203, 1, 1, 1, 4.705644), -- Pa'agrian Axe
(22073, 2112, 1, 1, 1, 419.12355), -- Pa'agrian Axe Blade
(22073, 204, 1, 1, 1, 3.672486), -- Deadman's Staff
(22073, 2116, 1, 1, 1, 407.203164), -- Deadman's Staff Head
(22073, 205, 1, 1, 1, 3.672486), -- Ghoul's Staff
(22073, 2117, 1, 1, 1, 407.203164), -- Ghoul's Staff Head
(22073, 206, 1, 1, 1, 3.672486), -- Demon's Staff
(22073, 2118, 1, 1, 1, 407.203164), -- Demon's Staff Head
(22073, 2503, 1, 1, 1, 3.672486), -- Yaksa Mace
(22073, 2969, 1, 1, 1, 415.740464), -- Yaksa Mace Head
(22073, 7891, 1, 1, 1, 3.672486), -- Ecliptic Axe
(22073, 8338, 1, 1, 1, 415.740464), -- Axe of Eclipse Head
(22073, 7897, 1, 1, 1, 3.672486), -- Dwarven Hammer
(22073, 8344, 1, 1, 1, 395.04547), -- Dwarven Hammer Piece
(22073, 1869, 1, 1, 2, 121137.865608), -- Iron Ore
(22073, 1864, 1, 1, 2, 242275.731216), -- Stem
(22073, 1880, 1, 1, 2, 12113.632556), -- Steel
(22073, 5550, 1, 1, 2, 1615.12534), -- Durable Metal Plate
(22073, 4043, 1, 1, 2, 4038.005856), -- Asofe
(22073, 3034, 1, 1, 2, 242.172548), -- Recipe: Spiritshot B
(22073, 8726, 1, 1, 2, 2804.042396), -- Life Stone - Level 55
(22073, 8736, 1, 1, 2, 701.106852), -- Mid-Grade Life Stone - Level 55
(22073, 8746, 1, 1, 2, 70.072184), -- High-Grade Life Stone - Level 55
(22073, 8756, 1, 1, 2, 14.245444), -- Top-Grade Life Stone - Level 55
-- Epic Cannon Golem
(22074, 2115, 1, 1, -1, 23474), -- Samurai Longsword Blade
(22074, 4141, 1, 1, -1, 24633), -- Recipe: Avadon Breastplate (100%)
(22074, 2116, 1, 1, -1, 24107), -- Deadman's Staff Head
(22074, 57, 2028, 4120, 0, 700000), -- Adena
(22074, 135, 1, 1, 1, 13.379184), -- Samurai Longsword
(22074, 2115, 1, 1, 1, 1444.589328), -- Samurai Longsword Blade
(22074, 5286, 1, 1, 1, 13.379184), -- Berserker Blade
(22074, 5530, 1, 1, 1, 1446.415152), -- Berserker Blade Edge
(22074, 7888, 1, 1, 1, 13.379184), -- Ecliptic Sword
(22074, 8335, 1, 1, 1, 1436.857968), -- Ecliptic Sword Blade
(22074, 1873, 1, 1, 2, 75674.008971), -- Silver Nugget
(22074, 1868, 1, 3, 2, 189185.205909), -- Thread
(22074, 1876, 1, 1, 2, 37837.187967), -- Mithril Ore
(22074, 1895, 1, 1, 2, 54052.915974), -- Metallic Fiber
(22074, 4042, 1, 1, 2, 3152.946096), -- Enria
(22074, 4142, 1, 1, 2, 1455.375258), -- Recipe: Avadon Gaiters (100%)
(22074, 8726, 1, 1, 2, 4379.336442), -- Life Stone - Level 55
(22074, 8736, 1, 1, 2, 1094.650629), -- Mid-Grade Life Stone - Level 55
(22074, 8746, 1, 1, 2, 109.354974), -- High-Grade Life Stone - Level 55
(22074, 8756, 1, 1, 2, 22.01778), -- Top-Grade Life Stone - Level 55
-- Epic Cannon Golem Adjunct
(22075, 8308, 1, 1, -1, 5333), -- Recipe: Ecliptic Axe (100%)
(22075, 4040, 1, 1, -1, 65387), -- Mold Lubricant
(22075, 4604, 1, 1, -1, 7265), -- Greater Dye of CON (Con+3 Dex-3)
(22075, 57, 1299, 2624, 0, 700000), -- Adena
(22075, 231, 1, 1, 1, 20.4577), -- Grace Dagger
(22075, 2106, 1, 1, 1, 1842.0423), -- Grace Dagger Edge
(22075, 233, 1, 1, 1, 20.4577), -- Dark Screamer
(22075, 2107, 1, 1, 1, 1842.0423), -- Dark Screamer Edge
(22075, 1895, 1, 1, 2, 42920.479756), -- Metallic Fiber
(22075, 4040, 1, 1, 2, 3004.404708), -- Mold Lubricant
(22075, 4042, 1, 1, 2, 2503.701308), -- Enria
(22075, 4043, 1, 1, 2, 5007.402616), -- Asofe
(22075, 2169, 1, 1, 2, 2658.765772), -- Recipe: Necklace of Seal
(22075, 8725, 1, 1, 2, 4172.794556), -- Life Stone - Level 52
(22075, 8735, 1, 1, 2, 1043.18328), -- Mid-Grade Life Stone - Level 52
(22075, 8745, 1, 1, 2, 104.318328), -- High-Grade Life Stone - Level 52
(22075, 8755, 1, 1, 2, 20.949676), -- Top-Grade Life Stone - Level 52
-- Deadly Ginzu Golem V
(22076, 2117, 1, 1, -1, 28277), -- Ghoul's Staff Head
(22076, 8310, 1, 1, -1, 6924), -- Recipe: Spell Breaker (60%)
(22076, 2118, 1, 1, -1, 28277), -- Demon's Staff Head
(22076, 57, 2379, 4833, 0, 700000), -- Adena
(22076, 135, 1, 1, 1, 15.691749), -- Samurai Longsword
(22076, 2115, 1, 1, 1, 1694.283683), -- Samurai Longsword Blade
(22076, 5286, 1, 1, 1, 15.691749), -- Berserker Blade
(22076, 5530, 1, 1, 1, 1696.425097), -- Berserker Blade Edge
(22076, 7888, 1, 1, 1, 15.691749), -- Ecliptic Sword
(22076, 8335, 1, 1, 1, 1685.215973), -- Ecliptic Sword Blade
(22076, 1866, 1, 1, 2, 147939.601134), -- Suede
(22076, 1871, 1, 1, 2, 221909.198712), -- Charcoal
(22076, 5220, 1, 1, 2, 8876.302992), -- Metal Hardener
(22076, 1885, 1, 1, 2, 18492.2979), -- High-Grade Suede
(22076, 4041, 1, 1, 2, 1929.613434), -- Mold Hardener
(22076, 8321, 1, 1, 2, 255.76614), -- Recipe: Ice Storm Hammer (100%)
(22076, 8726, 1, 1, 2, 5136.839634), -- Life Stone - Level 55
(22076, 8736, 1, 1, 2, 1284.108414), -- Mid-Grade Life Stone - Level 55
(22076, 8746, 1, 1, 2, 128.289048), -- High-Grade Life Stone - Level 55
(22076, 8756, 1, 1, 2, 25.982592), -- Top-Grade Life Stone - Level 55
-- Horrifying Ginzu Golem VIII
(22077, 8322, 1, 1, -1, 7203), -- Recipe: Ice Storm Hammer (60%)
(22077, 2119, 1, 1, -1, 28489), -- Crystal Dagger Blade
(22077, 1869, 1, 13, -1, 893152), -- Iron Ore
(22077, 57, 2469, 5029, 0, 700000), -- Adena
(22077, 203, 1, 1, 1, 8.96739), -- Pa'agrian Axe
(22077, 2112, 1, 1, 1, 798.709875), -- Pa'agrian Axe Blade
(22077, 204, 1, 1, 1, 6.998535), -- Deadman's Staff
(22077, 2116, 1, 1, 1, 775.99359), -- Deadman's Staff Head
(22077, 205, 1, 1, 1, 6.998535), -- Ghoul's Staff
(22077, 2117, 1, 1, 1, 775.99359), -- Ghoul's Staff Head
(22077, 206, 1, 1, 1, 6.998535), -- Demon's Staff
(22077, 2118, 1, 1, 1, 775.99359), -- Demon's Staff Head
(22077, 2503, 1, 1, 1, 6.998535), -- Yaksa Mace
(22077, 2969, 1, 1, 1, 792.26284), -- Yaksa Mace Head
(22077, 7891, 1, 1, 1, 6.998535), -- Ecliptic Axe
(22077, 8338, 1, 1, 1, 792.26284), -- Axe of Eclipse Head
(22077, 7897, 1, 1, 1, 6.998535), -- Dwarven Hammer
(22077, 8344, 1, 1, 1, 752.825075), -- Dwarven Hammer Piece
(22077, 1869, 1, 3, 2, 76948.570088), -- Iron Ore
(22077, 1864, 1, 3, 2, 230846.059022), -- Stem
(22077, 1880, 1, 1, 2, 23084.640778), -- Steel
(22077, 5550, 1, 1, 2, 3077.78935), -- Durable Metal Plate
(22077, 4043, 1, 1, 2, 7694.996512), -- Asofe
(22077, 8310, 1, 1, 2, 266.102354), -- Recipe: Spell Breaker (60%)
(22077, 8726, 1, 1, 2, 5343.670076), -- Life Stone - Level 55
(22077, 8736, 1, 1, 2, 1335.74314), -- Mid-Grade Life Stone - Level 55
(22077, 8746, 1, 1, 2, 133.574314), -- High-Grade Life Stone - Level 55
(22077, 8756, 1, 1, 2, 26.854366), -- Top-Grade Life Stone - Level 55
-- Deadly Ginzu Golem VIII
(22078, 1880, 1, 1, -1, 625206), -- Steel
(22078, 2120, 1, 1, -1, 30032), -- Great Pata Blade
(22078, 4144, 1, 1, -1, 64256), -- Recipe: Zubei's Leather Gaiters (100%)
(22078, 57, 2469, 5029, 0, 700000), -- Adena
(22078, 356, 1, 1, 1, 129.104375), -- Full Plate Armor
(22078, 1986, 1, 1, 1, 12195.895625), -- Full Plate Armor Temper
(22078, 1870, 1, 1, 2, 230845.224442), -- Coal
(22078, 1865, 1, 1, 2, 230845.224442), -- Varnish
(22078, 1874, 1, 1, 2, 15389.448403), -- Oriharukon Ore
(22078, 4043, 1, 1, 2, 7694.974087), -- Asofe
(22078, 4039, 1, 1, 2, 7694.974087), -- Mold Glue
(22078, 3955, 1, 1, 2, 461.788404), -- Recipe: Blessed Spiritshot B
(22078, 8726, 1, 1, 2, 5343.551532), -- Life Stone - Level 55
(22078, 8736, 1, 1, 2, 1335.887883), -- Mid-Grade Life Stone - Level 55
(22078, 8746, 1, 1, 2, 133.438857), -- High-Grade Life Stone - Level 55
(22078, 8756, 1, 1, 2, 26.487863), -- Top-Grade Life Stone - Level 55
-- Lost Bandersnatch
(22079, 2121, 1, 1, -1, 6491), -- Eminence Bow Shaft
(22079, 4145, 1, 1, -1, 6191), -- Recipe: Avadon Leather Armor (100%)
(22079, 2122, 1, 1, -1, 6443), -- Orcish Poleaxe Blade
(22079, 57, 559, 1135, 0, 700000), -- Adena
(22079, 442, 1, 1, 1, 31.58805), -- Divine Tunic
(22079, 1988, 1, 1, 1, 2503.688382), -- Divine Tunic Fabric
(22079, 473, 1, 1, 1, 50.527854), -- Divine Stockings
(22079, 1989, 1, 1, 1, 3927.195714), -- Divine Stocking Pattern
(22079, 1871, 1, 1, 2, 52120.334604), -- Charcoal
(22079, 1866, 1, 1, 2, 34746.889736), -- Suede
(22079, 1877, 1, 1, 2, 2084.805956), -- Adamantite Nugget
(22079, 4041, 1, 1, 2, 453.210612), -- Mold Hardener
(22079, 4040, 1, 1, 2, 1042.449404), -- Mold Lubricant
(22079, 4126, 1, 1, 2, 860.088076), -- Recipe: Adamantite Earrings (100%)
(22079, 8726, 1, 1, 2, 1206.518888), -- Life Stone - Level 55
(22079, 8736, 1, 1, 2, 301.583296), -- Mid-Grade Life Stone - Level 55
(22079, 8746, 1, 1, 2, 30.1769), -- High-Grade Life Stone - Level 55
(22079, 8756, 1, 1, 2, 5.942528), -- Top-Grade Life Stone - Level 55
-- Massive Lost Bandersnatch
(22080, 1867, 1, 5, -1, 690227), -- Animal Skin
(22080, 1872, 1, 5, -1, 690227), -- Animal Bone
(22080, 2917, 1, 1, -1, 89202), -- Ring of Seal Gemstone
(22080, 57, 613, 1249, 0, 700000), -- Adena
(22080, 119, 1, 1, 1, 44.001856), -- Necklace of Seal
(22080, 1920, 1, 1, 1, 3269.84048), -- Necklace of Seal Chain
(22080, 855, 1, 1, 1, 58.660416), -- Nassen's Earring
(22080, 1918, 1, 1, 1, 4138.635008), -- Nassen's Earring Gemstone
(22080, 886, 1, 1, 1, 87.990624), -- Ring of Seal
(22080, 2917, 1, 1, 1, 5488.871616), -- Ring of Seal Gemstone
(22080, 1871, 1, 1, 2, 57341.798358), -- Charcoal
(22080, 1866, 1, 1, 2, 38227.865572), -- Suede
(22080, 1877, 1, 1, 2, 2293.663762), -- Adamantite Nugget
(22080, 4041, 1, 1, 2, 498.613674), -- Mold Hardener
(22080, 4040, 1, 1, 2, 1146.882958), -- Mold Lubricant
(22080, 4126, 1, 1, 2, 946.252502), -- Recipe: Adamantite Earrings (100%)
(22080, 8726, 1, 1, 2, 1327.389076), -- Life Stone - Level 55
(22080, 8736, 1, 1, 2, 331.796192), -- Mid-Grade Life Stone - Level 55
(22080, 8746, 1, 1, 2, 33.20005), -- High-Grade Life Stone - Level 55
(22080, 8756, 1, 1, 2, 6.537856), -- Top-Grade Life Stone - Level 55
-- Lost Watcher
(22081, 4146, 1, 1, -1, 9434), -- Recipe: Tunic of Zubei (100%)
(22081, 2954, 1, 1, -1, 93142), -- Theca Leather Boots Texture
(22081, 4147, 1, 1, -1, 15125), -- Recipe: Stockings of Zubei (100%)
(22081, 57, 583, 1183, 0, 700000), -- Adena
(22081, 2436, 1, 1, 1, 36.683889), -- Theca Leather Boots
(22081, 2954, 1, 1, 1, 2456.89444), -- Theca Leather Boots Texture
(22081, 2437, 1, 1, 1, 28.223206), -- Drake Leather Boots
(22081, 2960, 1, 1, 1, 2113.742323), -- Drake Leather Boots Design
(22081, 2438, 1, 1, 1, 28.223206), -- Full Plate Boots
(22081, 2961, 1, 1, 1, 2113.742323), -- Full Plate Boots Part
(22081, 2460, 1, 1, 1, 36.683889), -- Theca Leather Gloves
(22081, 2955, 1, 1, 1, 2456.89444), -- Theca Leather Gloves Texture
(22081, 2461, 1, 1, 1, 28.223206), -- Drake Leather Gloves
(22081, 2962, 1, 1, 1, 2113.742323), -- Drake Leather Gloves Design
(22081, 2462, 1, 1, 1, 28.223206), -- Full Plate Gauntlets
(22081, 2963, 1, 1, 1, 2113.742323), -- Full Plate Gauntlets Part
(22081, 2463, 1, 1, 1, 28.223206), -- Divine Gloves
(22081, 2964, 1, 1, 1, 2113.75802), -- Divine Gloves Pattern
(22081, 1868, 1, 1, 2, 108675.06356), -- Thread
(22081, 1873, 1, 1, 2, 21734.984), -- Silver Nugget
(22081, 5549, 1, 1, 2, 5433.746), -- Metallic Thread
(22081, 1889, 1, 1, 2, 3622.44948), -- Compound Braid
(22081, 4044, 1, 1, 2, 1811.29652), -- Thons
(22081, 4128, 1, 1, 2, 672.43504), -- Recipe: Adamantite Necklace (100%)
(22081, 8726, 1, 1, 2, 1257.87272), -- Life Stone - Level 55
(22081, 8736, 1, 1, 2, 314.3964), -- Mid-Grade Life Stone - Level 55
(22081, 8746, 1, 1, 2, 31.43964), -- High-Grade Life Stone - Level 55
(22081, 8756, 1, 1, 2, 6.31664), -- Top-Grade Life Stone - Level 55
-- Elder Lost Watcher
(22082, 2955, 1, 1, -1, 107064), -- Theca Leather Gloves Texture
(22082, 4041, 1, 1, -1, 14710), -- Mold Hardener
(22082, 1872, 1, 5, -1, 751825), -- Animal Bone
(22082, 57, 668, 1361, 0, 700000), -- Adena
(22082, 2414, 1, 1, 1, 75.689053), -- Full Plate Helmet
(22082, 2959, 1, 1, 1, 5401.036314), -- Full Plate Helmet Design
(22082, 2497, 1, 1, 1, 108.129237), -- Full Plate Shield
(22082, 2966, 1, 1, 1, 8544.145396), -- Full Plate Shield Fragment
(22082, 1868, 1, 1, 2, 124918.791018), -- Thread
(22082, 1873, 1, 1, 2, 24983.7252), -- Silver Nugget
(22082, 5549, 1, 1, 2, 6245.9313), -- Metallic Thread
(22082, 1889, 1, 1, 2, 4163.899194), -- Compound Braid
(22082, 4044, 1, 1, 2, 2082.032106), -- Thons
(22082, 4128, 1, 1, 2, 772.944312), -- Recipe: Adamantite Necklace (100%)
(22082, 8726, 1, 1, 2, 1445.887716), -- Life Stone - Level 55
(22082, 8736, 1, 1, 2, 361.38942), -- Mid-Grade Life Stone - Level 55
(22082, 8746, 1, 1, 2, 36.138942), -- High-Grade Life Stone - Level 55
(22082, 8756, 1, 1, 2, 7.260792), -- Top-Grade Life Stone - Level 55
-- Baby Panthera
(22083, 2959, 1, 1, -1, 52739), -- Full Plate Helmet Design
(22083, 4148, 1, 1, -1, 6687), -- Recipe: Avadon Robe (100%)
(22083, 2960, 1, 1, -1, 83021), -- Drake Leather Boots Design
(22083, 57, 603, 1228, 0, 700000), -- Adena
(22083, 119, 1, 1, 1, 43.198338), -- Necklace of Seal
(22083, 1920, 1, 1, 1, 3210.129915), -- Necklace of Seal Chain
(22083, 855, 1, 1, 1, 57.589218), -- Nassen's Earring
(22083, 1918, 1, 1, 1, 4063.059384), -- Nassen's Earring Gemstone
(22083, 886, 1, 1, 1, 86.383827), -- Ring of Seal
(22083, 2917, 1, 1, 1, 5388.639318), -- Ring of Seal Gemstone
(22083, 1871, 1, 1, 2, 56295.95622), -- Charcoal
(22083, 1866, 1, 1, 2, 37530.70401), -- Suede
(22083, 1877, 1, 1, 2, 2251.874175), -- Adamantite Nugget
(22083, 4041, 1, 1, 2, 489.494475), -- Mold Hardener
(22083, 4040, 1, 1, 2, 1125.88719), -- Mold Lubricant
(22083, 4134, 1, 1, 2, 433.010505), -- Recipe: Zubei's Gaiters (100%)
(22083, 8726, 1, 1, 2, 1303.12311), -- Life Stone - Level 55
(22083, 8736, 1, 1, 2, 325.830675), -- Mid-Grade Life Stone - Level 55
(22083, 8746, 1, 1, 2, 32.53317), -- High-Grade Life Stone - Level 55
(22083, 8756, 1, 1, 2, 6.58647), -- Top-Grade Life Stone - Level 55
-- Panthera
(22084, 8311, 1, 1, -1, 1209), -- Recipe: Kaim Vanul's Bones (100%)
(22084, 4049, 1, 1, -1, 83088), -- Adamantite Earring Gemstone
(22084, 947, 1, 1, -1, 634), -- Scroll: Enchant Weapon (B-Grade)
(22084, 57, 625, 1276, 0, 700000), -- Adena
(22084, 12175, 1, 1, 1, 249.162664), -- Common Item - Tunic of Zubei
(22084, 4069, 1, 1, 1, 1838.681664), -- Tunic of Zubei Fabric
(22084, 12176, 1, 1, 1, 398.916228), -- Common Item - Stockings of Zubei
(22084, 4070, 1, 1, 1, 2791.756572), -- Stockings of Zubei Fabric
(22084, 12166, 1, 1, 1, 152.915492), -- Common Item - Avadon Robe
(22084, 4071, 1, 1, 1, 1412.56738), -- Avadon Robe Fabric
(22084, 1871, 1, 1, 2, 46791.165736), -- Charcoal
(22084, 1866, 1, 1, 2, 31194.165788), -- Suede
(22084, 1877, 1, 1, 2, 1871.67649), -- Adamantite Nugget
(22084, 4041, 1, 1, 2, 406.85013), -- Mold Hardener
(22084, 4040, 1, 1, 2, 935.796772), -- Mold Lubricant
(22084, 4134, 1, 1, 2, 359.902694), -- Recipe: Zubei's Gaiters (100%)
(22084, 8726, 1, 1, 2, 1083.108868), -- Life Stone - Level 55
(22084, 8736, 1, 1, 2, 270.81869), -- Mid-Grade Life Stone - Level 55
(22084, 8746, 1, 1, 2, 27.040396), -- High-Grade Life Stone - Level 55
(22084, 8756, 1, 1, 2, 5.474436), -- Top-Grade Life Stone - Level 55
-- Lost Gargoyle
(22085, 1874, 1, 1, -1, 93121), -- Oriharukon Ore
(22085, 4043, 1, 1, -1, 46560), -- Asofe
(22085, 1918, 1, 1, -1, 60494), -- Nassen's Earring Gemstone
(22085, 57, 552, 1125, 0, 700000), -- Adena
(22085, 119, 1, 1, 1, 39.574102), -- Necklace of Seal
(22085, 1920, 1, 1, 1, 2940.807785), -- Necklace of Seal Chain
(22085, 855, 1, 1, 1, 52.757622), -- Nassen's Earring
(22085, 1918, 1, 1, 1, 3722.178536), -- Nassen's Earring Gemstone
(22085, 886, 1, 1, 1, 79.136433), -- Ring of Seal
(22085, 2917, 1, 1, 1, 4936.545522), -- Ring of Seal Gemstone
(22085, 1870, 1, 1, 2, 46885.901538), -- Coal
(22085, 1865, 1, 1, 2, 46885.901538), -- Varnish
(22085, 1874, 1, 1, 2, 3125.767386), -- Oriharukon Ore
(22085, 4043, 1, 1, 2, 1562.832922), -- Asofe
(22085, 4039, 1, 1, 2, 1562.832922), -- Mold Glue
(22085, 1806, 1, 1, 2, 93.723266), -- Recipe: Soulshot (B-Grade)
(22085, 8297, 1, 1, 2, 35.742784), -- Recipe: Guardian's Sword (100%)
(22085, 8726, 1, 1, 2, 1085.280896), -- Life Stone - Level 55
(22085, 8736, 1, 1, 2, 271.320224), -- Mid-Grade Life Stone - Level 55
(22085, 8746, 1, 1, 2, 27.111714), -- High-Grade Life Stone - Level 55
(22085, 8756, 1, 1, 2, 5.58481), -- Top-Grade Life Stone - Level 55
-- Lost Gargoyle Youngling
(22086, 4130, 1, 1, -1, 26373), -- Recipe: Ring of Black Ore (100%)
(22086, 4049, 1, 1, -1, 85213), -- Adamantite Earring Gemstone
(22086, 4131, 1, 1, -1, 13208), -- Recipe: Necklace of Black Ore (100%)
(22086, 57, 641, 1309, 0, 700000), -- Adena
(22086, 12151, 1, 1, 1, 255.533714), -- Common Item - Zubei's Leather Shirt
(22086, 4066, 1, 1, 1, 1885.696464), -- Zubei's Leather Shirt Fabric
(22086, 12150, 1, 1, 1, 409.116453), -- Common Item - Zubei's Leather Gaiters
(22086, 4067, 1, 1, 1, 2863.141347), -- Zubei's Leather Gaiter Texture
(22086, 12165, 1, 1, 1, 156.825517), -- Common Item - Avadon Leather Armor
(22086, 4068, 1, 1, 1, 1448.686505), -- Avadon Leather Armor Lining
(22086, 1870, 1, 1, 2, 43625.10072), -- Coal
(22086, 1865, 1, 1, 2, 43625.10072), -- Varnish
(22086, 1874, 1, 1, 2, 2908.37784), -- Oriharukon Ore
(22086, 4043, 1, 1, 2, 1454.14168), -- Asofe
(22086, 4039, 1, 1, 2, 1454.14168), -- Mold Glue
(22086, 1806, 1, 1, 2, 87.20504), -- Recipe: Soulshot (B-Grade)
(22086, 8297, 1, 1, 2, 33.25696), -- Recipe: Guardian's Sword (100%)
(22086, 8726, 1, 1, 2, 1009.80224), -- Life Stone - Level 55
(22086, 8736, 1, 1, 2, 252.45056), -- Mid-Grade Life Stone - Level 55
(22086, 8746, 1, 1, 2, 25.22616), -- High-Grade Life Stone - Level 55
(22086, 8756, 1, 1, 2, 5.1964), -- Top-Grade Life Stone - Level 55
-- Pronghorn Spirit
(22087, 4050, 1, 1, -1, 161543), -- Adamantite Ring Wire
(22087, 948, 1, 1, -1, 6518), -- Scroll: Enchant Armor (B-Grade)
(22087, 1865, 1, 5, -1, 869100), -- Varnish
(22087, 57, 1029, 2101, 0, 700000), -- Adena
(22087, 11915, 1, 1, 1, 110.18856), -- Common Item - Kris
(22087, 4109, 1, 1, 1, 1084.81144), -- Kris Edge
(22087, 11919, 1, 1, 1, 110.18856), -- Common Item - Hell Knife
(22087, 4110, 1, 1, 1, 1084.81144), -- Hell Knife Edge
(22087, 1864, 1, 1, 2, 140028.390366), -- Stem
(22087, 1865, 1, 1, 2, 70014.40857), -- Varnish
(22087, 1866, 1, 1, 2, 46676.27238), -- Suede
(22087, 1873, 1, 1, 2, 28005.763428), -- Silver Nugget
(22087, 1868, 1, 1, 2, 140028.390366), -- Thread
(22087, 948, 1, 1, 2, 174.97734), -- Scroll: Enchant Armor (B-Grade)
(22087, 8298, 1, 1, 2, 53.34675), -- Recipe: Guardian's Sword (60%)
(22087, 8727, 1, 1, 2, 1400.245494), -- Life Stone - Level 58
(22087, 8737, 1, 1, 2, 349.95468), -- Mid-Grade Life Stone - Level 58
(22087, 8747, 1, 1, 2, 34.995468), -- High-Grade Life Stone - Level 58
(22087, 8757, 1, 1, 2, 7.255158), -- Top-Grade Life Stone - Level 58
-- Pronghorn
(22088, 1867, 1, 5, -1, 705071), -- Animal Skin
(22088, 4613, 1, 1, -1, 2188), -- Greater Dye of STR (Str+4 Con-4)
(22088, 4051, 1, 1, -1, 61524), -- Adamantite Necklace Chain
(22088, 57, 626, 1278, 0, 700000), -- Adena
(22088, 11889, 1, 1, 1, 44.69199), -- Common Item - Great Sword
(22088, 4104, 1, 1, 1, 446.924283), -- Great Sword Blade
(22088, 11916, 1, 1, 1, 44.69199), -- Common Item - Keshanberk
(22088, 4107, 1, 1, 1, 439.999143), -- Keshanberk Blade
(22088, 11900, 1, 1, 1, 44.69199), -- Common Item - Sword of Valhalla
(22088, 4108, 1, 1, 1, 440.000604), -- Sword of Valhalla Blade
(22088, 1864, 1, 1, 2, 85200.06403), -- Stem
(22088, 1865, 1, 1, 2, 42600.16185), -- Varnish
(22088, 1866, 1, 1, 2, 28400.1079), -- Suede
(22088, 1873, 1, 1, 2, 17040.06474), -- Silver Nugget
(22088, 1868, 1, 1, 2, 85200.06403), -- Thread
(22088, 948, 1, 1, 2, 106.4647), -- Scroll: Enchant Armor (B-Grade)
(22088, 8298, 1, 1, 2, 32.45875), -- Recipe: Guardian's Sword (60%)
(22088, 8727, 1, 1, 2, 851.97727), -- Life Stone - Level 58
(22088, 8737, 1, 1, 2, 212.9294), -- Mid-Grade Life Stone - Level 58
(22088, 8747, 1, 1, 2, 21.29294), -- High-Grade Life Stone - Level 58
(22088, 8757, 1, 1, 2, 4.41439), -- Top-Grade Life Stone - Level 58
-- Ice Tarantula
(22089, 4154, 1, 1, -1, 21580), -- Recipe: Doom Shield (100%)
(22089, 4056, 1, 1, -1, 33004), -- Zubei's Breastplate Part
(22089, 4155, 1, 1, -1, 5663), -- Recipe: Blue Wolf Breastplate (100%)
(22089, 57, 719, 1469, 0, 700000), -- Adena
(22089, 11918, 1, 1, 1, 38.52585), -- Common Item - Heavy War Axe
(22089, 4105, 1, 1, 1, 385.26015), -- Heavy War Axe Head
(22089, 11908, 1, 1, 1, 38.52585), -- Common Item - Sprite's Staff
(22089, 4106, 1, 1, 1, 378.939), -- Sprite's Staff Head
(22089, 11902, 1, 1, 1, 38.52585), -- Common Item - Spell Breaker
(22089, 8339, 1, 1, 1, 385.26015), -- Spell Breaker Head
(22089, 11904, 1, 1, 1, 38.52585), -- Common Item - Ice Storm Hammer
(22089, 8347, 1, 1, 1, 346.4373), -- Ice Storm Hammer Head
(22089, 1873, 1, 1, 2, 21545.294904), -- Silver Nugget
(22089, 1868, 1, 1, 2, 107726.790024), -- Thread
(22089, 1876, 1, 1, 2, 10772.726328), -- Mithril Ore
(22089, 1895, 1, 1, 2, 15389.49636), -- Metallic Fiber
(22089, 4042, 1, 1, 2, 897.766632), -- Enria
(22089, 8312, 1, 1, 2, 41.173272), -- Recipe: Kaim Vanul's Bones (60%)
(22089, 8727, 1, 1, 2, 1077.288408), -- Life Stone - Level 58
(22089, 8737, 1, 1, 2, 269.282664), -- Mid-Grade Life Stone - Level 58
(22089, 8747, 1, 1, 2, 26.975592), -- High-Grade Life Stone - Level 58
(22089, 8757, 1, 1, 2, 5.205816), -- Top-Grade Life Stone - Level 58
-- Frost Tarantula
(22090, 4057, 1, 1, -1, 52897), -- Zubei's Gaiter Material
(22090, 947, 1, 1, -1, 756), -- Scroll: Enchant Weapon (B-Grade)
(22090, 1866, 1, 3, -1, 630360), -- Suede
(22090, 57, 747, 1521, 0, 700000), -- Adena
(22090, 11918, 1, 1, 1, 39.950139), -- Common Item - Heavy War Axe
(22090, 4105, 1, 1, 1, 399.503101), -- Heavy War Axe Head
(22090, 11908, 1, 1, 1, 39.950139), -- Common Item - Sprite's Staff
(22090, 4106, 1, 1, 1, 392.94826), -- Sprite's Staff Head
(22090, 11902, 1, 1, 1, 39.950139), -- Common Item - Spell Breaker
(22090, 8339, 1, 1, 1, 399.503101), -- Spell Breaker Head
(22090, 11904, 1, 1, 1, 39.950139), -- Common Item - Ice Storm Hammer
(22090, 8347, 1, 1, 1, 359.244982), -- Ice Storm Hammer Head
(22090, 1873, 1, 1, 2, 22343.860623), -- Silver Nugget
(22090, 1868, 1, 1, 2, 111719.630313), -- Thread
(22090, 1876, 1, 1, 2, 11172.012111), -- Mithril Ore
(22090, 1895, 1, 1, 2, 15959.900445), -- Metallic Fiber
(22090, 4042, 1, 1, 2, 931.041909), -- Enria
(22090, 8312, 1, 1, 2, 42.699339), -- Recipe: Kaim Vanul's Bones (60%)
(22090, 8727, 1, 1, 2, 1117.217571), -- Life Stone - Level 58
(22090, 8737, 1, 1, 2, 279.263493), -- Mid-Grade Life Stone - Level 58
(22090, 8747, 1, 1, 2, 27.975429), -- High-Grade Life Stone - Level 58
(22090, 8757, 1, 1, 2, 5.398767), -- Top-Grade Life Stone - Level 58
-- Lost Iron Golem
(22091, 1869, 1, 5, -1, 664016), -- Iron Ore
(22091, 4614, 1, 1, -1, 2748), -- Greater Dye of STR (Str+4 Dex-4)
(22091, 8306, 1, 1, -1, 1521), -- Recipe: Wizard's Tear (60%)
(22091, 57, 787, 1603, 0, 700000), -- Adena
(22091, 12161, 1, 1, 1, 176.1697), -- Common Item - Zubei's Breastplate
(22091, 4056, 1, 1, 1, 1331.212106), -- Zubei's Breastplate Part
(22091, 12152, 1, 1, 1, 281.79459), -- Common Item - Zubei's Gaiters
(22091, 4057, 1, 1, 1, 2057.323604), -- Zubei's Gaiter Material
(22091, 12173, 1, 1, 1, 176.1697), -- Common Item - Avadon Breastplate
(22091, 4064, 1, 1, 1, 1331.212106), -- Avadon Breastplate Part
(22091, 12172, 1, 1, 1, 281.79459), -- Common Item - Avadon Plate Gaiters
(22091, 4065, 1, 1, 1, 2057.323604), -- Avadon Gaiters Material
(22091, 1869, 1, 1, 2, 58842.070304), -- Iron Ore
(22091, 1870, 1, 1, 2, 58842.070304), -- Coal
(22091, 1871, 1, 1, 2, 58842.070304), -- Charcoal
(22091, 1872, 1, 1, 2, 78456.3175), -- Animal Bone
(22091, 1867, 1, 1, 2, 78456.3175), -- Animal Skin
(22091, 4154, 1, 1, 2, 696.45715), -- Recipe: Doom Shield (100%)
(22091, 8727, 1, 1, 2, 1176.760852), -- Life Stone - Level 58
(22091, 8737, 1, 1, 2, 294.358034), -- Mid-Grade Life Stone - Level 58
(22091, 8747, 1, 1, 2, 29.536496), -- High-Grade Life Stone - Level 58
(22091, 8757, 1, 1, 2, 6.041556), -- Top-Grade Life Stone - Level 58
-- Frost Iron Golem
(22092, 4157, 1, 1, -1, 10280), -- Recipe: Blue Wolf Gaiters (100%)
(22092, 4065, 1, 1, -1, 57797), -- Avadon Gaiters Material
(22092, 8314, 1, 1, -1, 1129), -- Recipe: Spiritual Eye (60%)
(22092, 57, 816, 1662, 0, 700000), -- Adena
(22092, 11889, 1, 1, 1, 58.21277), -- Common Item - Great Sword
(22092, 4104, 1, 1, 1, 582.133409), -- Great Sword Blade
(22092, 11916, 1, 1, 1, 58.21277), -- Common Item - Keshanberk
(22092, 4107, 1, 1, 1, 573.113189), -- Keshanberk Blade
(22092, 11900, 1, 1, 1, 58.21277), -- Common Item - Sword of Valhalla
(22092, 4108, 1, 1, 1, 573.115092), -- Sword of Valhalla Blade
(22092, 1869, 1, 1, 2, 61033.11968), -- Iron Ore
(22092, 1870, 1, 1, 2, 61033.11968), -- Coal
(22092, 1871, 1, 1, 2, 61033.11968), -- Charcoal
(22092, 1872, 1, 1, 2, 81377.725), -- Animal Bone
(22092, 1867, 1, 1, 2, 81377.725), -- Animal Skin
(22092, 4154, 1, 1, 2, 722.3905), -- Recipe: Doom Shield (100%)
(22092, 8727, 1, 1, 2, 1220.57884), -- Life Stone - Level 58
(22092, 8737, 1, 1, 2, 305.31878), -- Mid-Grade Life Stone - Level 58
(22092, 8747, 1, 1, 2, 30.63632), -- High-Grade Life Stone - Level 58
(22092, 8757, 1, 1, 2, 6.26652), -- Top-Grade Life Stone - Level 58
-- Lost Buffalo
(22093, 8316, 1, 1, -1, 1117), -- Recipe: Flaming Dragon Skull (60%)
(22093, 4615, 1, 1, -1, 4162), -- Greater Dye of CON (Con+4 Str-4)
(22093, 8300, 1, 1, -1, 1649), -- Recipe: Infernal Master (60%)
(22093, 57, 1193, 2426, 0, 700000), -- Adena
(22093, 12151, 1, 1, 1, 474.55221), -- Common Item - Zubei's Leather Shirt
(22093, 4066, 1, 1, 1, 3501.93096), -- Zubei's Leather Shirt Fabric
(22093, 12150, 1, 1, 1, 759.771045), -- Common Item - Zubei's Leather Gaiters
(22093, 4067, 1, 1, 1, 5317.145955), -- Zubei's Leather Gaiter Texture
(22093, 12165, 1, 1, 1, 291.241005), -- Common Item - Avadon Leather Armor
(22093, 4068, 1, 1, 1, 2690.358825), -- Avadon Leather Armor Lining
(22093, 1873, 1, 1, 2, 32407.956224), -- Silver Nugget
(22093, 1868, 1, 1, 2, 162039.428096), -- Thread
(22093, 1876, 1, 1, 2, 16203.8016), -- Mithril Ore
(22093, 1895, 1, 1, 2, 23148.489728), -- Metallic Fiber
(22093, 4042, 1, 1, 2, 1350.3168), -- Enria
(22093, 4157, 1, 1, 2, 403.153408), -- Recipe: Blue Wolf Gaiters (100%)
(22093, 8728, 1, 1, 2, 1350.3168), -- Life Stone - Level 61
(22093, 8738, 1, 1, 2, 337.490944), -- Mid-Grade Life Stone - Level 61
(22093, 8748, 1, 1, 2, 33.890304), -- High-Grade Life Stone - Level 61
(22093, 8758, 1, 1, 2, 6.707456), -- Top-Grade Life Stone - Level 61
(22093, 1343, 10, 30, 2, 115742.44864), -- Silver Arrow
-- Frost Buffalo
(22094, 4066, 1, 1, -1, 43180), -- Zubei's Leather Shirt Fabric
(22094, 948, 1, 1, -1, 4579), -- Scroll: Enchant Armor (B-Grade)
(22094, 4042, 1, 1, -1, 30524), -- Enria
(22094, 57, 726, 1472, 0, 700000), -- Adena
(22094, 11918, 1, 1, 1, 38.689293), -- Common Item - Heavy War Axe
(22094, 4105, 1, 1, 1, 386.894587), -- Heavy War Axe Head
(22094, 11908, 1, 1, 1, 38.689293), -- Common Item - Sprite's Staff
(22094, 4106, 1, 1, 1, 380.54662), -- Sprite's Staff Head
(22094, 11902, 1, 1, 1, 38.689293), -- Common Item - Spell Breaker
(22094, 8339, 1, 1, 1, 386.894587), -- Spell Breaker Head
(22094, 11904, 1, 1, 1, 38.689293), -- Common Item - Ice Storm Hammer
(22094, 8347, 1, 1, 1, 347.907034), -- Ice Storm Hammer Head
(22094, 1873, 1, 1, 2, 21639.46204), -- Silver Nugget
(22094, 1868, 1, 1, 2, 108197.151762), -- Thread
(22094, 1876, 1, 1, 2, 10819.73102), -- Mithril Ore
(22094, 1895, 1, 1, 2, 15456.735966), -- Metallic Fiber
(22094, 4042, 1, 1, 2, 901.670658), -- Enria
(22094, 4157, 1, 1, 2, 269.186162), -- Recipe: Blue Wolf Gaiters (100%)
(22094, 8728, 1, 1, 2, 901.670658), -- Life Stone - Level 61
(22094, 8738, 1, 1, 2, 225.457274), -- Mid-Grade Life Stone - Level 61
(22094, 8748, 1, 1, 2, 22.498196), -- High-Grade Life Stone - Level 61
(22094, 8758, 1, 1, 2, 4.436264), -- Top-Grade Life Stone - Level 61
-- Ursus Cub
(22095, 4159, 1, 1, -1, 5380), -- Recipe: Blue Wolf Leather Armor (100%)
(22095, 4068, 1, 1, -1, 34399), -- Avadon Leather Armor Lining
(22095, 4160, 1, 1, -1, 5380), -- Recipe: Leather Armor of Doom (100%)
(22095, 57, 753, 1526, 0, 700000), -- Adena
(22095, 11915, 1, 1, 1, 80.267064), -- Common Item - Kris
(22095, 4109, 1, 1, 1, 790.232936), -- Kris Edge
(22095, 11919, 1, 1, 1, 80.267064), -- Common Item - Hell Knife
(22095, 4110, 1, 1, 1, 790.232936), -- Hell Knife Edge
(22095, 1865, 1, 1, 2, 46748.78988), -- Varnish
(22095, 1870, 1, 1, 2, 46748.78988), -- Coal
(22095, 1879, 1, 1, 2, 7791.46498), -- Cokes
(22095, 1875, 1, 1, 2, 3116.62065), -- Stone of Purity
(22095, 4040, 1, 1, 2, 934.89955), -- Mold Lubricant
(22095, 4159, 1, 1, 2, 132.39356), -- Recipe: Blue Wolf Leather Armor (100%)
(22095, 8306, 1, 1, 2, 35.69774), -- Recipe: Wizard's Tear (60%)
(22095, 8728, 1, 1, 2, 779.11184), -- Life Stone - Level 61
(22095, 8738, 1, 1, 2, 194.77796), -- Mid-Grade Life Stone - Level 61
(22095, 8748, 1, 1, 2, 19.40848), -- High-Grade Life Stone - Level 61
(22095, 8758, 1, 1, 2, 3.81238), -- Top-Grade Life Stone - Level 61
(22095, 1343, 10, 30, 2, 66784.2331), -- Silver Arrow
-- Ursus
(22096, 4052, 1, 1, -1, 69634), -- Earring of Black Ore Piece
(22096, 1875, 1, 1, -1, 131122), -- Stone of Purity
(22096, 4041, 1, 1, -1, 17103), -- Mold Hardener
(22096, 57, 780, 1580, 0, 700000), -- Adena
(22096, 11935, 1, 1, 1, 18.9702), -- Common Item - Deadman's Glory
(22096, 4116, 1, 1, 1, 253.78245), -- Deadman's Glory Stone
(22096, 11938, 1, 1, 1, 18.9702), -- Common Item - Art of Battle Axe
(22096, 4117, 1, 1, 1, 253.78245), -- Art of Battle Axe Blade
(22096, 11934, 1, 1, 1, 18.9702), -- Common Item - Staff of Evil Spirits
(22096, 4118, 1, 1, 1, 240.44445), -- Evil Spirit Head
(22096, 11941, 1, 1, 1, 18.9702), -- Common Item - Kaim Vanul's Bones
(22096, 8340, 1, 1, 1, 253.78245), -- Bones Head of Kaim Vanul
(22096, 11936, 1, 1, 1, 18.9702), -- Common Item - Star Buster
(22096, 8348, 1, 1, 1, 253.3572), -- Star Buster Head
(22096, 1865, 1, 1, 2, 52815.250437), -- Varnish
(22096, 1870, 1, 1, 2, 52815.250437), -- Coal
(22096, 1879, 1, 1, 2, 8802.521685), -- Cokes
(22096, 1875, 1, 1, 2, 3521.008674), -- Stone of Purity
(22096, 4040, 1, 1, 2, 1056.350733), -- Mold Lubricant
(22096, 4159, 1, 1, 2, 149.566461), -- Recipe: Blue Wolf Leather Armor (100%)
(22096, 8306, 1, 1, 2, 40.309545), -- Recipe: Wizard's Tear (60%)
(22096, 8728, 1, 1, 2, 880.312332), -- Life Stone - Level 61
(22096, 8738, 1, 1, 2, 220.078083), -- Mid-Grade Life Stone - Level 61
(22096, 8748, 1, 1, 2, 22.019841), -- High-Grade Life Stone - Level 61
(22096, 8758, 1, 1, 2, 4.331772), -- Top-Grade Life Stone - Level 61
-- Lost Yeti
(22097, 4053, 1, 1, -1, 98368), -- Ring of Black Ore Gemstone
(22097, 1807, 1, 1, -1, 3060), -- Recipe: Soulshot (A-Grade)
(22097, 4054, 1, 1, -1, 45202), -- Necklace of Black Ore Beads
(22097, 57, 910, 1844, 0, 700000), -- Adena
(22097, 12201, 1, 1, 1, 150.366672), -- Common Item - Blue Wolf Tunic
(22097, 4084, 1, 1, 1, 1472.588784), -- Blue Wolf Tunic Fabric
(22097, 12192, 1, 1, 1, 150.366672), -- Common Item - Tunic of Doom
(22097, 4085, 1, 1, 1, 1472.588784), -- Tunic of Doom Pattern
(22097, 12203, 1, 1, 1, 240.719184), -- Common Item - Blue Wolf Stockings
(22097, 4086, 1, 1, 1, 1988.32536), -- Blue Wolf Stockings Pattern
(22097, 12205, 1, 1, 1, 240.719184), -- Common Item - Stockings of Doom
(22097, 4087, 1, 1, 1, 1988.32536), -- Stockings of Doom Pattern
(22097, 1865, 1, 1, 2, 52144.816815), -- Varnish
(22097, 1870, 1, 1, 2, 52144.816815), -- Coal
(22097, 1879, 1, 1, 2, 8690.899308), -- Cokes
(22097, 1875, 1, 1, 2, 3476.321121), -- Stone of Purity
(22097, 4040, 1, 1, 2, 1042.838433), -- Mold Lubricant
(22097, 3035, 1, 1, 2, 69.48396), -- Recipe: Spiritshot A
(22097, 8326, 1, 1, 2, 19.3011), -- Recipe: Doom Crusher (60%)
(22097, 8305, 1, 1, 2, 39.760266), -- Recipe: Wizard's Tear (100%)
(22097, 8729, 1, 1, 2, 695.225622), -- Life Stone - Level 64
(22097, 8739, 1, 1, 2, 173.902911), -- Mid-Grade Life Stone - Level 64
(22097, 8749, 1, 1, 2, 17.37099), -- High-Grade Life Stone - Level 64
(22097, 8759, 1, 1, 2, 3.474198), -- Top-Grade Life Stone - Level 64
(22097, 1343, 10, 30, 2, 74492.788461), -- Silver Arrow
-- Frost Yeti
(22098, 3035, 1, 1, -1, 3168), -- Recipe: Spiritshot A
(22098, 4077, 1, 1, -1, 106869), -- Doom Shield Fragment
(22098, 4039, 1, 1, -1, 79190), -- Mold Glue
(22098, 57, 942, 1908, 0, 700000), -- Adena
(22098, 11930, 1, 1, 1, 38.21235), -- Common Item - Sword of Damascus
(22098, 4114, 1, 1, 1, 512.0742), -- Sword of Damascus Blade
(22098, 11929, 1, 1, 1, 38.21235), -- Common Item - Guardian Sword
(22098, 8330, 1, 1, 1, 511.2129), -- Guardian Sword Blade
(22098, 11943, 1, 1, 1, 38.21235), -- Common Item - Wizard's Tear
(22098, 8336, 1, 1, 1, 512.07585), -- Blade of the Wizard's Tear
(22098, 1865, 1, 1, 2, 58478.571322), -- Varnish
(22098, 1870, 1, 1, 2, 58478.571322), -- Coal
(22098, 1879, 1, 1, 2, 9746.450706), -- Cokes
(22098, 1875, 1, 1, 2, 3898.633448), -- Stone of Purity
(22098, 4040, 1, 1, 2, 1169.510286), -- Mold Lubricant
(22098, 3035, 1, 1, 2, 78.020518), -- Recipe: Spiritshot A
(22098, 8326, 1, 1, 2, 21.664982), -- Recipe: Doom Crusher (60%)
(22098, 8305, 1, 1, 2, 44.659104), -- Recipe: Wizard's Tear (100%)
(22098, 8729, 1, 1, 2, 779.673524), -- Life Stone - Level 64
(22098, 8739, 1, 1, 2, 194.984838), -- Mid-Grade Life Stone - Level 64
(22098, 8749, 1, 1, 2, 19.538358), -- High-Grade Life Stone - Level 64
(22098, 8759, 1, 1, 2, 3.721592), -- Top-Grade Life Stone - Level 64
-- Freya's Buffalo
(22099, 4039, 1, 1, -1, 345184), -- Mold Glue
(22099, 4616, 1, 1, -1, 14283), -- Greater Dye of CON (Con+4 Dex-4)
(22099, 4049, 1, 1, -1, 543169), -- Adamantite Earring Gemstone
(22099, 57, 4084, 8341, 0, 700000), -- Adena
(22099, 78, 1, 1, 1, 15.263371), -- Great Sword
(22099, 4104, 1, 1, 1, 2917.201987), -- Great Sword Blade
(22099, 142, 1, 1, 1, 15.263371), -- Keshanberk
(22099, 4107, 1, 1, 1, 2872.00395), -- Keshanberk Blade
(22099, 148, 1, 1, 1, 15.263371), -- Sword of Valhalla
(22099, 4108, 1, 1, 1, 2872.00395), -- Sword of Valhalla Blade
(22099, 1864, 3, 9, 2, 101961.985544), -- Stem
(22099, 1869, 2, 6, 2, 76471.22172), -- Iron Ore
(22099, 1878, 1, 1, 2, 122354.311336), -- Braided Hemp
(22099, 1884, 2, 6, 2, 37647.425552), -- Cord
(22099, 4039, 1, 1, 2, 10196.162896), -- Mold Glue
(22099, 947, 1, 1, 2, 122.308312), -- Scroll: Enchant Weapon (B-Grade)
(22099, 8727, 1, 1, 2, 6117.555104), -- Life Stone - Level 58
(22099, 8737, 1, 1, 2, 1529.388776), -- Mid-Grade Life Stone - Level 58
(22099, 8747, 1, 1, 2, 152.974536), -- High-Grade Life Stone - Level 58
(22099, 8757, 1, 1, 2, 30.666224), -- Top-Grade Life Stone - Level 58
-- Freya's Gardener
(22100, 4129, 1, 1, -1, 133766), -- Recipe: Earrings of Black Ore (100%)
(22100, 4050, 1, 1, -1, 765795), -- Adamantite Ring Wire
(22100, 4130, 1, 1, -1, 200648), -- Recipe: Ring of Black Ore (100%)
(22100, 57, 4881, 9944, 0, 700000), -- Adena
(22100, 2384, 1, 1, 1, 101.669667), -- Zubei's Leather Shirt
(22100, 4066, 1, 1, 1, 14349.241764), -- Zubei's Leather Shirt Fabric
(22100, 2388, 1, 1, 1, 162.690462), -- Zubei's Leather Gaiters
(22100, 4067, 1, 1, 1, 21787.083087), -- Zubei's Leather Gaiter Texture
(22100, 2390, 1, 1, 1, 62.540379), -- Avadon Leather Armor
(22100, 4068, 1, 1, 1, 11023.774641), -- Avadon Leather Armor Lining
(22100, 1871, 1, 3, 2, 182546.816116), -- Charcoal
(22100, 1866, 1, 1, 2, 243395.908582), -- Suede
(22100, 1877, 1, 1, 2, 14603.726838), -- Adamantite Nugget
(22100, 4041, 1, 1, 2, 3174.542724), -- Mold Hardener
(22100, 4040, 1, 1, 2, 7302.09406), -- Mold Lubricant
(22100, 948, 1, 1, 2, 912.877078), -- Scroll: Enchant Armor (B-Grade)
(22100, 8727, 1, 1, 2, 7302.09406), -- Life Stone - Level 58
(22100, 8737, 1, 1, 2, 1825.292874), -- Mid-Grade Life Stone - Level 58
(22100, 8747, 1, 1, 2, 182.667672), -- High-Grade Life Stone - Level 58
(22100, 8757, 1, 1, 2, 35.979996), -- Top-Grade Life Stone - Level 58
-- Freya's Servant
(22101, 4051, 1, 1, -1, 419407), -- Adamantite Necklace Chain
(22101, 947, 1, 1, -1, 4326), -- Scroll: Enchant Weapon (B-Grade)
(22101, 5220, 1, 1, -1, 432576), -- Metal Hardener
(22101, 57, 4271, 8700, 0, 700000), -- Adena
(22101, 357, 1, 1, 1, 50.03775), -- Zubei's Breastplate
(22101, 4056, 1, 1, 1, 7229.491185), -- Zubei's Breastplate Part
(22101, 383, 1, 1, 1, 80.0604), -- Zubei's Gaiters
(22101, 4057, 1, 1, 1, 11172.8736), -- Zubei's Gaiter Material
(22101, 2376, 1, 1, 1, 50.03775), -- Avadon Breastplate
(22101, 4064, 1, 1, 1, 7229.491185), -- Avadon Breastplate Part
(22101, 2379, 1, 1, 1, 80.0604), -- Avadon Gaiters
(22101, 4065, 1, 1, 1, 11172.94773), -- Avadon Gaiters Material
(22101, 1866, 1, 1, 2, 212960.604012), -- Suede
(22101, 1871, 1, 3, 2, 159720.453009), -- Charcoal
(22101, 5220, 1, 1, 2, 12777.67036), -- Metal Hardener
(22101, 1885, 1, 1, 2, 26619.862256), -- High-Grade Suede
(22101, 4041, 1, 1, 2, 2777.735883), -- Mold Hardener
(22101, 4129, 1, 1, 2, 3457.136046), -- Recipe: Earrings of Black Ore (100%)
(22101, 8727, 1, 1, 2, 6388.83518), -- Life Stone - Level 58
(22101, 8737, 1, 1, 2, 1597.208795), -- Mid-Grade Life Stone - Level 58
(22101, 8747, 1, 1, 2, 159.507634), -- High-Grade Life Stone - Level 58
(22101, 8757, 1, 1, 2, 31.986825), -- Top-Grade Life Stone - Level 58
-- Freya's Servant
(22102, 1895, 1, 7, -1, 772457), -- Metallic Fiber
(22102, 4617, 1, 1, -1, 14916), -- Greater Dye of DEX (Dex+4 Str-4)
(22102, 4056, 1, 1, -1, 195736), -- Zubei's Breastplate Part
(22102, 57, 4271, 8700, 0, 700000), -- Adena
(22102, 229, 1, 1, 1, 23.908578), -- Kris
(22102, 4109, 1, 1, 1, 4499.091422), -- Kris Edge
(22102, 243, 1, 1, 1, 23.908578), -- Hell Knife
(22102, 4110, 1, 1, 1, 4499.091422), -- Hell Knife Edge
(22102, 1873, 1, 1, 2, 127776.407142), -- Silver Nugget
(22102, 1868, 3, 9, 2, 106480.339285), -- Thread
(22102, 1876, 1, 1, 2, 63888.203571), -- Mithril Ore
(22102, 1895, 1, 1, 2, 91268.747056), -- Metallic Fiber
(22102, 4042, 1, 1, 2, 5324.117754), -- Enria
(22102, 8324, 1, 1, 2, 243.911195), -- Recipe: Star Buster (60%)
(22102, 8727, 1, 1, 2, 6388.860673), -- Life Stone - Level 58
(22102, 8737, 1, 1, 2, 1597.315958), -- Mid-Grade Life Stone - Level 58
(22102, 8747, 1, 1, 2, 159.650964), -- High-Grade Life Stone - Level 58
(22102, 8757, 1, 1, 2, 31.446402), -- Top-Grade Life Stone - Level 58
-- Freya's White Bear
(22103, 4131, 1, 1, -1, 88634), -- Recipe: Necklace of Black Ore (100%)
(22103, 4057, 1, 1, -1, 304949), -- Zubei's Gaiter Material
(22103, 4154, 1, 1, -1, 129017), -- Recipe: Doom Shield (100%)
(22103, 57, 4299, 8781, 0, 700000), -- Adena
(22103, 357, 1, 1, 1, 50.44275), -- Zubei's Breastplate
(22103, 4056, 1, 1, 1, 7288.005885), -- Zubei's Breastplate Part
(22103, 383, 1, 1, 1, 80.7084), -- Zubei's Gaiters
(22103, 4057, 1, 1, 1, 11263.3056), -- Zubei's Gaiter Material
(22103, 2376, 1, 1, 1, 50.44275), -- Avadon Breastplate
(22103, 4064, 1, 1, 1, 7288.005885), -- Avadon Breastplate Part
(22103, 2379, 1, 1, 1, 80.7084), -- Avadon Gaiters
(22103, 4065, 1, 1, 1, 11263.38033), -- Avadon Gaiters Material
(22103, 1866, 1, 1, 2, 195167.589288), -- Suede
(22103, 1871, 1, 3, 2, 146375.400864), -- Charcoal
(22103, 5220, 1, 1, 2, 11710.06312), -- Metal Hardener
(22103, 1885, 1, 1, 2, 24395.900144), -- High-Grade Suede
(22103, 4041, 1, 1, 2, 2545.784024), -- Mold Hardener
(22103, 8305, 1, 1, 2, 223.566336), -- Recipe: Wizard's Tear (100%)
(22103, 8323, 1, 1, 2, 223.566336), -- Recipe: Star Buster (100%)
(22103, 8727, 1, 1, 2, 5855.03156), -- Life Stone - Level 58
(22103, 8737, 1, 1, 2, 1463.660856), -- Mid-Grade Life Stone - Level 58
(22103, 8747, 1, 1, 2, 146.327272), -- High-Grade Life Stone - Level 58
(22103, 8757, 1, 1, 2, 29.1102), -- Top-Grade Life Stone - Level 58
-- Freya's Dog
(22104, 4064, 1, 1, -1, 206116), -- Avadon Breastplate Part
(22104, 948, 1, 1, -1, 28470), -- Scroll: Enchant Armor (B-Grade)
(22104, 4040, 1, 1, -1, 227758), -- Mold Lubricant
(22104, 57, 4497, 9162, 0, 700000), -- Adena
(22104, 554, 1, 1, 1, 210.712224), -- Sealed Zubei's Boots
(22104, 4097, 1, 1, 1, 21885.787776), -- Sealed Zubei's Boots Design
(22104, 600, 1, 1, 1, 210.712224), -- Sealed Avadon Boots
(22104, 4098, 1, 1, 1, 21885.787776), -- Sealed Avadon Boots Design
(22104, 612, 1, 1, 1, 210.712224), -- Sealed Zubei's Gauntlets
(22104, 4100, 1, 1, 1, 21885.787776), -- Sealed Zubei's Gauntlets Part
(22104, 2464, 1, 1, 1, 210.712224), -- Sealed Avadon Gloves
(22104, 4073, 1, 1, 1, 21885.787776), -- Sealed Avadon Gloves Part
(22104, 1865, 1, 3, 2, 168190.4448), -- Varnish
(22104, 1870, 1, 3, 2, 112126.837158), -- Coal
(22104, 1879, 1, 1, 2, 56063.607642), -- Cokes
(22104, 1875, 1, 1, 2, 22425.518682), -- Stone of Purity
(22104, 4040, 1, 1, 2, 6727.617792), -- Mold Lubricant
(22104, 4154, 1, 1, 2, 3980.910528), -- Recipe: Doom Shield (100%)
(22104, 8727, 1, 1, 2, 6727.617792), -- Life Stone - Level 58
(22104, 8737, 1, 1, 2, 1681.904448), -- Mid-Grade Life Stone - Level 58
(22104, 8747, 1, 1, 2, 168.26607), -- High-Grade Life Stone - Level 58
(22104, 8757, 1, 1, 2, 33.275088), -- Top-Grade Life Stone - Level 58
-- Spiked Stakato
(22105, 1875, 1, 1, -1, 559892), -- Stone of Purity
(22105, 5478, 1, 1, -1, 70622), -- Sealed Dark Crystal Leather Armor Pattern
(22105, 5434, 1, 1, -1, 3111), -- Recipe: Dragon Slayer(60%)
(22105, 57, 4141, 8456, 0, 700000), -- Adena
(22105, 212, 1, 1, 1, 5.49879), -- Dasparion's Staff
(22105, 5543, 1, 1, 1, 1319.662242), -- Dasparion's Staff Head
(22105, 2504, 1, 1, 1, 5.49879), -- Meteor Shower
(22105, 5532, 1, 1, 1, 1307.338638), -- Meteor Shower Head
(22105, 7894, 1, 1, 1, 5.49879), -- Spiritual Eye
(22105, 8341, 1, 1, 1, 1305.665322), -- Spiritual Eye Piece
(22105, 7899, 1, 1, 1, 5.49879), -- Destroyer Hammer
(22105, 8346, 1, 1, 1, 1307.338638), -- Hammer Piece of Destroyer
(22105, 1872, 1, 3, 2, 206729.341574), -- Animal Bone
(22105, 1867, 1, 3, 2, 137819.423357), -- Animal Skin
(22105, 1881, 1, 1, 2, 41345.703084), -- Coarse Bone Powder
(22105, 1875, 1, 1, 2, 20672.851542), -- Stone of Purity
(22105, 4041, 1, 1, 2, 2696.566656), -- Mold Hardener
(22105, 3957, 1, 1, 2, 137.967718), -- Recipe: Blessed Spiritshot S
(22105, 8731, 1, 1, 2, 2871.298227), -- Life Stone - Level 70
(22105, 8741, 1, 1, 2, 717.927826), -- Mid-Grade Life Stone - Level 70
(22105, 8751, 1, 1, 2, 71.875398), -- High-Grade Life Stone - Level 70
(22105, 8761, 1, 1, 2, 14.044618), -- Top-Grade Life Stone - Level 70
-- Spiked Stakato Worker
(22106, 5479, 1, 1, -1, 51240), -- Sealed Tallum Leather Armor Pattern
(22106, 5440, 1, 1, -1, 3207), -- Recipe: Elysian(60%)
(22106, 5482, 1, 1, -1, 114296), -- Sealed Dark Crystal Leggings Design
(22106, 57, 4276, 8707, 0, 700000), -- Adena
(22106, 212, 1, 1, 1, 5.67017), -- Dasparion's Staff
(22106, 5543, 1, 1, 1, 1360.791966), -- Dasparion's Staff Head
(22106, 2504, 1, 1, 1, 5.67017), -- Meteor Shower
(22106, 5532, 1, 1, 1, 1348.084274), -- Meteor Shower Head
(22106, 7894, 1, 1, 1, 5.67017), -- Spiritual Eye
(22106, 8341, 1, 1, 1, 1346.358806), -- Spiritual Eye Piece
(22106, 7899, 1, 1, 1, 5.67017), -- Destroyer Hammer
(22106, 8346, 1, 1, 1, 1348.084274), -- Hammer Piece of Destroyer
(22106, 1872, 1, 3, 2, 193781.973372), -- Animal Bone
(22106, 1867, 1, 3, 2, 129187.982248), -- Animal Skin
(22106, 1881, 1, 1, 2, 38756.299066), -- Coarse Bone Powder
(22106, 1875, 1, 1, 2, 19378.388554), -- Stone of Purity
(22106, 4041, 1, 1, 2, 2527.408054), -- Mold Hardener
(22106, 3957, 1, 1, 2, 129.07134), -- Recipe: Blessed Spiritshot S
(22106, 8731, 1, 1, 2, 2691.37646), -- Life Stone - Level 70
(22106, 8741, 1, 1, 2, 673.083136), -- Mid-Grade Life Stone - Level 70
(22106, 8751, 1, 1, 2, 67.403922), -- High-Grade Life Stone - Level 70
(22106, 8761, 1, 1, 2, 13.385176), -- Top-Grade Life Stone - Level 70
(22106, 1344, 40, 120, 2, 90835.628672), -- Mithril Arrow
-- Spiked Stakato Guard
(22107, 729, 1, 1, -1, 991), -- Scroll: Enchant Weapon (A-Grade)
(22107, 4039, 1, 1, -1, 297302), -- Mold Glue
(22107, 4041, 1, 1, -1, 77557), -- Mold Hardener
(22107, 57, 4401, 8971, 0, 700000), -- Adena
(22107, 98, 1, 1, 1, 23.357864), -- Halberd
(22107, 5542, 1, 1, 1, 5552.642136), -- Halberd Edge
(22107, 1894, 1, 1, 2, 12838.936384), -- Crafted Leather
(22107, 4039, 1, 1, 2, 12196.980582), -- Mold Glue
(22107, 4041, 1, 1, 2, 3181.797588), -- Mold Hardener
(22107, 4044, 1, 1, 2, 12196.980582), -- Thons
(22107, 3957, 1, 1, 2, 162.633594), -- Recipe: Blessed Spiritshot S
(22107, 8731, 1, 1, 2, 3388.042676), -- Life Stone - Level 70
(22107, 8741, 1, 1, 2, 847.033126), -- Mid-Grade Life Stone - Level 70
(22107, 8751, 1, 1, 2, 84.707804), -- High-Grade Life Stone - Level 70
(22107, 8761, 1, 1, 2, 16.887664), -- Top-Grade Life Stone - Level 70
-- Female Spiked Stakato
(22108, 5485, 1, 1, -1, 104604), -- Sealed Tallum Tunic Texture
(22108, 5442, 1, 1, -1, 4607), -- Recipe: Soul Bow(60%)
(22108, 5486, 1, 1, -1, 73607), -- Sealed Dark Crystal Robe Fabric
(22108, 57, 6139, 12513, 0, 700000), -- Adena
(22108, 5297, 1, 1, 1, 57.319341), -- Sealed Dark Crystal Leather Armor
(22108, 5478, 1, 1, 1, 6436.619821), -- Sealed Dark Crystal Leather Armor Pattern
(22108, 5298, 1, 1, 1, 91.664189), -- Sealed Dark Crystal Leggings
(22108, 5482, 1, 1, 1, 10102.868586), -- Sealed Dark Crystal Leggings Design
(22108, 5301, 1, 1, 1, 35.258727), -- Sealed Tallum Leather Armor
(22108, 5479, 1, 1, 1, 4529.269336), -- Sealed Tallum Leather Armor Pattern
(22108, 1869, 2, 6, 2, 164038.266112), -- Iron Ore
(22108, 1864, 5, 15, 2, 131230.788768), -- Stem
(22108, 1880, 1, 1, 2, 65615.394384), -- Steel
(22108, 5550, 1, 1, 2, 8748.631312), -- Durable Metal Plate
(22108, 4043, 1, 1, 2, 21871.798128), -- Asofe
(22108, 10302, 1, 1, 2, 2624.545424), -- Transformation Sealbook: Heretic
(22108, 1344, 180, 540, 2, 45566.575872), -- Mithril Arrow
-- Male Spiked Stakato
(22109, 5448, 1, 1, -1, 4546), -- Recipe: Soul Separator(60%)
(22109, 5489, 1, 1, -1, 162002), -- Sealed Tallum Stockings Fabric
(22109, 730, 1, 1, -1, 10228), -- Scroll: Enchant Armor (A-Grade)
(22109, 57, 6057, 12346, 0, 700000), -- Adena
(22109, 5287, 1, 1, 1, 42.41041), -- Sealed Dark Crystal breastplate
(22109, 5520, 1, 1, 1, 4871.12717), -- Sealed Dark Crystal Breastplate Pattern
(22109, 5288, 1, 1, 1, 67.86619), -- Sealed Dark Crystal Gaiters
(22109, 5524, 1, 1, 1, 7445.21183), -- Sealed Dark Crystal Gaiters Pattern
(22109, 5293, 1, 1, 1, 26.10727), -- Sealed Tallum Plate Armor
(22109, 5521, 1, 1, 1, 3437.27713), -- Sealed Tallum Plate Armor Pattern
(22109, 1864, 21, 63, 2, 35967.96414), -- Stem
(22109, 1869, 2, 6, 2, 188830.62279), -- Iron Ore
(22109, 1878, 3, 9, 2, 50354.99127), -- Braided Hemp
(22109, 1884, 2, 6, 2, 92962.81692), -- Cord
(22109, 4039, 1, 1, 2, 25177.495635), -- Mold Glue
(22109, 10302, 1, 1, 2, 3021.109245), -- Transformation Sealbook: Heretic
-- Male Spiked Stakato
(22110, 1885, 1, 1, -1, 774742), -- High-Grade Suede
(22110, 4041, 1, 1, -1, 80843), -- Mold Hardener
(22110, 5494, 1, 1, -1, 195252), -- Sealed Dark Crystal Shield Fragment
(22110, 57, 4588, 9352, 0, 700000), -- Adena
(22110, 5287, 1, 1, 1, 32.124084), -- Sealed Dark Crystal breastplate
(22110, 5520, 1, 1, 1, 3689.671908), -- Sealed Dark Crystal Breastplate Pattern
(22110, 5288, 1, 1, 1, 51.405756), -- Sealed Dark Crystal Gaiters
(22110, 5524, 1, 1, 1, 5639.431692), -- Sealed Dark Crystal Gaiters Pattern
(22110, 5293, 1, 1, 1, 19.775148), -- Sealed Tallum Plate Armor
(22110, 5521, 1, 1, 1, 2603.591412), -- Sealed Tallum Plate Armor Pattern
(22110, 1866, 2, 6, 2, 81731.108396), -- Suede
(22110, 1871, 1, 3, 2, 163461.843594), -- Charcoal
(22110, 5220, 1, 1, 2, 19615.28688), -- Metal Hardener
(22110, 1885, 1, 1, 2, 40865.554198), -- High-Grade Suede
(22110, 4041, 1, 1, 2, 4264.160348), -- Mold Hardener
(22110, 10302, 1, 1, 2, 1961.528688), -- Transformation Sealbook: Heretic
(22110, 1344, 100, 300, 2, 61298.517896), -- Mithril Arrow
-- Spiked Stakato Sorcerer
(22111, 1808, 1, 1, -1, 3980), -- Recipe: Soulshot (S-Grade)
(22111, 5480, 1, 1, -1, 40184), -- Sealed Leather Armor of Nightmare Fabric
(22111, 3036, 1, 1, -1, 3980), -- Recipe: Spiritshot S
(22111, 57, 4417, 9013, 0, 700000), -- Adena
(22111, 212, 1, 1, 1, 5.863495), -- Dasparion's Staff
(22111, 5543, 1, 1, 1, 1407.188301), -- Dasparion's Staff Head
(22111, 2504, 1, 1, 1, 5.863495), -- Meteor Shower
(22111, 5532, 1, 1, 1, 1394.047339), -- Meteor Shower Head
(22111, 7894, 1, 1, 1, 5.863495), -- Spiritual Eye
(22111, 8341, 1, 1, 1, 1392.263041), -- Spiritual Eye Piece
(22111, 7899, 1, 1, 1, 5.863495), -- Destroyer Hammer
(22111, 8346, 1, 1, 1, 1394.047339), -- Hammer Piece of Destroyer
(22111, 1870, 1, 3, 2, 165326.624265), -- Coal
(22111, 1865, 1, 3, 2, 110217.533712), -- Varnish
(22111, 1874, 1, 1, 2, 22043.442003), -- Oriharukon Ore
(22111, 4043, 1, 1, 2, 11021.88285), -- Asofe
(22111, 4039, 1, 1, 2, 11021.88285), -- Mold Glue
(22111, 5272, 1, 1, 2, 146.958438), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22111, 8731, 1, 1, 2, 3061.526226), -- Life Stone - Level 70
(22111, 8741, 1, 1, 2, 765.543405), -- Mid-Grade Life Stone - Level 70
(22111, 8751, 1, 1, 2, 76.392492), -- High-Grade Life Stone - Level 70
(22111, 8761, 1, 1, 2, 15.213759), -- Top-Grade Life Stone - Level 70
-- Cannibalistic Stakato Follower 
(22112, 5478, 1, 1, -1, 95559), -- Sealed Dark Crystal Leather Armor Pattern
(22112, 729, 1, 1, -1, 1263), -- Scroll: Enchant Weapon (A-Grade)
(22112, 4041, 1, 1, -1, 98816), -- Mold Hardener
(22112, 57, 5608, 11431, 0, 700000), -- Adena
(22112, 5289, 1, 1, 1, 104.68714), -- Sealed Dark Crystal Helmet
(22112, 5525, 1, 1, 1, 10810.753104), -- Sealed Dark Crystal Helmet Design
(22112, 5292, 1, 1, 1, 149.60544), -- Sealed Dark Crystal Shield
(22112, 5494, 1, 1, 1, 14687.55074), -- Sealed Dark Crystal Shield Fragment
(22112, 5294, 1, 1, 1, 104.68714), -- Sealed Tallum Helmet
(22112, 5526, 1, 1, 1, 10810.716436), -- Sealed Tallum Helm Design
(22112, 1872, 4, 12, 2, 116552.36797), -- Animal Bone
(22112, 1867, 7, 21, 2, 62161.43756), -- Animal Skin
(22112, 1881, 1, 1, 2, 93241.828885), -- Coarse Bone Powder
(22112, 1875, 1, 1, 2, 46621.07817), -- Stone of Purity
(22112, 4041, 1, 1, 2, 6080.83935), -- Mold Hardener
(22112, 10302, 1, 1, 2, 2797.448065), -- Transformation Sealbook: Heretic
-- Cannibalistic Stakato Leader
(22113, 1875, 1, 3, -1, 475374), -- Stone of Purity
(22113, 5480, 1, 1, -1, 63993), -- Sealed Leather Armor of Nightmare Fabric
(22113, 3957, 1, 1, -1, 6338), -- Recipe: Blessed Spiritshot S
(22113, 57, 7035, 14354, 0, 700000), -- Adena
(22113, 80, 1, 1, 1, 12.449766), -- Tallum Blade
(22113, 5548, 1, 1, 1, 2985.33326), -- Tallum Blade Edge
(22113, 150, 1, 1, 1, 12.449766), -- Elemental Sword
(22113, 5547, 1, 1, 1, 2985.33326), -- Elemental Sword Edge
(22113, 7884, 1, 1, 1, 12.449766), -- Infernal Master
(22113, 8331, 1, 1, 1, 2993.984182), -- Infernal Master Blade
(22113, 1872, 5, 15, 2, 63826.407948), -- Animal Bone
(22113, 1867, 9, 27, 2, 35459.351972), -- Animal Skin
(22113, 1881, 1, 1, 2, 63826.407948), -- Coarse Bone Powder
(22113, 1875, 1, 1, 2, 31913.381308), -- Stone of Purity
(22113, 4041, 1, 1, 2, 4162.738316), -- Mold Hardener
(22113, 5282, 1, 1, 2, 212.8008), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22113, 8731, 1, 1, 2, 4432.285996), -- Life Stone - Level 70
(22113, 8741, 1, 1, 2, 1107.982832), -- Mid-Grade Life Stone - Level 70
(22113, 8751, 1, 1, 2, 110.656416), -- High-Grade Life Stone - Level 70
(22113, 8761, 1, 1, 2, 21.989416), -- Top-Grade Life Stone - Level 70
(22113, 1344, 40, 120, 2, 149593.997048), -- Mithril Arrow
-- Cannibalistic Stakato Leader 
(22114, 5481, 1, 1, -1, 42968), -- Sealed Majestic Leather Armor Fabric
(22114, 5157, 1, 1, -1, 4256), -- Recipe: Soulshot (S) Compressed Package (100%)
(22114, 5487, 1, 1, -1, 43119), -- Sealed Robe of Nightmare Fabric
(22114, 57, 4723, 9638, 0, 700000), -- Adena
(22114, 80, 1, 1, 1, 8.360235), -- Tallum Blade
(22114, 5548, 1, 1, 1, 2004.70335), -- Tallum Blade Edge
(22114, 150, 1, 1, 1, 8.360235), -- Elemental Sword
(22114, 5547, 1, 1, 1, 2004.70335), -- Elemental Sword Edge
(22114, 7884, 1, 1, 1, 8.360235), -- Infernal Master
(22114, 8331, 1, 1, 1, 2010.512595), -- Infernal Master Blade
(22114, 1873, 1, 1, 2, 141423.43495), -- Silver Nugget
(22114, 1868, 3, 9, 2, 117853.00954), -- Thread
(22114, 1876, 1, 1, 2, 70711.717475), -- Mithril Ore
(22114, 1895, 1, 1, 2, 101016.86532), -- Metallic Fiber
(22114, 4042, 1, 1, 2, 5892.826975), -- Enria
(22114, 1808, 1, 1, 2, 157.08322), -- Recipe: Soulshot (S-Grade)
(22114, 8731, 1, 1, 2, 3273.596655), -- Life Stone - Level 70
(22114, 8741, 1, 1, 2, 818.509475), -- Mid-Grade Life Stone - Level 70
(22114, 8751, 1, 1, 2, 81.630325), -- High-Grade Life Stone - Level 70
(22114, 8761, 1, 1, 2, 16.326065), -- Top-Grade Life Stone - Level 70
-- Spiked Stakato Soldier
(22115, 4041, 1, 1, -1, 68518), -- Mold Hardener
(22115, 1875, 1, 1, -1, 525307), -- Stone of Purity
(22115, 5488, 1, 1, -1, 35483), -- Sealed Majestic Robe Fabric
(22115, 57, 3877, 7938, 0, 700000), -- Adena
(22115, 80, 1, 1, 1, 6.879042), -- Tallum Blade
(22115, 5548, 1, 1, 1, 1649.52762), -- Tallum Blade Edge
(22115, 150, 1, 1, 1, 6.879042), -- Elemental Sword
(22115, 5547, 1, 1, 1, 1649.52762), -- Elemental Sword Edge
(22115, 7884, 1, 1, 1, 6.879042), -- Infernal Master
(22115, 8331, 1, 1, 1, 1654.307634), -- Infernal Master Blade
(22115, 1872, 1, 3, 2, 193959.679287), -- Animal Bone
(22115, 1867, 1, 3, 2, 129306.452858), -- Animal Skin
(22115, 1881, 1, 1, 2, 38792.031482), -- Coarse Bone Powder
(22115, 1875, 1, 1, 2, 19396.015741), -- Stone of Purity
(22115, 4041, 1, 1, 2, 2529.748793), -- Mold Hardener
(22115, 3036, 1, 1, 2, 129.09321), -- Recipe: Spiritshot S
(22115, 8732, 1, 1, 2, 2424.561733), -- Life Stone - Level 76
(22115, 8742, 1, 1, 2, 606.259964), -- Mid-Grade Life Stone - Level 76
(22115, 8752, 1, 1, 2, 60.721621), -- High-Grade Life Stone - Level 76
(22115, 1344, 40, 120, 2, 90918.435311), -- Mithril Arrow
-- Spiked Stakato Drone
(22116, 5162, 1, 1, -1, 3604), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22116, 5495, 1, 1, -1, 123133), -- Sealed Shield of Nightmare Fragment
(22116, 5167, 1, 1, -1, 3604), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22116, 57, 3997, 8166, 0, 700000), -- Adena
(22116, 269, 1, 1, 1, 21.23823), -- Blood Tornado
(22116, 5539, 1, 1, 1, 5048.76177), -- Blood Tornado Edge
(22116, 1866, 1, 1, 2, 221782.717825), -- Suede
(22116, 1871, 1, 3, 2, 166337.1473), -- Charcoal
(22116, 5220, 1, 1, 2, 13307.0415), -- Metal Hardener
(22116, 1885, 1, 1, 2, 27723.003125), -- High-Grade Suede
(22116, 4041, 1, 1, 2, 2892.778275), -- Mold Hardener
(22116, 3957, 1, 1, 2, 147.710775), -- Recipe: Blessed Spiritshot S
(22116, 8732, 1, 1, 2, 2772.08245), -- Life Stone - Level 76
(22116, 8742, 1, 1, 2, 693.238475), -- Mid-Grade Life Stone - Level 76
(22116, 8752, 1, 1, 2, 69.280275), -- High-Grade Life Stone - Level 76
-- Spiked Stakato Captain
(22117, 5502, 1, 1, -1, 140851), -- Sealed Boots of Nightmare Lining
(22117, 5550, 1, 1, -1, 111197), -- Durable Metal Plate
(22117, 4043, 1, 1, -1, 277993), -- Asofe
(22117, 57, 4113, 8395, 0, 700000), -- Adena
(22117, 98, 1, 1, 1, 21.841446), -- Halberd
(22117, 5542, 1, 1, 1, 5192.158554), -- Halberd Edge
(22117, 1869, 2, 6, 2, 76982.53098), -- Iron Ore
(22117, 1864, 5, 15, 2, 61586.024784), -- Stem
(22117, 1880, 1, 1, 2, 30793.012392), -- Steel
(22117, 5550, 1, 1, 2, 4105.819104), -- Durable Metal Plate
(22117, 4043, 1, 1, 2, 10264.232316), -- Asofe
(22117, 5157, 1, 1, 2, 136.902696), -- Recipe: Soulshot (S) Compressed Package (100%)
(22117, 8732, 1, 1, 2, 2566.13694), -- Life Stone - Level 76
(22117, 8742, 1, 1, 2, 641.613096), -- Mid-Grade Life Stone - Level 76
(22117, 8752, 1, 1, 2, 64.035132), -- High-Grade Life Stone - Level 76
(22117, 1344, 30, 90, 2, 128303.69256), -- Mithril Arrow
-- Spiked Stakato Nurse
(22118, 5503, 1, 1, -1, 197084), -- Sealed Majestic Boots Lining
(22118, 5272, 1, 1, -1, 5186), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22118, 5514, 1, 1, -1, 197084), -- Sealed Gauntlets of Nightmare Design
(22118, 57, 5754, 11742, 0, 700000), -- Adena
(22118, 6326, 1, 1, 1, 71.88352), -- Sealed Majestic Necklace
(22118, 6344, 1, 1, 1, 10525.98864), -- Sealed Majestic Necklace Beads
(22118, 6327, 1, 1, 1, 95.86152), -- Sealed Majestic Earring
(22118, 6342, 1, 1, 1, 16265.31224), -- Sealed Majestic Earring Gemstone
(22118, 6328, 1, 1, 1, 143.76704), -- Sealed Majestic Ring
(22118, 6346, 1, 1, 1, 23377.18704), -- Sealed Majestic Ring Gemstone
(22118, 1867, 4, 12, 2, 79790.512668), -- Animal Skin
(22118, 1872, 1, 3, 2, 212775.129284), -- Animal Bone
(22118, 1882, 1, 1, 2, 106387.350224), -- Leather
(22118, 1894, 1, 1, 2, 16797.934956), -- Crafted Leather
(22118, 4042, 1, 1, 2, 7978.922616), -- Enria
(22118, 959, 1, 1, 2, 19.29762), -- Scroll: Enchant Weapon (S-Grade)
(22118, 8732, 1, 1, 2, 3989.461308), -- Life Stone - Level 76
(22118, 8742, 1, 1, 2, 997.472536), -- Mid-Grade Life Stone - Level 76
(22118, 8752, 1, 1, 2, 99.918788), -- High-Grade Life Stone - Level 76
-- Spiked Stakato Nurse
(22119, 5277, 1, 1, -1, 3838), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22119, 5515, 1, 1, -1, 145843), -- Sealed Majestic Gauntlets Design
(22119, 4042, 1, 1, -1, 143923), -- Enria
(22119, 57, 4258, 8689, 0, 700000), -- Adena
(22119, 6326, 1, 1, 1, 53.19352), -- Sealed Majestic Necklace
(22119, 6344, 1, 1, 1, 7789.18989), -- Sealed Majestic Necklace Beads
(22119, 6327, 1, 1, 1, 70.937145), -- Sealed Majestic Earring
(22119, 6342, 1, 1, 1, 12036.266615), -- Sealed Majestic Earring Gemstone
(22119, 6328, 1, 1, 1, 106.38704), -- Sealed Majestic Ring
(22119, 6346, 1, 1, 1, 17299.02579), -- Sealed Majestic Ring Gemstone
(22119, 1873, 1, 1, 2, 127537.520055), -- Silver Nugget
(22119, 1868, 4, 12, 2, 79710.900345), -- Thread
(22119, 1876, 1, 1, 2, 63768.56127), -- Mithril Ore
(22119, 1895, 1, 1, 2, 91098.115035), -- Metallic Fiber
(22119, 4042, 1, 1, 2, 5313.98052), -- Enria
(22119, 960, 1, 1, 2, 127.602315), -- Scroll: Enchant Armor (S-Grade)
(22119, 8732, 1, 1, 2, 2656.99026), -- Life Stone - Level 76
(22119, 8742, 1, 1, 2, 664.247565), -- Mid-Grade Life Stone - Level 76
(22119, 8752, 1, 1, 2, 66.385005), -- High-Grade Life Stone - Level 76
(22119, 1344, 150, 450, 2, 26570.69763), -- Mithril Arrow
-- Spiked Stakato Baby
(22120, 5522, 1, 1, -1, 56599), -- Sealed Armor of Nightmare Pattern
(22120, 5282, 1, 1, -1, 7387), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22120, 57, 5463, 11149, 0, 700000), -- Adena
(22120, 5313, 1, 1, 1, 75.480768), -- Sealed Gauntlets of Nightmare
(22120, 5514, 1, 1, 1, 8636.519232), -- Sealed Gauntlets of Nightmare Design
(22120, 5314, 1, 1, 1, 75.480768), -- Sealed Boots of Nightmare
(22120, 5502, 1, 1, 1, 8636.519232), -- Sealed Boots of Nightmare Lining
(22120, 5318, 1, 1, 1, 75.480768), -- Sealed Majestic Gauntlets
(22120, 5515, 1, 1, 1, 8636.519232), -- Sealed Majestic Gauntlets Design
(22120, 5319, 1, 1, 1, 75.480768), -- Sealed Majestic Boots
(22120, 5503, 1, 1, 1, 8636.519232), -- Sealed Majestic Boots Lining
(22120, 1869, 2, 6, 2, 113639.63046), -- Iron Ore
(22120, 1870, 2, 6, 2, 90911.63354), -- Coal
(22120, 1871, 3, 9, 2, 75759.75364), -- Charcoal
(22120, 1872, 7, 21, 2, 43291.13602), -- Animal Bone
(22120, 1867, 12, 36, 2, 25253.36926), -- Animal Skin
(22120, 6901, 1, 1, 2, 454.71576), -- Recipe: Shining Arrow (100%)
(22120, 8732, 1, 1, 2, 3787.88144), -- Life Stone - Level 76
(22120, 8742, 1, 1, 2, 946.97036), -- Mid-Grade Life Stone - Level 76
(22120, 8752, 1, 1, 2, 94.90952), -- High-Grade Life Stone - Level 76
-- Spiked Stakato Shaman
(22121, 5523, 1, 1, -1, 29268), -- Sealed Majestic Plate Armor Pattern
(22121, 1808, 1, 1, -1, 3820), -- Recipe: Soulshot (S-Grade)
(22121, 5527, 1, 1, -1, 102753), -- Sealed Helm of Nightmare Design
(22121, 57, 4237, 8649, 0, 700000), -- Adena
(22121, 5326, 1, 1, 1, 24.028472), -- Sealed Robe of Nightmare
(22121, 5487, 1, 1, 1, 3571.971528), -- Sealed Robe of Nightmare Fabric
(22121, 5329, 1, 1, 1, 24.028472), -- Sealed Majestic Robe
(22121, 5488, 1, 1, 1, 3571.971528), -- Sealed Majestic Robe Fabric
(22121, 1864, 4, 12, 2, 113330.646099), -- Stem
(22121, 1869, 2, 6, 2, 90664.422093), -- Iron Ore
(22121, 1878, 1, 1, 2, 181328.844186), -- Braided Hemp
(22121, 1884, 3, 9, 2, 46494.526824), -- Cord
(22121, 4039, 1, 1, 2, 15110.816004), -- Mold Glue
(22121, 959, 1, 1, 2, 18.009378), -- Scroll: Enchant Weapon (S-Grade)
(22121, 1344, 210, 630, 2, 26983.735416), -- Mithril Arrow
-- Monastic Pilgrim
(22122, 6901, 1, 1, -1, 11538), -- Recipe: Shining Arrow (100%)
(22122, 6346, 1, 1, -1, 375658), -- Sealed Majestic Ring Gemstone
(22122, 4040, 1, 1, -1, 230766), -- Mold Lubricant
(22122, 57, 5688, 11612, 0, 700000), -- Adena
(22122, 5313, 1, 1, 1, 78.60414), -- Sealed Gauntlets of Nightmare
(22122, 5514, 1, 1, 1, 8993.89586), -- Sealed Gauntlets of Nightmare Design
(22122, 5314, 1, 1, 1, 78.60414), -- Sealed Boots of Nightmare
(22122, 5502, 1, 1, 1, 8993.89586), -- Sealed Boots of Nightmare Lining
(22122, 5318, 1, 1, 1, 78.60414), -- Sealed Majestic Gauntlets
(22122, 5515, 1, 1, 1, 8993.89586), -- Sealed Majestic Gauntlets Design
(22122, 5319, 1, 1, 1, 78.60414), -- Sealed Majestic Boots
(22122, 5503, 1, 1, 1, 8993.89586), -- Sealed Majestic Boots Lining
(22122, 1865, 4, 12, 2, 88756.297632), -- Varnish
(22122, 1870, 7, 21, 2, 47336.565568), -- Coal
(22122, 1879, 1, 1, 2, 118341.41392), -- Cokes
(22122, 1875, 1, 1, 2, 47336.565568), -- Stone of Purity
(22122, 4040, 1, 1, 2, 14200.843168), -- Mold Lubricant
(22122, 960, 1, 1, 2, 284.314144), -- Scroll: Enchant Armor (S-Grade)
-- Monastic Crusader
(22123, 6342, 1, 1, -1, 264323), -- Sealed Majestic Earring Gemstone
(22123, 5282, 1, 1, -1, 5186), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22123, 6344, 1, 1, -1, 171056), -- Sealed Majestic Necklace Beads
(22123, 57, 5741, 11756, 0, 700000), -- Adena
(22123, 5312, 1, 1, 1, 70.676736), -- Sealed Helm of Nightmare
(22123, 5527, 1, 1, 1, 8585.043092), -- Sealed Helm of Nightmare Design
(22123, 5315, 1, 1, 1, 101.003172), -- Sealed Shield of Nightmare
(22123, 5495, 1, 1, 1, 10903.557172), -- Sealed Shield of Nightmare Fragment
(22123, 5317, 1, 1, 1, 70.676736), -- Sealed Majestic Circlet
(22123, 5528, 1, 1, 1, 8585.043092), -- Sealed Majestic Circlet Design
(22123, 1895, 1, 1, 2, 153870.98702), -- Metallic Fiber
(22123, 4040, 1, 1, 2, 10771.05218), -- Mold Lubricant
(22123, 4042, 1, 1, 2, 8975.74493), -- Enria
(22123, 4043, 1, 1, 2, 17951.68769), -- Asofe
(22123, 6901, 1, 1, 2, 538.49326), -- Recipe: Shining Arrow (100%)
(22123, 8732, 1, 1, 2, 4487.97138), -- Life Stone - Level 76
(22123, 8742, 1, 1, 2, 1121.89393), -- Mid-Grade Life Stone - Level 76
(22123, 8752, 1, 1, 2, 112.16961), -- High-Grade Life Stone - Level 76
-- Solina Brother
(22124, 4040, 1, 1, -1, 185092), -- Mold Lubricant
(22124, 5480, 1, 1, -1, 41527), -- Sealed Leather Armor of Nightmare Fabric
(22124, 1808, 1, 1, -1, 4113), -- Recipe: Soulshot (S-Grade)
(22124, 57, 4553, 9324, 0, 700000), -- Adena
(22124, 6326, 1, 1, 1, 57.008416), -- Sealed Majestic Necklace
(22124, 6344, 1, 1, 1, 8347.809612), -- Sealed Majestic Necklace Beads
(22124, 6327, 1, 1, 1, 76.024566), -- Sealed Majestic Earring
(22124, 6342, 1, 1, 1, 12899.475242), -- Sealed Majestic Earring Gemstone
(22124, 6328, 1, 1, 1, 114.016832), -- Sealed Majestic Ring
(22124, 6346, 1, 1, 1, 18539.665332), -- Sealed Majestic Ring Gemstone
(22124, 1873, 1, 1, 2, 151870.17367), -- Silver Nugget
(22124, 1868, 3, 9, 2, 126558.162579), -- Thread
(22124, 1876, 1, 1, 2, 75935.086835), -- Mithril Ore
(22124, 1895, 1, 1, 2, 108478.357465), -- Metallic Fiber
(22124, 4042, 1, 1, 2, 6327.884468), -- Enria
(22124, 959, 1, 1, 2, 15.143008), -- Scroll: Enchant Weapon (S-Grade)
(22124, 8732, 1, 1, 2, 3163.942234), -- Life Stone - Level 76
(22124, 8742, 1, 1, 2, 791.222168), -- Mid-Grade Life Stone - Level 76
(22124, 8752, 1, 1, 2, 79.027573), -- High-Grade Life Stone - Level 76
-- Solina Lay Brother
(22125, 5481, 1, 1, -1, 41603), -- Sealed Majestic Leather Armor Fabric
(22125, 3036, 1, 1, -1, 4121), -- Recipe: Spiritshot S
(22125, 5487, 1, 1, -1, 41751), -- Sealed Robe of Nightmare Fabric
(22125, 57, 4561, 9343, 0, 700000), -- Adena
(22125, 305, 1, 1, 1, 16.50384), -- Tallum Glaive
(22125, 5541, 1, 1, 1, 4693.49616), -- Tallum Glaive Edge
(22125, 1895, 1, 1, 2, 195619.46802), -- Metallic Fiber
(22125, 4040, 1, 1, 2, 13693.41884), -- Mold Lubricant
(22125, 4042, 1, 1, 2, 11411.01982), -- Enria
(22125, 4043, 1, 1, 2, 22822.28346), -- Asofe
(22125, 960, 1, 1, 2, 273.80986), -- Scroll: Enchant Armor (S-Grade)
-- Silent Seeker
(22126, 5550, 1, 1, -1, 126630), -- Durable Metal Plate
(22126, 4043, 1, 1, -1, 316576), -- Asofe
(22126, 5488, 1, 1, -1, 42767), -- Sealed Majestic Robe Fabric
(22126, 57, 4672, 9570, 0, 700000), -- Adena
(22126, 5311, 1, 1, 1, 19.914443), -- Sealed Armor of Nightmare
(22126, 5522, 1, 1, 1, 2985.585557), -- Sealed Armor of Nightmare Pattern
(22126, 5316, 1, 1, 1, 19.914443), -- Sealed Majestic Plate Armor
(22126, 5523, 1, 1, 1, 2985.585557), -- Sealed Majestic Plate Armor Pattern
(22126, 1868, 3, 9, 2, 129877.243314), -- Thread
(22126, 1873, 1, 1, 2, 155852.765614), -- Silver Nugget
(22126, 5549, 1, 1, 2, 38963.28345), -- Metallic Thread
(22126, 1889, 1, 1, 2, 25975.5223), -- Compound Braid
(22126, 4044, 1, 1, 2, 12987.76115), -- Thons
(22126, 6901, 1, 1, 2, 389.540788), -- Recipe: Shining Arrow (100%)
(22126, 8732, 1, 1, 2, 3247.032334), -- Life Stone - Level 76
(22126, 8742, 1, 1, 2, 811.85013), -- Mid-Grade Life Stone - Level 76
(22126, 8752, 1, 1, 2, 81.00092), -- High-Grade Life Stone - Level 76
-- Silent Brother
(22127, 4041, 1, 1, -1, 82682), -- Mold Hardener
(22127, 6688, 1, 1, -1, 20552), -- Forgotten Blade Edge
(22127, 6901, 1, 1, -1, 9508), -- Recipe: Shining Arrow (100%)
(22127, 57, 4689, 9571, 0, 700000), -- Adena
(22127, 164, 1, 1, 1, 4.231956), -- Elysian
(22127, 5533, 1, 1, 1, 1203.875538), -- Elysian Head
(22127, 213, 1, 1, 1, 4.231956), -- Branch of the Mother Tree
(22127, 5544, 1, 1, 1, 1202.687112); -- Branch of the Mother Tree Head

INSERT INTO `droplist` VALUES
(22127, 7895, 1, 1, 1, 4.231956), -- Flaming Dragon Skull
(22127, 8342, 1, 1, 1, 1203.875538), -- Flaming Dragon Skull Piece
(22127, 7902, 1, 1, 1, 4.231956), -- Doom Crusher
(22127, 8349, 1, 1, 1, 1203.633988), -- Doom Crusher Head
(22127, 1872, 4, 12, 2, 97522.48209), -- Animal Bone
(22127, 1867, 1, 3, 2, 260060.112147), -- Animal Skin
(22127, 1881, 1, 1, 2, 78017.985672), -- Coarse Bone Powder
(22127, 1875, 1, 1, 2, 39008.992836), -- Stone of Purity
(22127, 4041, 1, 1, 2, 5087.920926), -- Mold Hardener
(22127, 959, 1, 1, 2, 23.506329), -- Scroll: Enchant Weapon (S-Grade)
-- Monastic Guardian
(22128, 1875, 1, 1, -1, 186510), -- Stone of Purity
(22128, 4041, 1, 1, -1, 24327), -- Mold Hardener
(22128, 6695, 1, 1, -1, 5933), -- Demon Splinter Blade
(22128, 57, 1380, 2816, 0, 700000), -- Adena
(22128, 289, 1, 1, 1, 4.9805), -- Soul Bow
(22128, 5534, 1, 1, 1, 1418.0195), -- Soul Bow Stave
(22128, 1869, 1, 1, 2, 172163.363792), -- Iron Ore
(22128, 1864, 1, 3, 2, 172163.363792), -- Stem
(22128, 1880, 1, 1, 2, 17216.26245), -- Steel
(22128, 5550, 1, 1, 2, 2295.50166), -- Durable Metal Plate
(22128, 4043, 1, 1, 2, 5738.75415), -- Asofe
(22128, 960, 1, 1, 2, 68.754156), -- Scroll: Enchant Armor (S-Grade)
-- Warrior Monk
(22129, 6698, 1, 1, -1, 196115), -- Sealed Tateossian Earring Part
(22129, 6699, 1, 1, -1, 217615), -- Sealed Tateossian Ring Gem
(22129, 6700, 1, 1, -1, 119528), -- Sealed Tateossian Necklace Chain
(22129, 57, 4923, 10046, 0, 700000), -- Adena
(22129, 5320, 1, 1, 1, 27.915456), -- Sealed Leather Armor of Nightmare
(22129, 5480, 1, 1, 1, 4136.084544), -- Sealed Leather Armor of Nightmare Fabric
(22129, 5323, 1, 1, 1, 27.915456), -- Sealed Majestic Leather Armor
(22129, 5481, 1, 1, 1, 4136.084544), -- Sealed Majestic Leather Armor Fabric
(22129, 1895, 1, 1, 2, 210655.145883), -- Metallic Fiber
(22129, 4040, 1, 1, 2, 14745.789201), -- Mold Lubricant
(22129, 4042, 1, 1, 2, 12288.289169), -- Enria
(22129, 4043, 1, 1, 2, 24576.315335), -- Asofe
(22129, 6901, 1, 1, 2, 737.460412), -- Recipe: Shining Arrow (100%)
-- Divine Advocate
(22130, 959, 1, 1, -1, 587), -- Scroll: Enchant Weapon (S-Grade)
(22130, 1894, 1, 1, -1, 514911), -- Crafted Leather
(22130, 4039, 1, 1, -1, 489165), -- Mold Glue
(22130, 57, 7234, 14769, 0, 700000), -- Adena
(22130, 236, 1, 1, 1, 26.12492), -- Soul Separator
(22130, 5537, 1, 1, 1, 7433.87508), -- Soul Separator Head
(22130, 1868, 3, 9, 2, 200682.8368), -- Thread
(22130, 1873, 2, 6, 2, 60204.85104), -- Silver Nugget
(22130, 5549, 1, 1, 2, 60204.85104), -- Metallic Thread
(22130, 1889, 1, 1, 2, 40136.56736), -- Compound Braid
(22130, 4044, 1, 1, 2, 20068.28368), -- Thons
(22130, 959, 1, 1, 2, 24.038516), -- Scroll: Enchant Weapon (S-Grade)
(22130, 8732, 1, 1, 2, 5017.07092), -- Life Stone - Level 76
(22130, 8742, 1, 1, 2, 1254.26773), -- Mid-Grade Life Stone - Level 76
(22130, 8752, 1, 1, 2, 125.232914), -- High-Grade Life Stone - Level 76
-- Pilgrim of Light
(22131, 6704, 1, 1, -1, 224973), -- Sealed Imperial Crusader Boots Design
(22131, 6705, 1, 1, -1, 220361), -- Sealed Imperial Crusader Shield Part
(22131, 6706, 1, 1, -1, 256322), -- Sealed Imperial Crusader Helmet Pattern
(22131, 57, 7789, 15902, 0, 700000), -- Adena
(22131, 5326, 1, 1, 1, 44.178043), -- Sealed Robe of Nightmare
(22131, 5487, 1, 1, 1, 6567.321957), -- Sealed Robe of Nightmare Fabric
(22131, 5329, 1, 1, 1, 44.178043), -- Sealed Majestic Robe
(22131, 5488, 1, 1, 1, 6567.321957), -- Sealed Majestic Robe Fabric
(22131, 1894, 1, 1, 2, 40941.960885), -- Crafted Leather
(22131, 4039, 1, 1, 2, 38894.946915), -- Mold Glue
(22131, 4041, 1, 1, 2, 10146.468525), -- Mold Hardener
(22131, 4044, 1, 1, 2, 38894.946915), -- Thons
(22131, 960, 1, 1, 2, 466.67676), -- Scroll: Enchant Armor (S-Grade)
-- Judge of Light
(22132, 6701, 1, 1, -1, 54702), -- Sealed Imperial Crusader Breastplate Part
(22132, 6702, 1, 1, -1, 70417), -- Sealed Imperial Crusader Gaiters Pattern
(22132, 13099, 1, 1, -1, 143288), -- Sealed Arcana Sigil Piece
(22132, 57, 5056, 10350, 0, 700000), -- Adena
(22132, 81, 1, 1, 1, 6.097221), -- Dragon Slayer
(22132, 5529, 1, 1, 1, 1734.025932), -- Dragon Slayer Edge
(22132, 151, 1, 1, 1, 6.097221), -- Sword of Miracles
(22132, 5546, 1, 1, 1, 1904.661864), -- Sword of Miracles Edge
(22132, 2500, 1, 1, 1, 6.097221), -- Dark Legion's Edge
(22132, 5545, 1, 1, 1, 1734.020541), -- Dark Legion's Edge Blade
(22132, 1872, 4, 12, 2, 70252.962048), -- Animal Bone
(22132, 1867, 1, 3, 2, 187341.582592), -- Animal Skin
(22132, 1881, 1, 1, 2, 56202.509824), -- Coarse Bone Powder
(22132, 1875, 1, 1, 2, 28101.254912), -- Stone of Purity
(22132, 4041, 1, 1, 2, 3665.502976), -- Mold Hardener
(22132, 6901, 1, 1, 2, 421.608192), -- Recipe: Shining Arrow (100%)
(22132, 8732, 1, 1, 2, 3512.700672), -- Life Stone - Level 76
(22132, 8742, 1, 1, 2, 878.262784), -- Mid-Grade Life Stone - Level 76
(22132, 8752, 1, 1, 2, 87.616), -- High-Grade Life Stone - Level 76
-- Guardian of the Grail
(22133, 6688, 1, 1, -1, 8634), -- Forgotten Blade Edge
(22133, 6689, 1, 1, -1, 8471), -- Basalt Battlehammer Head
(22133, 6690, 1, 1, -1, 8650), -- Imperial Staff Head
(22133, 57, 1966, 4024, 0, 700000), -- Adena
(22133, 236, 1, 1, 1, 7.10906), -- Soul Separator
(22133, 5537, 1, 1, 1, 2022.89094), -- Soul Separator Head
(22133, 1872, 1, 3, 2, 163866.451562), -- Animal Bone
(22133, 1867, 1, 3, 2, 109244.192902), -- Animal Skin
(22133, 1881, 1, 1, 2, 32773.355196), -- Coarse Bone Powder
(22133, 1875, 1, 1, 2, 16386.677598), -- Stone of Purity
(22133, 4041, 1, 1, 2, 2137.265784), -- Mold Hardener
(22133, 959, 1, 1, 2, 10.056958), -- Scroll: Enchant Weapon (S-Grade)
-- Guardian of the Holy Land
(22134, 6707, 1, 1, -1, 51815), -- Sealed Draconic Leather Armor Part
(22134, 6708, 1, 1, -1, 148895), -- Sealed Draconic Leather Gloves Fabric
(22134, 6709, 1, 1, -1, 148895), -- Sealed Draconic Leather Boots Design
(22134, 57, 5142, 10540, 0, 700000), -- Adena
(22134, 81, 1, 1, 1, 6.205797), -- Dragon Slayer
(22134, 5529, 1, 1, 1, 1764.904524), -- Dragon Slayer Edge
(22134, 151, 1, 1, 1, 6.205797), -- Sword of Miracles
(22134, 5546, 1, 1, 1, 1938.579048), -- Sword of Miracles Edge
(22134, 2500, 1, 1, 1, 6.205797), -- Dark Legion's Edge
(22134, 5545, 1, 1, 1, 1764.899037), -- Dark Legion's Edge Blade
(22134, 1894, 1, 1, 2, 27096.807465), -- Crafted Leather
(22134, 4039, 1, 1, 2, 25742.022735), -- Mold Glue
(22134, 4041, 1, 1, 2, 6715.284225), -- Mold Hardener
(22134, 4044, 1, 1, 2, 25742.022735), -- Thons
(22134, 960, 1, 1, 2, 308.86284), -- Scroll: Enchant Armor (S-Grade)
-- Beholder of Light
(22135, 6691, 1, 1, -1, 36433), -- Angel Slayer Blade
(22135, 6693, 1, 1, -1, 37093), -- Dragon Hunter Axe Blade
(22135, 6694, 1, 1, -1, 37093), -- Saint Spear Blade
(22135, 57, 8288, 16989, 0, 700000), -- Adena
(22135, 6326, 1, 1, 1, 103.83096), -- Sealed Majestic Necklace
(22135, 6344, 1, 1, 1, 15204.08997), -- Sealed Majestic Necklace Beads
(22135, 6327, 1, 1, 1, 138.465585), -- Sealed Majestic Earring
(22135, 6342, 1, 1, 1, 23494.160895), -- Sealed Majestic Earring Gemstone
(22135, 6328, 1, 1, 1, 207.66192), -- Sealed Majestic Ring
(22135, 6346, 1, 1, 1, 33766.79067), -- Sealed Majestic Ring Gemstone
(22135, 1895, 1, 1, 2, 222271.746968), -- Metallic Fiber
(22135, 4040, 1, 1, 2, 15559.142312), -- Mold Lubricant
(22135, 4042, 1, 1, 2, 12965.761412), -- Enria
(22135, 4043, 1, 1, 2, 25931.808596), -- Asofe
(22135, 6901, 1, 1, 2, 777.871384), -- Recipe: Shining Arrow (100%)
(22135, 8732, 1, 1, 2, 6483.023592), -- Life Stone - Level 76
(22135, 8742, 1, 1, 2, 1620.613012), -- Mid-Grade Life Stone - Level 76
(22135, 8752, 1, 1, 2, 162.032724), -- High-Grade Life Stone - Level 76
-- Penance Guard
(22137, 4041, 1, 1, -1, 8702), -- Mold Hardener
(22137, 4040, 1, 1, -1, 20015), -- Mold Lubricant
(22137, 5480, 1, 1, -1, 4491), -- Sealed Leather Armor of Nightmare Fabric
(22137, 57, 492, 1008, 0, 700000), -- Adena
(22137, 11976, 1, 1, 1, 32.87466), -- Common Item - Tallum Glaive
(22137, 5541, 1, 1, 1, 507.12534), -- Tallum Glaive Edge
(22137, 1871, 1, 1, 2, 52787.883876), -- Charcoal
(22137, 1866, 1, 1, 2, 35191.922584), -- Suede
(22137, 1877, 1, 1, 2, 2111.527964), -- Adamantite Nugget
(22137, 4041, 1, 1, 2, 458.966144), -- Mold Hardener
(22137, 4040, 1, 1, 2, 1055.685176), -- Mold Lubricant
(22137, 960, 1, 1, 2, 21.120008), -- Scroll: Enchant Armor (S-Grade)
(22137, 1344, 10, 30, 2, 65984.894248), -- Mithril Arrow
-- Chapel Guard
(22138, 6901, 1, 1, -1, 1106), -- Recipe: Shining Arrow (100%)
(22138, 6688, 1, 1, -1, 2390), -- Forgotten Blade Edge
(22138, 57, 545, 1113, 0, 700000), -- Adena
(22138, 12263, 1, 1, 1, 42.807391), -- Common Item - Sealed Armor of Nightmare
(22138, 5522, 1, 1, 1, 347.692609), -- Sealed Armor of Nightmare Pattern
(22138, 12262, 1, 1, 1, 42.807391), -- Common Item - Sealed Majestic Plate Armor
(22138, 5523, 1, 1, 1, 347.692609), -- Sealed Majestic Plate Armor Pattern
(22138, 1873, 1, 1, 2, 16333.443952), -- Silver Nugget
(22138, 1868, 1, 1, 2, 81667.559824), -- Thread
(22138, 1876, 1, 1, 2, 8166.806992), -- Mithril Ore
(22138, 1895, 1, 1, 2, 11666.74568), -- Metallic Fiber
(22138, 4042, 1, 1, 2, 680.638096), -- Enria
(22138, 6901, 1, 1, 2, 40.80768), -- Recipe: Shining Arrow (100%)
(22138, 8732, 1, 1, 2, 340.234032), -- Life Stone - Level 76
(22138, 8742, 1, 1, 2, 85.016), -- Mid-Grade Life Stone - Level 76
(22138, 8752, 1, 1, 2, 8.5016), -- High-Grade Life Stone - Level 76
(22138, 1344, 10, 30, 2, 51042.246144), -- Mithril Arrow
-- Old Aristocrat's Soldier
(22139, 5515, 1, 1, -1, 155316), -- Sealed Majestic Gauntlets Design
(22139, 3957, 1, 1, -1, 4087), -- Recipe: Blessed Spiritshot S
(22139, 5522, 1, 1, -1, 31318), -- Sealed Armor of Nightmare Pattern
(22139, 57, 4525, 9265, 0, 700000), -- Adena
(22139, 305, 1, 1, 1, 16.370688), -- Tallum Glaive
(22139, 5541, 1, 1, 1, 4655.629312), -- Tallum Glaive Edge
(22139, 1894, 1, 1, 2, 19856.989196), -- Crafted Leather
(22139, 4039, 1, 1, 2, 18863.869188), -- Mold Glue
(22139, 4041, 1, 1, 2, 4921.063644), -- Mold Hardener
(22139, 4044, 1, 1, 2, 18863.869188), -- Thons
(22139, 959, 1, 1, 2, 22.476312), -- Scroll: Enchant Weapon (S-Grade)
(22139, 1344, 20, 60, 2, 353699.732472), -- Mithril Arrow
-- Zombie Worker
(22140, 5488, 1, 1, -1, 40326), -- Sealed Majestic Robe Fabric
(22140, 5495, 1, 1, -1, 135982), -- Sealed Shield of Nightmare Fragment
(22140, 730, 1, 1, -1, 7463), -- Scroll: Enchant Armor (A-Grade)
(22140, 57, 4415, 9013, 0, 700000), -- Adena
(22140, 5313, 1, 1, 1, 61.00539), -- Sealed Gauntlets of Nightmare
(22140, 5514, 1, 1, 1, 6980.24461), -- Sealed Gauntlets of Nightmare Design
(22140, 5314, 1, 1, 1, 61.00539), -- Sealed Boots of Nightmare
(22140, 5502, 1, 1, 1, 6980.24461), -- Sealed Boots of Nightmare Lining
(22140, 5318, 1, 1, 1, 61.00539), -- Sealed Majestic Gauntlets
(22140, 5515, 1, 1, 1, 6980.24461), -- Sealed Majestic Gauntlets Design
(22140, 5319, 1, 1, 1, 61.00539), -- Sealed Majestic Boots
(22140, 5503, 1, 1, 1, 6980.24461), -- Sealed Majestic Boots Lining
(22140, 1871, 1, 3, 2, 157452.774742), -- Charcoal
(22140, 1866, 2, 6, 2, 78726.551302), -- Suede
(22140, 1877, 1, 1, 2, 18894.359198), -- Adamantite Nugget
(22140, 4041, 1, 1, 2, 4107.455136), -- Mold Hardener
(22140, 4040, 1, 1, 2, 9447.015668), -- Mold Lubricant
(22140, 960, 1, 1, 2, 188.848512), -- Scroll: Enchant Armor (S-Grade)
(22140, 1344, 100, 300, 2, 59044.995442), -- Mithril Arrow
-- Forgotten Victim
(22141, 5488, 1, 1, -1, 41711), -- Sealed Majestic Robe Fabric
(22141, 730, 1, 1, -1, 7719), -- Scroll: Enchant Armor (A-Grade)
(22141, 5480, 1, 1, -1, 41564), -- Sealed Leather Armor of Nightmare Fabric
(22141, 57, 4566, 9322, 0, 700000), -- Adena
(22141, 5312, 1, 1, 1, 56.102592), -- Sealed Helm of Nightmare
(22141, 5527, 1, 1, 1, 6814.734199), -- Sealed Helm of Nightmare Design
(22141, 5315, 1, 1, 1, 80.175459), -- Sealed Shield of Nightmare
(22141, 5495, 1, 1, 1, 8655.150959), -- Sealed Shield of Nightmare Fragment
(22141, 5317, 1, 1, 1, 56.102592), -- Sealed Majestic Circlet
(22141, 5528, 1, 1, 1, 6814.734199), -- Sealed Majestic Circlet Design
(22141, 1865, 1, 3, 2, 114002.34504), -- Varnish
(22141, 1870, 2, 6, 2, 85501.75878), -- Coal
(22141, 1879, 1, 1, 2, 57001.17252), -- Cokes
(22141, 1875, 1, 1, 2, 22800.469008), -- Stone of Purity
(22141, 4040, 1, 1, 2, 6840.207277), -- Mold Lubricant
(22141, 6901, 1, 1, 2, 341.860571), -- Recipe: Shining Arrow (100%)
(22141, 8732, 1, 1, 2, 2850.058626), -- Life Stone - Level 76
(22141, 8742, 1, 1, 2, 712.681093), -- Mid-Grade Life Stone - Level 76
(22141, 8752, 1, 1, 2, 71.234822), -- High-Grade Life Stone - Level 76
(22141, 1344, 100, 300, 2, 42751.212263), -- Mithril Arrow
-- Triol's Layperson
(22142, 5220, 1, 1, -1, 372700), -- Metal Hardener
(22142, 5495, 1, 1, -1, 141485), -- Sealed Shield of Nightmare Fragment
(22142, 3957, 1, 1, -1, 4141), -- Recipe: Blessed Spiritshot S
(22142, 57, 4584, 9387, 0, 700000), -- Adena
(22142, 5312, 1, 1, 1, 56.43456), -- Sealed Helm of Nightmare
(22142, 5527, 1, 1, 1, 6855.05807), -- Sealed Helm of Nightmare Design
(22142, 5315, 1, 1, 1, 80.64987), -- Sealed Shield of Nightmare
(22142, 5495, 1, 1, 1, 8706.36487), -- Sealed Shield of Nightmare Fragment
(22142, 5317, 1, 1, 1, 56.43456), -- Sealed Majestic Circlet
(22142, 5528, 1, 1, 1, 6855.05807), -- Sealed Majestic Circlet Design
(22142, 1866, 1, 3, 2, 127418.849625), -- Suede
(22142, 1871, 1, 3, 2, 286692.289197), -- Charcoal
(22142, 5220, 1, 1, 2, 22935.148014), -- Metal Hardener
(22142, 1885, 1, 1, 2, 47782.129839), -- High-Grade Suede
(22142, 4041, 1, 1, 2, 4986.050823), -- Mold Hardener
(22142, 959, 1, 1, 2, 22.532502), -- Scroll: Enchant Weapon (S-Grade)
-- Triol's Believer
(22143, 5502, 1, 1, -1, 182996), -- Sealed Boots of Nightmare Lining
(22143, 5157, 1, 1, -1, 4816), -- Recipe: Soulshot (S) Compressed Package (100%)
(22143, 5503, 1, 1, -1, 182996), -- Sealed Majestic Boots Lining
(22143, 57, 5331, 10918, 0, 700000), -- Adena
(22143, 5313, 1, 1, 1, 73.812948), -- Sealed Gauntlets of Nightmare
(22143, 5514, 1, 1, 1, 8445.687052), -- Sealed Gauntlets of Nightmare Design
(22143, 5314, 1, 1, 1, 73.812948), -- Sealed Boots of Nightmare
(22143, 5502, 1, 1, 1, 8445.687052), -- Sealed Boots of Nightmare Lining
(22143, 5318, 1, 1, 1, 73.812948), -- Sealed Majestic Gauntlets
(22143, 5515, 1, 1, 1, 8445.687052), -- Sealed Majestic Gauntlets Design
(22143, 5319, 1, 1, 1, 73.812948), -- Sealed Majestic Boots
(22143, 5503, 1, 1, 1, 8445.687052), -- Sealed Majestic Boots Lining
(22143, 1869, 1, 3, 2, 222260.435307), -- Iron Ore
(22143, 1864, 4, 12, 2, 166695.204726), -- Stem
(22143, 1880, 1, 1, 2, 66677.984487), -- Steel
(22143, 5550, 1, 1, 2, 8890.495335), -- Durable Metal Plate
(22143, 4043, 1, 1, 2, 22225.994829), -- Asofe
(22143, 960, 1, 1, 2, 266.885316), -- Scroll: Enchant Armor (S-Grade)
-- Resurrected Temple Knight
(22144, 1894, 1, 1, -1, 331138), -- Crafted Leather
(22144, 4042, 1, 1, -1, 157290), -- Enria
(22144, 5514, 1, 1, -1, 159389), -- Sealed Gauntlets of Nightmare Design
(22144, 57, 4643, 9510, 0, 700000), -- Adena
(22144, 81, 1, 1, 1, 5.600712), -- Dragon Slayer
(22144, 5529, 1, 1, 1, 1592.820704), -- Dragon Slayer Edge
(22144, 151, 1, 1, 1, 5.600712), -- Sword of Miracles
(22144, 5546, 1, 1, 1, 1749.561408), -- Sword of Miracles Edge
(22144, 2500, 1, 1, 1, 5.600712), -- Dark Legion's Edge
(22144, 5545, 1, 1, 1, 1592.815752), -- Dark Legion's Edge Blade
(22144, 1867, 5, 15, 2, 46461.21233), -- Animal Skin
(22144, 1872, 1, 3, 2, 154871.254096), -- Animal Bone
(22144, 1882, 1, 1, 2, 77435.627048), -- Leather
(22144, 1894, 1, 1, 2, 12226.85048), -- Crafted Leather
(22144, 4042, 1, 1, 2, 5807.753978), -- Enria
(22144, 6901, 1, 1, 2, 348.28495), -- Recipe: Shining Arrow (100%)
(22144, 8732, 1, 1, 2, 2903.876989), -- Life Stone - Level 76
(22144, 8742, 1, 1, 2, 726.071684), -- Mid-Grade Life Stone - Level 76
(22144, 8752, 1, 1, 2, 72.525219), -- High-Grade Life Stone - Level 76
(22144, 1344, 40, 120, 2, 108893.543226), -- Mithril Arrow
-- Ritual Sacrifice
(22145, 5162, 1, 1, -1, 4026), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22145, 5515, 1, 1, -1, 152986), -- Sealed Majestic Gauntlets Design
(22145, 5167, 1, 1, -1, 4026), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22145, 57, 4457, 9126, 0, 700000), -- Adena
(22145, 6326, 1, 1, 1, 55.79944), -- Sealed Majestic Necklace
(22145, 6344, 1, 1, 1, 8170.77783), -- Sealed Majestic Necklace Beads
(22145, 6327, 1, 1, 1, 74.412315), -- Sealed Majestic Earring
(22145, 6342, 1, 1, 1, 12625.916405), -- Sealed Majestic Earring Gemstone
(22145, 6328, 1, 1, 1, 111.59888), -- Sealed Majestic Ring
(22145, 6346, 1, 1, 1, 18146.49513), -- Sealed Majestic Ring Gemstone
(22145, 1868, 4, 12, 2, 119450.477082), -- Thread
(22145, 1873, 1, 1, 2, 191120.495751), -- Silver Nugget
(22145, 5549, 1, 1, 2, 47780.012446), -- Metallic Thread
(22145, 1889, 1, 1, 2, 31853.638942), -- Compound Braid
(22145, 4044, 1, 1, 2, 15926.819471), -- Thons
(22145, 959, 1, 1, 2, 19.176581), -- Scroll: Enchant Weapon (S-Grade)
(22145, 1344, 150, 450, 2, 39816.379727), -- Mithril Arrow
-- Triol's Priest
(22146, 6688, 1, 1, -1, 21727), -- Forgotten Blade Edge
(22146, 960, 1, 1, -1, 4021), -- Scroll: Enchant Armor (S-Grade)
(22146, 57, 4956, 10114, 0, 700000), -- Adena
(22146, 5326, 1, 1, 1, 28.104492), -- Sealed Robe of Nightmare
(22146, 5487, 1, 1, 1, 4177.895508), -- Sealed Robe of Nightmare Fabric
(22146, 5329, 1, 1, 1, 28.104492), -- Sealed Majestic Robe
(22146, 5488, 1, 1, 1, 4177.895508), -- Sealed Majestic Robe Fabric
(22146, 1864, 4, 12, 2, 154647.031884), -- Stem
(22146, 1865, 2, 6, 2, 123717.800382), -- Varnish
(22146, 1866, 3, 9, 2, 68731.917018), -- Suede
(22146, 1873, 4, 12, 2, 30929.231502), -- Silver Nugget
(22146, 1868, 10, 30, 2, 58913.134185), -- Thread
(22146, 960, 1, 1, 2, 247.885029), -- Scroll: Enchant Armor (S-Grade)
-- Ritual Offering
(22147, 6689, 1, 1, -1, 21231), -- Basalt Battlehammer Head
(22147, 6901, 1, 1, -1, 10011), -- Recipe: Shining Arrow (100%)
(22147, 57, 4937, 10077, 0, 700000), -- Adena
(22147, 6326, 1, 1, 1, 61.667744), -- Sealed Majestic Necklace
(22147, 6344, 1, 1, 1, 9030.080508), -- Sealed Majestic Necklace Beads
(22147, 6327, 1, 1, 1, 82.238094), -- Sealed Majestic Earring
(22147, 6342, 1, 1, 1, 13953.756178), -- Sealed Majestic Earring Gemstone
(22147, 6328, 1, 1, 1, 123.335488), -- Sealed Majestic Ring
(22147, 6346, 1, 1, 1, 20054.921988), -- Sealed Majestic Ring Gemstone
(22147, 1869, 2, 6, 2, 73927.297044), -- Iron Ore
(22147, 1870, 3, 9, 2, 61606.259472), -- Coal
(22147, 1871, 3, 9, 2, 52805.110116), -- Charcoal
(22147, 1872, 8, 24, 2, 30803.129736), -- Animal Bone
(22147, 1867, 13, 39, 2, 18253.838808), -- Animal Skin
(22147, 6901, 1, 1, 2, 369.70614), -- Recipe: Shining Arrow (100%)
(22147, 8732, 1, 1, 2, 3080.170092), -- Life Stone - Level 76
(22147, 8742, 1, 1, 2, 770.131824), -- Mid-Grade Life Stone - Level 76
(22147, 8752, 1, 1, 2, 77.156064), -- High-Grade Life Stone - Level 76
(22147, 1344, 40, 120, 2, 115511.200704), -- Mithril Arrow
-- Triol's Believer
(22148, 5480, 1, 1, -1, 35322), -- Sealed Leather Armor of Nightmare Fabric
(22148, 1808, 1, 1, -1, 3499), -- Recipe: Soulshot (S-Grade)
(22148, 5481, 1, 1, -1, 35322), -- Sealed Majestic Leather Armor Fabric
(22148, 57, 3873, 7932, 0, 700000), -- Adena
(22148, 270, 1, 1, 1, 14.012), -- Dragon Grinder
(22148, 5538, 1, 1, 1, 3985.988), -- Dragon Grinder Edge
(22148, 1869, 2, 6, 2, 121103.620604), -- Iron Ore
(22148, 1870, 2, 6, 2, 96882.747768), -- Coal
(22148, 1871, 3, 9, 2, 80735.62314), -- Charcoal
(22148, 1872, 7, 21, 2, 46134.801132), -- Animal Bone
(22148, 1867, 12, 36, 2, 26911.87438), -- Animal Skin
(22148, 959, 1, 1, 2, 19.332976), -- Scroll: Enchant Weapon (S-Grade)
-- Ritual Offering
(22149, 4042, 1, 1, -1, 157290), -- Enria
(22149, 1876, 1, 3, -1, 943743), -- Mithril Ore
(22149, 5487, 1, 1, -1, 42498), -- Sealed Robe of Nightmare Fabric
(22149, 57, 4643, 9510, 0, 700000), -- Adena
(22149, 81, 1, 1, 1, 5.600712), -- Dragon Slayer
(22149, 5529, 1, 1, 1, 1592.820704), -- Dragon Slayer Edge
(22149, 151, 1, 1, 1, 5.600712), -- Sword of Miracles
(22149, 5546, 1, 1, 1, 1749.561408), -- Sword of Miracles Edge
(22149, 2500, 1, 1, 1, 5.600712), -- Dark Legion's Edge
(22149, 5545, 1, 1, 1, 1592.815752), -- Dark Legion's Edge Blade
(22149, 1873, 1, 1, 2, 139383.463769), -- Silver Nugget
(22149, 1868, 4, 12, 2, 87114.610551), -- Thread
(22149, 1876, 1, 1, 2, 69691.514666), -- Mithril Ore
(22149, 1895, 1, 1, 2, 99559.492853), -- Metallic Fiber
(22149, 4042, 1, 1, 2, 5807.553816), -- Enria
(22149, 960, 1, 1, 2, 139.454277), -- Scroll: Enchant Armor (S-Grade)
(22149, 8732, 1, 1, 2, 2903.776908), -- Life Stone - Level 76
(22149, 8742, 1, 1, 2, 725.944227), -- Mid-Grade Life Stone - Level 76
(22149, 8752, 1, 1, 2, 72.550979), -- High-Grade Life Stone - Level 76
(22149, 1344, 150, 450, 2, 29038.637954), -- Mithril Arrow
-- Triol's Believer
(22150, 6901, 1, 1, -1, 8287), -- Recipe: Shining Arrow (100%)
(22150, 6688, 1, 1, -1, 17911), -- Forgotten Blade Edge
(22150, 57, 4087, 8341, 0, 700000), -- Adena
(22150, 81, 1, 1, 1, 4.917588), -- Dragon Slayer
(22150, 5529, 1, 1, 1, 1398.542896), -- Dragon Slayer Edge
(22150, 151, 1, 1, 1, 4.917588), -- Sword of Miracles
(22150, 5546, 1, 1, 1, 1536.165792), -- Sword of Miracles Edge
(22150, 2500, 1, 1, 1, 4.917588), -- Dark Legion's Edge
(22150, 5545, 1, 1, 1, 1398.538548), -- Dark Legion's Edge Blade
(22150, 1873, 2, 6, 2, 50994.245276), -- Silver Nugget
(22150, 1868, 3, 9, 2, 169981.136034), -- Thread
(22150, 1876, 1, 1, 2, 101988.490552), -- Mithril Ore
(22150, 1895, 1, 1, 2, 145698.253078), -- Metallic Fiber
(22150, 4042, 1, 1, 2, 8499.200103), -- Enria
(22150, 6901, 1, 1, 2, 509.674957), -- Recipe: Shining Arrow (100%)
-- Triol's Priest
(22151, 6689, 1, 1, -1, 24744), -- Basalt Battlehammer Head
(22151, 959, 1, 1, -1, 467), -- Scroll: Enchant Weapon (S-Grade)
(22151, 5549, 1, 3, -1, 583380), -- Metallic Thread
(22151, 57, 5752, 11742, 0, 700000), -- Adena
(22151, 81, 1, 1, 1, 6.923982), -- Dragon Slayer
(22151, 5529, 1, 1, 1, 1969.153544), -- Dragon Slayer Edge
(22151, 151, 1, 1, 1, 6.923982), -- Sword of Miracles
(22151, 5546, 1, 1, 1, 2162.927088), -- Sword of Miracles Edge
(22151, 2500, 1, 1, 1, 6.923982), -- Dark Legion's Edge
(22151, 5545, 1, 1, 1, 1969.147422), -- Dark Legion's Edge Blade
(22151, 1868, 3, 9, 2, 239335.088495), -- Thread
(22151, 1873, 2, 6, 2, 71800.572025), -- Silver Nugget
(22151, 5549, 1, 1, 2, 71800.572025), -- Metallic Thread
(22151, 1889, 1, 1, 2, 47867.199605), -- Compound Braid
(22151, 4044, 1, 1, 2, 23933.37242), -- Thons
(22151, 959, 1, 1, 2, 28.19543), -- Scroll: Enchant Weapon (S-Grade)
-- Temple Guard
(22152, 1889, 1, 1, -1, 684135), -- Compound Braid
(22152, 6690, 1, 1, -1, 22223), -- Imperial Staff Head
(22152, 6901, 1, 1, -1, 10262), -- Recipe: Shining Arrow (100%)
(22152, 57, 5060, 10326, 0, 700000), -- Adena
(22152, 236, 1, 1, 1, 18.269934), -- Soul Separator
(22152, 5537, 1, 1, 1, 5198.730066), -- Soul Separator Head
(22152, 1868, 4, 12, 2, 94726.51379), -- Thread
(22152, 1873, 1, 1, 2, 151562.90619), -- Silver Nugget
(22152, 5549, 1, 1, 2, 37890.605516), -- Metallic Thread
(22152, 1889, 1, 1, 2, 25260.242302), -- Compound Braid
(22152, 4044, 1, 1, 2, 12630.363214), -- Thons
(22152, 960, 1, 1, 2, 151.531438), -- Scroll: Enchant Armor (S-Grade)
(22152, 8732, 1, 1, 2, 3157.469772), -- Life Stone - Level 76
(22152, 8742, 1, 1, 2, 789.609506), -- Mid-Grade Life Stone - Level 76
(22152, 8752, 1, 1, 2, 78.912538), -- High-Grade Life Stone - Level 76
(22152, 1344, 30, 90, 2, 157877.845734), -- Mithril Arrow
-- Temple Guard Captain
(22153, 6691, 1, 1, -1, 21445), -- Angel Slayer Blade
(22153, 6901, 1, 1, -1, 9921), -- Recipe: Shining Arrow (100%)
(22153, 6693, 1, 1, -1, 21833), -- Dragon Hunter Axe Blade
(22153, 57, 4892, 9983, 0, 700000), -- Adena
(22153, 81, 1, 1, 1, 5.886855), -- Dragon Slayer
(22153, 5529, 1, 1, 1, 1674.19866), -- Dragon Slayer Edge
(22153, 151, 1, 1, 1, 5.886855), -- Sword of Miracles
(22153, 5546, 1, 1, 1, 1838.94732), -- Sword of Miracles Edge
(22153, 2500, 1, 1, 1, 5.886855), -- Dark Legion's Edge
(22153, 5545, 1, 1, 1, 1674.193455), -- Dark Legion's Edge Blade
(22153, 1868, 4, 12, 2, 91581.045832), -- Thread
(22153, 1873, 1, 1, 2, 146529.486024), -- Silver Nugget
(22153, 5549, 1, 1, 2, 36632.137372), -- Metallic Thread
(22153, 1889, 1, 1, 2, 24421.581004), -- Compound Braid
(22153, 4044, 1, 1, 2, 12210.556368), -- Thons
(22153, 6901, 1, 1, 2, 366.185576), -- Recipe: Shining Arrow (100%)
(22153, 8732, 1, 1, 2, 3052.639092), -- Life Stone - Level 76
(22153, 8742, 1, 1, 2, 763.27684), -- Mid-Grade Life Stone - Level 76
(22153, 8752, 1, 1, 2, 76.327684), -- High-Grade Life Stone - Level 76
(22153, 1344, 30, 90, 2, 152634.764208), -- Mithril Arrow
-- Ritual Sacrifice
(22154, 960, 1, 1, -1, 4004), -- Scroll: Enchant Armor (S-Grade)
(22154, 1895, 1, 7, -1, 715000), -- Metallic Fiber
(22154, 4042, 1, 1, -1, 166833), -- Enria
(22154, 57, 4935, 10074, 0, 700000), -- Adena
(22154, 6326, 1, 1, 1, 61.662048), -- Sealed Majestic Necklace
(22154, 6344, 1, 1, 1, 9029.246436), -- Sealed Majestic Necklace Beads
(22154, 6327, 1, 1, 1, 82.230498), -- Sealed Majestic Earring
(22154, 6342, 1, 1, 1, 13952.467326), -- Sealed Majestic Earring Gemstone
(22154, 6328, 1, 1, 1, 123.324096), -- Sealed Majestic Ring
(22154, 6346, 1, 1, 1, 20053.069596), -- Sealed Majestic Ring Gemstone
(22154, 1873, 3, 9, 2, 35200.033875), -- Silver Nugget
(22154, 1868, 4, 12, 2, 132000.960873), -- Thread
(22154, 1876, 1, 1, 2, 105600.578106), -- Mithril Ore
(22154, 1895, 1, 1, 2, 150858.172929), -- Metallic Fiber
(22154, 4042, 1, 1, 2, 8800.127589), -- Enria
(22154, 959, 1, 1, 2, 20.965164), -- Scroll: Enchant Weapon (S-Grade)
(22154, 1344, 150, 450, 2, 44000.161464), -- Mithril Arrow
-- Triol's High Priest
(22155, 6704, 1, 1, -1, 203748), -- Sealed Imperial Crusader Boots Design
(22155, 6705, 1, 1, -1, 199571), -- Sealed Imperial Crusader Shield Part
(22155, 6706, 1, 1, -1, 232140), -- Sealed Imperial Crusader Helmet Pattern
(22155, 57, 7054, 14402, 0, 700000), -- Adena
(22155, 5326, 1, 1, 1, 40.011816), -- Sealed Robe of Nightmare
(22155, 5487, 1, 1, 1, 5947.988184), -- Sealed Robe of Nightmare Fabric
(22155, 5329, 1, 1, 1, 40.011816), -- Sealed Majestic Robe
(22155, 5488, 1, 1, 1, 5947.988184), -- Sealed Majestic Robe Fabric
(22155, 1868, 15, 45, 2, 58708.665), -- Thread
(22155, 1873, 2, 6, 2, 88062.9975), -- Silver Nugget
(22155, 5549, 1, 1, 2, 88062.9975), -- Metallic Thread
(22155, 1889, 1, 1, 2, 58708.665), -- Compound Braid
(22155, 4044, 1, 1, 2, 29354.3325), -- Thons
(22155, 960, 1, 1, 2, 352.3425), -- Scroll: Enchant Armor (S-Grade)
-- Triol's Priest
(22156, 6688, 1, 1, -1, 28190), -- Forgotten Blade Edge
(22156, 6689, 1, 1, -1, 27659), -- Basalt Battlehammer Head
(22156, 13099, 1, 1, -1, 181883), -- Sealed Arcana Sigil Piece
(22156, 57, 6418, 13138, 0, 700000), -- Adena
(22156, 6326, 1, 1, 1, 80.337808), -- Sealed Majestic Necklace
(22156, 6344, 1, 1, 1, 11763.960006), -- Sealed Majestic Necklace Beads
(22156, 6327, 1, 1, 1, 107.135883), -- Sealed Majestic Earring
(22156, 6342, 1, 1, 1, 18178.290821), -- Sealed Majestic Earring Gemstone
(22156, 6328, 1, 1, 1, 160.675616), -- Sealed Majestic Ring
(22156, 6346, 1, 1, 1, 26126.599866), -- Sealed Majestic Ring Gemstone
(22156, 1868, 3, 9, 2, 178350.969123), -- Thread
(22156, 1873, 2, 6, 2, 53505.394263), -- Silver Nugget
(22156, 5549, 1, 1, 2, 53505.394263), -- Metallic Thread
(22156, 1889, 1, 1, 2, 35670.262842), -- Compound Braid
(22156, 4044, 1, 1, 2, 17835.131421), -- Thons
(22156, 6901, 1, 1, 2, 534.88485), -- Recipe: Shining Arrow (100%)
(22156, 8732, 1, 1, 2, 4458.869127), -- Life Stone - Level 76
(22156, 8742, 1, 1, 2, 1114.63101), -- Mid-Grade Life Stone - Level 76
(22156, 8752, 1, 1, 2, 111.463101), -- High-Grade Life Stone - Level 76
-- Triol's Priest
(22157, 959, 1, 1, -1, 500), -- Scroll: Enchant Weapon (S-Grade)
(22157, 1894, 1, 1, -1, 438256), -- Crafted Leather
(22157, 4039, 1, 1, -1, 416344), -- Mold Glue
(22157, 57, 6157, 12570, 0, 700000), -- Adena
(22157, 6326, 1, 1, 1, 76.940144), -- Sealed Majestic Necklace
(22157, 6344, 1, 1, 1, 11266.436058), -- Sealed Majestic Necklace Beads
(22157, 6327, 1, 1, 1, 102.604869), -- Sealed Majestic Earring
(22157, 6342, 1, 1, 1, 17409.490603), -- Sealed Majestic Earring Gemstone
(22157, 6328, 1, 1, 1, 153.880288), -- Sealed Majestic Ring
(22157, 6346, 1, 1, 1, 25021.648038), -- Sealed Majestic Ring Gemstone
(22157, 1873, 2, 6, 2, 76863.419325), -- Silver Nugget
(22157, 1868, 15, 45, 2, 51242.27955), -- Thread
(22157, 1876, 1, 1, 2, 153726.507375), -- Mithril Ore
(22157, 1895, 3, 9, 2, 36601.580925), -- Metallic Fiber
(22157, 4042, 1, 1, 2, 12810.40425), -- Enria
(22157, 959, 1, 1, 2, 30.808575), -- Scroll: Enchant Weapon (S-Grade)
-- Triol's Believer
(22158, 960, 1, 1, -1, 5096), -- Scroll: Enchant Armor (S-Grade)
(22158, 4040, 1, 1, -1, 254792), -- Mold Lubricant
(22158, 1877, 1, 1, -1, 509585), -- Adamantite Nugget
(22158, 57, 6280, 12821, 0, 700000), -- Adena
(22158, 5313, 1, 1, 1, 86.787288), -- Sealed Gauntlets of Nightmare
(22158, 5514, 1, 1, 1, 9930.212712), -- Sealed Gauntlets of Nightmare Design
(22158, 5314, 1, 1, 1, 86.787288), -- Sealed Boots of Nightmare
(22158, 5502, 1, 1, 1, 9930.212712), -- Sealed Boots of Nightmare Lining
(22158, 5318, 1, 1, 1, 86.787288), -- Sealed Majestic Gauntlets
(22158, 5515, 1, 1, 1, 9930.212712), -- Sealed Majestic Gauntlets Design
(22158, 5319, 1, 1, 1, 86.787288), -- Sealed Majestic Boots
(22158, 5503, 1, 1, 1, 9930.212712), -- Sealed Majestic Boots Lining
(22158, 1871, 1, 3, 2, 261325.428096), -- Charcoal
(22158, 1866, 1, 3, 2, 116144.68128), -- Suede
(22158, 1877, 1, 1, 2, 20906.084544), -- Adamantite Nugget
(22158, 4041, 1, 1, 2, 4544.691648), -- Mold Hardener
(22158, 4040, 1, 1, 2, 10452.832704), -- Mold Lubricant
(22158, 960, 1, 1, 2, 209.148864), -- Scroll: Enchant Armor (S-Grade)
(22158, 8732, 1, 1, 2, 4355.242176), -- Life Stone - Level 76
(22158, 8742, 1, 1, 2, 1088.915328), -- Mid-Grade Life Stone - Level 76
(22158, 8752, 1, 1, 2, 108.97536), -- High-Grade Life Stone - Level 76
-- Triol's High Priest
(22159, 6701, 1, 1, -1, 77997), -- Sealed Imperial Crusader Breastplate Part
(22159, 6702, 1, 1, -1, 100403), -- Sealed Imperial Crusader Gaiters Pattern
(22159, 6703, 1, 1, -1, 208583), -- Sealed Imperial Crusader Gauntlets Design
(22159, 57, 7209, 14758, 0, 700000), -- Adena
(22159, 5326, 1, 1, 1, 40.96066), -- Sealed Robe of Nightmare
(22159, 5487, 1, 1, 1, 6089.03934), -- Sealed Robe of Nightmare Fabric
(22159, 5329, 1, 1, 1, 40.96066), -- Sealed Majestic Robe
(22159, 5488, 1, 1, 1, 6089.03934), -- Sealed Majestic Robe Fabric
(22159, 1867, 4, 12, 2, 100169.913572), -- Animal Skin
(22159, 1872, 7, 21, 2, 53423.932222), -- Animal Bone
(22159, 1882, 1, 1, 2, 133559.993178), -- Leather
(22159, 1894, 1, 1, 2, 21088.300148), -- Crafted Leather
(22159, 4042, 1, 1, 2, 10016.926308), -- Enria
(22159, 6901, 1, 1, 2, 601.054608), -- Recipe: Shining Arrow (100%)
(22159, 8732, 1, 1, 2, 5008.463154), -- Life Stone - Level 76
(22159, 8742, 1, 1, 2, 1252.1971), -- Mid-Grade Life Stone - Level 76
(22159, 8752, 1, 1, 2, 125.21971), -- High-Grade Life Stone - Level 76
-- Triol's Priest
(22160, 6691, 1, 1, -1, 28190), -- Angel Slayer Blade
(22160, 6693, 1, 1, -1, 28701), -- Dragon Hunter Axe Blade
(22160, 6694, 1, 1, -1, 28701), -- Saint Spear Blade
(22160, 57, 6418, 13138, 0, 700000), -- Adena
(22160, 6326, 1, 1, 1, 80.337808), -- Sealed Majestic Necklace
(22160, 6344, 1, 1, 1, 11763.960006), -- Sealed Majestic Necklace Beads
(22160, 6327, 1, 1, 1, 107.135883), -- Sealed Majestic Earring
(22160, 6342, 1, 1, 1, 18178.290821), -- Sealed Majestic Earring Gemstone
(22160, 6328, 1, 1, 1, 160.675616), -- Sealed Majestic Ring
(22160, 6346, 1, 1, 1, 26126.599866), -- Sealed Majestic Ring Gemstone
(22160, 1895, 1, 1, 2, 275170.017875), -- Metallic Fiber
(22160, 4040, 1, 1, 2, 19262.034875), -- Mold Lubricant
(22160, 4042, 1, 1, 2, 16051.638625), -- Enria
(22160, 4043, 1, 1, 2, 32103.27725), -- Asofe
(22160, 959, 1, 1, 2, 38.031375), -- Scroll: Enchant Weapon (S-Grade)
-- Ritual Sacrifice
(22161, 959, 1, 1, -1, 591), -- Scroll: Enchant Weapon (S-Grade)
(22161, 1894, 1, 1, -1, 518308), -- Crafted Leather
(22161, 4039, 1, 1, -1, 492392), -- Mold Glue
(22161, 57, 7282, 14866, 0, 700000), -- Adena
(22161, 5312, 1, 1, 1, 89.471616), -- Sealed Helm of Nightmare
(22161, 5527, 1, 1, 1, 10868.041202), -- Sealed Helm of Nightmare Design
(22161, 5315, 1, 1, 1, 127.862682), -- Sealed Shield of Nightmare
(22161, 5495, 1, 1, 1, 13803.111682), -- Sealed Shield of Nightmare Fragment
(22161, 5317, 1, 1, 1, 89.471616), -- Sealed Majestic Circlet
(22161, 5528, 1, 1, 1, 10868.041202), -- Sealed Majestic Circlet Design
(22161, 1873, 3, 9, 2, 36361.320543), -- Silver Nugget
(22161, 1868, 4, 12, 2, 136354.827489), -- Thread
(22161, 1876, 1, 1, 2, 109083.961629), -- Mithril Ore
(22161, 1895, 1, 1, 2, 155834.017389), -- Metallic Fiber
(22161, 4042, 1, 1, 2, 9090.454683), -- Enria
(22161, 960, 1, 1, 2, 218.206782), -- Scroll: Enchant Armor (S-Grade)
(22161, 8732, 1, 1, 2, 4544.978247), -- Life Stone - Level 76
(22161, 8742, 1, 1, 2, 1136.369109), -- Mid-Grade Life Stone - Level 76
(22161, 8752, 1, 1, 2, 113.587092), -- High-Grade Life Stone - Level 76
(22161, 1344, 150, 450, 2, 45451.277037), -- Mithril Arrow
-- Triol's Believer
(22162, 960, 1, 1, -1, 5096), -- Scroll: Enchant Armor (S-Grade)
(22162, 4040, 1, 1, -1, 254792), -- Mold Lubricant
(22162, 1877, 1, 1, -1, 509585), -- Adamantite Nugget
(22162, 57, 6280, 12821, 0, 700000), -- Adena
(22162, 81, 1, 1, 1, 7.559604), -- Dragon Slayer
(22162, 5529, 1, 1, 1, 2149.921968), -- Dragon Slayer Edge
(22162, 151, 1, 1, 1, 7.559604), -- Sword of Miracles
(22162, 5546, 1, 1, 1, 2361.483936), -- Sword of Miracles Edge
(22162, 2500, 1, 1, 1, 7.559604), -- Dark Legion's Edge
(22162, 5545, 1, 1, 1, 2149.915284), -- Dark Legion's Edge Blade
(22162, 1894, 1, 1, 2, 33009.505821), -- Crafted Leather
(22162, 4039, 1, 1, 2, 31359.077712), -- Mold Glue
(22162, 4041, 1, 1, 2, 8180.633527), -- Mold Hardener
(22162, 4044, 1, 1, 2, 31359.077712), -- Thons
(22162, 6901, 1, 1, 2, 940.705228), -- Recipe: Shining Arrow (100%)
-- Triol's High Priest
(22163, 6707, 1, 1, -1, 84077), -- Sealed Draconic Leather Armor Part
(22163, 6708, 1, 1, -1, 241600), -- Sealed Draconic Leather Gloves Fabric
(22163, 6709, 1, 1, -1, 241600), -- Sealed Draconic Leather Boots Design
(22163, 57, 8351, 17094, 0, 700000), -- Adena
(22163, 236, 1, 1, 1, 30.208252), -- Soul Separator
(22163, 5537, 1, 1, 1, 8595.791748), -- Soul Separator Head
(22163, 1871, 4, 12, 2, 87019.345168), -- Charcoal
(22163, 1866, 1, 3, 2, 154701.322048), -- Suede
(22163, 1877, 1, 1, 2, 27846.095424), -- Adamantite Nugget
(22163, 4041, 1, 1, 2, 6053.395712), -- Mold Hardener
(22163, 4040, 1, 1, 2, 13923.047712), -- Mold Lubricant
(22163, 959, 1, 1, 2, 27.914992), -- Scroll: Enchant Weapon (S-Grade)
(22163, 8732, 1, 1, 2, 5801.26988), -- Life Stone - Level 76
(22163, 8742, 1, 1, 2, 1450.391712), -- Mid-Grade Life Stone - Level 76
(22163, 8752, 1, 1, 2, 145.217352), -- High-Grade Life Stone - Level 76
-- Triol's Believer
(22164, 6695, 1, 1, -1, 27659), -- Demon Splinter Blade
(22164, 6696, 1, 1, -1, 28638), -- Heavens Divider Edge
(22164, 6697, 1, 1, -1, 27659), -- Arcana Mace Head
(22164, 57, 6418, 13138, 0, 700000), -- Adena
(22164, 6326, 1, 1, 1, 80.337808), -- Sealed Majestic Necklace
(22164, 6344, 1, 1, 1, 11763.960006), -- Sealed Majestic Necklace Beads
(22164, 6327, 1, 1, 1, 107.135883), -- Sealed Majestic Earring
(22164, 6342, 1, 1, 1, 18178.290821), -- Sealed Majestic Earring Gemstone
(22164, 6328, 1, 1, 1, 160.675616), -- Sealed Majestic Ring
(22164, 6346, 1, 1, 1, 26126.599866), -- Sealed Majestic Ring Gemstone
(22164, 1865, 4, 12, 2, 100322.602443), -- Varnish
(22164, 1870, 7, 21, 2, 53505.244982), -- Coal
(22164, 1879, 1, 1, 2, 133763.112455), -- Cokes
(22164, 1875, 1, 1, 2, 53505.244982), -- Stone of Purity
(22164, 4040, 1, 1, 2, 16051.430507), -- Mold Lubricant
(22164, 960, 1, 1, 2, 321.364631), -- Scroll: Enchant Armor (S-Grade)
-- Triol's Priest
(22165, 959, 1, 1, -1, 500), -- Scroll: Enchant Weapon (S-Grade)
(22165, 1894, 1, 1, -1, 438256), -- Crafted Leather
(22165, 4039, 1, 1, -1, 416344), -- Mold Glue
(22165, 57, 6157, 12570, 0, 700000), -- Adena
(22165, 5313, 1, 1, 1, 85.089144), -- Sealed Gauntlets of Nightmare
(22165, 5514, 1, 1, 1, 9735.910856), -- Sealed Gauntlets of Nightmare Design
(22165, 5314, 1, 1, 1, 85.089144), -- Sealed Boots of Nightmare
(22165, 5502, 1, 1, 1, 9735.910856), -- Sealed Boots of Nightmare Lining
(22165, 5318, 1, 1, 1, 85.089144), -- Sealed Majestic Gauntlets
(22165, 5515, 1, 1, 1, 9735.910856), -- Sealed Majestic Gauntlets Design
(22165, 5319, 1, 1, 1, 85.089144), -- Sealed Majestic Boots
(22165, 5503, 1, 1, 1, 9735.910856), -- Sealed Majestic Boots Lining
(22165, 1866, 1, 3, 2, 113871.65958), -- Suede
(22165, 1871, 1, 3, 2, 256211.67775), -- Charcoal
(22165, 5220, 1, 1, 2, 20496.93422), -- Metal Hardener
(22165, 1885, 1, 1, 2, 42702.09419), -- High-Grade Suede
(22165, 4041, 1, 1, 2, 4456.028885), -- Mold Hardener
(22165, 6901, 1, 1, 2, 512.467725), -- Recipe: Shining Arrow (100%)
(22165, 8732, 1, 1, 2, 4270.12068), -- Life Stone - Level 76
(22165, 8742, 1, 1, 2, 1067.53017), -- Mid-Grade Life Stone - Level 76
(22165, 8752, 1, 1, 2, 106.4868), -- High-Grade Life Stone - Level 76
-- Triol's Believer
(22166, 960, 1, 1, -1, 4996), -- Scroll: Enchant Armor (S-Grade)
(22166, 4040, 1, 1, -1, 249806), -- Mold Lubricant
(22166, 1877, 1, 1, -1, 499612), -- Adamantite Nugget
(22166, 57, 6157, 12570, 0, 700000), -- Adena
(22166, 6326, 1, 1, 1, 76.940144), -- Sealed Majestic Necklace
(22166, 6344, 1, 1, 1, 11266.436058), -- Sealed Majestic Necklace Beads
(22166, 6327, 1, 1, 1, 102.604869), -- Sealed Majestic Earring
(22166, 6342, 1, 1, 1, 17409.490603), -- Sealed Majestic Earring Gemstone
(22166, 6328, 1, 1, 1, 153.880288), -- Sealed Majestic Ring
(22166, 6346, 1, 1, 1, 25021.648038), -- Sealed Majestic Ring Gemstone
(22166, 1869, 7, 21, 2, 51242.314752), -- Iron Ore
(22166, 1864, 4, 12, 2, 192159.392652), -- Stem
(22166, 1880, 1, 1, 2, 76863.828294), -- Steel
(22166, 5550, 1, 1, 2, 10248.320484), -- Durable Metal Plate
(22166, 4043, 1, 1, 2, 25621.157376), -- Asofe
(22166, 959, 1, 1, 2, 30.986442), -- Scroll: Enchant Weapon (S-Grade)
-- Triol's High Priest
(22167, 6710, 1, 1, -1, 243157), -- Sealed Draconic Leather Helmet Pattern
(22167, 6711, 1, 1, -1, 74269), -- Sealed Major Arcana Robe Part
(22167, 6712, 1, 1, -1, 213418), -- Sealed Major Arcana Gloves fabric
(22167, 57, 7370, 15108, 0, 700000), -- Adena
(22167, 5326, 1, 1, 1, 41.909504), -- Sealed Robe of Nightmare
(22167, 5487, 1, 1, 1, 6230.090496), -- Sealed Robe of Nightmare Fabric
(22167, 5329, 1, 1, 1, 41.909504), -- Sealed Majestic Robe
(22167, 5488, 1, 1, 1, 6230.090496), -- Sealed Majestic Robe Fabric
(22167, 1894, 1, 1, 2, 38838.915633), -- Crafted Leather
(22167, 4039, 1, 1, 2, 36897.049607), -- Mold Glue
(22167, 4041, 1, 1, 2, 9625.279945), -- Mold Hardener
(22167, 4044, 1, 1, 2, 36897.049607), -- Thons
(22167, 960, 1, 1, 2, 442.705208), -- Scroll: Enchant Armor (S-Grade)
-- Triol's Priest
(22168, 6698, 1, 1, -1, 256985), -- Sealed Tateossian Earring Part
(22168, 6699, 1, 1, -1, 285159), -- Sealed Tateossian Ring Gem
(22168, 6700, 1, 1, -1, 156628), -- Sealed Tateossian Necklace Chain
(22168, 57, 6433, 13186, 0, 700000), -- Adena
(22168, 5320, 1, 1, 1, 36.580376), -- Sealed Leather Armor of Nightmare
(22168, 5480, 1, 1, 1, 5419.919624), -- Sealed Leather Armor of Nightmare Fabric
(22168, 5323, 1, 1, 1, 36.580376), -- Sealed Majestic Leather Armor
(22168, 5481, 1, 1, 1, 5419.919624), -- Sealed Majestic Leather Armor Fabric
(22168, 1869, 18, 54, 2, 22364.284899), -- Iron Ore
(22168, 1870, 2, 6, 2, 161022.587403), -- Coal
(22168, 1871, 3, 9, 2, 134185.269611), -- Charcoal
(22168, 1872, 7, 21, 2, 76677.485399), -- Animal Bone
(22168, 1867, 12, 36, 2, 44728.569798), -- Animal Skin
(22168, 6901, 1, 1, 2, 804.80289), -- Recipe: Shining Arrow (100%)
-- Ritual Sacrifice
(22169, 1894, 1, 1, -1, 530607), -- Crafted Leather
(22169, 4039, 1, 1, -1, 504077), -- Mold Glue
(22169, 13099, 1, 1, -1, 210896), -- Sealed Arcana Sigil Piece
(22169, 57, 7442, 15233, 0, 700000), -- Adena
(22169, 5311, 1, 1, 1, 31.712036), -- Sealed Armor of Nightmare
(22169, 5522, 1, 1, 1, 4754.287964), -- Sealed Armor of Nightmare Pattern
(22169, 5316, 1, 1, 1, 31.712036), -- Sealed Majestic Plate Armor
(22169, 5523, 1, 1, 1, 4754.287964), -- Sealed Majestic Plate Armor Pattern
(22169, 1864, 5, 15, 2, 111672.574277), -- Stem
(22169, 1865, 3, 9, 2, 93060.537341), -- Varnish
(22169, 1866, 3, 9, 2, 53177.399529), -- Suede
(22169, 1873, 4, 12, 2, 24816.049248), -- Silver Nugget
(22169, 1868, 12, 36, 2, 46530.445001), -- Thread
(22169, 959, 1, 1, 2, 22.217643), -- Scroll: Enchant Weapon (S-Grade)
(22169, 8732, 1, 1, 2, 4653.009234), -- Life Stone - Level 76
(22169, 8742, 1, 1, 2, 1163.428639), -- Mid-Grade Life Stone - Level 76
(22169, 8752, 1, 1, 2, 116.37813), -- High-Grade Life Stone - Level 76
(22169, 1344, 400, 1200, 2, 17448.960958), -- Mithril Arrow
-- Triol's Believer
(22170, 960, 1, 1, -1, 5217), -- Scroll: Enchant Armor (S-Grade)
(22170, 4040, 1, 1, -1, 260839), -- Mold Lubricant
(22170, 1877, 1, 1, -1, 521677), -- Adamantite Nugget
(22170, 57, 6418, 13138, 0, 700000), -- Adena
(22170, 5326, 1, 1, 1, 36.463674), -- Sealed Robe of Nightmare
(22170, 5487, 1, 1, 1, 5420.536326), -- Sealed Robe of Nightmare Fabric
(22170, 5329, 1, 1, 1, 36.463674), -- Sealed Majestic Robe
(22170, 5488, 1, 1, 1, 5420.536326), -- Sealed Majestic Robe Fabric
(22170, 1894, 1, 1, 2, 33792.746547), -- Crafted Leather
(22170, 4039, 1, 1, 2, 32103.178613), -- Mold Glue
(22170, 4041, 1, 1, 2, 8374.709755), -- Mold Hardener
(22170, 4044, 1, 1, 2, 32103.178613), -- Thons
(22170, 960, 1, 1, 2, 385.186472), -- Scroll: Enchant Armor (S-Grade)
-- Triol's High Priest
(22171, 6713, 1, 1, -1, 247201), -- Sealed Major Arcana Boots Design
(22171, 6714, 1, 1, -1, 281647), -- Sealed Major Arcana Circlet Pattern
(22171, 7579, 1, 1, -1, 37962), -- Draconic Bow Shaft
(22171, 57, 8537, 17499, 0, 700000), -- Adena
(22171, 164, 1, 1, 1, 7.727196), -- Elysian
(22171, 5533, 1, 1, 1, 2198.175558), -- Elysian Head
(22171, 213, 1, 1, 1, 7.727196), -- Branch of the Mother Tree
(22171, 5544, 1, 1, 1, 2196.005592), -- Branch of the Mother Tree Head
(22171, 7895, 1, 1, 1, 7.727196), -- Flaming Dragon Skull
(22171, 8342, 1, 1, 1, 2198.175558), -- Flaming Dragon Skull Piece
(22171, 7902, 1, 1, 1, 7.727196), -- Doom Crusher
(22171, 8349, 1, 1, 1, 2197.734508), -- Doom Crusher Head
(22171, 1873, 2, 6, 2, 106843.953105), -- Silver Nugget
(22171, 1868, 15, 45, 2, 71229.30207), -- Thread
(22171, 1876, 1, 1, 2, 213687.90621), -- Mithril Ore
(22171, 1895, 3, 9, 2, 50877.875115), -- Metallic Fiber
(22171, 4042, 1, 1, 2, 17807.556275), -- Enria
(22171, 6901, 1, 1, 2, 1068.407225), -- Recipe: Shining Arrow (100%)
-- Ritual Sacrifice
(22172, 6901, 1, 1, -1, 15122), -- Recipe: Shining Arrow (100%)
(22172, 6714, 1, 1, -1, 245313), -- Sealed Major Arcana Circlet Pattern
(22172, 959, 1, 1, -1, 605), -- Scroll: Enchant Weapon (S-Grade)
(22172, 57, 7442, 15233, 0, 700000), -- Adena
(22172, 5312, 1, 1, 1, 91.595712), -- Sealed Helm of Nightmare
(22172, 5527, 1, 1, 1, 11126.053339), -- Sealed Helm of Nightmare Design
(22172, 5315, 1, 1, 1, 130.898199), -- Sealed Shield of Nightmare
(22172, 5495, 1, 1, 1, 14130.803699), -- Sealed Shield of Nightmare Fragment
(22172, 5317, 1, 1, 1, 91.595712), -- Sealed Majestic Circlet
(22172, 5528, 1, 1, 1, 11126.053339), -- Sealed Majestic Circlet Design
(22172, 1872, 5, 15, 2, 74448.227302), -- Animal Bone
(22172, 1867, 9, 27, 2, 41359.942822), -- Animal Skin
(22172, 1881, 1, 1, 2, 74448.227302), -- Coarse Bone Powder
(22172, 1875, 1, 1, 2, 37223.907262), -- Stone of Purity
(22172, 4041, 1, 1, 2, 4855.507614), -- Mold Hardener
(22172, 959, 1, 1, 2, 22.290012), -- Scroll: Enchant Weapon (S-Grade)
(22172, 8732, 1, 1, 2, 4652.833616), -- Life Stone - Level 76
(22172, 8742, 1, 1, 2, 1163.208404), -- Mid-Grade Life Stone - Level 76
(22172, 8752, 1, 1, 2, 116.403396), -- High-Grade Life Stone - Level 76
(22172, 1344, 40, 120, 2, 174487.45227), -- Mithril Arrow
-- Triol's Priest
(22173, 959, 1, 1, -1, 511), -- Scroll: Enchant Weapon (S-Grade)
(22173, 1894, 1, 1, -1, 448656), -- Crafted Leather
(22173, 4039, 1, 1, -1, 426223), -- Mold Glue
(22173, 57, 6293, 12881, 0, 700000), -- Adena
(22173, 5326, 1, 1, 1, 35.752041), -- Sealed Robe of Nightmare
(22173, 5487, 1, 1, 1, 5314.747959), -- Sealed Robe of Nightmare Fabric
(22173, 5329, 1, 1, 1, 35.752041), -- Sealed Majestic Robe
(22173, 5488, 1, 1, 1, 5314.747959), -- Sealed Majestic Robe Fabric
(22173, 1868, 3, 9, 2, 262291.389312), -- Thread
(22173, 1873, 2, 6, 2, 78687.31706), -- Silver Nugget
(22173, 5549, 1, 1, 2, 78687.31706), -- Metallic Thread
(22173, 1889, 1, 1, 2, 52458.377596), -- Compound Braid
(22173, 4044, 1, 1, 2, 26228.939464), -- Thons
(22173, 960, 1, 1, 2, 314.659508), -- Scroll: Enchant Armor (S-Grade)
-- Triol's Priest
(22174, 960, 1, 1, -1, 5096), -- Scroll: Enchant Armor (S-Grade)
(22174, 4040, 1, 1, -1, 254792), -- Mold Lubricant
(22174, 1877, 1, 1, -1, 509585), -- Adamantite Nugget
(22174, 57, 6280, 12821, 0, 700000), -- Adena
(22174, 5326, 1, 1, 1, 35.618401), -- Sealed Robe of Nightmare
(22174, 5487, 1, 1, 1, 5294.881599), -- Sealed Robe of Nightmare Fabric
(22174, 5329, 1, 1, 1, 35.618401), -- Sealed Majestic Robe
(22174, 5488, 1, 1, 1, 5294.881599), -- Sealed Majestic Robe Fabric
(22174, 1872, 5, 15, 2, 89597.323944), -- Animal Bone
(22174, 1867, 9, 27, 2, 49776.454506), -- Animal Skin
(22174, 1881, 1, 1, 2, 89597.323944), -- Coarse Bone Powder
(22174, 1875, 1, 1, 2, 44798.661972), -- Stone of Purity
(22174, 4041, 1, 1, 2, 5843.133204), -- Mold Hardener
(22174, 6901, 1, 1, 2, 672.171138), -- Recipe: Shining Arrow (100%)
(22174, 1344, 40, 120, 2, 209992.931292), -- Mithril Arrow
-- Andreas' Captain of the Royal Guard
(22175, 6689, 1, 1, -1, 1078), -- Basalt Battlehammer Head
(22175, 960, 1, 1, -1, 203), -- Scroll: Enchant Armor (S-Grade)
(22175, 4042, 1, 1, -1, 8469), -- Enria
(22175, 57, 250, 511, 0, 700000), -- Adena
(22175, 5311, 1, 1, 1, 1.066786), -- Sealed Armor of Nightmare
(22175, 5522, 1, 1, 1, 159.933214), -- Sealed Armor of Nightmare Pattern
(22175, 5316, 1, 1, 1, 1.066786), -- Sealed Majestic Plate Armor
(22175, 5523, 1, 1, 1, 159.933214), -- Sealed Majestic Plate Armor Pattern
(22175, 1873, 1, 1, 2, 12507.628896), -- Silver Nugget
(22175, 1868, 1, 1, 2, 62538.14448), -- Thread
(22175, 1876, 1, 1, 2, 6253.814448), -- Mithril Ore
(22175, 1895, 1, 1, 2, 8934.02064), -- Metallic Fiber
(22175, 4042, 1, 1, 2, 521.120952), -- Enria
(22175, 959, 1, 1, 2, 1.270584), -- Scroll: Enchant Weapon (S-Grade)
-- Andreas' Royal Guards
(22176, 1877, 1, 1, -1, 20325), -- Adamantite Nugget
(22176, 6690, 1, 1, -1, 1100), -- Imperial Staff Head
(22176, 6901, 1, 1, -1, 508), -- Recipe: Shining Arrow (100%)
(22176, 57, 250, 511, 0, 700000), -- Adena
(22176, 5320, 1, 1, 1, 1.421248), -- Sealed Leather Armor of Nightmare
(22176, 5480, 1, 1, 1, 210.578752), -- Sealed Leather Armor of Nightmare Fabric
(22176, 5323, 1, 1, 1, 1.421248), -- Sealed Majestic Leather Armor
(22176, 5481, 1, 1, 1, 210.578752), -- Sealed Majestic Leather Armor Fabric
(22176, 1871, 1, 1, 2, 26801.878152), -- Charcoal
(22176, 1866, 1, 1, 2, 17867.918768), -- Suede
(22176, 1877, 1, 1, 2, 1072.081528), -- Adamantite Nugget
(22176, 4041, 1, 1, 2, 233.029888), -- Mold Hardener
(22176, 4040, 1, 1, 2, 536.000752), -- Mold Lubricant
(22176, 960, 1, 1, 2, 10.723216), -- Scroll: Enchant Armor (S-Grade)
(22176, 1344, 10, 30, 2, 33502.367696), -- Mithril Arrow
-- Andreas' Captain of the Royal Guard
(22188, 1894, 1, 1, -1, 366512), -- Crafted Leather
(22188, 6688, 1, 1, -1, 22578), -- Forgotten Blade Edge
(22188, 6901, 1, 1, -1, 10446), -- Recipe: Shining Arrow (100%)
(22188, 57, 5136, 10528, 0, 700000), -- Adena
(22188, 81, 1, 1, 1, 6.19788), -- Dragon Slayer
(22188, 5529, 1, 1, 1, 1762.65296), -- Dragon Slayer Edge
(22188, 151, 1, 1, 1, 6.19788), -- Sword of Miracles
(22188, 5546, 1, 1, 1, 1936.10592), -- Sword of Miracles Edge
(22188, 2500, 1, 1, 1, 6.19788), -- Dark Legion's Edge
(22188, 5545, 1, 1, 1, 1762.64748), -- Dark Legion's Edge Blade
(22188, 1894, 1, 1, 2, 16915.93334), -- Crafted Leather
(22188, 4039, 1, 1, 2, 16070.0958), -- Mold Glue
(22188, 4041, 1, 1, 2, 4192.22683), -- Mold Hardener
(22188, 4044, 1, 1, 2, 16070.0958), -- Thons
(22188, 959, 1, 1, 2, 19.2687), -- Scroll: Enchant Weapon (S-Grade)
(22188, 8732, 1, 1, 2, 4017.52395), -- Life Stone - Level 76
(22188, 8742, 1, 1, 2, 1004.36639), -- Mid-Grade Life Stone - Level 76
(22188, 8752, 1, 1, 2, 100.48919), -- High-Grade Life Stone - Level 76
-- Andreas' Royal Guards
(22189, 6689, 1, 1, -1, 17862), -- Basalt Battlehammer Head
(22189, 6901, 1, 1, -1, 8422), -- Recipe: Shining Arrow (100%)
(22189, 6690, 1, 1, -1, 18240), -- Imperial Staff Head
(22189, 57, 4145, 8484, 0, 700000), -- Adena
(22189, 164, 1, 1, 1, 3.748404), -- Elysian
(22189, 5533, 1, 1, 1, 1066.318242), -- Elysian Head
(22189, 213, 1, 1, 1, 3.748404), -- Branch of the Mother Tree
(22189, 5544, 1, 1, 1, 1065.265608), -- Branch of the Mother Tree Head
(22189, 7895, 1, 1, 1, 3.748404), -- Flaming Dragon Skull
(22189, 8342, 1, 1, 1, 1066.318242), -- Flaming Dragon Skull Piece
(22189, 7902, 1, 1, 1, 3.748404), -- Doom Crusher
(22189, 8349, 1, 1, 1, 1066.104292), -- Doom Crusher Head
(22189, 1894, 1, 1, 2, 21823.051152), -- Crafted Leather
(22189, 4039, 1, 1, 2, 20731.943408), -- Mold Glue
(22189, 4041, 1, 1, 2, 5408.31208), -- Mold Hardener
(22189, 4044, 1, 1, 2, 20731.943408), -- Thons
(22189, 960, 1, 1, 2, 248.749952), -- Scroll: Enchant Armor (S-Grade)
-- Ritual Sacrifice
(22190, 959, 1, 1, -1, 391), -- Scroll: Enchant Weapon (S-Grade)
(22190, 1895, 1, 5, -1, 931221), -- Metallic Fiber
(22190, 4040, 1, 1, -1, 195556), -- Mold Lubricant
(22190, 57, 4812, 9850, 0, 700000), -- Adena
(22190, 5312, 1, 1, 1, 59.222592), -- Sealed Helm of Nightmare
(22190, 5527, 1, 1, 1, 7193.717949), -- Sealed Helm of Nightmare Design
(22190, 5315, 1, 1, 1, 84.634209), -- Sealed Shield of Nightmare
(22190, 5495, 1, 1, 1, 9136.484709), -- Sealed Shield of Nightmare Fragment
(22190, 5317, 1, 1, 1, 59.222592), -- Sealed Majestic Circlet
(22190, 5528, 1, 1, 1, 7193.717949), -- Sealed Majestic Circlet Design
(22190, 1895, 1, 1, 2, 128938.022556), -- Metallic Fiber
(22190, 4040, 1, 1, 2, 9025.731204), -- Mold Lubricant
(22190, 4042, 1, 1, 2, 7521.332154), -- Enria
(22190, 4043, 1, 1, 2, 15042.830082), -- Asofe
(22190, 6901, 1, 1, 2, 451.236828), -- Recipe: Shining Arrow (100%)
(22190, 8732, 1, 1, 2, 3760.748964), -- Life Stone - Level 76
(22190, 8742, 1, 1, 2, 940.104354), -- Mid-Grade Life Stone - Level 76
(22190, 8752, 1, 1, 2, 93.993858), -- High-Grade Life Stone - Level 76
-- Andreas' Captain of the Royal Guard
(22191, 6691, 1, 1, -1, 10329), -- Angel Slayer Blade
(22191, 6901, 1, 1, -1, 4779), -- Recipe: Shining Arrow (100%)
(22191, 6693, 1, 1, -1, 10517), -- Dragon Hunter Axe Blade
(22191, 57, 2350, 4817, 0, 700000), -- Adena
(22191, 5320, 1, 1, 1, 13.361072), -- Sealed Leather Armor of Nightmare
(22191, 5480, 1, 1, 1, 1979.638928), -- Sealed Leather Armor of Nightmare Fabric
(22191, 5323, 1, 1, 1, 13.361072), -- Sealed Majestic Leather Armor
(22191, 5481, 1, 1, 1, 1979.638928), -- Sealed Majestic Leather Armor Fabric
(22191, 1895, 1, 1, 2, 100828.880158), -- Metallic Fiber
(22191, 4040, 1, 1, 2, 7058.070574), -- Mold Lubricant
(22191, 4042, 1, 1, 2, 5881.704554), -- Enria
(22191, 4043, 1, 1, 2, 11763.409108), -- Asofe
(22191, 959, 1, 1, 2, 13.935606), -- Scroll: Enchant Weapon (S-Grade)
-- Andreas' Royal Guards
(22192, 6901, 1, 1, -1, 2552), -- Recipe: Shining Arrow (100%)
(22192, 6694, 1, 1, -1, 5617), -- Saint Spear Blade
(22192, 960, 1, 1, -1, 1021), -- Scroll: Enchant Armor (S-Grade)
(22192, 57, 1256, 2571, 0, 700000), -- Adena
(22192, 5311, 1, 1, 1, 5.350495), -- Sealed Armor of Nightmare
(22192, 5522, 1, 1, 1, 802.149505), -- Sealed Armor of Nightmare Pattern
(22192, 5316, 1, 1, 1, 5.350495), -- Sealed Majestic Plate Armor
(22192, 5523, 1, 1, 1, 802.149505), -- Sealed Majestic Plate Armor Pattern
(22192, 1894, 1, 1, 2, 6613.007436), -- Crafted Leather
(22192, 4039, 1, 1, 2, 6282.370644), -- Mold Glue
(22192, 4041, 1, 1, 2, 1638.87294), -- Mold Hardener
(22192, 4044, 1, 1, 2, 6282.370644), -- Thons
(22192, 960, 1, 1, 2, 75.378336), -- Scroll: Enchant Armor (S-Grade)
-- Andreas' Royal Guards
(22193, 4042, 1, 1, -1, 42537), -- Enria
(22193, 4043, 1, 1, -1, 85075), -- Asofe
(22193, 6695, 1, 1, -1, 5413), -- Demon Splinter Blade
(22193, 57, 1256, 2571, 0, 700000), -- Adena
(22193, 5326, 1, 1, 1, 7.136376), -- Sealed Robe of Nightmare
(22193, 5487, 1, 1, 1, 1060.863624), -- Sealed Robe of Nightmare Fabric
(22193, 5329, 1, 1, 1, 7.136376), -- Sealed Majestic Robe
(22193, 5488, 1, 1, 1, 1060.863624), -- Sealed Majestic Robe Fabric
(22193, 1895, 1, 1, 2, 33655.924174), -- Metallic Fiber
(22193, 4040, 1, 1, 2, 2355.932866), -- Mold Lubricant
(22193, 4042, 1, 1, 2, 1963.248541), -- Enria
(22193, 4043, 1, 1, 2, 3926.540353), -- Asofe
(22193, 6901, 1, 1, 2, 117.783662), -- Recipe: Shining Arrow (100%)
(22193, 8732, 1, 1, 2, 981.645906), -- Life Stone - Level 76
(22193, 8742, 1, 1, 2, 245.389841), -- Mid-Grade Life Stone - Level 76
(22193, 8752, 1, 1, 2, 24.534657), -- High-Grade Life Stone - Level 76
-- Ritual Sacrifice
(22195, 5162, 1, 1, -1, 4026), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22195, 5515, 1, 1, -1, 152986), -- Sealed Majestic Gauntlets Design
(22195, 5167, 1, 1, -1, 4026), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22195, 57, 4457, 9126, 0, 700000), -- Adena
(22195, 6326, 1, 1, 1, 55.79944), -- Sealed Majestic Necklace
(22195, 6344, 1, 1, 1, 8170.77783), -- Sealed Majestic Necklace Beads
(22195, 6327, 1, 1, 1, 74.412315), -- Sealed Majestic Earring
(22195, 6342, 1, 1, 1, 12625.916405), -- Sealed Majestic Earring Gemstone
(22195, 6328, 1, 1, 1, 111.59888), -- Sealed Majestic Ring
(22195, 6346, 1, 1, 1, 18146.49513), -- Sealed Majestic Ring Gemstone
(22195, 1868, 4, 12, 2, 83615.338457), -- Thread
(22195, 1873, 1, 1, 2, 133784.285201), -- Silver Nugget
(22195, 5549, 1, 1, 2, 33445.964496), -- Metallic Thread
(22195, 1889, 1, 1, 2, 22297.309664), -- Compound Braid
(22195, 4044, 1, 1, 2, 11148.654832), -- Thons
(22195, 959, 1, 1, 2, 13.243727), -- Scroll: Enchant Weapon (S-Grade)
(22195, 8732, 1, 1, 2, 2787.163708), -- Life Stone - Level 76
(22195, 8742, 1, 1, 2, 696.790927), -- Mid-Grade Life Stone - Level 76
(22195, 8752, 1, 1, 2, 69.636371), -- High-Grade Life Stone - Level 76
(22195, 1344, 30, 90, 2, 139358.612617), -- Mithril Arrow
-- Velociraptor
(22196, 6688, 1, 1, -1, 14653), -- Forgotten Blade Edge
(22196, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22196, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22196, 57, 3342, 6823, 0, 700000), -- Adena
(22196, 6364, 1, 1, 1, 2.927043), -- Forgotten Blade
(22196, 6372, 1, 1, 1, 2.927043), -- Heaven's Divider
(22196, 6688, 1, 1, 1, 1352.826801), -- Forgotten Blade Edge
(22196, 6696, 1, 1, 1, 1374.319113), -- Heavens Divider Edge
(22196, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22196, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22196, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22196, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22196, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22196, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22196, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22196, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22196, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Velociraptor
(22197, 6689, 1, 1, -1, 14377), -- Basalt Battlehammer Head
(22197, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22197, 6690, 1, 1, -1, 14681), -- Imperial Staff Head
(22197, 57, 3342, 6823, 0, 700000), -- Adena
(22197, 6364, 1, 1, 1, 2.927043), -- Forgotten Blade
(22197, 6372, 1, 1, 1, 2.927043), -- Heaven's Divider
(22197, 6688, 1, 1, 1, 1352.826801), -- Forgotten Blade Edge
(22197, 6696, 1, 1, 1, 1374.319113), -- Heavens Divider Edge
(22197, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22197, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22197, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22197, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22197, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22197, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22197, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22197, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22197, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Velociraptor
(22198, 959, 1, 1, -1, 407), -- Scroll: Enchant Weapon (S-Grade)
(22198, 13099, 1, 1, -1, 141810), -- Sealed Arcana Sigil Piece
(22198, 57, 3342, 6823, 0, 700000), -- Adena
(22198, 6364, 1, 1, 1, 2.927043), -- Forgotten Blade
(22198, 6372, 1, 1, 1, 2.927043), -- Heaven's Divider
(22198, 6688, 1, 1, 1, 1352.826801), -- Forgotten Blade Edge
(22198, 6696, 1, 1, 1, 1374.319113), -- Heavens Divider Edge
(22198, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22198, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22198, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22198, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22198, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22198, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22198, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22198, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22198, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Pterosaur
(22199, 6691, 1, 1, -1, 14653), -- Angel Slayer Blade
(22199, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22199, 6693, 1, 1, -1, 14918), -- Dragon Hunter Axe Blade
(22199, 57, 3342, 6823, 0, 700000), -- Adena
(22199, 6724, 1, 1, 1, 25.515042), -- Sealed Tateossian Earring
(22199, 6725, 1, 1, 1, 38.261382), -- Sealed Tateossian Ring
(22199, 6726, 1, 1, 1, 19.11951), -- Sealed Tateossian Necklace
(22199, 6698, 1, 1, 1, 8193.503886), -- Sealed Tateossian Earring Part
(22199, 6699, 1, 1, 1, 9091.785426), -- Sealed Tateossian Ring Gem
(22199, 6700, 1, 1, 1, 4993.814754), -- Sealed Tateossian Necklace Chain
(22199, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22199, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22199, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22199, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22199, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22199, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22199, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22199, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22199, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Ornithomimus
(22200, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22200, 6694, 1, 1, -1, 14918), -- Saint Spear Blade
(22200, 960, 1, 1, -1, 2712), -- Scroll: Enchant Armor (S-Grade)
(22200, 57, 3342, 6823, 0, 700000), -- Adena
(22200, 6365, 1, 1, 1, 1.951366), -- Basalt Battlehammer
(22200, 6366, 1, 1, 1, 1.951366), -- Imperial Staff
(22200, 6369, 1, 1, 1, 1.951366), -- Dragon Hunter Axe
(22200, 6689, 1, 1, 1, 885.355652), -- Basalt Battlehammer Head
(22200, 6690, 1, 1, 1, 904.076824), -- Imperial Staff Head
(22200, 6693, 1, 1, 1, 918.713426), -- Dragon Hunter Axe Blade
(22200, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22200, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22200, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22200, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22200, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22200, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22200, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22200, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22200, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Ornithomimus
(22201, 1895, 1, 5, -1, 645620), -- Metallic Fiber
(22201, 4040, 1, 1, -1, 135580), -- Mold Lubricant
(22201, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22201, 57, 3342, 6823, 0, 700000), -- Adena
(22201, 6365, 1, 1, 1, 1.951366), -- Basalt Battlehammer
(22201, 6366, 1, 1, 1, 1.951366), -- Imperial Staff
(22201, 6369, 1, 1, 1, 1.951366), -- Dragon Hunter Axe
(22201, 6689, 1, 1, 1, 885.355652), -- Basalt Battlehammer Head
(22201, 6690, 1, 1, 1, 904.076824), -- Imperial Staff Head
(22201, 6693, 1, 1, 1, 918.713426), -- Dragon Hunter Axe Blade
(22201, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22201, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22201, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22201, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22201, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22201, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22201, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22201, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22201, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Ornithomimus
(22202, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22202, 6696, 1, 1, -1, 14886), -- Heavens Divider Edge
(22202, 57, 3342, 6823, 0, 700000), -- Adena
(22202, 6365, 1, 1, 1, 1.951366), -- Basalt Battlehammer
(22202, 6366, 1, 1, 1, 1.951366), -- Imperial Staff
(22202, 6369, 1, 1, 1, 1.951366), -- Dragon Hunter Axe
(22202, 6689, 1, 1, 1, 885.355652), -- Basalt Battlehammer Head
(22202, 6690, 1, 1, 1, 904.076824), -- Imperial Staff Head
(22202, 6693, 1, 1, 1, 918.713426), -- Dragon Hunter Axe Blade
(22202, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22202, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22202, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22202, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22202, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22202, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22202, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22202, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22202, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Deinonychus
(22203, 6697, 1, 1, -1, 14377), -- Arcana Mace Head
(22203, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22203, 1875, 1, 1, -1, 451934), -- Stone of Purity
(22203, 57, 3342, 6823, 0, 700000), -- Adena
(22203, 7575, 1, 1, 1, 5.85417), -- Draconic Bow
(22203, 7579, 1, 1, 1, 2736.14583), -- Draconic Bow Shaft
(22203, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22203, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22203, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22203, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22203, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22203, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22203, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22203, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22203, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Deinonychus
(22204, 1885, 1, 1, -1, 564917), -- High-Grade Suede
(22204, 6698, 1, 1, -1, 133157), -- Sealed Tateossian Earring Part
(22204, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22204, 57, 3342, 6823, 0, 700000), -- Adena
(22204, 7575, 1, 1, 1, 5.85417), -- Draconic Bow
(22204, 7579, 1, 1, 1, 2736.14583), -- Draconic Bow Shaft
(22204, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22204, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22204, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22204, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22204, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22204, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22204, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22204, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22204, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Deinonychus
(22205, 6699, 1, 1, -1, 147755), -- Sealed Tateossian Ring Gem
(22205, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22205, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22205, 57, 3342, 6823, 0, 700000), -- Adena
(22205, 7575, 1, 1, 1, 5.85417), -- Draconic Bow
(22205, 7579, 1, 1, 1, 2736.14583), -- Draconic Bow Shaft
(22205, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22205, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22205, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22205, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22205, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22205, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22205, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22205, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22205, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Pachycephalosaurus
(22208, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22208, 6703, 1, 1, -1, 96519), -- Sealed Imperial Crusader Gauntlets Design
(22208, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22208, 57, 3342, 6823, 0, 700000), -- Adena
(22208, 6367, 1, 1, 1, 5.853049), -- Angel Slayer
(22208, 6691, 1, 1, 1, 2705.146951), -- Angel Slayer Blade
(22208, 8954, 1, 1, 2, 1430.429), -- Blue Primeval Crystal
(22208, 8955, 1, 1, 2, 715.2145), -- Green Primeval Crystal
(22208, 8956, 1, 1, 2, 357.60725), -- Red Primeval Crystal
(22208, 8752, 1, 1, 2, 74.50025), -- High-Grade Life Stone - Level 76
(22208, 8762, 1, 1, 2, 14.8995), -- Top-Grade Life Stone - Level 76
(22208, 959, 1, 1, 2, 14.3055), -- Scroll: Enchant Weapon (S-Grade)
(22208, 960, 1, 1, 2, 143.044), -- Scroll: Enchant Armor (S-Grade)
-- Pachycephalosaurus
(22209, 1894, 1, 1, -1, 237860), -- Crafted Leather
(22209, 4042, 1, 1, -1, 112983), -- Enria
(22209, 6704, 1, 1, -1, 96519), -- Sealed Imperial Crusader Boots Design
(22209, 57, 3342, 6823, 0, 700000), -- Adena
(22209, 6367, 1, 1, 1, 5.853049), -- Angel Slayer
(22209, 6691, 1, 1, 1, 2705.146951), -- Angel Slayer Blade
(22209, 8954, 1, 1, 2, 1430.429), -- Blue Primeval Crystal
(22209, 8955, 1, 1, 2, 715.2145), -- Green Primeval Crystal
(22209, 8956, 1, 1, 2, 357.60725), -- Red Primeval Crystal
(22209, 8752, 1, 1, 2, 74.50025), -- High-Grade Life Stone - Level 76
(22209, 8762, 1, 1, 2, 14.8995), -- Top-Grade Life Stone - Level 76
(22209, 959, 1, 1, 2, 14.3055), -- Scroll: Enchant Weapon (S-Grade)
(22209, 960, 1, 1, 2, 143.044), -- Scroll: Enchant Armor (S-Grade)
-- Pachycephalosaurus
(22210, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22210, 6705, 1, 1, -1, 94540), -- Sealed Imperial Crusader Shield Part
(22210, 57, 3342, 6823, 0, 700000), -- Adena
(22210, 6367, 1, 1, 1, 5.853049), -- Angel Slayer
(22210, 6691, 1, 1, 1, 2705.146951), -- Angel Slayer Blade
(22210, 8954, 1, 1, 2, 1430.429), -- Blue Primeval Crystal
(22210, 8955, 1, 1, 2, 715.2145), -- Green Primeval Crystal
(22210, 8956, 1, 1, 2, 357.60725), -- Red Primeval Crystal
(22210, 8752, 1, 1, 2, 74.50025), -- High-Grade Life Stone - Level 76
(22210, 8762, 1, 1, 2, 14.8995), -- Top-Grade Life Stone - Level 76
(22210, 959, 1, 1, 2, 14.3055), -- Scroll: Enchant Weapon (S-Grade)
(22210, 960, 1, 1, 2, 143.044), -- Scroll: Enchant Armor (S-Grade)
-- Wild Strider
(22211, 6706, 1, 1, -1, 109968), -- Sealed Imperial Crusader Helmet Pattern
(22211, 960, 1, 1, -1, 2712), -- Scroll: Enchant Armor (S-Grade)
(22211, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22211, 57, 3342, 6823, 0, 700000), -- Adena
(22211, 6371, 1, 1, 1, 5.85466), -- Demon Splinter
(22211, 6695, 1, 1, 1, 2654.14534), -- Demon Splinter Blade
(22211, 8954, 1, 1, 2, 2002.149016), -- Blue Primeval Crystal
(22211, 8955, 1, 1, 2, 1001.074508), -- Green Primeval Crystal
(22211, 8956, 1, 1, 2, 500.539116), -- Red Primeval Crystal
(22211, 959, 1, 1, 2, 20.020224), -- Scroll: Enchant Weapon (S-Grade)
(22211, 960, 1, 1, 2, 200.217136), -- Scroll: Enchant Armor (S-Grade)
-- Wild Strider
(22212, 4041, 1, 1, -1, 58948), -- Mold Hardener
(22212, 6707, 1, 1, -1, 33589), -- Sealed Draconic Leather Armor Part
(22212, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22212, 57, 3342, 6823, 0, 700000), -- Adena
(22212, 6371, 1, 1, 1, 5.85466), -- Demon Splinter
(22212, 6695, 1, 1, 1, 2654.14534), -- Demon Splinter Blade
(22212, 8954, 1, 1, 2, 2002.149016), -- Blue Primeval Crystal
(22212, 8955, 1, 1, 2, 1001.074508), -- Green Primeval Crystal
(22212, 8956, 1, 1, 2, 500.539116), -- Red Primeval Crystal
(22212, 959, 1, 1, 2, 20.020224), -- Scroll: Enchant Weapon (S-Grade)
(22212, 960, 1, 1, 2, 200.217136), -- Scroll: Enchant Armor (S-Grade)
-- Wild Strider
(22213, 6708, 1, 1, -1, 96519), -- Sealed Draconic Leather Gloves Fabric
(22213, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22213, 6709, 1, 1, -1, 96519), -- Sealed Draconic Leather Boots Design
(22213, 57, 3342, 6823, 0, 700000), -- Adena
(22213, 6371, 1, 1, 1, 5.85466), -- Demon Splinter
(22213, 6695, 1, 1, 1, 2654.14534), -- Demon Splinter Blade
(22213, 8954, 1, 1, 2, 2002.149016), -- Blue Primeval Crystal
(22213, 8955, 1, 1, 2, 1001.074508), -- Green Primeval Crystal
(22213, 8956, 1, 1, 2, 500.539116), -- Red Primeval Crystal
(22213, 959, 1, 1, 2, 20.020224), -- Scroll: Enchant Weapon (S-Grade)
(22213, 960, 1, 1, 2, 200.217136), -- Scroll: Enchant Armor (S-Grade)
-- Elroki
(22214, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22214, 5549, 1, 1, -1, 677901), -- Metallic Thread
(22214, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22214, 57, 3342, 6823, 0, 700000), -- Adena
(22214, 6676, 1, 1, 1, 13.05678), -- Sealed Imperial Crusader Gauntlet
(22214, 6677, 1, 1, 1, 13.05678), -- Sealed Imperial Crusader Boots
(22214, 6681, 1, 1, 1, 13.05678), -- Sealed Draconic Leather Glove
(22214, 6682, 1, 1, 1, 13.05678), -- Sealed Draconic Leather Boots
(22214, 6685, 1, 1, 1, 13.05678), -- Sealed Major Arcana Glove
(22214, 6686, 1, 1, 1, 13.05678), -- Sealed Major Arcana Boots
(22214, 6703, 1, 1, 1, 2967.949182), -- Sealed Imperial Crusader Gauntlets Design
(22214, 6704, 1, 1, 1, 2967.949182), -- Sealed Imperial Crusader Boots Design
(22214, 6708, 1, 1, 1, 2967.949182), -- Sealed Draconic Leather Gloves Fabric
(22214, 6709, 1, 1, 1, 2967.949182), -- Sealed Draconic Leather Boots Design
(22214, 6712, 1, 1, 1, 2967.949182), -- Sealed Major Arcana Gloves fabric
(22214, 6713, 1, 1, 1, 2967.91341), -- Sealed Major Arcana Boots Design
(22214, 8954, 1, 1, 2, 2002.149016), -- Blue Primeval Crystal
(22214, 8955, 1, 1, 2, 1001.074508), -- Green Primeval Crystal
(22214, 8956, 1, 1, 2, 500.539116), -- Red Primeval Crystal
(22214, 959, 1, 1, 2, 20.020224), -- Scroll: Enchant Weapon (S-Grade)
(22214, 960, 1, 1, 2, 200.217136), -- Scroll: Enchant Armor (S-Grade)
-- Tyrannosaurus
(22215, 6710, 1, 7, -1, 797242), -- Sealed Draconic Leather Helmet Pattern
(22215, 6901, 1, 1, -1, 196584), -- Recipe: Shining Arrow (100%)
(22215, 6711, 1, 3, -1, 487016), -- Sealed Major Arcana Robe Part
(22215, 57, 96910, 197846, 0, 700000), -- Adena
(22215, 6370, 1, 1, 1, 169.752114), -- Saint Spear
(22215, 6694, 1, 1, 1, 79864.247886), -- Saint Spear Blade
(22215, 1879, 15, 45, 2, 44805.479755), -- Cokes
(22215, 1885, 2, 6, 2, 168020.01748), -- High-Grade Suede
(22215, 9628, 1, 1, 2, 63254.594816), -- Leonard
(22215, 9630, 1, 1, 2, 42447.29661), -- Orichalcum
(22215, 9629, 1, 1, 2, 35065.269012), -- Adamantine
(22215, 9573, 1, 1, 2, 56006.530733), -- Life Stone - Level 80
(22215, 9574, 1, 1, 2, 14001.526363), -- Mid-Grade Life Stone - Level 80
(22215, 9575, 1, 1, 2, 1400.025052), -- High-Grade Life Stone - Level 80
(22215, 9576, 1, 1, 2, 280.260179), -- Top-Grade Life Stone - Level 80
-- Tyrannosaurus
(22216, 6901, 1, 1, -1, 196584), -- Recipe: Shining Arrow (100%)
(22216, 6712, 1, 5, -1, 932982), -- Sealed Major Arcana Gloves fabric
(22216, 960, 1, 1, -1, 78634), -- Scroll: Enchant Armor (S-Grade)
(22216, 57, 96910, 197846, 0, 700000), -- Adena
(22216, 6370, 1, 1, 1, 169.752114), -- Saint Spear
(22216, 6694, 1, 1, 1, 79864.247886), -- Saint Spear Blade
(22216, 1879, 15, 45, 2, 44805.479755), -- Cokes
(22216, 1885, 2, 6, 2, 168020.01748), -- High-Grade Suede
(22216, 9628, 1, 1, 2, 63254.594816), -- Leonard
(22216, 9630, 1, 1, 2, 42447.29661), -- Orichalcum
(22216, 9629, 1, 1, 2, 35065.269012), -- Adamantine
(22216, 9573, 1, 1, 2, 56006.530733), -- Life Stone - Level 80
(22216, 9574, 1, 1, 2, 14001.526363), -- Mid-Grade Life Stone - Level 80
(22216, 9575, 1, 1, 2, 1400.025052), -- High-Grade Life Stone - Level 80
(22216, 9576, 1, 1, 2, 280.260179), -- Top-Grade Life Stone - Level 80
-- Tyrannosaurus
(22217, 4042, 1, 7, -1, 819100), -- Enria
(22217, 4043, 1, 13, -1, 936114), -- Asofe
(22217, 6713, 1, 5, -1, 932982), -- Sealed Major Arcana Boots Design
(22217, 57, 96910, 197846, 0, 700000), -- Adena
(22217, 6370, 1, 1, 1, 169.752114), -- Saint Spear
(22217, 6694, 1, 1, 1, 79864.247886), -- Saint Spear Blade
(22217, 1879, 15, 45, 2, 44805.479755), -- Cokes
(22217, 1885, 2, 6, 2, 168020.01748), -- High-Grade Suede
(22217, 9628, 1, 1, 2, 63254.594816), -- Leonard
(22217, 9630, 1, 1, 2, 42447.29661), -- Orichalcum
(22217, 9629, 1, 1, 2, 35065.269012), -- Adamantine
(22217, 9573, 1, 1, 2, 56006.530733), -- Life Stone - Level 80
(22217, 9574, 1, 1, 2, 14001.526363), -- Mid-Grade Life Stone - Level 80
(22217, 9575, 1, 1, 2, 1400.025052), -- High-Grade Life Stone - Level 80
(22217, 9576, 1, 1, 2, 280.260179), -- Top-Grade Life Stone - Level 80
-- Velociraptor
(22218, 6688, 1, 1, -1, 14653), -- Forgotten Blade Edge
(22218, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22218, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22218, 57, 3342, 6823, 0, 700000), -- Adena
(22218, 6364, 1, 1, 1, 2.927043), -- Forgotten Blade
(22218, 6372, 1, 1, 1, 2.927043), -- Heaven's Divider
(22218, 6688, 1, 1, 1, 1352.826801), -- Forgotten Blade Edge
(22218, 6696, 1, 1, 1, 1374.319113), -- Heavens Divider Edge
(22218, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22218, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22218, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22218, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22218, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22218, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22218, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22218, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22218, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Ornithomimus
(22219, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22219, 6694, 1, 1, -1, 14918), -- Saint Spear Blade
(22219, 960, 1, 1, -1, 2712), -- Scroll: Enchant Armor (S-Grade)
(22219, 57, 3342, 6823, 0, 700000), -- Adena
(22219, 6365, 1, 1, 1, 1.951366), -- Basalt Battlehammer
(22219, 6366, 1, 1, 1, 1.951366), -- Imperial Staff
(22219, 6369, 1, 1, 1, 1.951366), -- Dragon Hunter Axe
(22219, 6689, 1, 1, 1, 885.355652), -- Basalt Battlehammer Head
(22219, 6690, 1, 1, 1, 904.076824), -- Imperial Staff Head
(22219, 6693, 1, 1, 1, 918.713426), -- Dragon Hunter Axe Blade
(22219, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22219, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22219, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22219, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22219, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22219, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22219, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22219, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22219, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Deinonychus
(22220, 6697, 1, 1, -1, 14377), -- Arcana Mace Head
(22220, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22220, 1875, 1, 1, -1, 451934), -- Stone of Purity
(22220, 57, 3342, 6823, 0, 700000), -- Adena
(22220, 7575, 1, 1, 1, 5.85417), -- Draconic Bow
(22220, 7579, 1, 1, 1, 2736.14583), -- Draconic Bow Shaft
(22220, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22220, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22220, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22220, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22220, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22220, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22220, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22220, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22220, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Pachycephalosaurus
(22221, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22221, 6703, 1, 1, -1, 96519), -- Sealed Imperial Crusader Gauntlets Design
(22221, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22221, 57, 3342, 6823, 0, 700000), -- Adena
(22221, 6367, 1, 1, 1, 5.853049), -- Angel Slayer
(22221, 6691, 1, 1, 1, 2705.146951), -- Angel Slayer Blade
(22221, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22221, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22221, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22221, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22221, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22221, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22221, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22221, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22221, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Wild Strider
(22222, 6706, 1, 1, -1, 109968), -- Sealed Imperial Crusader Helmet Pattern
(22222, 960, 1, 1, -1, 2712), -- Scroll: Enchant Armor (S-Grade)
(22222, 1875, 1, 1, -1, 451934), -- Stone of Purity
(22222, 57, 3342, 6823, 0, 700000), -- Adena
(22222, 6371, 1, 1, 1, 5.85466), -- Demon Splinter
(22222, 6695, 1, 1, 1, 2654.14534), -- Demon Splinter Blade
(22222, 8954, 1, 1, 2, 1430.429), -- Blue Primeval Crystal
(22222, 8955, 1, 1, 2, 715.2145), -- Green Primeval Crystal
(22222, 8956, 1, 1, 2, 357.60725), -- Red Primeval Crystal
(22222, 8752, 1, 1, 2, 74.50025), -- High-Grade Life Stone - Level 76
(22222, 8762, 1, 1, 2, 14.8995), -- Top-Grade Life Stone - Level 76
(22222, 959, 1, 1, 2, 14.3055), -- Scroll: Enchant Weapon (S-Grade)
(22222, 960, 1, 1, 2, 143.044), -- Scroll: Enchant Armor (S-Grade)
-- Velociraptor
(22223, 6688, 1, 1, -1, 14653), -- Forgotten Blade Edge
(22223, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22223, 13099, 1, 1, -1, 94540), -- Sealed Arcana Sigil Piece
(22223, 57, 5707, 11651, 0, 700000), -- Adena
(22223, 81, 1, 1, 1, 6.869694), -- Dragon Slayer
(22223, 5529, 1, 1, 1, 1953.714248), -- Dragon Slayer Edge
(22223, 151, 1, 1, 1, 6.869694), -- Sword of Miracles
(22223, 5546, 1, 1, 1, 2145.968496), -- Sword of Miracles Edge
(22223, 2500, 1, 1, 1, 6.869694), -- Dark Legion's Edge
(22223, 5545, 1, 1, 1, 1953.708174), -- Dark Legion's Edge Blade
(22223, 1879, 1, 1, 2, 101770.251152), -- Cokes
(22223, 1885, 1, 1, 2, 50885.125576), -- High-Grade Suede
(22223, 9628, 1, 1, 2, 4789.190214), -- Leonard
(22223, 9630, 1, 1, 2, 3213.731972), -- Orichalcum
(22223, 9629, 1, 1, 2, 2654.93586), -- Adamantine
(22223, 959, 1, 1, 2, 24.373718), -- Scroll: Enchant Weapon (S-Grade)
(22223, 960, 1, 1, 2, 244.391508), -- Scroll: Enchant Armor (S-Grade)
-- Ornithomimus
(22224, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22224, 6694, 1, 1, -1, 14918), -- Saint Spear Blade
(22224, 960, 1, 1, -1, 2712), -- Scroll: Enchant Armor (S-Grade)
(22224, 57, 3342, 6823, 0, 700000), -- Adena
(22224, 6365, 1, 1, 1, 1.951366), -- Basalt Battlehammer
(22224, 6366, 1, 1, 1, 1.951366), -- Imperial Staff
(22224, 6369, 1, 1, 1, 1.951366), -- Dragon Hunter Axe
(22224, 6689, 1, 1, 1, 885.355652), -- Basalt Battlehammer Head
(22224, 6690, 1, 1, 1, 904.076824), -- Imperial Staff Head
(22224, 6693, 1, 1, 1, 918.713426), -- Dragon Hunter Axe Blade
(22224, 8954, 1, 1, 2, 2002.149016), -- Blue Primeval Crystal
(22224, 8955, 1, 1, 2, 1001.074508), -- Green Primeval Crystal
(22224, 8956, 1, 1, 2, 500.539116), -- Red Primeval Crystal
(22224, 959, 1, 1, 2, 20.020224), -- Scroll: Enchant Weapon (S-Grade)
(22224, 960, 1, 1, 2, 200.217136), -- Scroll: Enchant Armor (S-Grade)
-- Deinonychus
(22225, 6697, 1, 1, -1, 14377), -- Arcana Mace Head
(22225, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22225, 1875, 1, 1, -1, 451934), -- Stone of Purity
(22225, 57, 3342, 6823, 0, 700000), -- Adena
(22225, 7575, 1, 1, 1, 5.85417), -- Draconic Bow
(22225, 7579, 1, 1, 1, 2736.14583), -- Draconic Bow Shaft
(22225, 1879, 1, 1, 2, 46352.403325), -- Cokes
(22225, 1885, 1, 1, 2, 23176.24009), -- High-Grade Suede
(22225, 9628, 1, 1, 2, 2181.29861), -- Leonard
(22225, 9630, 1, 1, 2, 1463.78033), -- Orichalcum
(22225, 9629, 1, 1, 2, 1209.159715), -- Adamantine
(22225, 9573, 1, 1, 2, 1931.36615), -- Life Stone - Level 80
(22225, 9574, 1, 1, 2, 482.80311), -- Mid-Grade Life Stone - Level 80
(22225, 9575, 1, 1, 2, 48.26494), -- High-Grade Life Stone - Level 80
(22225, 9576, 1, 1, 2, 9.68373), -- Top-Grade Life Stone - Level 80
-- Pachycephalosaurus
(22226, 6901, 1, 1, -1, 6779), -- Recipe: Shining Arrow (100%)
(22226, 6703, 1, 1, -1, 96519), -- Sealed Imperial Crusader Gauntlets Design
(22226, 959, 1, 1, -1, 271), -- Scroll: Enchant Weapon (S-Grade)
(22226, 57, 3342, 6823, 0, 700000), -- Adena
(22226, 6367, 1, 1, 1, 5.853049), -- Angel Slayer
(22226, 6691, 1, 1, 1, 2705.146951), -- Angel Slayer Blade
(22226, 8954, 1, 1, 2, 1430.429), -- Blue Primeval Crystal
(22226, 8955, 1, 1, 2, 715.2145), -- Green Primeval Crystal
(22226, 8956, 1, 1, 2, 357.60725), -- Red Primeval Crystal
(22226, 8752, 1, 1, 2, 74.50025), -- High-Grade Life Stone - Level 76
(22226, 8762, 1, 1, 2, 14.8995), -- Top-Grade Life Stone - Level 76
(22226, 959, 1, 1, 2, 14.3055), -- Scroll: Enchant Weapon (S-Grade)
(22226, 960, 1, 1, 2, 143.044), -- Scroll: Enchant Armor (S-Grade)
-- Wild Strider
(22227, 6706, 1, 1, -1, 109968), -- Sealed Imperial Crusader Helmet Pattern
(22227, 960, 1, 1, -1, 2712), -- Scroll: Enchant Armor (S-Grade)
(22227, 1875, 1, 1, -1, 451934), -- Stone of Purity
(22227, 57, 3342, 6823, 0, 700000), -- Adena
(22227, 6371, 1, 1, 1, 5.85466), -- Demon Splinter
(22227, 6695, 1, 1, 1, 2654.14534), -- Demon Splinter Blade
(22227, 8954, 1, 1, 2, 2002.149016), -- Blue Primeval Crystal
(22227, 8955, 1, 1, 2, 1001.074508), -- Green Primeval Crystal
(22227, 8956, 1, 1, 2, 500.539116), -- Red Primeval Crystal
(22227, 959, 1, 1, 2, 20.020224), -- Scroll: Enchant Weapon (S-Grade)
(22227, 960, 1, 1, 2, 200.217136), -- Scroll: Enchant Armor (S-Grade)
-- Grey Elpy
(22228, 1864, 1, 1, -1, 31786), -- Stem
(22228, 1666, 1, 1, -1, 5298), -- Recipe: Wooden Arrow
(22228, 1786, 1, 1, -1, 12714), -- Recipe: Broad Sword
(22228, 57, 8, 12, 0, 700000), -- Adena
(22228, 112, 1, 1, 1, 28826.1324), -- Apprentice's Earring
(22228, 116, 1, 1, 1, 43815.6836), -- Magic Ring
(22228, 118, 1, 1, 1, 21478.184), -- Necklace of Magic
(22228, 1864, 1, 1, 2, 5476.875), -- Stem
(22228, 1865, 1, 1, 2, 2738.4375), -- Varnish
(22228, 1866, 1, 1, 2, 1825.630842), -- Suede
(22228, 1873, 1, 1, 2, 1095.375), -- Silver Nugget
(22228, 1868, 1, 1, 2, 5476.875), -- Thread
(22228, 1666, 1, 1, 2, 912.806658), -- Recipe: Wooden Arrow
-- Young Grey Keltir
(22229, 1871, 1, 1, -1, 15893), -- Charcoal
(22229, 1866, 1, 1, -1, 10595), -- Suede
(22229, 1787, 1, 1, -1, 12714), -- Recipe: Willow Staff
(22229, 57, 8, 12, 0, 700000), -- Adena
(22229, 21, 1, 1, 1, 14540.73921), -- Shirt
(22229, 28, 1, 1, 1, 23142.26079), -- Pants
(22229, 1871, 1, 1, 2, 4107.736359), -- Charcoal
(22229, 1866, 1, 1, 2, 2738.490906), -- Suede
(22229, 1786, 1, 1, 2, 3286.182953), -- Recipe: Broad Sword
(22229, 17, 10, 30, 2, 20538.589782), -- Wooden Arrow
-- Grey Keltir
(22230, 1788, 1, 1, -1, 14309), -- Recipe: Bow
(22230, 1870, 1, 1, -1, 17886), -- Coal
(22230, 1865, 1, 1, -1, 17886), -- Varnish
(22230, 57, 8, 13, 0, 700000), -- Adena
(22230, 18, 1, 1, 1, 61637.298112), -- Leather Shield
(22230, 41, 1, 1, 1, 44026.701888), -- Cloth Cap
(22230, 1870, 1, 1, 2, 6163.573894), -- Coal
(22230, 1865, 1, 1, 2, 6163.573894), -- Varnish
(22230, 1787, 1, 1, 2, 4930.852212), -- Recipe: Willow Staff
-- Dominant Grey Keltir
(22231, 1666, 1, 1, -1, 9020), -- Recipe: Wooden Arrow
(22231, 1786, 1, 1, -1, 21649), -- Recipe: Broad Sword
(22231, 1866, 1, 1, -1, 18041), -- Suede
(22231, 57, 13, 20, 0, 700000), -- Adena
(22231, 13, 1, 1, 1, 9484), -- Short Bow
(22231, 1866, 1, 1, 2, 4662.7931), -- Suede
(22231, 1871, 1, 1, 2, 6994.18965), -- Charcoal
(22231, 1788, 1, 1, 2, 5595.35172), -- Recipe: Bow
(22231, 1060, 1, 1, 2, 15542.66553), -- Lesser Healing Potion
-- Black Wolf
(22232, 1864, 1, 1, -1, 77083), -- Stem
(22232, 1787, 1, 1, -1, 30833), -- Recipe: Willow Staff
(22232, 1788, 1, 1, -1, 30833), -- Recipe: Bow
(22232, 57, 19, 29, 0, 700000), -- Adena
(22232, 21, 1, 1, 1, 35261.95821), -- Shirt
(22232, 28, 1, 1, 1, 56121.04179), -- Pants
(22232, 1864, 1, 1, 2, 26564.4), -- Stem
(22232, 1869, 1, 1, 2, 13282.2), -- Iron Ore
(22232, 1666, 1, 1, 2, 4427.4), -- Recipe: Wooden Arrow
-- Dominant Black Wolf
(22233, 1874, 1, 1, -1, 3731), -- Oriharukon Ore
(22233, 4043, 1, 1, -1, 1865), -- Asofe
(22233, 1666, 1, 1, -1, 18654), -- Recipe: Wooden Arrow
(22233, 57, 30, 42, 0, 700000), -- Adena
(22233, 13, 1, 1, 1, 19612), -- Short Bow
(22233, 1870, 1, 1, 2, 19285.722), -- Coal
(22233, 1865, 1, 1, 2, 19285.722), -- Varnish
(22233, 1786, 1, 1, 2, 15428.556), -- Recipe: Broad Sword
-- Green Goblin
(22234, 2005, 1, 1, -1, 5489), -- Broadsword Blade
(22234, 1789, 1, 1, -1, 14204), -- Recipe: Cedar Staff
(22234, 2006, 1, 1, -1, 5489), -- Willow Staff Head
(22234, 57, 41, 58, 0, 700000), -- Adena
(22234, 22, 1, 1, 1, 2427.747344), -- Leather Shirt
(22234, 29, 1, 1, 1, 3880.252656), -- Leather Pants
(22234, 1866, 1, 1, 2, 10087.997139), -- Suede
(22234, 1871, 1, 1, 2, 15131.9817), -- Charcoal
(22234, 1789, 1, 1, 2, 2797.021161), -- Recipe: Cedar Staff
-- Mountain Werewolf
(22235, 1877, 1, 1, -1, 3864), -- Adamantite Nugget
(22235, 4041, 1, 1, -1, 840), -- Mold Hardener
(22235, 1060, 1, 1, -1, 214653), -- Lesser Healing Potion
(22235, 57, 51, 71, 0, 700000), -- Adena
(22235, 14, 1, 1, 1, 594.321392), -- Bow
(22235, 2007, 1, 1, 1, 2037.678608), -- Bow Shaft
(22235, 1871, 1, 1, 2, 14266.175985), -- Charcoal
(22235, 1866, 1, 1, 2, 9510.78399), -- Suede
(22235, 1790, 1, 1, 2, 2636.96461), -- Recipe: Dirk
(22235, 17, 10, 30, 2, 71331.075415), -- Wooden Arrow
-- Muertos Archer
(22236, 2007, 1, 1, -1, 8799), -- Bow Shaft
(22236, 1790, 1, 1, -1, 22769), -- Recipe: Dirk
(22236, 2005, 1, 1, -1, 8799), -- Broadsword Blade
(22236, 57, 66, 90, 0, 700000), -- Adena
(22236, 14, 1, 1, 1, 758.030742), -- Bow
(22236, 2007, 1, 1, 1, 2598.969258), -- Bow Shaft
(22236, 1867, 1, 1, 2, 32343.13113), -- Animal Skin
(22236, 1872, 1, 1, 2, 32343.13113), -- Animal Bone
(22236, 1791, 1, 1, 2, 4483.73774), -- Recipe: Brandish
-- Mountain Fungus
(22237, 1791, 1, 1, -1, 27308), -- Recipe: Brandish
(22237, 2006, 1, 1, -1, 10553), -- Willow Staff Head
(22237, 1865, 1, 1, -1, 147736), -- Varnish
(22237, 57, 79, 107, 0, 700000), -- Adena
(22237, 3, 1, 1, 1, 909.094956), -- Broadsword
(22237, 2005, 1, 1, 1, 3116.905044), -- Broadsword Blade
(22237, 1865, 1, 1, 2, 21819.514624), -- Varnish
(22237, 1870, 1, 1, 2, 21819.514624), -- Coal
(22237, 1795, 1, 1, 2, 82337.41248), -- Recipe: Leather Shoes
(22237, 1060, 1, 1, 2, 48487.558272), -- Lesser Healing Potion
-- Mountain Werewolf Chief
(22238, 4039, 1, 1, -1, 5902), -- Mold Glue
(22238, 1060, 1, 1, -1, 393476), -- Lesser Healing Potion
(22238, 2007, 1, 1, -1, 12647), -- Bow Shaft
(22238, 57, 95, 129, 0, 700000), -- Adena
(22238, 5, 1, 1, 1, 544.793529), -- Mace
(22238, 8, 1, 1, 1, 544.793529), -- Willow Staff
(22238, 2006, 1, 1, 1, 1867.860813), -- Willow Staff Head
(22238, 152, 1, 1, 1, 843.552129), -- Heavy Chisel
(22238, 1870, 1, 1, 2, 34867.98525), -- Coal
(22238, 1865, 1, 1, 2, 34867.98525), -- Varnish
(22238, 1796, 1, 1, 2, 43859.0295), -- Recipe: Leather Tunic
-- Muertos Guard
(22239, 1792, 1, 1, -1, 14651), -- Recipe: Short Spear
(22239, 1896, 1, 1, -1, 84428), -- Necklace of Anguish Chain
(22239, 1793, 1, 1, -1, 14651), -- Recipe: Sword of Reflection
(22239, 57, 108, 145, 0, 700000), -- Adena
(22239, 66, 1, 1, 1, 188.6388), -- Gladius
(22239, 1333, 1, 1, 1, 188.6388), -- Brandish
(22239, 2010, 1, 1, 1, 1526.7224), -- Brandish Blade
(22239, 1867, 1, 1, 2, 52315.83525), -- Animal Skin
(22239, 1872, 1, 1, 2, 52315.83525), -- Animal Bone
(22239, 736, 1, 1, 2, 19618.3295), -- Scroll of Escape
-- Muertos Scout
(22240, 1921, 1, 1, -1, 133342), -- Leather Shoes Texture
(22240, 1869, 1, 1, -1, 206680), -- Iron Ore
(22240, 1878, 1, 1, -1, 82672), -- Braided Hemp
(22240, 57, 110, 152, 0, 700000), -- Adena
(22240, 9, 1, 1, 1, 195.673125), -- Cedar Staff
(22240, 2008, 1, 1, 1, 1583.65375), -- Cedar Staff Head
(22240, 154, 1, 1, 1, 195.673125), -- Dwarven Mace
(22240, 1864, 1, 1, 2, 81400.266774), -- Stem
(22240, 1869, 1, 1, 2, 40700.133387), -- Iron Ore
(22240, 1792, 1, 1, 2, 2992.599839), -- Recipe: Short Spear
-- Colossus
(22241, 1831, 1, 1, -1, 701496), -- Antidote
(22241, 1922, 1, 1, -1, 67107), -- Leather Tunic Pattern
(22241, 1794, 1, 1, -1, 19343), -- Recipe: Forest Bow
(22241, 57, 138, 196, 0, 700000), -- Adena
(22241, 271, 1, 1, 1, 747), -- Hunting Bow
(22241, 1871, 1, 1, 2, 51802.793256), -- Charcoal
(22241, 1866, 1, 1, 2, 34535.225553), -- Suede
(22241, 1793, 1, 1, 2, 3808.981191), -- Recipe: Sword of Reflection
-- Muertos Warrior
(22242, 1923, 1, 1, -1, 89762), -- Leather Stockings Pattern
(22242, 1798, 1, 1, -1, 214725), -- Recipe: Leather Helmet
(22242, 2008, 1, 1, -1, 8522), -- Cedar Staff Head
(22242, 57, 112, 166, 0, 700000), -- Adena
(22242, 66, 1, 1, 1, 207.363975), -- Gladius
(22242, 1333, 1, 1, 1, 207.363975), -- Brandish
(22242, 2010, 1, 1, 1, 1678.27205), -- Brandish Blade
(22242, 1870, 1, 1, 2, 32347.647308), -- Coal
(22242, 1865, 1, 1, 2, 32347.647308), -- Varnish
(22242, 1794, 1, 1, 2, 2378.517008), -- Recipe: Forest Bow
(22242, 1831, 1, 1, 2, 86260.188376), -- Antidote
-- Muertos Captain
(22243, 1868, 1, 1, -1, 457876), -- Thread
(22243, 1873, 1, 1, -1, 91575), -- Silver Nugget
(22243, 1833, 1, 1, -1, 610501), -- Bandage
(22243, 57, 115, 175, 0, 700000), -- Adena
(22243, 23, 1, 1, 1, 1473.292452), -- Wooden Breastplate
(22243, 30, 1, 1, 1, 2360.353774), -- Hard Leather Pants
(22243, 2386, 1, 1, 1, 2360.353774), -- Wooden Gaiters
(22243, 1868, 1, 1, 2, 90166.411153), -- Thread
(22243, 1873, 1, 1, 2, 18033.221271), -- Silver Nugget
(22243, 1798, 1, 1, 2, 44199.367576), -- Recipe: Leather Helmet
-- Crimson Spider
(22244, 1897, 1, 1, -1, 55910), -- Necklace of Wisdom Chain
(22244, 1800, 1, 1, -1, 73843), -- Recipe: Piece Bone Breastplate
(22244, 1924, 1, 1, -1, 75749), -- Leather Helmet Design
(22244, 57, 116, 181, 0, 700000), -- Adena
(22244, 38, 1, 1, 1, 1775.114565), -- Low Boots
(22244, 50, 1, 1, 1, 1775.114565), -- Leather Gloves
(22244, 1925, 1, 1, 1, 30322.77087), -- Leather Gloves Lining
(22244, 1870, 1, 1, 2, 46241.756625), -- Coal
(22244, 1865, 1, 1, 2, 46241.756625), -- Varnish
(22244, 1800, 1, 1, 2, 14541.48675), -- Recipe: Piece Bone Breastplate
-- Muertos Lieutenant
(22245, 1801, 1, 1, -1, 122537), -- Recipe: Piece Bone Gaiters
(22245, 1925, 1, 1, -1, 159499), -- Leather Gloves Lining
(22245, 1870, 1, 1, -1, 243236), -- Coal
(22245, 57, 119, 190, 0, 700000), -- Adena
(22245, 176, 1, 1, 1, 137), -- Apprentice's Staff
(22245, 2501, 1, 1, 1, 137), -- Bone Club
(22245, 1870, 1, 1, 2, 47898.763488), -- Coal
(22245, 1865, 1, 1, 2, 47898.763488), -- Varnish
(22245, 1801, 1, 1, 2, 24130.473024), -- Recipe: Piece Bone Gaiters
-- Muertos Commander
(22246, 1865, 1, 1, -1, 250330), -- Varnish
(22246, 734, 1, 1, -1, 41722), -- Haste Potion
(22246, 2011, 1, 1, -1, 5711), -- Short Spear Edge
(22246, 57, 120, 198, 0, 700000), -- Adena
(22246, 44, 1, 1, 1, 945.585525), -- Leather Helmet
(22246, 1924, 1, 1, 1, 11926.6254), -- Leather Helmet Design
(22246, 102, 1, 1, 1, 1351.836075), -- Round Shield
(22246, 945, 1, 1, 1, 2800.953), -- Skeleton Buckler
(22246, 1870, 1, 1, 2, 49295.859795), -- Coal
(22246, 1865, 1, 1, 2, 49295.859795), -- Varnish
(22246, 1817, 1, 1, 2, 9859.28041), -- Recipe: Cord
-- Grotto Golem
(22247, 1792, 1, 1, -1, 34791), -- Recipe: Short Spear
(22247, 1896, 1, 1, -1, 200493), -- Necklace of Anguish Chain
(22247, 1793, 1, 1, -1, 34791), -- Recipe: Sword of Reflection
(22247, 57, 238, 361, 0, 700000), -- Adena
(22247, 23, 1, 1, 1, 3045.058116), -- Wooden Breastplate
(22247, 30, 1, 1, 1, 4878.470942), -- Hard Leather Pants
(22247, 2386, 1, 1, 1, 4878.470942), -- Wooden Gaiters
(22247, 1865, 1, 1, 2, 93176.8), -- Varnish
(22247, 1870, 1, 1, 2, 93176.8), -- Coal
(22247, 736, 1, 1, 2, 46588.4), -- Scroll of Escape
-- Shady Muertos
(22248, 1921, 1, 1, -1, 225868), -- Leather Shoes Texture
(22248, 1874, 1, 1, -1, 23340), -- Oriharukon Ore
(22248, 4043, 1, 1, -1, 11670), -- Asofe
(22248, 57, 176, 267, 0, 700000), -- Adena
(22248, 66, 1, 1, 1, 331.405875), -- Gladius
(22248, 1333, 1, 1, 1, 331.405875), -- Brandish
(22248, 2010, 1, 1, 1, 2682.18825), -- Brandish Blade
(22248, 1870, 1, 1, 2, 68941.94331), -- Coal
(22248, 1865, 1, 1, 2, 68941.94331), -- Varnish
(22248, 1792, 1, 1, 2, 5069.11338), -- Recipe: Short Spear
-- Shady Muertos Guard
(22249, 735, 1, 1, -1, 29924), -- Alacrity Potion
(22249, 1897, 1, 1, -1, 85498), -- Necklace of Wisdom Chain
(22249, 1800, 1, 1, -1, 112922), -- Recipe: Piece Bone Breastplate
(22249, 57, 178, 277, 0, 700000), -- Adena
(22249, 24, 1, 1, 1, 679.89405), -- Bone Breastplate
(22249, 31, 1, 1, 1, 1085.60595), -- Bone Gaiters
(22249, 390, 1, 1, 1, 679.89405), -- Cotton Shirt
(22249, 412, 1, 1, 1, 1085.60595), -- Cotton Pants
(22249, 1870, 1, 1, 2, 70713.48616), -- Coal
(22249, 1865, 1, 1, 2, 70713.48616), -- Varnish
(22249, 1800, 1, 1, 2, 22237.02768), -- Recipe: Piece Bone Breastplate
-- Grotto Leopard
(22250, 1924, 1, 1, -1, 115836), -- Leather Helmet Design
(22250, 1801, 1, 1, -1, 180903), -- Recipe: Piece Bone Gaiters
(22250, 1925, 1, 1, -1, 235470), -- Leather Gloves Lining
(22250, 57, 178, 277, 0, 700000), -- Adena
(22250, 38, 1, 1, 1, 2714.526595), -- Low Boots
(22250, 50, 1, 1, 1, 2714.526595), -- Leather Gloves
(22250, 1925, 1, 1, 1, 46369.94681), -- Leather Gloves Lining
(22250, 1873, 1, 1, 2, 21214.078708), -- Silver Nugget
(22250, 1868, 1, 1, 2, 106070.556382), -- Thread
(22250, 1801, 1, 1, 2, 26717.975466), -- Recipe: Piece Bone Gaiters
(22250, 734, 1, 1, 2, 8839.389444), -- Haste Potion
-- Shady Muertos Captain
(22251, 5549, 1, 1, -1, 37094), -- Metallic Thread
(22251, 1889, 1, 1, -1, 24730), -- Compound Braid
(22251, 6035, 1, 1, -1, 30912), -- Magic Haste Potion
(22251, 57, 181, 290, 0, 700000), -- Adena
(22251, 176, 1, 1, 1, 208.5), -- Apprentice's Staff
(22251, 2501, 1, 1, 1, 208.5), -- Bone Club
(22251, 1868, 1, 1, 2, 146094.659213), -- Thread
(22251, 1873, 1, 1, 2, 29218.893858), -- Silver Nugget
(22251, 1817, 1, 1, 2, 14609.446929), -- Recipe: Cord
-- Grotto Grizzly
(22252, 2011, 1, 1, -1, 8430), -- Short Spear Edge
(22252, 1817, 1, 1, -1, 73905), -- Recipe: Cord
(22252, 2012, 1, 1, -1, 7698), -- Sword of Reflection Blade
(22252, 57, 180, 289, 0, 700000), -- Adena
(22252, 845, 1, 1, 1, 1595.819094), -- Cat's Eye Earring
(22252, 877, 1, 1, 1, 2393.728641), -- Ring of Wisdom
(22252, 908, 1, 1, 1, 1196.873411), -- Necklace of Wisdom
(22252, 1897, 1, 1, 1, 12994.578854), -- Necklace of Wisdom Chain
(22252, 1864, 1, 1, 2, 145535), -- Stem
(22252, 1869, 1, 1, 2, 72767.5), -- Iron Ore
(22252, 2139, 1, 1, 2, 14553.5), -- Recipe: Steel Mold
-- Shady Muertos Warrior
(22253, 2139, 1, 1, -1, 76353), -- Recipe: Steel Mold
(22253, 2013, 1, 1, -1, 8239), -- Forest Bow Shaft
(22253, 1869, 1, 1, -1, 381764), -- Iron Ore
(22253, 57, 183, 301, 0, 700000), -- Adena
(22253, 15, 1, 1, 1, 214.769007), -- Short Spear
(22253, 2011, 1, 1, 1, 2572.230993), -- Short Spear Edge
(22253, 1869, 1, 1, 2, 37589.07751), -- Iron Ore
(22253, 1870, 1, 1, 2, 37589.07751), -- Coal
(22253, 1871, 1, 1, 2, 37589.07751), -- Charcoal
(22253, 1872, 1, 1, 2, 50118.696506), -- Animal Bone
(22253, 1867, 1, 1, 2, 50118.696506), -- Animal Skin
(22253, 2140, 1, 1, 2, 7517.374458), -- Recipe: High-Grade Suede
-- Shady Muertos Archer
(22254, 1865, 1, 1, -1, 382809), -- Varnish
(22254, 734, 1, 1, -1, 63802), -- Haste Potion
(22254, 1897, 1, 1, -1, 91145), -- Necklace of Wisdom Chain
(22254, 57, 183, 302, 0, 700000), -- Adena
(22254, 217, 1, 1, 1, 215.5), -- Shining Knife
(22254, 218, 1, 1, 1, 215.5), -- Throwing Knife
(22254, 1864, 1, 1, 2, 75383.951247), -- Stem
(22254, 1865, 1, 1, 2, 37691.857522), -- Varnish
(22254, 1866, 1, 1, 2, 25127.983749), -- Suede
(22254, 1873, 1, 1, 2, 15076.83749), -- Silver Nugget
(22254, 1868, 1, 1, 2, 75383.951247), -- Thread
(22254, 2141, 1, 1, 2, 7538.418745), -- Recipe: Silver Mold
-- Shady Muertos Commander
(22255, 2140, 1, 1, -1, 78741), -- Recipe: High-Grade Suede
(22255, 1924, 1, 1, -1, 127002), -- Leather Helmet Design
(22255, 2141, 1, 1, -1, 78741), -- Recipe: Silver Mold
(22255, 57, 185, 314, 0, 700000), -- Adena
(22255, 24, 1, 1, 1, 745.5536), -- Bone Breastplate
(22255, 31, 1, 1, 1, 1190.4464), -- Bone Gaiters
(22255, 390, 1, 1, 1, 745.5536), -- Cotton Shirt
(22255, 412, 1, 1, 1, 1190.4464), -- Cotton Pants
(22255, 1868, 1, 1, 2, 116294.966918), -- Thread
(22255, 1873, 1, 1, 2, 23258.930972), -- Silver Nugget
(22255, 2142, 1, 1, 2, 11629.465486), -- Recipe: Varnish of Purity
(22255, 735, 1, 1, 2, 4845.636624), -- Alacrity Potion
-- Shady Muertos Wizard
(22256, 1925, 1, 1, -1, 285016), -- Leather Gloves Lining
(22256, 1871, 1, 1, -1, 434649), -- Charcoal
(22256, 5220, 1, 1, -1, 17386), -- Metal Hardener
(22256, 57, 204, 347, 0, 700000), -- Adena
(22256, 24, 1, 1, 1, 822.9587), -- Bone Breastplate
(22256, 31, 1, 1, 1, 1314.0413), -- Bone Gaiters
(22256, 390, 1, 1, 1, 822.9587), -- Cotton Shirt
(22256, 412, 1, 1, 1, 1314.0413), -- Cotton Pants
(22256, 1866, 1, 1, 2, 57061.808539), -- Suede
(22256, 1871, 1, 1, 2, 85592.632922), -- Charcoal
(22256, 2143, 1, 1, 2, 17118.558539), -- Recipe: Synthetic Cokes
-- Island Guardian
(22257, 5480, 1, 1, -1, 15799), -- Sealed Leather Armor of Nightmare Fabric
(22257, 1808, 1, 1, -1, 1565), -- Recipe: Soulshot (S-Grade)
(22257, 5481, 1, 1, -1, 15799), -- Sealed Majestic Leather Armor Fabric
(22257, 57, 1771, 3615, 0, 700000), -- Adena
(22257, 12221, 1, 1, 1, 708.082067), -- Common Item - Sealed Dark Crystal Gloves
(22257, 5508, 1, 1, 1, 3810.167933), -- Sealed Dark Crystal Gloves Design
(22257, 12224, 1, 1, 1, 708.082067), -- Common Item - Sealed Dark Crystal Boots
(22257, 5496, 1, 1, 1, 3810.167933), -- Sealed Dark Crystal Boots Lining
(22257, 12229, 1, 1, 1, 708.082067), -- Common Item - Sealed Tallum Gloves
(22257, 5509, 1, 1, 1, 3810.167933), -- Sealed Tallum Gloves Design
(22257, 12231, 1, 1, 1, 708.082067), -- Common Item - Sealed Tallum Boots
(22257, 5497, 1, 1, 1, 3810.167933), -- Sealed Tallum Boots Lining
(22257, 1873, 1, 1, 2, 47273.083), -- Silver Nugget
(22257, 1868, 1, 1, 2, 236365.069941), -- Thread
(22257, 1876, 1, 1, 2, 23636.5415), -- Mithril Ore
(22257, 1895, 1, 1, 2, 33766.438563), -- Metallic Fiber
(22257, 4042, 1, 1, 2, 1969.596772), -- Enria
(22257, 1808, 1, 1, 2, 52.448968), -- Recipe: Soulshot (S-Grade)
(22257, 9573, 1, 1, 2, 820.550302), -- Life Stone - Level 80
(22257, 9574, 1, 1, 2, 205.310105), -- Mid-Grade Life Stone - Level 80
(22257, 9575, 1, 1, 2, 20.358481), -- High-Grade Life Stone - Level 80
(22257, 9576, 1, 1, 2, 4.140708), -- Top-Grade Life Stone - Level 80
(22257, 9546, 1, 1, 2, 945.46166), -- Fire Stone
-- White Sand Mirage
(22258, 3036, 1, 1, -1, 1206), -- Recipe: Spiritshot S
(22258, 5487, 1, 1, -1, 12222), -- Sealed Robe of Nightmare Fabric
(22258, 1894, 1, 1, -1, 95236), -- Crafted Leather
(22258, 57, 1821, 3717, 0, 700000), -- Adena
(22258, 11968, 1, 1, 1, 39.613827), -- Common Item - Dragon Slayer
(22258, 5529, 1, 1, 1, 611.334009), -- Dragon Slayer Edge
(22258, 11971, 1, 1, 1, 39.613827), -- Common Item - Sword of Miracles
(22258, 5546, 1, 1, 1, 671.490501), -- Sword of Miracles Edge
(22258, 11964, 1, 1, 1, 39.613827), -- Common Item - Dark Legion's Edge
(22258, 5545, 1, 1, 1, 611.334009), -- Dark Legion's Edge Blade
(22258, 1894, 1, 1, 2, 7819.15422), -- Crafted Leather
(22258, 4039, 1, 1, 2, 7428.20179), -- Mold Glue
(22258, 4041, 1, 1, 2, 1937.783735), -- Mold Hardener
(22258, 4044, 1, 1, 2, 7428.20179), -- Thons
(22258, 959, 1, 1, 2, 8.92489), -- Scroll: Enchant Weapon (S-Grade)
(22258, 9546, 1, 1, 2, 1782.733575), -- Fire Stone
-- Muddy Coral
(22259, 4040, 1, 1, -1, 59275), -- Mold Lubricant
(22259, 5488, 1, 1, -1, 13346), -- Sealed Majestic Robe Fabric
(22259, 3957, 1, 1, -1, 1317), -- Recipe: Blessed Spiritshot S
(22259, 57, 1988, 4059, 0, 700000), -- Adena
(22259, 11974, 1, 1, 1, 32.451172), -- Common Item - Elysian
(22259, 5533, 1, 1, 1, 500.698068), -- Elysian Head
(22259, 11970, 1, 1, 1, 32.451172), -- Common Item - Branch of the Mother Tree
(22259, 5544, 1, 1, 1, 500.203444), -- Branch of the Mother Tree Head
(22259, 11969, 1, 1, 1, 32.451172), -- Common Item - Flaming Dragon Skull
(22259, 8342, 1, 1, 1, 500.698068), -- Flaming Dragon Skull Piece
(22259, 11966, 1, 1, 1, 32.451172), -- Common Item - Doom Crusher
(22259, 8349, 1, 1, 1, 500.595732), -- Doom Crusher Head
(22259, 1871, 1, 1, 2, 182498.511656), -- Charcoal
(22259, 1866, 1, 1, 2, 121665.818536), -- Suede
(22259, 1877, 1, 1, 2, 7299.750256), -- Adamantite Nugget
(22259, 4041, 1, 1, 2, 1586.958616), -- Mold Hardener
(22259, 4040, 1, 1, 2, 3649.875128), -- Mold Lubricant
(22259, 960, 1, 1, 2, 73.058024), -- Scroll: Enchant Armor (S-Grade)
(22259, 9546, 1, 1, 2, 1459.863592), -- Fire Stone
(22259, 1344, 20, 60, 2, 114062.164192), -- Mithril Arrow
-- Kleopora
(22260, 5495, 1, 1, -1, 37283), -- Sealed Shield of Nightmare Fragment
(22260, 5157, 1, 1, -1, 1091), -- Recipe: Soulshot (S) Compressed Package (100%)
(22260, 5502, 1, 1, -1, 41467), -- Sealed Boots of Nightmare Lining
(22260, 57, 1647, 3363, 0, 700000), -- Adena
(22260, 12263, 1, 1, 1, 126.777843), -- Common Item - Sealed Armor of Nightmare
(22260, 5522, 1, 1, 1, 1029.722157), -- Sealed Armor of Nightmare Pattern
(22260, 12262, 1, 1, 1, 126.777843), -- Common Item - Sealed Majestic Plate Armor
(22260, 5523, 1, 1, 1, 1029.722157), -- Sealed Majestic Plate Armor Pattern
(22260, 10557, 1, 1, 2, 20853), -- Forgotten Scroll - Song of Windstorm
-- Seychelles
(22261, 1885, 1, 1, -1, 211091), -- High-Grade Suede
(22261, 4041, 1, 1, -1, 22027), -- Mold Hardener
(22261, 5503, 1, 1, -1, 42781), -- Sealed Majestic Boots Lining
(22261, 57, 1696, 3473, 0, 700000), -- Adena
(22261, 11975, 1, 1, 1, 110.930208), -- Common Item - Soul Bow
(22261, 5534, 1, 1, 1, 1713.069792), -- Soul Bow Stave
(22261, 10558, 1, 1, 2, 21514), -- Forgotten Scroll - Dance of Blade Storm
-- Naiad
(22262, 5162, 1, 1, -1, 1140), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22262, 5514, 1, 1, -1, 43313), -- Sealed Gauntlets of Nightmare Design
(22262, 5167, 1, 1, -1, 1140), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22262, 57, 1717, 3516, 0, 700000), -- Adena
(22262, 11974, 1, 1, 1, 28.067524), -- Common Item - Elysian
(22262, 5533, 1, 1, 1, 433.061556), -- Elysian Head
(22262, 11970, 1, 1, 1, 28.067524), -- Common Item - Branch of the Mother Tree
(22262, 5544, 1, 1, 1, 432.633748), -- Branch of the Mother Tree Head
(22262, 11969, 1, 1, 1, 28.067524), -- Common Item - Flaming Dragon Skull
(22262, 8342, 1, 1, 1, 433.061556), -- Flaming Dragon Skull Piece
(22262, 11966, 1, 1, 1, 28.067524), -- Common Item - Doom Crusher
(22262, 8349, 1, 1, 1, 432.973044), -- Doom Crusher Head
(22262, 1895, 1, 1, 2, 36095.375106), -- Metallic Fiber
(22262, 4040, 1, 1, 2, 2526.658848), -- Mold Lubricant
(22262, 9628, 1, 1, 2, 990.85077), -- Leonard
(22262, 9630, 1, 1, 2, 664.912458), -- Orichalcum
(22262, 960, 1, 1, 2, 50.52978), -- Scroll: Enchant Armor (S-Grade)
(22262, 9573, 1, 1, 2, 877.307382), -- Life Stone - Level 80
(22262, 9574, 1, 1, 2, 219.31623), -- Mid-Grade Life Stone - Level 80
(22262, 9575, 1, 1, 2, 21.952854), -- High-Grade Life Stone - Level 80
(22262, 9576, 1, 1, 2, 4.373586), -- Top-Grade Life Stone - Level 80
(22262, 9546, 1, 1, 2, 1010.722986), -- Fire Stone
-- Sonneratia
(22263, 5515, 1, 1, -1, 49910), -- Sealed Majestic Gauntlets Design
(22263, 1895, 1, 1, -1, 844332), -- Metallic Fiber
(22263, 4040, 1, 1, -1, 59103), -- Mold Lubricant
(22263, 57, 1978, 4052, 0, 700000), -- Adena
(22263, 11967, 1, 1, 1, 129.403242), -- Common Item - Dragon Grinder
(22263, 5538, 1, 1, 1, 1996.596758), -- Dragon Grinder Edge
(22263, 1895, 1, 1, 2, 41592.732527), -- Metallic Fiber
(22263, 4040, 1, 1, 2, 2911.471216), -- Mold Lubricant
(22263, 9628, 1, 1, 2, 1141.758215), -- Leonard
(22263, 9630, 1, 1, 2, 766.179211), -- Orichalcum
(22263, 960, 1, 1, 2, 58.22551), -- Scroll: Enchant Armor (S-Grade)
(22263, 9573, 1, 1, 2, 1010.922069), -- Life Stone - Level 80
(22263, 9574, 1, 1, 2, 252.718285), -- Mid-Grade Life Stone - Level 80
(22263, 9575, 1, 1, 2, 25.296293), -- High-Grade Life Stone - Level 80
(22263, 9576, 1, 1, 2, 5.039687), -- Top-Grade Life Stone - Level 80
(22263, 9546, 1, 1, 2, 1164.656987), -- Fire Stone
-- Castalia
(22264, 5522, 1, 1, -1, 8946), -- Sealed Armor of Nightmare Pattern
(22264, 5272, 1, 1, -1, 1167), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22264, 5523, 1, 1, -1, 8946), -- Sealed Majestic Plate Armor Pattern
(22264, 57, 1759, 3602, 0, 700000), -- Adena
(22264, 11975, 1, 1, 1, 115.004947), -- Common Item - Soul Bow
(22264, 5534, 1, 1, 1, 1775.995053), -- Soul Bow Stave
(22264, 1868, 1, 1, 2, 369712.693067), -- Thread
(22264, 1873, 1, 1, 2, 73942.635036), -- Silver Nugget
(22264, 5549, 1, 1, 2, 18485.658759), -- Metallic Thread
(22264, 1889, 1, 1, 2, 12323.772506), -- Compound Braid
(22264, 4044, 1, 1, 2, 6161.886253), -- Thons
(22264, 959, 1, 1, 2, 7.231695), -- Scroll: Enchant Weapon (S-Grade)
(22264, 9546, 1, 1, 2, 1479.122684), -- Fire Stone
-- Chrysocolla
(22265, 6901, 1, 1, -1, 3038), -- Recipe: Shining Arrow (100%)
(22265, 6688, 1, 1, -1, 6566), -- Forgotten Blade Edge
(22265, 959, 1, 1, -1, 122), -- Scroll: Enchant Weapon (S-Grade)
(22265, 57, 1778, 3566, 0, 700000), -- Adena
(22265, 11973, 1, 1, 1, 133.031216), -- Common Item - Soul Separator
(22265, 5537, 1, 1, 1, 2052.968784), -- Soul Separator Head
(22265, 1895, 1, 1, 2, 42754.768648), -- Metallic Fiber
(22265, 4040, 1, 1, 2, 2992.813184), -- Mold Lubricant
(22265, 9628, 1, 1, 2, 1173.65716), -- Leonard
(22265, 9630, 1, 1, 2, 787.585064), -- Orichalcum
(22265, 960, 1, 1, 2, 59.85224), -- Scroll: Enchant Armor (S-Grade)
(22265, 9573, 1, 1, 2, 1039.165656), -- Life Stone - Level 80
(22265, 9574, 1, 1, 2, 259.77884), -- Mid-Grade Life Stone - Level 80
(22265, 9575, 1, 1, 2, 26.003032), -- High-Grade Life Stone - Level 80
(22265, 9576, 1, 1, 2, 5.180488), -- Top-Grade Life Stone - Level 80
(22265, 9546, 1, 1, 2, 1197.195688), -- Fire Stone
-- Pythia
(22266, 1895, 1, 1, -1, 773207), -- Metallic Fiber
(22266, 4040, 1, 1, -1, 54124), -- Mold Lubricant
(22266, 6689, 1, 1, -1, 5739), -- Basalt Battlehammer Head
(22266, 57, 1584, 3176, 0, 700000), -- Adena
(22266, 11973, 1, 1, 1, 118.486632), -- Common Item - Soul Separator
(22266, 5537, 1, 1, 1, 1828.513368), -- Soul Separator Head
(22266, 1895, 1, 1, 2, 54412.968016), -- Metallic Fiber
(22266, 4040, 1, 1, 2, 3808.985888), -- Mold Lubricant
(22266, 9628, 1, 1, 2, 1493.725848), -- Leonard
(22266, 9630, 1, 1, 2, 1002.427968), -- Orichalcum
(22266, 6901, 1, 1, 2, 190.509392), -- Recipe: Shining Arrow (100%)
(22266, 9546, 1, 1, 2, 1523.47416), -- Fire Stone
(22266, 1344, 10, 30, 2, 238055.908728), -- Mithril Arrow
-- Dark Water Dragon
(22267, 6901, 1, 1, -1, 42222), -- Recipe: Shining Arrow (100%)
(22267, 6690, 1, 1, -1, 91435), -- Imperial Staff Head
(22267, 57, 24706, 49558, 0, 700000), -- Adena
(22267, 11976, 1, 1, 1, 1848.773472), -- Common Item - Tallum Glaive
(22267, 5541, 1, 1, 1, 28519.226528), -- Tallum Glaive Edge
(22267, 1895, 3, 9, 2, 198083.702472), -- Metallic Fiber
(22267, 4040, 1, 1, 2, 83195.101284), -- Mold Lubricant
(22267, 9628, 1, 1, 2, 32625.46404), -- Leonard
(22267, 9630, 1, 1, 2, 21893.430024), -- Orichalcum
(22267, 959, 1, 1, 2, 166.30218), -- Scroll: Enchant Weapon (S-Grade)
-- Shade
(22268, 5480, 1, 1, -1, 9230), -- Sealed Leather Armor of Nightmare Fabric
(22268, 1876, 1, 1, -1, 411375), -- Mithril Ore
(22268, 1895, 1, 1, -1, 587678), -- Metallic Fiber
(22268, 57, 1377, 2821, 0, 700000), -- Adena
(22268, 12265, 1, 1, 1, 141.495048), -- Common Item - Sealed Leather Armor of Nightmare
(22268, 5480, 1, 1, 1, 1136.504952), -- Sealed Leather Armor of Nightmare Fabric
(22268, 12258, 1, 1, 1, 141.495048), -- Common Item - Sealed Majestic Leather Armor
(22268, 5481, 1, 1, 1, 1136.504952), -- Sealed Majestic Leather Armor Fabric
(22268, 1873, 1, 1, 2, 50661.908728), -- Silver Nugget
(22268, 1868, 1, 3, 2, 126654.971984), -- Thread
(22268, 1876, 1, 1, 2, 25331.154528), -- Mithril Ore
(22268, 1895, 1, 1, 2, 36187.249232), -- Metallic Fiber
(22268, 4042, 1, 1, 2, 2110.929544), -- Enria
(22268, 960, 1, 1, 2, 50.841656), -- Scroll: Enchant Armor (S-Grade)
(22268, 9548, 1, 1, 2, 1013.230168), -- Earth Stone
(22268, 1344, 10, 30, 2, 158317.71416), -- Mithril Arrow
-- Shade
(22269, 5481, 1, 1, -1, 9321), -- Sealed Majestic Leather Armor Fabric
(22269, 1808, 1, 1, -1, 923), -- Recipe: Soulshot (S-Grade)
(22269, 5487, 1, 1, -1, 9354), -- Sealed Robe of Nightmare Fabric
(22269, 57, 1391, 2849, 0, 700000), -- Adena
(22269, 12263, 1, 1, 1, 107.265127), -- Common Item - Sealed Armor of Nightmare
(22269, 5522, 1, 1, 1, 871.234873), -- Sealed Armor of Nightmare Pattern
(22269, 12262, 1, 1, 1, 107.265127), -- Common Item - Sealed Majestic Plate Armor
(22269, 5523, 1, 1, 1, 871.234873), -- Sealed Majestic Plate Armor Pattern
(22269, 1872, 1, 1, 2, 194913.656213), -- Animal Bone
(22269, 1867, 1, 1, 2, 194913.656213), -- Animal Skin
(22269, 1881, 1, 1, 2, 19491.239126), -- Coarse Bone Powder
(22269, 1875, 1, 1, 2, 9745.619563), -- Stone of Purity
(22269, 4041, 1, 1, 2, 1271.277765), -- Mold Hardener
(22269, 6901, 1, 1, 2, 146.312897), -- Recipe: Shining Arrow (100%)
(22269, 9548, 1, 1, 2, 1169.238223), -- Earth Stone
-- Water Dragon Detractor
(22270, 3036, 1, 1, -1, 1020), -- Recipe: Spiritshot S
(22270, 5488, 1, 1, -1, 10335), -- Sealed Majestic Robe Fabric
(22270, 4044, 1, 1, -1, 76502), -- Thons
(22270, 57, 1537, 3147, 0, 700000), -- Adena
(22270, 12266, 1, 1, 1, 157.881424), -- Common Item - Sealed Robe of Nightmare
(22270, 5487, 1, 1, 1, 1272.618576), -- Sealed Robe of Nightmare Fabric
(22270, 12259, 1, 1, 1, 157.881424), -- Common Item - Sealed Majestic Robe
(22270, 5488, 1, 1, 1, 1272.618576), -- Sealed Majestic Robe Fabric
(22270, 1868, 1, 1, 2, 188428.48992), -- Thread
(22270, 1873, 1, 1, 2, 37685.62512), -- Silver Nugget
(22270, 5549, 1, 1, 2, 9421.3152), -- Metallic Thread
(22270, 1889, 1, 1, 2, 6280.8768), -- Compound Braid
(22270, 4044, 1, 1, 2, 3140.4384), -- Thons
(22270, 959, 1, 1, 2, 3.6432), -- Scroll: Enchant Weapon (S-Grade)
(22270, 9573, 1, 1, 2, 654.31872), -- Life Stone - Level 80
(22270, 9574, 1, 1, 2, 163.57968), -- Mid-Grade Life Stone - Level 80
(22270, 9575, 1, 1, 2, 16.3944), -- High-Grade Life Stone - Level 80
(22270, 9576, 1, 1, 2, 3.27888), -- Top-Grade Life Stone - Level 80
(22270, 9549, 1, 1, 2, 753.77808), -- Wind Stone
(22270, 1344, 10, 30, 2, 117768.2616), -- Mithril Arrow
-- Water Dragon Detractor
(22271, 1895, 1, 1, -1, 655731), -- Metallic Fiber
(22271, 5495, 1, 1, -1, 34850), -- Sealed Shield of Nightmare Fragment
(22271, 3957, 1, 1, -1, 1020), -- Recipe: Blessed Spiritshot S
(22271, 57, 1537, 3147, 0, 700000), -- Adena
(22271, 12350, 1, 1, 1, 347.975824), -- Common Item - Sealed Majestic Necklace
(22271, 6344, 1, 1, 1, 2762.22408), -- Sealed Majestic Necklace Beads
(22271, 12352, 1, 1, 1, 463.532496), -- Common Item - Sealed Majestic Earring
(22271, 6342, 1, 1, 1, 4268.334224), -- Sealed Majestic Earring Gemstone
(22271, 12351, 1, 1, 1, 695.291408), -- Common Item - Sealed Majestic Ring
(22271, 6346, 1, 1, 1, 6134.641968), -- Sealed Majestic Ring Gemstone
(22271, 1895, 1, 1, 2, 53836.99099), -- Metallic Fiber
(22271, 4040, 1, 1, 2, 3768.598618), -- Mold Lubricant
(22271, 9628, 1, 1, 2, 1477.880602), -- Leonard
(22271, 9630, 1, 1, 2, 991.707272), -- Orichalcum
(22271, 960, 1, 1, 2, 75.346076), -- Scroll: Enchant Armor (S-Grade)
(22271, 9549, 1, 1, 2, 1507.476442), -- Wind Stone
-- Beleth's Minion
(22272, 5502, 1, 1, -1, 55226), -- Sealed Boots of Nightmare Lining
(22272, 5157, 1, 1, -1, 1453), -- Recipe: Soulshot (S) Compressed Package (100%)
(22272, 5503, 1, 1, -1, 55226), -- Sealed Majestic Boots Lining
(22272, 57, 2189, 4484, 0, 700000), -- Adena
(22272, 6326, 1, 1, 1, 26.873728), -- Sealed Majestic Necklace
(22272, 6344, 1, 1, 1, 3935.151696), -- Sealed Majestic Necklace Beads
(22272, 6327, 1, 1, 1, 35.837928), -- Sealed Majestic Earring
(22272, 6342, 1, 1, 1, 6080.803736), -- Sealed Majestic Earring Gemstone
(22272, 6328, 1, 1, 1, 53.747456), -- Sealed Majestic Ring
(22272, 6346, 1, 1, 1, 8739.585456), -- Sealed Majestic Ring Gemstone
(22272, 1873, 1, 1, 2, 92045.237241), -- Silver Nugget
(22272, 1868, 4, 12, 2, 57528.408759), -- Thread
(22272, 1876, 1, 1, 2, 46022.799265), -- Mithril Ore
(22272, 1895, 1, 1, 2, 65746.649642), -- Metallic Fiber
(22272, 4042, 1, 1, 2, 3835.082735), -- Enria
(22272, 6901, 1, 1, 2, 230.141093), -- Recipe: Shining Arrow (100%)
(22272, 1344, 30, 90, 2, 95880.681265), -- Mithril Arrow
-- Beleth's Minion
(22273, 4040, 1, 1, -1, 63254), -- Mold Lubricant
(22273, 1895, 1, 1, -1, 903635), -- Metallic Fiber
(22273, 5514, 1, 1, -1, 53415), -- Sealed Gauntlets of Nightmare Design
(22273, 57, 2117, 4337, 0, 700000), -- Adena
(22273, 5312, 1, 1, 1, 25.556544), -- Sealed Helm of Nightmare
(22273, 5527, 1, 1, 1, 3104.331693), -- Sealed Helm of Nightmare Design
(22273, 5315, 1, 1, 1, 36.522513), -- Sealed Shield of Nightmare
(22273, 5495, 1, 1, 1, 3942.701013), -- Sealed Shield of Nightmare Fragment
(22273, 5317, 1, 1, 1, 25.556544), -- Sealed Majestic Circlet
(22273, 5528, 1, 1, 1, 3104.331693), -- Sealed Majestic Circlet Design
(22273, 1895, 1, 1, 2, 49460.252802), -- Metallic Fiber
(22273, 4040, 1, 1, 2, 3462.205214), -- Mold Lubricant
(22273, 9628, 1, 1, 2, 1357.71641), -- Leonard
(22273, 9630, 1, 1, 2, 911.082746), -- Orichalcum
(22273, 959, 1, 1, 2, 6.921914), -- Scroll: Enchant Weapon (S-Grade)
(22273, 9573, 1, 1, 2, 1202.143556), -- Life Stone - Level 80
(22273, 9574, 1, 1, 2, 300.535889), -- Mid-Grade Life Stone - Level 80
(22273, 9575, 1, 1, 2, 30.07061), -- High-Grade Life Stone - Level 80
(22273, 9576, 1, 1, 2, 6.070859), -- Top-Grade Life Stone - Level 80
-- Beleth's Minion
(22274, 5162, 1, 1, -1, 1434), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22274, 5515, 1, 1, -1, 54507), -- Sealed Majestic Gauntlets Design
(22274, 5167, 1, 1, -1, 1434), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22274, 57, 2161, 4426, 0, 700000), -- Adena
(22274, 5312, 1, 1, 1, 26.080704), -- Sealed Helm of Nightmare
(22274, 5527, 1, 1, 1, 3168.000963), -- Sealed Helm of Nightmare Design
(22274, 5315, 1, 1, 1, 37.271583), -- Sealed Shield of Nightmare
(22274, 5495, 1, 1, 1, 4023.565083), -- Sealed Shield of Nightmare Fragment
(22274, 5317, 1, 1, 1, 26.080704), -- Sealed Majestic Circlet
(22274, 5528, 1, 1, 1, 3168.000963), -- Sealed Majestic Circlet Design
(22274, 1871, 1, 3, 2, 75706.540644), -- Charcoal
(22274, 1866, 1, 1, 2, 151413.081288), -- Suede
(22274, 1877, 1, 1, 2, 9084.615582), -- Adamantite Nugget
(22274, 4041, 1, 1, 2, 1974.983346), -- Mold Hardener
(22274, 4040, 1, 1, 2, 4542.500172), -- Mold Lubricant
(22274, 960, 1, 1, 2, 90.803832), -- Scroll: Enchant Armor (S-Grade)
(22274, 1344, 20, 60, 2, 141949.475136), -- Mithril Arrow
-- Gatekeeper Lohan
(22275, 5522, 1, 1, -1, 62805), -- Sealed Armor of Nightmare Pattern
(22275, 1895, 1, 11, -1, 878191), -- Metallic Fiber
(22275, 4040, 1, 1, -1, 368840), -- Mold Lubricant
(22275, 57, 12348, 25286, 0, 700000), -- Adena
(22275, 164, 1, 1, 1, 10.95), -- Elysian
(22275, 5533, 1, 1, 1, 3114.975), -- Elysian Head
(22275, 213, 1, 1, 1, 10.95), -- Branch of the Mother Tree
(22275, 5544, 1, 1, 1, 3111.9), -- Branch of the Mother Tree Head
(22275, 7895, 1, 1, 1, 10.95), -- Flaming Dragon Skull
(22275, 8342, 1, 1, 1, 3114.975), -- Flaming Dragon Skull Piece
(22275, 7902, 1, 1, 1, 10.95), -- Doom Crusher
(22275, 8349, 1, 1, 1, 3114.35), -- Doom Crusher Head
(22275, 1895, 1, 3, 2, 216303.282885), -- Metallic Fiber
(22275, 4040, 1, 1, 2, 30282.426012), -- Mold Lubricant
(22275, 4042, 1, 1, 2, 25235.243037), -- Enria
(22275, 4043, 1, 1, 2, 50470.821993), -- Asofe
(22275, 6901, 1, 1, 2, 1513.986933), -- Recipe: Shining Arrow (100%)
(22275, 9546, 1, 1, 2, 12113.23914), -- Fire Stone
-- Gatekeeper of the Square
(22276, 5523, 1, 1, -1, 19263), -- Sealed Majestic Plate Armor Pattern
(22276, 5272, 1, 1, -1, 2514), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22276, 5527, 1, 1, -1, 67627), -- Sealed Helm of Nightmare Design
(22276, 57, 3787, 7755, 0, 700000), -- Adena
(22276, 164, 1, 1, 1, 3.358584), -- Elysian
(22276, 5533, 1, 1, 1, 955.425132), -- Elysian Head
(22276, 213, 1, 1, 1, 3.358584), -- Branch of the Mother Tree
(22276, 5544, 1, 1, 1, 954.481968), -- Branch of the Mother Tree Head
(22276, 7895, 1, 1, 1, 3.358584), -- Flaming Dragon Skull
(22276, 8342, 1, 1, 1, 955.425132), -- Flaming Dragon Skull Piece
(22276, 7902, 1, 1, 1, 3.358584), -- Doom Crusher
(22276, 8349, 1, 1, 1, 955.233432), -- Doom Crusher Head
(22276, 1895, 1, 1, 2, 72373.456032), -- Metallic Fiber
(22276, 4040, 1, 1, 2, 5066.013384), -- Mold Lubricant
(22276, 9628, 1, 1, 2, 1986.719172), -- Leonard
(22276, 9630, 1, 1, 2, 1333.182558), -- Orichalcum
(22276, 959, 1, 1, 2, 10.04205), -- Scroll: Enchant Weapon (S-Grade)
(22276, 9573, 1, 1, 2, 1758.965478), -- Life Stone - Level 80
(22276, 9574, 1, 1, 2, 439.84179), -- Mid-Grade Life Stone - Level 80
(22276, 9575, 1, 1, 2, 43.783338), -- High-Grade Life Stone - Level 80
(22276, 9576, 1, 1, 2, 8.837004), -- Top-Grade Life Stone - Level 80
(22276, 9546, 1, 1, 2, 2026.48569), -- Fire Stone
(22276, 1344, 10, 30, 2, 316634.673504), -- Mithril Arrow
-- Gatekeeper Provo
(22277, 5277, 1, 1, -1, 8196), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22277, 5528, 1, 1, -1, 220493), -- Sealed Majestic Circlet Design
(22277, 4042, 1, 1, -1, 307367), -- Enria
(22277, 57, 12348, 25286, 0, 700000), -- Adena
(22277, 289, 1, 1, 1, 43.8025), -- Soul Bow
(22277, 5534, 1, 1, 1, 12471.1975), -- Soul Bow Stave
(22277, 1873, 2, 6, 2, 129781.89308), -- Silver Nugget
(22277, 1868, 15, 45, 2, 86521.377959), -- Thread
(22277, 1876, 3, 9, 2, 37080.54088), -- Mithril Ore
(22277, 1895, 3, 9, 2, 61801.133278), -- Metallic Fiber
(22277, 4042, 1, 1, 2, 21630.431419), -- Enria
(22277, 960, 1, 1, 2, 519.141481), -- Scroll: Enchant Armor (S-Grade)
(22277, 9547, 1, 1, 2, 10382.481903), -- Water Stone
-- Gatekeeper of Fire
(22278, 4039, 1, 1, -1, 188545), -- Mold Glue
(22278, 5529, 1, 1, -1, 15518), -- Dragon Slayer Edge
(22278, 5282, 1, 1, -1, 2514), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22278, 57, 3787, 7755, 0, 700000), -- Adena
(22278, 289, 1, 1, 1, 13.433), -- Soul Bow
(22278, 5534, 1, 1, 1, 3824.567), -- Soul Bow Stave
(22278, 1894, 1, 1, 2, 13966.814088), -- Crafted Leather
(22278, 4039, 1, 1, 2, 13268.651184), -- Mold Glue
(22278, 4041, 1, 1, 2, 3461.477454), -- Mold Hardener
(22278, 4044, 1, 1, 2, 13268.651184); -- Thons

INSERT INTO `droplist` VALUES
(22278, 6901, 1, 1, 2, 397.976562), -- Recipe: Shining Arrow (100%)
(22278, 9547, 1, 1, 2, 3184.405164), -- Water Stone
(22278, 1344, 20, 60, 2, 248786.024364), -- Mithril Arrow
-- Chromatic Detainee
(22279, 5533, 1, 1, -1, 15188), -- Elysian Head
(22279, 1808, 1, 1, -1, 2461), -- Recipe: Soulshot (S-Grade)
(22279, 5534, 1, 1, -1, 15201), -- Soul Bow Stave
(22279, 57, 3707, 7592, 0, 700000), -- Adena
(22279, 81, 1, 1, 1, 4.383756), -- Dragon Slayer
(22279, 5529, 1, 1, 1, 1246.723152), -- Dragon Slayer Edge
(22279, 151, 1, 1, 1, 4.383756), -- Sword of Miracles
(22279, 5546, 1, 1, 1, 1369.406304), -- Sword of Miracles Edge
(22279, 2500, 1, 1, 1, 4.383756), -- Dark Legion's Edge
(22279, 5545, 1, 1, 1, 1246.719276), -- Dark Legion's Edge Blade
(22279, 1871, 1, 3, 2, 194826.902634), -- Charcoal
(22279, 1866, 1, 1, 2, 259769.365011), -- Suede
(22279, 1877, 1, 1, 2, 15586.26849), -- Adamantite Nugget
(22279, 4041, 1, 1, 2, 3388.087521), -- Mold Hardener
(22279, 4040, 1, 1, 2, 7793.134245), -- Mold Lubricant
(22279, 959, 1, 1, 2, 15.503904), -- Scroll: Enchant Weapon (S-Grade)
(22279, 9546, 1, 1, 2, 3117.738195), -- Fire Stone
-- Rodo Knight
(22280, 4041, 1, 1, -1, 27398), -- Mold Hardener
(22280, 4044, 1, 1, -1, 105027), -- Thons
(22280, 5537, 1, 1, -1, 8644), -- Soul Separator Head
(22280, 57, 2109, 4321, 0, 700000), -- Adena
(22280, 5313, 1, 1, 1, 28.636686), -- Sealed Gauntlets of Nightmare
(22280, 5514, 1, 1, 1, 3276.613314), -- Sealed Gauntlets of Nightmare Design
(22280, 5314, 1, 1, 1, 28.636686), -- Sealed Boots of Nightmare
(22280, 5502, 1, 1, 1, 3276.613314), -- Sealed Boots of Nightmare Lining
(22280, 5318, 1, 1, 1, 28.636686), -- Sealed Majestic Gauntlets
(22280, 5515, 1, 1, 1, 3276.613314), -- Sealed Majestic Gauntlets Design
(22280, 5319, 1, 1, 1, 28.636686), -- Sealed Majestic Boots
(22280, 5503, 1, 1, 1, 3276.613314), -- Sealed Majestic Boots Lining
(22280, 1894, 1, 1, 2, 5446.139841), -- Crafted Leather
(22280, 4039, 1, 1, 2, 5173.835823), -- Mold Glue
(22280, 4041, 1, 1, 2, 1349.703198), -- Mold Hardener
(22280, 4044, 1, 1, 2, 5173.835823), -- Thons
(22280, 960, 1, 1, 2, 62.078337), -- Scroll: Enchant Armor (S-Grade)
(22280, 9573, 1, 1, 2, 1077.875028), -- Life Stone - Level 80
(22280, 9574, 1, 1, 2, 269.468757), -- Mid-Grade Life Stone - Level 80
(22280, 9575, 1, 1, 2, 26.944893), -- High-Grade Life Stone - Level 80
(22280, 9576, 1, 1, 2, 5.392944), -- Top-Grade Life Stone - Level 80
(22280, 9546, 1, 1, 2, 1241.725356), -- Fire Stone
-- Plaza Caiman
(22281, 3036, 1, 1, -1, 840), -- Recipe: Spiritshot S
(22281, 5538, 1, 1, -1, 5187), -- Dragon Grinder Edge
(22281, 3957, 1, 1, -1, 840), -- Recipe: Blessed Spiritshot S
(22281, 57, 1266, 2593, 0, 700000), -- Adena
(22281, 305, 1, 1, 1, 4.492128), -- Tallum Glaive
(22281, 5541, 1, 1, 1, 1277.507872), -- Tallum Glaive Edge
(22281, 1895, 1, 1, 2, 44359.636629), -- Metallic Fiber
(22281, 4040, 1, 1, 2, 3105.175073), -- Mold Lubricant
(22281, 9628, 1, 1, 2, 1217.710725), -- Leonard
(22281, 9630, 1, 1, 2, 817.151335), -- Orichalcum
(22281, 6901, 1, 1, 2, 155.23585), -- Recipe: Shining Arrow (100%)
(22281, 9546, 1, 1, 2, 1242.090388), -- Fire Stone
-- Chromatic Detainee
(22282, 5541, 1, 1, -1, 15185), -- Tallum Glaive Edge
(22282, 5550, 1, 1, -1, 73826), -- Durable Metal Plate
(22282, 4043, 1, 1, -1, 184566), -- Asofe
(22282, 57, 3707, 7592, 0, 700000), -- Adena
(22282, 5320, 1, 1, 1, 20.655024), -- Sealed Leather Armor of Nightmare
(22282, 5480, 1, 1, 1, 3060.344976), -- Sealed Leather Armor of Nightmare Fabric
(22282, 5323, 1, 1, 1, 20.655024), -- Sealed Majestic Leather Armor
(22282, 5481, 1, 1, 1, 3060.344976), -- Sealed Majestic Leather Armor Fabric
(22282, 1869, 1, 3, 2, 129884.64426), -- Iron Ore
(22282, 1864, 4, 12, 2, 97413.4113), -- Stem
(22282, 1880, 1, 1, 2, 38965.36452), -- Steel
(22282, 5550, 1, 1, 2, 5195.42028), -- Durable Metal Plate
(22282, 4043, 1, 1, 2, 12988.5507), -- Asofe
(22282, 959, 1, 1, 2, 15.52932), -- Scroll: Enchant Weapon (S-Grade)
(22282, 9546, 1, 1, 2, 3117.07962), -- Fire Stone
-- Emerald Alligar
(22283, 5544, 1, 1, -1, 5182), -- Branch of the Mother Tree Head
(22283, 5157, 1, 1, -1, 840), -- Recipe: Soulshot (S) Compressed Package (100%)
(22283, 5545, 1, 1, -1, 5188), -- Dark Legion's Edge Blade
(22283, 57, 1266, 2593, 0, 700000), -- Adena
(22283, 5311, 1, 1, 1, 5.290861), -- Sealed Armor of Nightmare
(22283, 5522, 1, 1, 1, 793.209139), -- Sealed Armor of Nightmare Pattern
(22283, 5316, 1, 1, 1, 5.290861), -- Sealed Majestic Plate Armor
(22283, 5523, 1, 1, 1, 793.209139), -- Sealed Majestic Plate Armor Pattern
(22283, 1895, 1, 1, 2, 44359.76662), -- Metallic Fiber
(22283, 4040, 1, 1, 2, 3105.191284), -- Mold Lubricant
(22283, 9628, 1, 1, 2, 1217.721076), -- Leonard
(22283, 9630, 1, 1, 2, 817.131536), -- Orichalcum
(22283, 960, 1, 1, 2, 62.082488), -- Scroll: Enchant Armor (S-Grade)
(22283, 9546, 1, 1, 2, 1242.106996), -- Fire Stone
-- Chromatic Detainee
(22284, 5162, 1, 1, -1, 2358), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22284, 5546, 1, 1, -1, 15986), -- Sword of Miracles Edge
(22284, 5549, 1, 1, -1, 530489), -- Metallic Thread
(22284, 57, 3552, 7274, 0, 700000), -- Adena
(22284, 5326, 1, 1, 1, 19.788743), -- Sealed Robe of Nightmare
(22284, 5487, 1, 1, 1, 2941.711257), -- Sealed Robe of Nightmare Fabric
(22284, 5329, 1, 1, 1, 19.788743), -- Sealed Majestic Robe
(22284, 5488, 1, 1, 1, 2941.711257), -- Sealed Majestic Robe Fabric
(22284, 1868, 1, 3, 2, 237568.069951), -- Thread
(22284, 1873, 1, 1, 2, 95027.381724), -- Silver Nugget
(22284, 5549, 1, 1, 2, 23756.845431), -- Metallic Thread
(22284, 1889, 1, 1, 2, 15837.896954), -- Compound Braid
(22284, 4044, 1, 1, 2, 7918.948477), -- Thons
(22284, 6901, 1, 1, 2, 237.533862), -- Recipe: Shining Arrow (100%)
(22284, 9573, 1, 1, 2, 1649.668828), -- Life Stone - Level 80
(22284, 9574, 1, 1, 2, 412.417207), -- Mid-Grade Life Stone - Level 80
(22284, 9575, 1, 1, 2, 41.126413), -- High-Grade Life Stone - Level 80
(22284, 9576, 1, 1, 2, 8.071539), -- Top-Grade Life Stone - Level 80
(22284, 9547, 1, 1, 2, 1901.039614), -- Water Stone
-- Chromatic Detainee
(22285, 6342, 1, 1, -1, 194619), -- Sealed Majestic Earring Gemstone
(22285, 5167, 1, 1, -1, 3818), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22285, 57, 3835, 7853, 0, 700000), -- Adena
(22285, 6326, 1, 1, 1, 47.071744), -- Sealed Majestic Necklace
(22285, 6344, 1, 1, 1, 6892.771008), -- Sealed Majestic Necklace Beads
(22285, 6327, 1, 1, 1, 62.773344), -- Sealed Majestic Earring
(22285, 6342, 1, 1, 1, 10651.072928), -- Sealed Majestic Earring Gemstone
(22285, 6328, 1, 1, 1, 94.143488), -- Sealed Majestic Ring
(22285, 6346, 1, 1, 1, 15308.167488), -- Sealed Majestic Ring Gemstone
(22285, 1864, 4, 12, 2, 100767.441024), -- Stem
(22285, 1865, 2, 6, 2, 80614.038624), -- Varnish
(22285, 1866, 3, 9, 2, 44785.81536), -- Suede
(22285, 1873, 1, 1, 2, 161228.077248), -- Silver Nugget
(22285, 1868, 10, 30, 2, 38387.780448), -- Thread
(22285, 959, 1, 1, 2, 16.302912), -- Scroll: Enchant Weapon (S-Grade)
(22285, 9547, 1, 1, 2, 3224.544384), -- Water Stone
-- Plaza Gaviel
(22286, 6344, 1, 1, -1, 27722), -- Sealed Majestic Necklace Beads
(22286, 5272, 1, 1, -1, 840), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22286, 6346, 1, 1, -1, 61568), -- Sealed Majestic Ring Gemstone
(22286, 57, 1266, 2593, 0, 700000), -- Adena
(22286, 5313, 1, 1, 1, 17.18721), -- Sealed Gauntlets of Nightmare
(22286, 5514, 1, 1, 1, 1966.56279), -- Sealed Gauntlets of Nightmare Design
(22286, 5314, 1, 1, 1, 17.18721), -- Sealed Boots of Nightmare
(22286, 5502, 1, 1, 1, 1966.56279), -- Sealed Boots of Nightmare Lining
(22286, 5318, 1, 1, 1, 17.18721), -- Sealed Majestic Gauntlets
(22286, 5515, 1, 1, 1, 1966.56279), -- Sealed Majestic Gauntlets Design
(22286, 5319, 1, 1, 1, 17.18721), -- Sealed Majestic Boots
(22286, 5503, 1, 1, 1, 1966.56279), -- Sealed Majestic Boots Lining
(22286, 1869, 2, 6, 2, 33269.705755), -- Iron Ore
(22286, 1870, 1, 1, 2, 133078.374611), -- Coal
(22286, 1871, 1, 1, 2, 133078.374611), -- Charcoal
(22286, 1872, 1, 3, 2, 88719.065877), -- Animal Bone
(22286, 1867, 1, 3, 2, 59146.043918), -- Animal Skin
(22286, 960, 1, 1, 2, 53.360671), -- Scroll: Enchant Armor (S-Grade)
(22286, 9546, 1, 1, 2, 1064.074557), -- Fire Stone
-- Crystalline Unicorn
(22287, 1894, 1, 1, -1, 230482), -- Crafted Leather
(22287, 4039, 1, 1, -1, 218958), -- Mold Glue
(22287, 8342, 1, 1, -1, 18018), -- Flaming Dragon Skull Piece
(22287, 57, 4398, 9008, 0, 700000), -- Adena
(22287, 5312, 1, 1, 1, 53.079936), -- Sealed Helm of Nightmare
(22287, 5527, 1, 1, 1, 6447.574742), -- Sealed Helm of Nightmare Design
(22287, 5315, 1, 1, 1, 75.855822), -- Sealed Shield of Nightmare
(22287, 5495, 1, 1, 1, 8188.834822), -- Sealed Shield of Nightmare Fragment
(22287, 5317, 1, 1, 1, 53.079936), -- Sealed Majestic Circlet
(22287, 5528, 1, 1, 1, 6447.574742), -- Sealed Majestic Circlet Design
(22287, 1894, 1, 1, 2, 18922.98848), -- Crafted Leather
(22287, 4039, 1, 1, 2, 17976.85194), -- Mold Glue
(22287, 4041, 1, 1, 2, 4689.58274), -- Mold Hardener
(22287, 4044, 1, 1, 2, 17976.85194), -- Thons
(22287, 6901, 1, 1, 2, 539.32424), -- Recipe: Shining Arrow (100%)
(22287, 9546, 1, 1, 2, 4314.40066), -- Fire Stone
-- Emerald Boar
(22288, 5277, 1, 1, -1, 3207), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22288, 8349, 1, 1, -1, 19787), -- Doom Crusher Head
(22288, 5282, 1, 1, -1, 3207), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22288, 57, 4830, 9894, 0, 700000), -- Adena
(22288, 5312, 1, 1, 1, 58.30656), -- Sealed Helm of Nightmare
(22288, 5527, 1, 1, 1, 7082.44832), -- Sealed Helm of Nightmare Design
(22288, 5315, 1, 1, 1, 83.32512), -- Sealed Shield of Nightmare
(22288, 5495, 1, 1, 1, 8995.16512), -- Sealed Shield of Nightmare Fragment
(22288, 5317, 1, 1, 1, 58.30656), -- Sealed Majestic Circlet
(22288, 5528, 1, 1, 1, 7082.44832), -- Sealed Majestic Circlet Design
(22288, 1873, 2, 6, 2, 50775.71412), -- Silver Nugget
(22288, 1868, 3, 9, 2, 169251.901203), -- Thread
(22288, 1876, 1, 1, 2, 101551.42824), -- Mithril Ore
(22288, 1895, 1, 1, 2, 145073.058174), -- Metallic Fiber
(22288, 4042, 1, 1, 2, 8462.61902), -- Enria
(22288, 959, 1, 1, 2, 20.126274), -- Scroll: Enchant Weapon (S-Grade)
(22288, 9546, 1, 1, 2, 4062.152969), -- Fire Stone
-- Plaza Helm
(22289, 5480, 1, 1, -1, 31544), -- Sealed Leather Armor of Nightmare Fabric
(22289, 1876, 1, 3, -1, 702978), -- Mithril Ore
(22289, 1895, 1, 5, -1, 669503), -- Metallic Fiber
(22289, 57, 4706, 9640, 0, 700000), -- Adena
(22289, 164, 1, 1, 1, 4.17414), -- Elysian
(22289, 5533, 1, 1, 1, 1187.42847), -- Elysian Head
(22289, 213, 1, 1, 1, 4.17414), -- Branch of the Mother Tree
(22289, 5544, 1, 1, 1, 1186.25628), -- Branch of the Mother Tree Head
(22289, 7895, 1, 1, 1, 4.17414), -- Flaming Dragon Skull
(22289, 8342, 1, 1, 1, 1187.42847), -- Flaming Dragon Skull Piece
(22289, 7902, 1, 1, 1, 4.17414), -- Doom Crusher
(22289, 8349, 1, 1, 1, 1187.19022), -- Doom Crusher Head
(22289, 1873, 1, 1, 2, 125925.287646), -- Silver Nugget
(22289, 1868, 3, 9, 2, 104937.936936), -- Thread
(22289, 1876, 1, 1, 2, 62962.841054), -- Mithril Ore
(22289, 1895, 1, 1, 2, 89946.803088), -- Metallic Fiber
(22289, 4042, 1, 1, 2, 5246.739062), -- Enria
(22289, 960, 1, 1, 2, 125.833378), -- Scroll: Enchant Armor (S-Grade)
(22289, 9573, 1, 1, 2, 2186.108404), -- Life Stone - Level 80
(22289, 9574, 1, 1, 2, 546.724332), -- Mid-Grade Life Stone - Level 80
(22289, 9575, 1, 1, 2, 54.830218), -- High-Grade Life Stone - Level 80
(22289, 9576, 1, 1, 2, 11.044936), -- Top-Grade Life Stone - Level 80
(22289, 9546, 1, 1, 2, 2517.850946), -- Fire Stone
-- Terod's Minion
(22290, 5481, 1, 1, -1, 94465), -- Sealed Majestic Leather Armor Fabric
(22290, 1808, 1, 1, -1, 9356), -- Recipe: Soulshot (S-Grade)
(22290, 5487, 1, 1, -1, 94799), -- Sealed Robe of Nightmare Fabric
(22290, 57, 14094, 28869, 0, 700000), -- Adena
(22290, 164, 1, 1, 1, 12.499644), -- Elysian
(22290, 5533, 1, 1, 1, 3555.806262), -- Elysian Head
(22290, 213, 1, 1, 1, 12.499644), -- Branch of the Mother Tree
(22290, 5544, 1, 1, 1, 3552.296088), -- Branch of the Mother Tree Head
(22290, 7895, 1, 1, 1, 12.499644), -- Flaming Dragon Skull
(22290, 8342, 1, 1, 1, 3555.806262), -- Flaming Dragon Skull Piece
(22290, 7902, 1, 1, 1, 12.499644), -- Doom Crusher
(22290, 8349, 1, 1, 1, 3555.092812), -- Doom Crusher Head
(22290, 1868, 15, 45, 2, 98766.1745), -- Thread
(22290, 1873, 12, 36, 2, 24691.76017), -- Silver Nugget
(22290, 5549, 1, 1, 2, 148149.26175), -- Metallic Thread
(22290, 1889, 1, 1, 2, 98766.1745), -- Compound Braid
(22290, 4044, 1, 1, 2, 49383.08725), -- Thons
(22290, 6901, 1, 1, 2, 1481.60089), -- Recipe: Shining Arrow (100%)
(22290, 9546, 1, 1, 2, 11851.94094), -- Fire Stone
-- Weylin's Minion
(22291, 3036, 1, 1, -1, 8051), -- Recipe: Spiritshot S
(22291, 5488, 1, 1, -1, 81576), -- Sealed Majestic Robe Fabric
(22291, 1889, 1, 3, -1, 603856), -- Compound Braid
(22291, 57, 12128, 24842, 0, 700000), -- Adena
(22291, 289, 1, 1, 1, 43.0255), -- Soul Bow
(22291, 5534, 1, 1, 1, 12249.9745), -- Soul Bow Stave
(22291, 1868, 15, 45, 2, 84990.239232), -- Thread
(22291, 1873, 2, 6, 2, 127485.12), -- Silver Nugget
(22291, 5549, 1, 1, 2, 127485.12), -- Metallic Thread
(22291, 1889, 1, 1, 2, 84990.239232), -- Compound Braid
(22291, 4044, 1, 1, 2, 42494.880768), -- Thons
(22291, 959, 1, 1, 2, 51.113472), -- Scroll: Enchant Weapon (S-Grade)
(22291, 9546, 1, 1, 2, 10199.287296), -- Fire Stone
-- Tourmaline
(22292, 4040, 1, 1, -1, 103289), -- Mold Lubricant
(22292, 5495, 1, 1, -1, 78421), -- Sealed Shield of Nightmare Fragment
(22292, 3957, 1, 1, -1, 2295), -- Recipe: Blessed Spiritshot S
(22292, 57, 3458, 7082, 0, 700000), -- Adena
(22292, 289, 1, 1, 1, 12.2675), -- Soul Bow
(22292, 5534, 1, 1, 1, 3492.7325), -- Soul Bow Stave
(22292, 1895, 1, 1, 2, 72687.187004), -- Metallic Fiber
(22292, 4040, 1, 1, 2, 5088.068032), -- Mold Lubricant
(22292, 9628, 1, 1, 2, 1995.32918), -- Leonard
(22292, 9630, 1, 1, 2, 1338.969772), -- Orichalcum
(22292, 960, 1, 1, 2, 101.75452), -- Scroll: Enchant Armor (S-Grade)
(22292, 9573, 1, 1, 2, 1766.680788), -- Life Stone - Level 80
(22292, 9574, 1, 1, 2, 441.64882), -- Mid-Grade Life Stone - Level 80
(22292, 9575, 1, 1, 2, 44.207636), -- High-Grade Life Stone - Level 80
(22292, 9576, 1, 1, 2, 8.807324), -- Top-Grade Life Stone - Level 80
(22292, 9546, 1, 1, 2, 2035.346924), -- Fire Stone
-- Spinel
(22293, 5502, 1, 1, -1, 101659), -- Sealed Boots of Nightmare Lining
(22293, 5157, 1, 1, -1, 2675), -- Recipe: Soulshot (S) Compressed Package (100%)
(22293, 5503, 1, 1, -1, 101659), -- Sealed Majestic Boots Lining
(22293, 57, 4030, 8254, 0, 700000), -- Adena
(22293, 305, 1, 1, 1, 14.29632), -- Tallum Glaive
(22293, 5541, 1, 1, 1, 4065.70368), -- Tallum Glaive Edge
(22293, 1871, 1, 3, 2, 211794.810568), -- Charcoal
(22293, 1866, 1, 3, 2, 94130.951622), -- Suede
(22293, 1877, 1, 1, 2, 16943.544185), -- Adamantite Nugget
(22293, 4041, 1, 1, 2, 3683.497027), -- Mold Hardener
(22293, 4040, 1, 1, 2, 8471.941511), -- Mold Lubricant
(22293, 6901, 1, 1, 2, 423.54625), -- Recipe: Shining Arrow (100%)
(22293, 9546, 1, 1, 2, 3388.708837), -- Fire Stone
-- Fire Opal
(22294, 1895, 1, 3, -1, 737778), -- Metallic Fiber
(22294, 4040, 1, 1, -1, 103289), -- Mold Lubricant
(22294, 5514, 1, 1, -1, 87223), -- Sealed Gauntlets of Nightmare Design
(22294, 57, 3458, 7082, 0, 700000), -- Adena
(22294, 305, 1, 1, 1, 12.267504), -- Tallum Glaive
(22294, 5541, 1, 1, 1, 3488.732496), -- Tallum Glaive Edge
(22294, 1895, 1, 1, 2, 121145.623264), -- Metallic Fiber
(22294, 4040, 1, 1, 2, 8480.167296), -- Mold Lubricant
(22294, 9628, 1, 1, 2, 3325.51504), -- Leonard
(22294, 9630, 1, 1, 2, 2231.608384), -- Orichalcum
(22294, 959, 1, 1, 2, 16.908224), -- Scroll: Enchant Weapon (S-Grade)
(22294, 9546, 1, 1, 2, 3392.177792), -- Fire Stone
-- Reef Golem
(22295, 5162, 1, 1, -1, 6687), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22295, 5515, 1, 1, -1, 254123), -- Sealed Majestic Gauntlets Design
(22295, 5167, 1, 1, -1, 6687), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22295, 57, 10074, 20633, 0, 700000), -- Adena
(22295, 5320, 1, 1, 1, 56.125888), -- Sealed Leather Armor of Nightmare
(22295, 5480, 1, 1, 1, 8315.874112), -- Sealed Leather Armor of Nightmare Fabric
(22295, 5323, 1, 1, 1, 56.125888), -- Sealed Majestic Leather Armor
(22295, 5481, 1, 1, 1, 8315.874112), -- Sealed Majestic Leather Armor Fabric
(22295, 1895, 1, 1, 2, 352959.044913), -- Metallic Fiber
(22295, 4040, 1, 1, 2, 24707.218608), -- Mold Lubricant
(22295, 4042, 1, 1, 2, 20589.198903), -- Enria
(22295, 4043, 1, 1, 2, 41178.397806), -- Asofe
(22295, 960, 1, 1, 2, 494.342289), -- Scroll: Enchant Armor (S-Grade)
(22295, 9546, 1, 1, 2, 9882.797481), -- Fire Stone
-- Reef Golem
(22296, 5522, 1, 1, -1, 53897), -- Sealed Armor of Nightmare Pattern
(22296, 1877, 1, 1, -1, 633054), -- Adamantite Nugget
(22296, 4041, 1, 1, -1, 137620), -- Mold Hardener
(22296, 57, 10596, 21703, 0, 700000), -- Adena
(22296, 5311, 1, 1, 1, 44.278245), -- Sealed Armor of Nightmare
(22296, 5522, 1, 1, 1, 6638.221755), -- Sealed Armor of Nightmare Pattern
(22296, 5316, 1, 1, 1, 44.278245), -- Sealed Majestic Plate Armor
(22296, 5523, 1, 1, 1, 6638.221755), -- Sealed Majestic Plate Armor Pattern
(22296, 1871, 9, 27, 2, 54140.43668), -- Charcoal
(22296, 1866, 2, 6, 2, 162421.724135), -- Suede
(22296, 1877, 1, 1, 2, 38981.24692), -- Adamantite Nugget
(22296, 4041, 1, 1, 2, 8474.04008), -- Mold Hardener
(22296, 4040, 1, 1, 2, 19490.62346), -- Mold Lubricant
(22296, 6901, 1, 1, 2, 974.365535), -- Recipe: Shining Arrow (100%)
(22296, 9546, 1, 1, 2, 7796.166565), -- Fire Stone
(22296, 1344, 100, 300, 2, 121816.396625), -- Mithril Arrow
-- Reef Golem
(22297, 5523, 1, 1, -1, 53050), -- Sealed Majestic Plate Armor Pattern
(22297, 5272, 1, 1, -1, 6923), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22297, 5527, 1, 1, -1, 186245), -- Sealed Helm of Nightmare Design
(22297, 57, 10429, 21361, 0, 700000), -- Adena
(22297, 5326, 1, 1, 1, 58.106672), -- Sealed Robe of Nightmare
(22297, 5487, 1, 1, 1, 8637.893328), -- Sealed Robe of Nightmare Fabric
(22297, 5329, 1, 1, 1, 58.106672), -- Sealed Majestic Robe
(22297, 5488, 1, 1, 1, 8637.893328), -- Sealed Majestic Robe Fabric
(22297, 1871, 4, 12, 2, 137029.418637), -- Charcoal
(22297, 1866, 1, 3, 2, 243607.493877), -- Suede
(22297, 1877, 1, 1, 2, 43849.358193), -- Adamantite Nugget
(22297, 4041, 1, 1, 2, 9532.630827), -- Mold Hardener
(22297, 4040, 1, 1, 2, 21924.446718), -- Mold Lubricant
(22297, 959, 1, 1, 2, 43.687158), -- Scroll: Enchant Weapon (S-Grade)
(22297, 9546, 1, 1, 2, 8769.96459), -- Fire Stone
-- Weylin
(22298, 5277, 1, 1, -1, 15930), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22298, 5528, 1, 1, -1, 428543), -- Sealed Majestic Circlet Design
(22298, 4042, 1, 1, -1, 597389), -- Enria
(22298, 57, 23997, 49152, 0, 700000), -- Adena
(22298, 6326, 1, 1, 1, 294.574336), -- Sealed Majestic Necklace
(22298, 6344, 1, 1, 1, 43134.867552), -- Sealed Majestic Necklace Beads
(22298, 6327, 1, 1, 1, 392.834736), -- Sealed Majestic Earring
(22298, 6342, 1, 1, 1, 66654.270032), -- Sealed Majestic Earring Gemstone
(22298, 6328, 1, 1, 1, 589.148672), -- Sealed Majestic Ring
(22298, 6346, 1, 1, 1, 95798.304672), -- Sealed Majestic Ring Gemstone
(22298, 1873, 3, 9, 2, 98093.577582), -- Silver Nugget
(22298, 1868, 32, 96, 2, 45981.134199), -- Thread
(22298, 1876, 4, 12, 2, 32697.859194), -- Mithril Ore
(22298, 1895, 3, 9, 2, 60057.434437), -- Metallic Fiber
(22298, 4042, 1, 1, 2, 24523.189691), -- Enria
(22298, 960, 1, 1, 2, 588.730142), -- Scroll: Enchant Armor (S-Grade)
(22298, 9573, 1, 1, 2, 10218.029822), -- Life Stone - Level 80
(22298, 9574, 1, 1, 2, 2554.71216), -- Mid-Grade Life Stone - Level 80
(22298, 9575, 1, 1, 2, 255.471216), -- High-Grade Life Stone - Level 80
(22298, 9576, 1, 1, 2, 51.176125), -- Top-Grade Life Stone - Level 80
(22298, 9546, 1, 1, 2, 11771.327568), -- Fire Stone
(22298, 1344, 150, 450, 2, 122616.357864), -- Mithril Arrow
-- Dolph
(22299, 4041, 1, 1, -1, 447646), -- Mold Hardener
(22299, 5529, 1, 1, -1, 141233), -- Dragon Slayer Edge
(22299, 5282, 1, 1, -1, 22880), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22299, 57, 34465, 70594, 0, 700000), -- Adena
(22299, 5313, 1, 1, 1, 467.881992), -- Sealed Gauntlets of Nightmare
(22299, 5514, 1, 1, 1, 53535.118008), -- Sealed Gauntlets of Nightmare Design
(22299, 5314, 1, 1, 1, 467.881992), -- Sealed Boots of Nightmare
(22299, 5502, 1, 1, 1, 53535.118008), -- Sealed Boots of Nightmare Lining
(22299, 5318, 1, 1, 1, 467.881992), -- Sealed Majestic Gauntlets
(22299, 5515, 1, 1, 1, 53535.118008), -- Sealed Majestic Gauntlets Design
(22299, 5319, 1, 1, 1, 467.881992), -- Sealed Majestic Boots
(22299, 5503, 1, 1, 1, 53535.118008), -- Sealed Majestic Boots Lining
(22299, 1894, 1, 3, 2, 88979.871617), -- Crafted Leather
(22299, 4039, 1, 1, 2, 169061.898956), -- Mold Glue
(22299, 4041, 1, 1, 2, 44102.959121), -- Mold Hardener
(22299, 4044, 1, 1, 2, 169061.898956), -- Thons
(22299, 6901, 1, 1, 2, 5072.37135), -- Recipe: Shining Arrow (100%)
-- Dolph's Minion
(22300, 5533, 1, 1, -1, 22932), -- Elysian Head
(22300, 1808, 1, 1, -1, 3716), -- Recipe: Soulshot (S-Grade)
(22300, 5534, 1, 1, -1, 22952), -- Soul Bow Stave
(22300, 57, 5597, 11465, 0, 700000), -- Adena
(22300, 5312, 1, 1, 1, 67.559232), -- Sealed Helm of Nightmare
(22300, 5527, 1, 1, 1, 8206.362529), -- Sealed Helm of Nightmare Design
(22300, 5315, 1, 1, 1, 96.547989), -- Sealed Shield of Nightmare
(22300, 5495, 1, 1, 1, 10422.608489), -- Sealed Shield of Nightmare Fragment
(22300, 5317, 1, 1, 1, 67.559232), -- Sealed Majestic Circlet
(22300, 5528, 1, 1, 1, 8206.362529), -- Sealed Majestic Circlet Design
(22300, 1871, 4, 12, 2, 85800.698676), -- Charcoal
(22300, 1866, 1, 3, 2, 152534.638872), -- Suede
(22300, 1877, 1, 1, 2, 27456.360624), -- Adamantite Nugget
(22300, 4041, 1, 1, 2, 5968.71198), -- Mold Hardener
(22300, 4040, 1, 1, 2, 13728.180312), -- Mold Lubricant
(22300, 959, 1, 1, 2, 27.409536), -- Scroll: Enchant Weapon (S-Grade)
-- Terod
(22301, 1875, 1, 7, -1, 739835), -- Stone of Purity
(22301, 4040, 1, 1, -1, 887802), -- Mold Lubricant
(22301, 5537, 1, 1, -1, 121784), -- Soul Separator Head
(22301, 57, 29719, 60872, 0, 700000), -- Adena
(22301, 81, 1, 1, 1, 35.143563), -- Dragon Slayer
(22301, 5529, 1, 1, 1, 9994.692596), -- Dragon Slayer Edge
(22301, 151, 1, 1, 1, 35.143563), -- Sword of Miracles
(22301, 5546, 1, 1, 1, 10978.215192), -- Sword of Miracles Edge
(22301, 2500, 1, 1, 1, 35.143563), -- Dark Legion's Edge
(22301, 5545, 1, 1, 1, 9994.661523), -- Dark Legion's Edge Blade
(22301, 1865, 28, 84, 2, 55783.293097), -- Varnish
(22301, 1870, 60, 180, 2, 26031.955145), -- Coal
(22301, 1879, 3, 9, 2, 86773.494192), -- Cokes
(22301, 1875, 1, 1, 2, 208256.572286), -- Stone of Purity
(22301, 4040, 1, 1, 2, 62477.157911), -- Mold Lubricant
(22301, 960, 1, 1, 2, 1249.571092), -- Scroll: Enchant Armor (S-Grade)
(22301, 9546, 1, 1, 2, 24990.956277), -- Fire Stone
-- Darnel's Guardian
(22302, 3036, 1, 1, -1, 11856), -- Recipe: Spiritshot S
(22302, 5538, 1, 1, -1, 73171), -- Dragon Grinder Edge
(22302, 3957, 1, 1, -1, 11856), -- Recipe: Blessed Spiritshot S
(22302, 57, 17859, 36581, 0, 700000), -- Adena
(22302, 164, 1, 1, 1, 15.838956), -- Elysian
(22302, 5533, 1, 1, 1, 4505.749038), -- Elysian Head
(22302, 213, 1, 1, 1, 15.838956), -- Branch of the Mother Tree
(22302, 5544, 1, 1, 1, 4501.301112), -- Branch of the Mother Tree Head
(22302, 7895, 1, 1, 1, 15.838956), -- Flaming Dragon Skull
(22302, 8342, 1, 1, 1, 4505.749038), -- Flaming Dragon Skull Piece
(22302, 7902, 1, 1, 1, 15.838956), -- Doom Crusher
(22302, 8349, 1, 1, 1, 4504.844988), -- Doom Crusher Head
(22302, 1895, 1, 3, 2, 375452.73921), -- Metallic Fiber
(22302, 4040, 1, 1, 2, 52563.54162), -- Mold Lubricant
(22302, 9628, 1, 1, 2, 20613.25389), -- Leonard
(22302, 9630, 1, 1, 2, 13832.24169), -- Orichalcum
(22302, 6901, 1, 1, 2, 2628.22359), -- Recipe: Shining Arrow (100%)
-- Guardian of the Square
(22303, 5541, 1, 1, -1, 76313), -- Tallum Glaive Edge
(22303, 5550, 1, 1, -1, 371029), -- Durable Metal Plate
(22303, 4043, 1, 1, -1, 927572), -- Asofe
(22303, 57, 18630, 38159, 0, 700000), -- Adena
(22303, 270, 1, 1, 1, 66.091101), -- Dragon Grinder
(22303, 5538, 1, 1, 1, 18800.908899), -- Dragon Grinder Edge
(22303, 1869, 7, 21, 2, 152310.588869), -- Iron Ore
(22303, 1864, 24, 72, 2, 95193.972974), -- Stem
(22303, 1880, 3, 9, 2, 32637.845168), -- Steel
(22303, 5550, 1, 1, 2, 30462.195144), -- Durable Metal Plate
(22303, 4043, 1, 1, 2, 76155.101009), -- Asofe
(22303, 959, 1, 1, 2, 91.296836), -- Scroll: Enchant Weapon (S-Grade)
-- Guardian of the Emerald
(22304, 5544, 1, 1, -1, 76561), -- Branch of the Mother Tree Head
(22304, 5157, 1, 1, -1, 12418), -- Recipe: Soulshot (S) Compressed Package (100%)
(22304, 5545, 1, 1, -1, 76652), -- Dark Legion's Edge Blade
(22304, 57, 18705, 38313, 0, 700000), -- Adena
(22304, 289, 1, 1, 1, 66.3565), -- Soul Bow
(22304, 5534, 1, 1, 1, 18892.6435), -- Soul Bow Stave
(22304, 1867, 4, 12, 2, 229388.231105), -- Animal Skin
(22304, 1872, 7, 21, 2, 122340.227683), -- Animal Bone
(22304, 1882, 3, 9, 2, 50975.054308), -- Leather
(22304, 1894, 1, 1, 2, 48292.25918), -- Crafted Leather
(22304, 4042, 1, 1, 2, 22938.579751), -- Enria
(22304, 960, 1, 1, 2, 550.479189), -- Scroll: Enchant Armor (S-Grade)
(22304, 9573, 1, 1, 2, 9557.701003), -- Life Stone - Level 80
(22304, 9574, 1, 1, 2, 2389.303571), -- Mid-Grade Life Stone - Level 80
(22304, 9575, 1, 1, 2, 238.979029), -- High-Grade Life Stone - Level 80
(22304, 9576, 1, 1, 2, 48.185181), -- Top-Grade Life Stone - Level 80
-- Kechi's Captain
(22305, 5162, 1, 1, -1, 2880), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22305, 5546, 1, 1, -1, 19529), -- Sword of Miracles Edge
(22305, 1895, 1, 3, -1, 925777), -- Metallic Fiber
(22305, 57, 4339, 8887, 0, 700000), -- Adena
(22305, 289, 1, 1, 1, 15.393), -- Soul Bow
(22305, 5534, 1, 1, 1, 4382.607), -- Soul Bow Stave
(22305, 1895, 1, 1, 2, 152016.100383), -- Metallic Fiber
(22305, 4040, 1, 1, 2, 10641.128771), -- Mold Lubricant
(22305, 9628, 1, 1, 2, 4172.974575), -- Leonard
(22305, 9630, 1, 1, 2, 2800.297045), -- Orichalcum
(22305, 6901, 1, 1, 2, 531.97795), -- Recipe: Shining Arrow (100%)
(22305, 9547, 1, 1, 2, 4256.521276), -- Water Stone
-- Kechi's Captain
(22306, 6342, 1, 1, -1, 505968), -- Sealed Majestic Earring Gemstone
(22306, 5167, 1, 1, -1, 9927), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22306, 57, 9969, 20420, 0, 700000), -- Adena
(22306, 236, 1, 1, 1, 35.366698), -- Soul Separator
(22306, 5537, 1, 1, 1, 10063.633302), -- Soul Separator Head
(22306, 1864, 36, 108, 2, 29108.268112), -- Stem
(22306, 1865, 25, 75, 2, 20957.796024), -- Varnish
(22306, 1866, 3, 9, 2, 116432.74533), -- Suede
(22306, 1873, 4, 12, 2, 52394.817178), -- Silver Nugget
(22306, 1868, 10, 30, 2, 99799.449266), -- Thread
(22306, 959, 1, 1, 2, 41.871104), -- Scroll: Enchant Weapon (S-Grade)
(22306, 9547, 1, 1, 2, 8383.052986), -- Water Stone
-- Kechi's Captain
(22307, 6344, 1, 1, -1, 528217), -- Sealed Majestic Necklace Beads
(22307, 5272, 1, 1, -1, 16014), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22307, 6346, 1, 3, -1, 586559), -- Sealed Majestic Ring Gemstone
(22307, 57, 24123, 49411, 0, 700000), -- Adena
(22307, 236, 1, 1, 1, 85.578374), -- Soul Separator
(22307, 5537, 1, 1, 1, 24351.421626), -- Soul Separator Head
(22307, 1879, 1, 1, 2, 268937.773487), -- Cokes
(22307, 1885, 1, 1, 2, 134469.116478), -- High-Grade Suede
(22307, 9628, 1, 1, 2, 12656.073605), -- Leonard
(22307, 9630, 1, 1, 2, 8492.824996), -- Orichalcum
(22307, 9629, 1, 1, 2, 7015.632161), -- Adamantine
(22307, 960, 1, 1, 2, 645.553945), -- Scroll: Enchant Armor (S-Grade)
(22307, 9573, 1, 1, 2, 11205.529972), -- Life Stone - Level 80
(22307, 9574, 1, 1, 2, 2801.382493), -- Mid-Grade Life Stone - Level 80
(22307, 9575, 1, 1, 2, 280.27609), -- High-Grade Life Stone - Level 80
(22307, 9576, 1, 1, 2, 56.055218), -- Top-Grade Life Stone - Level 80
(22307, 9547, 1, 1, 2, 12908.781555), -- Water Stone
-- Kechi's Guard
(22308, 8342, 1, 1, -1, 48761), -- Flaming Dragon Skull Piece
(22308, 57, 3967, 8126, 0, 700000), -- Adena
(22308, 5320, 1, 1, 1, 22.103088), -- Sealed Leather Armor of Nightmare
(22308, 5480, 1, 1, 1, 3274.896912), -- Sealed Leather Armor of Nightmare Fabric
(22308, 5323, 1, 1, 1, 22.103088), -- Sealed Majestic Leather Armor
(22308, 5481, 1, 1, 1, 3274.896912), -- Sealed Majestic Leather Armor Fabric
(22308, 1879, 1, 1, 2, 69501.008059), -- Cokes
(22308, 1885, 1, 1, 2, 34750.446388), -- High-Grade Suede
(22308, 9628, 1, 1, 2, 3270.57871), -- Leonard
(22308, 9630, 1, 1, 2, 2194.757754), -- Orichalcum
(22308, 9629, 1, 1, 2, 1813.055741), -- Adamantine
(22308, 6901, 1, 1, 2, 416.978611), -- Recipe: Shining Arrow (100%)
(22308, 9547, 1, 1, 2, 3336.174737), -- Water Stone
-- Kechi's Guard
(22309, 5277, 1, 1, -1, 3614), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22309, 8349, 1, 1, -1, 22297), -- Doom Crusher Head
(22309, 5282, 1, 1, -1, 3614), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22309, 57, 5443, 11149, 0, 700000), -- Adena
(22309, 5320, 1, 1, 1, 30.328896), -- Sealed Leather Armor of Nightmare
(22309, 5480, 1, 1, 1, 4493.671104), -- Sealed Leather Armor of Nightmare Fabric
(22309, 5323, 1, 1, 1, 30.328896), -- Sealed Majestic Leather Armor
(22309, 5481, 1, 1, 1, 4493.671104), -- Sealed Majestic Leather Armor Fabric
(22309, 1895, 1, 1, 2, 190722.714113), -- Metallic Fiber
(22309, 4040, 1, 1, 2, 13350.548532), -- Mold Lubricant
(22309, 9628, 1, 1, 2, 5235.445055), -- Leonard
(22309, 9630, 1, 1, 2, 3513.279278), -- Orichalcum
(22309, 959, 1, 1, 2, 26.619058), -- Scroll: Enchant Weapon (S-Grade)
(22309, 9547, 1, 1, 2, 5340.393964), -- Water Stone
-- Kechi's Guard
(22310, 5480, 1, 1, -1, 34308), -- Sealed Leather Armor of Nightmare Fabric
(22310, 1876, 1, 3, -1, 764565), -- Mithril Ore
(22310, 1895, 1, 5, -1, 728157), -- Metallic Fiber
(22310, 57, 5119, 10485, 0, 700000), -- Adena
(22310, 5326, 1, 1, 1, 28.518776), -- Sealed Robe of Nightmare
(22310, 5487, 1, 1, 1, 4239.481224), -- Sealed Robe of Nightmare Fabric
(22310, 5329, 1, 1, 1, 28.518776), -- Sealed Majestic Robe
(22310, 5488, 1, 1, 1, 4239.481224), -- Sealed Majestic Robe Fabric
(22310, 1895, 1, 1, 2, 153727.608429), -- Metallic Fiber
(22310, 4040, 1, 1, 2, 10761.073785), -- Mold Lubricant
(22310, 9628, 1, 1, 2, 4220.000685), -- Leonard
(22310, 9630, 1, 1, 2, 2831.967684), -- Orichalcum
(22310, 960, 1, 1, 2, 215.250291), -- Scroll: Enchant Armor (S-Grade)
(22310, 9547, 1, 1, 2, 4304.429514), -- Water Stone
(22310, 1344, 60, 180, 2, 112092.669612), -- Mithril Arrow
-- Parme's Guardian
(22311, 6688, 1, 1, -1, 57298), -- Forgotten Blade Edge
(22311, 6901, 1, 1, -1, 26509), -- Recipe: Shining Arrow (100%)
(22311, 6689, 1, 1, -1, 56218), -- Basalt Battlehammer Head
(22311, 57, 15512, 31115, 0, 700000), -- Adena
(22311, 6326, 1, 1, 1, 217.859184), -- Sealed Majestic Necklace
(22311, 6344, 1, 1, 1, 31901.377338), -- Sealed Majestic Necklace Beads
(22311, 6327, 1, 1, 1, 290.529909), -- Sealed Majestic Earring
(22311, 6342, 1, 1, 1, 49295.689083), -- Sealed Majestic Earring Gemstone
(22311, 6328, 1, 1, 1, 435.718368), -- Sealed Majestic Ring
(22311, 6346, 1, 1, 1, 70849.826118), -- Sealed Majestic Ring Gemstone
(22311, 1868, 15, 45, 2, 79142.3072), -- Thread
(22311, 1873, 2, 6, 2, 118713.4608), -- Silver Nugget
(22311, 5549, 1, 1, 2, 118713.4608), -- Metallic Thread
(22311, 1889, 1, 1, 2, 79142.3072), -- Compound Braid
(22311, 4044, 1, 1, 2, 39571.1536), -- Thons
(22311, 6901, 1, 1, 2, 1186.952), -- Recipe: Shining Arrow (100%)
(22311, 10483, 1, 1, 2, 8243.83816), -- Life Stone - Level 82
(22311, 10484, 1, 1, 2, 2061.1878), -- Mid-Grade Life Stone - Level 82
(22311, 10485, 1, 1, 2, 205.89052), -- High-Grade Life Stone - Level 82
(22311, 10486, 1, 1, 2, 41.0868), -- Top-Grade Life Stone - Level 82
(22311, 9546, 1, 1, 2, 9498.35512), -- Fire Stone
-- Fafurion's Henchman
(22312, 6901, 1, 1, -1, 32736), -- Recipe: Shining Arrow (100%)
(22312, 6690, 1, 1, -1, 70893), -- Imperial Staff Head
(22312, 960, 1, 1, -1, 13094), -- Scroll: Enchant Armor (S-Grade)
(22312, 57, 19156, 38424, 0, 700000), -- Adena
(22312, 5313, 1, 1, 1, 297.528258), -- Sealed Gauntlets of Nightmare
(22312, 5514, 1, 1, 1, 34043.221742), -- Sealed Gauntlets of Nightmare Design
(22312, 5314, 1, 1, 1, 297.528258), -- Sealed Boots of Nightmare
(22312, 5502, 1, 1, 1, 34043.221742), -- Sealed Boots of Nightmare Lining
(22312, 5318, 1, 1, 1, 297.528258), -- Sealed Majestic Gauntlets
(22312, 5515, 1, 1, 1, 34043.221742), -- Sealed Majestic Gauntlets Design
(22312, 5319, 1, 1, 1, 297.528258), -- Sealed Majestic Boots
(22312, 5503, 1, 1, 1, 34043.221742), -- Sealed Majestic Boots Lining
(22312, 1895, 1, 3, 2, 383952.44882), -- Metallic Fiber
(22312, 4040, 1, 1, 2, 53753.53076), -- Mold Lubricant
(22312, 9628, 1, 1, 2, 21079.7675), -- Leonard
(22312, 9630, 1, 1, 2, 14145.82216), -- Orichalcum
(22312, 959, 1, 1, 2, 107.31518), -- Scroll: Enchant Weapon (S-Grade)
(22312, 9546, 1, 1, 2, 21501.11558), -- Fire Stone
-- Garden Stakato
(22313, 4042, 1, 1, -1, 149381), -- Enria
(22313, 1876, 1, 3, -1, 896287), -- Mithril Ore
(22313, 6691, 1, 1, -1, 19373), -- Angel Slayer Blade
(22313, 57, 5245, 10520, 0, 700000), -- Adena
(22313, 5312, 1, 1, 1, 72.428928), -- Sealed Helm of Nightmare
(22313, 5527, 1, 1, 1, 8797.880366), -- Sealed Helm of Nightmare Design
(22313, 5315, 1, 1, 1, 103.507206), -- Sealed Shield of Nightmare
(22313, 5495, 1, 1, 1, 11173.874206), -- Sealed Shield of Nightmare Fragment
(22313, 5317, 1, 1, 1, 72.428928), -- Sealed Majestic Circlet
(22313, 5528, 1, 1, 1, 8797.880366), -- Sealed Majestic Circlet Design
(22313, 1873, 3, 9, 2, 36793.365), -- Silver Nugget
(22313, 1868, 4, 12, 2, 137974.5675), -- Thread
(22313, 1876, 1, 1, 2, 110379.7275), -- Mithril Ore
(22313, 1895, 3, 9, 2, 22526.6475), -- Metallic Fiber
(22313, 4042, 1, 1, 2, 9198.1575), -- Enria
(22313, 960, 1, 1, 2, 220.8675), -- Scroll: Enchant Armor (S-Grade)
(22313, 9546, 1, 1, 2, 4415.145), -- Fire Stone
(22313, 1344, 150, 450, 2, 45991.5225), -- Mithril Arrow
-- Garden Poison Moth
(22314, 6901, 1, 1, -1, 8769), -- Recipe: Shining Arrow (100%)
(22314, 6693, 1, 1, -1, 19298), -- Dragon Hunter Axe Blade
(22314, 57, 5131, 10293, 0, 700000), -- Adena
(22314, 164, 1, 1, 1, 5.206944), -- Elysian
(22314, 5533, 1, 1, 1, 1481.232912), -- Elysian Head
(22314, 213, 1, 1, 1, 5.206944), -- Branch of the Mother Tree
(22314, 5544, 1, 1, 1, 1479.770688), -- Branch of the Mother Tree Head
(22314, 7895, 1, 1, 1, 5.206944), -- Flaming Dragon Skull
(22314, 8342, 1, 1, 1, 1481.232912), -- Flaming Dragon Skull Piece
(22314, 7902, 1, 1, 1, 5.206944), -- Doom Crusher
(22314, 8349, 1, 1, 1, 1480.935712), -- Doom Crusher Head
(22314, 1895, 1, 1, 2, 205703.140026), -- Metallic Fiber
(22314, 4040, 1, 1, 2, 14399.222162), -- Mold Lubricant
(22314, 9628, 1, 1, 2, 5646.73065), -- Leonard
(22314, 9630, 1, 1, 2, 3789.26899), -- Orichalcum
(22314, 6901, 1, 1, 2, 719.8549), -- Recipe: Shining Arrow (100%)
(22314, 9546, 1, 1, 2, 5759.783272), -- Fire Stone
-- Garden Guard 
(22315, 6694, 1, 1, -1, 11476), -- Saint Spear Blade
(22315, 959, 1, 1, -1, 209), -- Scroll: Enchant Weapon (S-Grade)
(22315, 4040, 1, 1, -1, 104299), -- Mold Lubricant
(22315, 57, 3052, 6121, 0, 700000), -- Adena
(22315, 289, 1, 1, 1, 12.3865), -- Soul Bow
(22315, 5534, 1, 1, 1, 3526.6135), -- Soul Bow Stave
(22315, 1895, 1, 1, 2, 66725.839312), -- Metallic Fiber
(22315, 4040, 1, 1, 2, 4670.690244), -- Mold Lubricant
(22315, 9628, 1, 1, 2, 1831.686802), -- Leonard
(22315, 9630, 1, 1, 2, 1229.148503), -- Orichalcum
(22315, 959, 1, 1, 2, 9.258425), -- Scroll: Enchant Weapon (S-Grade)
(22315, 10483, 1, 1, 2, 1621.705723), -- Life Stone - Level 82
(22315, 10484, 1, 1, 2, 405.519015), -- Mid-Grade Life Stone - Level 82
(22315, 10485, 1, 1, 2, 40.366733), -- High-Grade Life Stone - Level 82
(22315, 10486, 1, 1, 2, 8.147414), -- Top-Grade Life Stone - Level 82
(22315, 9546, 1, 1, 2, 1868.350165), -- Fire Stone
(22315, 1344, 10, 30, 2, 291926.287664), -- Mithril Arrow
-- Garden Guardian Tree
(22316, 4042, 1, 1, -1, 251633), -- Enria
(22316, 6695, 1, 1, -1, 32019), -- Demon Splinter Blade
(22316, 6901, 1, 1, -1, 15098), -- Recipe: Shining Arrow (100%)
(22316, 57, 8835, 17721, 0, 700000), -- Adena
(22316, 236, 1, 1, 1, 35.856978), -- Soul Separator
(22316, 5537, 1, 1, 1, 10203.143022), -- Soul Separator Head
(22316, 1895, 1, 1, 2, 354163.533318), -- Metallic Fiber
(22316, 4040, 1, 1, 2, 24791.533088), -- Mold Lubricant
(22316, 4042, 1, 1, 2, 20659.460458), -- Enria
(22316, 4043, 1, 1, 2, 41318.920916), -- Asofe
(22316, 960, 1, 1, 2, 496.029254), -- Scroll: Enchant Armor (S-Grade)
(22316, 9546, 1, 1, 2, 9916.522966), -- Fire Stone
-- Garden Castalia
(22317, 6696, 1, 1, -1, 4729), -- Heavens Divider Edge
(22317, 6901, 1, 1, -1, 2154), -- Recipe: Shining Arrow (100%)
(22317, 6697, 1, 1, -1, 4567), -- Arcana Mace Head
(22317, 57, 1260, 2528, 0, 700000), -- Adena
(22317, 5312, 1, 1, 1, 17.402112), -- Sealed Helm of Nightmare
(22317, 5527, 1, 1, 1, 2113.819764), -- Sealed Helm of Nightmare Design
(22317, 5315, 1, 1, 1, 24.869124), -- Sealed Shield of Nightmare
(22317, 5495, 1, 1, 1, 2684.687124), -- Sealed Shield of Nightmare Fragment
(22317, 5317, 1, 1, 1, 17.402112), -- Sealed Majestic Circlet
(22317, 5528, 1, 1, 1, 2113.819764), -- Sealed Majestic Circlet Design
(22317, 1873, 1, 1, 2, 35361.624473), -- Silver Nugget
(22317, 1868, 1, 1, 2, 176808.122365), -- Thread
(22317, 1876, 1, 1, 2, 17680.996571), -- Mithril Ore
(22317, 1895, 1, 1, 2, 25258.250528), -- Metallic Fiber
(22317, 4042, 1, 1, 2, 1473.569993), -- Enria
(22317, 6901, 1, 1, 2, 88.48056), -- Recipe: Shining Arrow (100%)
(22317, 10483, 1, 1, 2, 613.833885), -- Life Stone - Level 82
(22317, 10484, 1, 1, 2, 153.366304), -- Mid-Grade Life Stone - Level 82
(22317, 10485, 1, 1, 2, 15.484098), -- High-Grade Life Stone - Level 82
(22317, 10486, 1, 1, 2, 2.949352), -- Top-Grade Life Stone - Level 82
(22317, 9546, 1, 1, 2, 707.107142), -- Fire Stone
(22317, 1344, 10, 30, 2, 110505.214729), -- Mithril Arrow
-- Junior Watchman
(22320, 960, 1, 1, -1, 11241), -- Scroll: Enchant Armor (S-Grade)
(22320, 1895, 1, 17, -1, 892165), -- Metallic Fiber
(22320, 4040, 1, 1, -1, 562064), -- Mold Lubricant
(22320, 57, 16445, 32986, 0, 700000), -- Adena
(22320, 5311, 1, 1, 1, 78.624116), -- Sealed Armor of Nightmare
(22320, 5522, 1, 1, 1, 11787.375884), -- Sealed Armor of Nightmare Pattern
(22320, 5316, 1, 1, 1, 78.624116), -- Sealed Majestic Plate Armor
(22320, 5523, 1, 1, 1, 11787.375884), -- Sealed Majestic Plate Armor Pattern
(22320, 1895, 1, 3, 2, 188352.764901), -- Metallic Fiber
(22320, 4040, 1, 1, 2, 39554.017965), -- Mold Lubricant
(22320, 9628, 1, 1, 2, 15511.23504), -- Leonard
(22320, 9630, 1, 1, 2, 10408.893894), -- Orichalcum
(22320, 959, 1, 1, 2, 79.251795), -- Scroll: Enchant Weapon (S-Grade)
(22320, 9674, 4, 12, 2, 98885.229219), -- Darion's Badge
(22320, 9551, 1, 1, 2, 15821.607186), -- Holy Stone
(22320, 9599, 1, 3, 2, 721000), -- Ancient Tome of the Demon
-- Junior Summoner
(22321, 6698, 1, 1, -1, 529832), -- Sealed Tateossian Earring Part
(22321, 6901, 1, 1, -1, 26974), -- Recipe: Shining Arrow (100%)
(22321, 6699, 1, 1, -1, 587920), -- Sealed Tateossian Ring Gem
(22321, 57, 15784, 31661, 0, 700000), -- Adena
(22321, 5326, 1, 1, 1, 100.617556), -- Sealed Robe of Nightmare
(22321, 5487, 1, 1, 1, 14957.382444), -- Sealed Robe of Nightmare Fabric
(22321, 5329, 1, 1, 1, 100.617556), -- Sealed Majestic Robe
(22321, 5488, 1, 1, 1, 14957.382444), -- Sealed Majestic Robe Fabric
(22321, 1866, 16, 48, 2, 30758.282217), -- Suede
(22321, 1871, 10, 30, 2, 70304.461929), -- Charcoal
(22321, 5220, 1, 1, 2, 59055.611277), -- Metal Hardener
(22321, 1885, 1, 1, 2, 123032.701545), -- High-Grade Suede
(22321, 4041, 1, 1, 2, 12838.064889), -- Mold Hardener
(22321, 960, 1, 1, 2, 590.560386), -- Scroll: Enchant Armor (S-Grade)
(22321, 9674, 3, 9, 2, 98426.161236), -- Darion's Badge
(22321, 9551, 1, 1, 2, 11811.20772), -- Holy Stone
(22321, 1344, 900, 2700, 2, 20505.948801), -- Mithril Arrow
(22321, 9599, 1, 3, 2, 721000), -- Ancient Tome of the Demon
-- Subjugated Native
(22322, 6901, 1, 1, -1, 2192), -- Recipe: Shining Arrow (100%)
(22322, 6700, 1, 1, -1, 26236), -- Sealed Tateossian Necklace Chain
(22322, 959, 1, 1, -1, 88), -- Scroll: Enchant Weapon (S-Grade)
(22322, 57, 1282, 2572, 0, 700000), -- Adena
(22322, 6326, 1, 1, 1, 18.010752), -- Sealed Majestic Necklace
(22322, 6344, 1, 1, 1, 2637.335664), -- Sealed Majestic Necklace Beads
(22322, 6327, 1, 1, 1, 24.018552), -- Sealed Majestic Earring
(22322, 6342, 1, 1, 1, 4075.350024), -- Sealed Majestic Earring Gemstone
(22322, 6328, 1, 1, 1, 36.021504), -- Sealed Majestic Ring
(22322, 6346, 1, 1, 1, 5857.263504), -- Sealed Majestic Ring Gemstone
(22322, 1879, 1, 1, 2, 17992.774481), -- Cokes
(22322, 1885, 1, 1, 2, 8996.37227), -- High-Grade Suede
(22322, 9628, 1, 1, 2, 846.73148), -- Leonard
(22322, 9630, 1, 1, 2, 568.190357), -- Orichalcum
(22322, 9629, 1, 1, 2, 469.385057), -- Adamantine
(22322, 6901, 1, 1, 2, 107.967246), -- Recipe: Shining Arrow (100%)
(22322, 10483, 1, 1, 2, 749.692699), -- Life Stone - Level 82
(22322, 10484, 1, 1, 2, 187.43066), -- Mid-Grade Life Stone - Level 82
(22322, 10485, 1, 1, 2, 18.743066), -- High-Grade Life Stone - Level 82
(22322, 10486, 1, 1, 2, 3.712684), -- Top-Grade Life Stone - Level 82
(22322, 9599, 1, 1, 2, 112500), -- Ancient Tome of the Demon
-- Charmed Native
(22323, 4044, 1, 1, -1, 75435), -- Thons
(22323, 1894, 1, 1, -1, 79405), -- Crafted Leather
(22323, 6701, 1, 1, -1, 12049), -- Sealed Imperial Crusader Breastplate Part
(22323, 57, 1324, 2656, 0, 700000), -- Adena
(22323, 5313, 1, 1, 1, 20.568336), -- Sealed Gauntlets of Nightmare
(22323, 5514, 1, 1, 1, 2353.431664), -- Sealed Gauntlets of Nightmare Design
(22323, 5314, 1, 1, 1, 20.568336), -- Sealed Boots of Nightmare
(22323, 5502, 1, 1, 1, 2353.431664), -- Sealed Boots of Nightmare Lining
(22323, 5318, 1, 1, 1, 20.568336), -- Sealed Majestic Gauntlets
(22323, 5515, 1, 1, 1, 2353.431664), -- Sealed Majestic Gauntlets Design
(22323, 5319, 1, 1, 1, 20.568336), -- Sealed Majestic Boots
(22323, 5503, 1, 1, 1, 2353.431664), -- Sealed Majestic Boots Lining
(22323, 1895, 1, 1, 2, 31851.37683), -- Metallic Fiber
(22323, 4040, 1, 1, 2, 2229.543612), -- Mold Lubricant
(22323, 9628, 1, 1, 2, 874.334277), -- Leonard
(22323, 9630, 1, 1, 2, 586.759032), -- Orichalcum
(22323, 959, 1, 1, 2, 4.397175), -- Scroll: Enchant Weapon (S-Grade)
(22323, 10483, 1, 1, 2, 774.078687), -- Life Stone - Level 82
(22323, 10484, 1, 1, 2, 193.4757), -- Mid-Grade Life Stone - Level 82
(22323, 10485, 1, 1, 2, 19.34757), -- High-Grade Life Stone - Level 82
(22323, 10486, 1, 1, 2, 3.869514), -- Top-Grade Life Stone - Level 82
(22323, 1344, 10, 30, 2, 139349.817603), -- Mithril Arrow
(22323, 9599, 1, 1, 2, 116100), -- Ancient Tome of the Demon
-- Blind Huntsman
(22324, 6901, 1, 1, -1, 5552), -- Recipe: Shining Arrow (100%)
(22324, 6702, 1, 1, -1, 38051), -- Sealed Imperial Crusader Gaiters Pattern
(22324, 57, 3249, 6517, 0, 700000), -- Adena
(22324, 5312, 1, 1, 1, 44.8656), -- Sealed Helm of Nightmare
(22324, 5527, 1, 1, 1, 5449.786325), -- Sealed Helm of Nightmare Design
(22324, 5315, 1, 1, 1, 64.116825), -- Sealed Shield of Nightmare
(22324, 5495, 1, 1, 1, 6921.579325), -- Sealed Shield of Nightmare Fragment
(22324, 5317, 1, 1, 1, 44.8656), -- Sealed Majestic Circlet
(22324, 5528, 1, 1, 1, 5449.786325), -- Sealed Majestic Circlet Design
(22324, 1864, 4, 12, 2, 85468.445398), -- Stem
(22324, 1865, 2, 6, 2, 68374.832539), -- Varnish
(22324, 1866, 3, 9, 2, 37986.060422), -- Suede
(22324, 1873, 4, 12, 2, 17093.612859), -- Silver Nugget
(22324, 1868, 10, 30, 2, 32559.534805), -- Thread
(22324, 960, 1, 1, 2, 136.815977), -- Scroll: Enchant Armor (S-Grade)
(22324, 9674, 1, 1, 2, 136749.283975), -- Darion's Badge
(22324, 9551, 1, 1, 2, 2734.414025), -- Holy Stone
(22324, 9599, 1, 1, 2, 284900), -- Ancient Tome of the Demon
-- Blind Watchman
(22325, 6703, 1, 1, -1, 106314), -- Sealed Imperial Crusader Gauntlets Design
(22325, 960, 1, 1, -1, 2987), -- Scroll: Enchant Armor (S-Grade)
(22325, 57, 2913, 5843, 0, 700000), -- Adena
(22325, 5312, 1, 1, 1, 40.225536), -- Sealed Helm of Nightmare
(22325, 5527, 1, 1, 1, 4886.161692), -- Sealed Helm of Nightmare Design
(22325, 5315, 1, 1, 1, 57.485772), -- Sealed Shield of Nightmare
(22325, 5495, 1, 1, 1, 6205.739772), -- Sealed Shield of Nightmare Fragment
(22325, 5317, 1, 1, 1, 40.225536), -- Sealed Majestic Circlet
(22325, 5528, 1, 1, 1, 4886.161692), -- Sealed Majestic Circlet Design
(22325, 1869, 2, 6, 2, 54493.568224), -- Iron Ore
(22325, 1870, 3, 9, 2, 45410.987376), -- Coal
(22325, 1871, 3, 9, 2, 38923.840384), -- Charcoal
(22325, 1872, 8, 24, 2, 22705.733296), -- Animal Bone
(22325, 1867, 1, 3, 2, 121096.445552), -- Animal Skin
(22325, 6901, 1, 1, 2, 272.673904), -- Recipe: Shining Arrow (100%)
(22325, 9674, 1, 1, 2, 108987.136448), -- Darion's Badge
(22325, 9551, 1, 1, 2, 2179.953584), -- Holy Stone
(22325, 1344, 40, 120, 2, 85145.661232), -- Mithril Arrow
(22325, 9599, 1, 1, 2, 255400), -- Ancient Tome of the Demon
-- Hellinark
(22326, 4039, 1, 35, -1, 910052), -- Mold Glue
(22326, 6704, 1, 15, -1, 874614), -- Sealed Imperial Crusader Boots Design
(22326, 6901, 1, 1, -1, 491428), -- Recipe: Shining Arrow (100%)
(22326, 57, 287985, 576519, 0, 700000), -- Adena
(22326, 81, 1, 1, 1, 389.057214), -- Dragon Slayer
(22326, 5529, 1, 1, 1, 110646.358088), -- Dragon Slayer Edge
(22326, 151, 1, 1, 1, 389.057214), -- Sword of Miracles
(22326, 5546, 1, 1, 1, 121534.456176), -- Sword of Miracles Edge
(22326, 2500, 1, 1, 1, 389.057214), -- Dark Legion's Edge
(22326, 5545, 1, 1, 1, 110646.014094), -- Dark Legion's Edge Blade
(22326, 1894, 5, 15, 2, 141569.046206), -- Crafted Leather
(22326, 4039, 9, 27, 2, 74716.862087), -- Mold Glue
(22326, 4041, 3, 9, 2, 50120.718222), -- Mold Hardener
(22326, 4044, 16, 48, 2, 42028.4295), -- Thons
(22326, 959, 1, 1, 2, 1614.030058), -- Scroll: Enchant Weapon (S-Grade)
(22326, 9551, 4, 12, 2, 35863.913927), -- Holy Stone
(22326, 9599, 14, 44, 2, 869600), -- Ancient Tome of the Demon
-- Arcane Scout
(22327, 6705, 1, 1, -1, 766903), -- Sealed Imperial Crusader Shield Part
(22327, 6901, 1, 1, -1, 54991), -- Recipe: Shining Arrow (100%)
(22327, 6706, 1, 1, -1, 892056), -- Sealed Imperial Crusader Helmet Pattern
(22327, 57, 32178, 64546, 0, 700000), -- Adena
(22327, 164, 1, 1, 1, 32.651148), -- Elysian
(22327, 5533, 1, 1, 1, 9288.357054), -- Elysian Head
(22327, 213, 1, 1, 1, 32.651148), -- Branch of the Mother Tree
(22327, 5544, 1, 1, 1, 9279.187896), -- Branch of the Mother Tree Head
(22327, 7895, 1, 1, 1, 32.651148), -- Flaming Dragon Skull
(22327, 8342, 1, 1, 1, 9288.357054), -- Flaming Dragon Skull Piece
(22327, 7902, 1, 1, 1, 32.651148), -- Doom Crusher
(22327, 8349, 1, 1, 1, 9286.493404), -- Doom Crusher Head
(22327, 1873, 18, 54, 2, 37623.708036), -- Silver Nugget
(22327, 1868, 198, 594, 2, 17101.5084), -- Thread
(22327, 1876, 4, 12, 2, 84653.245692), -- Mithril Ore
(22327, 1895, 3, 9, 2, 138209.404572), -- Metallic Fiber
(22327, 4042, 1, 1, 2, 56435.367276), -- Enria
(22327, 960, 1, 1, 2, 1354.486212), -- Scroll: Enchant Armor (S-Grade)
(22327, 9674, 25, 75, 2, 27088.945128), -- Darion's Badge
(22327, 9551, 1, 1, 2, 27089.334684), -- Holy Stone
(22327, 9599, 2, 6, 2, 705400), -- Ancient Tome of the Demon
-- Arcane Guardian
(22328, 959, 1, 1, -1, 889), -- Scroll: Enchant Weapon (S-Grade)
(22328, 1885, 1, 3, -1, 925910), -- High-Grade Suede
(22328, 13099, 1, 1, -1, 309907), -- Sealed Arcana Sigil Piece
(22328, 57, 13003, 26083, 0, 700000), -- Adena
(22328, 270, 1, 1, 1, 52.779701), -- Dragon Grinder
(22328, 5538, 1, 1, 1, 15014.220299), -- Dragon Grinder Edge
(22328, 1879, 1, 1, 2, 152037.9462), -- Cokes
(22328, 1885, 1, 1, 2, 76018.9731), -- High-Grade Suede
(22328, 9628, 1, 1, 2, 7154.72688), -- Leonard
(22328, 9630, 1, 1, 2, 4801.105092), -- Orichalcum
(22328, 9629, 1, 1, 2, 3966.091794), -- Adamantine
(22328, 6901, 1, 1, 2, 912.05058), -- Recipe: Shining Arrow (100%)
(22328, 10483, 1, 1, 2, 6334.766844), -- Life Stone - Level 82
(22328, 10484, 1, 1, 2, 1583.691711), -- Mid-Grade Life Stone - Level 82
(22328, 10485, 1, 1, 2, 158.501994), -- High-Grade Life Stone - Level 82
(22328, 10486, 1, 1, 2, 31.877496), -- Top-Grade Life Stone - Level 82
(22328, 9674, 1, 3, 2, 182445.53544), -- Darion's Badge
(22328, 9551, 1, 1, 2, 7297.732869), -- Holy Stone
(22328, 9599, 1, 3, 2, 570100), -- Ancient Tome of the Demon
-- Arcane Watchman
(22329, 6707, 1, 1, -1, 281342), -- Sealed Draconic Leather Armor Part
(22329, 6901, 1, 1, -1, 56782), -- Recipe: Shining Arrow (100%)
(22329, 6708, 1, 1, -1, 808455), -- Sealed Draconic Leather Gloves Fabric
(22329, 57, 33226, 66648, 0, 700000), -- Adena
(22329, 289, 1, 1, 1, 134.8585), -- Soul Bow
(22329, 5534, 1, 1, 1, 38396.1415), -- Soul Bow Stave
(22329, 1895, 20, 60, 2, 24974.36847), -- Metallic Fiber
(22329, 4040, 1, 1, 2, 69928.09564), -- Mold Lubricant
(22329, 9628, 1, 1, 2, 27422.7159), -- Leonard
(22329, 9630, 1, 1, 2, 18402.23786), -- Orichalcum
(22329, 959, 1, 1, 2, 139.81809), -- Scroll: Enchant Weapon (S-Grade)
(22329, 9674, 14, 42, 2, 49948.73694), -- Darion's Badge
(22329, 9551, 1, 1, 2, 27971.10218), -- Holy Stone
(22329, 1344, 360, 1080, 2, 121402.92492), -- Mithril Arrow
(22329, 9599, 2, 6, 2, 728400), -- Ancient Tome of the Demon
-- Remnant Wraith
(22330, 6901, 1, 1, -1, 3493), -- Recipe: Shining Arrow (100%)
(22330, 6709, 1, 1, -1, 49735), -- Sealed Draconic Leather Boots Design
(22330, 960, 1, 1, -1, 1397), -- Scroll: Enchant Armor (S-Grade)
(22330, 57, 2044, 4100, 0, 700000), -- Adena
(22330, 236, 1, 1, 1, 8.296238), -- Soul Separator
(22330, 5537, 1, 1, 1, 2360.703762), -- Soul Separator Head
(22330, 1879, 1, 1, 2, 28679.413903), -- Cokes
(22330, 1885, 1, 1, 2, 14339.730762), -- High-Grade Suede
(22330, 9628, 1, 1, 2, 1349.626761), -- Leonard
(22330, 9630, 1, 1, 2, 905.656178), -- Orichalcum
(22330, 9629, 1, 1, 2, 748.173531), -- Adamantine
(22330, 960, 1, 1, 2, 68.812345), -- Scroll: Enchant Armor (S-Grade)
(22330, 9573, 1, 1, 2, 1194.953753), -- Life Stone - Level 80
(22330, 9574, 1, 1, 2, 298.726533), -- Mid-Grade Life Stone - Level 80
(22330, 9575, 1, 1, 2, 29.858367), -- High-Grade Life Stone - Level 80
(22330, 9576, 1, 1, 2, 6.047867), -- Top-Grade Life Stone - Level 80
(22330, 9599, 1, 1, 2, 179200), -- Ancient Tome of the Demon
-- Sand Scorpion
(22334, 1885, 1, 3, -1, 909782), -- High-Grade Suede
(22334, 6713, 1, 1, -1, 310882), -- Sealed Major Arcana Boots Design
(22334, 6901, 1, 1, -1, 21835), -- Recipe: Shining Arrow (100%)
(22334, 57, 12796, 25615, 0, 700000), -- Adena
(22334, 5311, 1, 1, 1, 61.085094), -- Sealed Armor of Nightmare
(22334, 5522, 1, 1, 1, 9157.914906), -- Sealed Armor of Nightmare Pattern
(22334, 5316, 1, 1, 1, 61.085094), -- Sealed Majestic Plate Armor
(22334, 5523, 1, 1, 1, 9157.914906), -- Sealed Majestic Plate Armor Pattern
(22334, 1879, 1, 1, 2, 137897.9592), -- Cokes
(22334, 1885, 1, 1, 2, 68948.9796), -- High-Grade Suede
(22334, 9628, 1, 1, 2, 6489.36804), -- Leonard
(22334, 9630, 1, 1, 2, 4354.55538), -- Orichalcum
(22334, 9629, 1, 1, 2, 3597.2994), -- Adamantine
(22334, 6901, 1, 1, 2, 827.51226), -- Recipe: Shining Arrow (100%)
(22334, 10483, 1, 1, 2, 5745.89652), -- Life Stone - Level 82
(22334, 10484, 1, 1, 2, 1436.2518), -- Mid-Grade Life Stone - Level 82
(22334, 10485, 1, 1, 2, 143.62518), -- High-Grade Life Stone - Level 82
(22334, 10486, 1, 1, 2, 28.9029), -- Top-Grade Life Stone - Level 82
(22334, 10012, 1, 1, 2, 165477.55104), -- Scorpion Poison Stinger
(22334, 9549, 1, 1, 2, 6619.20876), -- Wind Stone
(22334, 1344, 240, 720, 2, 43092.88992), -- Mithril Arrow
(22334, 9599, 1, 3, 2, 560200), -- Ancient Tome of the Demon
-- Desert Scorpion
(22335, 6714, 1, 1, -1, 363104), -- Sealed Major Arcana Circlet Pattern
(22335, 6901, 1, 1, -1, 22384), -- Recipe: Shining Arrow (100%)
(22335, 7579, 1, 1, -1, 48941), -- Draconic Bow Shaft
(22335, 57, 13117, 26259, 0, 700000), -- Adena
(22335, 5326, 1, 1, 1, 83.494931), -- Sealed Robe of Nightmare
(22335, 5487, 1, 1, 1, 12412.005069), -- Sealed Robe of Nightmare Fabric
(22335, 5329, 1, 1, 1, 83.494931), -- Sealed Majestic Robe
(22335, 5488, 1, 1, 1, 12412.005069), -- Sealed Majestic Robe Fabric
(22335, 1873, 2, 6, 2, 137829.85144), -- Silver Nugget
(22335, 1868, 15, 45, 2, 91886.70204), -- Thread
(22335, 1876, 3, 9, 2, 39380.01516), -- Mithril Ore
(22335, 1895, 3, 9, 2, 65633.3586), -- Metallic Fiber
(22335, 4042, 1, 1, 2, 22971.77632), -- Enria
(22335, 959, 1, 1, 2, 55.24388), -- Scroll: Enchant Weapon (S-Grade)
(22335, 10012, 4, 12, 2, 34457.26124), -- Scorpion Poison Stinger
(22335, 9549, 1, 1, 2, 11025.79132), -- Wind Stone
(22335, 9599, 1, 3, 2, 574300), -- Ancient Tome of the Demon
-- Sand Devil
(22336, 960, 1, 1, -1, 2971), -- Scroll: Enchant Armor (S-Grade)
(22336, 1876, 1, 3, -1, 742735), -- Mithril Ore
(22336, 1895, 1, 5, -1, 707366), -- Metallic Fiber
(22336, 57, 4353, 8713, 0, 700000), -- Adena
(22336, 6326, 1, 1, 1, 61.041184), -- Sealed Majestic Necklace
(22336, 6344, 1, 1, 1, 8938.332588), -- Sealed Majestic Necklace Beads
(22336, 6327, 1, 1, 1, 81.402534), -- Sealed Majestic Earring
(22336, 6342, 1, 1, 1, 13811.982458), -- Sealed Majestic Earring Gemstone
(22336, 6328, 1, 1, 1, 122.082368), -- Sealed Majestic Ring
(22336, 6346, 1, 1, 1, 19851.158868), -- Sealed Majestic Ring Gemstone
(22336, 1873, 1, 1, 2, 121959.597969), -- Silver Nugget
(22336, 1868, 4, 12, 2, 76224.930108), -- Thread
(22336, 1876, 1, 1, 2, 60980.040821), -- Mithril Ore
(22336, 1895, 1, 1, 2, 87114.34403), -- Metallic Fiber
(22336, 4042, 1, 1, 2, 5081.468538), -- Enria
(22336, 960, 1, 1, 2, 121.885596), -- Scroll: Enchant Armor (S-Grade)
(22336, 10483, 1, 1, 2, 2117.520394), -- Life Stone - Level 82
(22336, 10484, 1, 1, 2, 529.138262), -- Mid-Grade Life Stone - Level 82
(22336, 10485, 1, 1, 2, 52.720357), -- High-Grade Life Stone - Level 82
(22336, 10486, 1, 1, 2, 10.640806), -- Top-Grade Life Stone - Level 82
(22336, 9549, 1, 1, 2, 2439.162939), -- Wind Stone
(22336, 1344, 30, 90, 2, 127041.55018), -- Mithril Arrow
(22336, 9599, 1, 1, 2, 381100), -- Ancient Tome of the Demon
-- Desiccator
(22337, 8712, 1, 1, -1, 16897), -- Sirra's Blade Edge
(22337, 6901, 1, 1, -1, 6962), -- Recipe: Shining Arrow (100%)
(22337, 8713, 1, 1, -1, 16897), -- Sword of Ipos Blade
(22337, 57, 4080, 8167, 0, 700000), -- Adena
(22337, 5313, 1, 1, 1, 63.273192), -- Sealed Gauntlets of Nightmare
(22337, 5514, 1, 1, 1, 7239.726808), -- Sealed Gauntlets of Nightmare Design
(22337, 5314, 1, 1, 1, 63.273192), -- Sealed Boots of Nightmare
(22337, 5502, 1, 1, 1, 7239.726808), -- Sealed Boots of Nightmare Lining
(22337, 5318, 1, 1, 1, 63.273192), -- Sealed Majestic Gauntlets
(22337, 5515, 1, 1, 1, 7239.726808), -- Sealed Majestic Gauntlets Design
(22337, 5319, 1, 1, 1, 63.273192), -- Sealed Majestic Boots
(22337, 5503, 1, 1, 1, 7239.726808), -- Sealed Majestic Boots Lining
(22337, 1871, 1, 3, 2, 244959.45628), -- Charcoal
(22337, 1866, 1, 3, 2, 108870.78237), -- Suede
(22337, 1877, 1, 1, 2, 19596.709475), -- Adamantite Nugget
(22337, 4041, 1, 1, 2, 4260.290545), -- Mold Hardener
(22337, 4040, 1, 1, 2, 9798.550685), -- Mold Lubricant
(22337, 6901, 1, 1, 2, 489.86875), -- Recipe: Shining Arrow (100%)
(22337, 9549, 1, 1, 2, 3919.341895), -- Wind Stone
(22337, 9599, 1, 1, 2, 357200), -- Ancient Tome of the Demon
-- Wandering Caravan
(22339, 1885, 1, 1, -1, 450440), -- High-Grade Suede
(22339, 8715, 1, 1, -1, 13120), -- Behemoth's Tuning Fork Piece
(22339, 57, 2112, 4227, 0, 700000), -- Adena
(22339, 81, 1, 1, 1, 2.852382), -- Dragon Slayer
(22339, 5529, 1, 1, 1, 811.206344), -- Dragon Slayer Edge
(22339, 151, 1, 1, 1, 2.852382), -- Sword of Miracles
(22339, 5546, 1, 1, 1, 891.032688), -- Sword of Miracles Edge
(22339, 2500, 1, 1, 1, 2.852382), -- Dark Legion's Edge
(22339, 5545, 1, 1, 1, 811.203822), -- Dark Legion's Edge Blade
(22339, 1895, 1, 1, 2, 84530.274303), -- Metallic Fiber
(22339, 4040, 1, 1, 2, 5917.161443), -- Mold Lubricant
(22339, 9628, 1, 1, 2, 2320.444275), -- Leonard
(22339, 9630, 1, 1, 2, 1557.123713), -- Orichalcum
(22339, 960, 1, 1, 2, 118.391179), -- Scroll: Enchant Armor (S-Grade)
(22339, 9676, 1, 1, 2, 19723.605087), -- Mark of Betrayal
(22339, 9599, 1, 1, 2, 184900), -- Ancient Tome of the Demon
-- Sandstorm
(22340, 6901, 1, 1, -1, 21685), -- Recipe: Shining Arrow (100%)
(22340, 8716, 1, 1, -1, 52634), -- Naga Storm Piece
(22340, 57, 12708, 25440, 0, 700000), -- Adena
(22340, 164, 1, 1, 1, 12.875448), -- Elysian
(22340, 5533, 1, 1, 1, 3662.712204), -- Elysian Head
(22340, 213, 1, 1, 1, 12.875448), -- Branch of the Mother Tree
(22340, 5544, 1, 1, 1, 3659.096496), -- Branch of the Mother Tree Head
(22340, 7895, 1, 1, 1, 12.875448), -- Flaming Dragon Skull
(22340, 8342, 1, 1, 1, 3662.712204), -- Flaming Dragon Skull Piece
(22340, 7902, 1, 1, 1, 12.875448), -- Doom Crusher
(22340, 8349, 1, 1, 1, 3661.977304), -- Doom Crusher Head
(22340, 1895, 1, 3, 2, 254341.249371), -- Metallic Fiber
(22340, 4040, 1, 1, 2, 35607.636603), -- Mold Lubricant
(22340, 9628, 1, 1, 2, 13963.934028), -- Leonard
(22340, 9630, 1, 1, 2, 9370.430685), -- Orichalcum
(22340, 6901, 1, 1, 2, 1780.233642), -- Recipe: Shining Arrow (100%)
(22340, 9549, 1, 1, 2, 14243.515671), -- Wind Stone
(22340, 9599, 1, 3, 2, 556400), -- Ancient Tome of the Demon
-- Keltas
(22341, 8717, 1, 1, -1, 267916), -- Tiphon's Spear Edge
(22341, 960, 1, 1, -1, 44153), -- Scroll: Enchant Armor (S-Grade)
(22341, 4042, 1, 3, -1, 919845), -- Enria
(22341, 57, 64685, 129494, 0, 700000), -- Adena
(22341, 289, 1, 1, 1, 262.164), -- Soul Bow
(22341, 5534, 1, 1, 1, 74641.836), -- Soul Bow Stave
(22341, 1867, 28, 84, 2, 107887.114896), -- Animal Skin
(22341, 1872, 60, 180, 2, 50347.502436), -- Animal Bone
(22341, 1882, 27, 81, 2, 18647.338776), -- Leather
(22341, 1894, 5, 15, 2, 15899.067492), -- Crafted Leather
(22341, 4042, 1, 1, 2, 75521.058492), -- Enria
(22341, 959, 1, 1, 2, 181.110336), -- Scroll: Enchant Weapon (S-Grade)
(22341, 10483, 1, 1, 2, 31467.140232), -- Life Stone - Level 82
(22341, 10484, 1, 1, 2, 7866.589896), -- Mid-Grade Life Stone - Level 82
(22341, 10485, 1, 1, 2, 786.50286), -- High-Grade Life Stone - Level 82
(22341, 10486, 1, 1, 2, 157.300572), -- Top-Grade Life Stone - Level 82
(22341, 9684, 1, 1, 2, 45312.71316), -- Native Treasure
(22341, 9551, 1, 1, 2, 36250.560852), -- Holy Stone
(22341, 9599, 4, 12, 2, 708000), -- Ancient Tome of the Demon
-- Darion's Enforcer
(22342, 4041, 1, 1, -1, 20698), -- Mold Hardener
(22342, 8718, 1, 1, -1, 5777), -- Shyeed's Bow Shaft
(22342, 6901, 1, 1, -1, 2380), -- Recipe: Shining Arrow (100%)
(22342, 57, 1395, 2792, 0, 700000), -- Adena
(22342, 236, 1, 1, 1, 5.652228), -- Soul Separator
(22342, 5537, 1, 1, 1, 1608.347772), -- Soul Separator Head
(22342, 1894, 1, 1, 2, 5142.800376), -- Crafted Leather
(22342, 4039, 1, 1, 2, 4885.86777), -- Mold Glue
(22342, 4041, 1, 1, 2, 1274.551656), -- Mold Hardener
(22342, 4044, 1, 1, 2, 4885.86777), -- Thons
(22342, 960, 1, 1, 2, 58.594116), -- Scroll: Enchant Armor (S-Grade)
(22342, 9674, 1, 1, 2, 58629.376176), -- Darion's Badge
(22342, 9551, 1, 1, 2, 1172.660118), -- Holy Stone
(22342, 1344, 10, 30, 2, 183216.282018), -- Mithril Arrow
(22342, 9599, 1, 1, 2, 122100), -- Ancient Tome of the Demon
-- Darion's Executioner
(22343, 8719, 1, 1, -1, 4649), -- Sobekk's Hurricane Edge
(22343, 6901, 1, 1, -1, 1915), -- Recipe: Shining Arrow (100%)
(22343, 8720, 1, 1, -1, 4649), -- Themis' Tongue Piece
(22343, 57, 1122, 2247, 0, 700000), -- Adena
(22343, 270, 1, 1, 1, 4.550397), -- Dragon Grinder
(22343, 5538, 1, 1, 1, 1294.449603), -- Dragon Grinder Edge
(22343, 1868, 1, 1, 2, 235877.160221), -- Thread
(22343, 1873, 1, 1, 2, 47175.573995), -- Silver Nugget
(22343, 5549, 1, 1, 2, 11793.982218), -- Metallic Thread
(22343, 1889, 1, 1, 2, 7862.654812), -- Compound Braid
(22343, 4044, 1, 1, 2, 3931.327406), -- Thons
(22343, 6901, 1, 1, 2, 117.819164), -- Recipe: Shining Arrow (100%)
(22343, 9674, 1, 1, 2, 47175.573995), -- Darion's Badge
(22343, 9551, 1, 1, 2, 942.908189), -- Holy Stone
(22343, 9599, 1, 1, 2, 98300), -- Ancient Tome of the Demon
-- Quarry Supervisor
(22344, 959, 1, 1, -1, 607), -- Scroll: Enchant Weapon (S-Grade)
(22344, 13099, 1, 1, -1, 211509), -- Sealed Arcana Sigil Piece
(22344, 57, 5925, 11862, 0, 700000), -- Adena
(22344, 305, 1, 1, 1, 24.012912), -- Tallum Glaive
(22344, 5541, 1, 1, 1, 6828.987088), -- Tallum Glaive Edge
(22344, 1864, 5, 15, 2, 83011.952687), -- Stem
(22344, 1865, 3, 9, 2, 69176.945145), -- Varnish
(22344, 1866, 3, 9, 2, 39529.68294), -- Suede
(22344, 1873, 4, 12, 2, 18447.185372), -- Silver Nugget
(22344, 1868, 12, 36, 2, 34588.281829), -- Thread
(22344, 959, 1, 1, 2, 16.785428), -- Scroll: Enchant Weapon (S-Grade)
(22344, 10483, 1, 1, 2, 2882.515772), -- Life Stone - Level 82
(22344, 10484, 1, 1, 2, 720.628943), -- Mid-Grade Life Stone - Level 82
(22344, 10485, 1, 1, 2, 72.101043), -- High-Grade Life Stone - Level 82
(22344, 10486, 1, 1, 2, 14.496506), -- Top-Grade Life Stone - Level 82
(22344, 9551, 1, 1, 2, 3320.462848), -- Holy Stone
(22344, 1344, 40, 120, 2, 129705.961487), -- Mithril Arrow
(22344, 9599, 1, 1, 2, 518800), -- Ancient Tome of the Demon
-- Quarry Bowman
(22345, 8721, 1, 1, -1, 7722), -- Cabrio's Hand Head
(22345, 6901, 1, 1, -1, 3182), -- Recipe: Shining Arrow (100%)
(22345, 8722, 1, 1, -1, 7722), -- Daimon Crystal Fragment
(22345, 57, 1864, 3732, 0, 700000), -- Adena
(22345, 5320, 1, 1, 1, 11.869432), -- Sealed Leather Armor of Nightmare
(22345, 5480, 1, 1, 1, 1758.630568), -- Sealed Leather Armor of Nightmare Fabric
(22345, 5323, 1, 1, 1, 11.869432), -- Sealed Majestic Leather Armor
(22345, 5481, 1, 1, 1, 1758.630568), -- Sealed Majestic Leather Armor Fabric
(22345, 1869, 2, 6, 2, 55974.06765), -- Iron Ore
(22345, 1870, 2, 6, 2, 44779.5651), -- Coal
(22345, 1871, 3, 9, 2, 37316.0451), -- Charcoal
(22345, 1872, 1, 3, 2, 149264.569125), -- Animal Bone
(22345, 1867, 1, 3, 2, 99509.71275), -- Animal Skin
(22345, 960, 1, 1, 2, 89.40675), -- Scroll: Enchant Armor (S-Grade)
(22345, 9551, 1, 1, 2, 1791.633525), -- Holy Stone
(22345, 9599, 1, 1, 2, 163300), -- Ancient Tome of the Demon
-- Quarry Foreman
(22346, 6901, 1, 1, -1, 46590), -- Recipe: Shining Arrow (100%)
(22346, 6688, 1, 1, -1, 100704), -- Forgotten Blade Edge
(22346, 960, 1, 1, -1, 18636), -- Scroll: Enchant Armor (S-Grade)
(22346, 57, 27302, 54657, 0, 700000), -- Adena
(22346, 5311, 1, 1, 1, 130.343359), -- Sealed Armor of Nightmare
(22346, 5522, 1, 1, 1, 19541.156641), -- Sealed Armor of Nightmare Pattern
(22346, 5316, 1, 1, 1, 130.343359), -- Sealed Majestic Plate Armor
(22346, 5523, 1, 1, 1, 19541.156641), -- Sealed Majestic Plate Armor Pattern
(22346, 1894, 1, 1, 2, 73208.156488), -- Crafted Leather
(22346, 4039, 1, 1, 2, 69547.673376), -- Mold Glue
(22346, 4041, 1, 1, 2, 18142.805848), -- Mold Hardener
(22346, 4044, 1, 1, 2, 69547.673376), -- Thons
(22346, 6901, 1, 1, 2, 2086.595834), -- Recipe: Shining Arrow (100%)
(22346, 10483, 1, 1, 2, 14489.09862), -- Life Stone - Level 82
(22346, 10484, 1, 1, 2, 3622.086436), -- Mid-Grade Life Stone - Level 82
(22346, 10485, 1, 1, 2, 362.133356), -- High-Grade Life Stone - Level 82
(22346, 10486, 1, 1, 2, 72.276096), -- Top-Grade Life Stone - Level 82
(22346, 9551, 1, 1, 2, 16691.26092), -- Holy Stone
(22346, 1344, 240, 720, 2, 108668.23965), -- Mithril Arrow
(22346, 9599, 2, 6, 2, 597700), -- Ancient Tome of the Demon
-- Quarry Patrolman
(22347, 4042, 1, 1, -1, 370010), -- Enria
(22347, 1876, 1, 9, -1, 888025), -- Mithril Ore
(22347, 6689, 1, 1, -1, 47082), -- Basalt Battlehammer Head
(22347, 57, 13010, 26045, 0, 700000), -- Adena
(22347, 5326, 1, 1, 1, 82.813367), -- Sealed Robe of Nightmare
(22347, 5487, 1, 1, 1, 12310.686633), -- Sealed Robe of Nightmare Fabric
(22347, 5329, 1, 1, 1, 82.813367), -- Sealed Majestic Robe
(22347, 5488, 1, 1, 1, 12310.686633), -- Sealed Majestic Robe Fabric
(22347, 1873, 2, 6, 2, 156232.422603), -- Silver Nugget
(22347, 1868, 15, 45, 2, 104154.948402), -- Thread
(22347, 1876, 3, 9, 2, 44637.954464), -- Mithril Ore
(22347, 1895, 3, 9, 2, 74396.451433), -- Metallic Fiber
(22347, 4042, 1, 1, 2, 26038.52809), -- Enria
(22347, 959, 1, 1, 2, 62.285129), -- Scroll: Enchant Weapon (S-Grade)
(22347, 9551, 1, 1, 2, 12498.409879), -- Holy Stone
(22347, 9599, 1, 3, 2, 569600), -- Ancient Tome of the Demon
-- Chimera of Earth
(22349, 6901, 1, 1, -1, 47785), -- Recipe: Shining Arrow (100%)
(22349, 6690, 1, 1, -1, 103484), -- Imperial Staff Head
(22349, 57, 28003, 56059, 0, 700000), -- Adena
(22349, 5320, 1, 1, 1, 178.249304), -- Sealed Leather Armor of Nightmare
(22349, 5480, 1, 1, 1, 26410.250696), -- Sealed Leather Armor of Nightmare Fabric
(22349, 5323, 1, 1, 1, 178.249304), -- Sealed Majestic Leather Armor
(22349, 5481, 1, 1, 1, 26410.250696), -- Sealed Majestic Leather Armor Fabric
(22349, 1895, 12, 36, 2, 40033.337397), -- Metallic Fiber
(22349, 4040, 1, 1, 2, 67255.853358), -- Mold Lubricant
(22349, 9628, 1, 1, 2, 26374.919684), -- Leonard
(22349, 9630, 1, 1, 2, 17698.807812), -- Orichalcum
(22349, 960, 1, 1, 2, 1345.091489), -- Scroll: Enchant Armor (S-Grade)
(22349, 9549, 1, 1, 2, 26902.469234), -- Wind Stone
(22349, 1344, 300, 900, 2, 140116.521026), -- Mithril Arrow
(22349, 9599, 2, 6, 2, 613000), -- Ancient Tome of the Demon
-- Chimera of Darkness
(22350, 6691, 1, 1, -1, 107379), -- Angel Slayer Blade
(22350, 959, 1, 1, -1, 1987), -- Scroll: Enchant Weapon (S-Grade)
(22350, 13099, 1, 1, -1, 692815), -- Sealed Arcana Sigil Piece
(22350, 57, 29112, 58280, 0, 700000), -- Adena
(22350, 5320, 1, 1, 1, 185.308616), -- Sealed Leather Armor of Nightmare
(22350, 5480, 1, 1, 1, 27456.191384), -- Sealed Leather Armor of Nightmare Fabric
(22350, 5323, 1, 1, 1, 185.308616), -- Sealed Majestic Leather Armor
(22350, 5481, 1, 1, 1, 27456.191384), -- Sealed Majestic Leather Armor Fabric
(22350, 1879, 3, 9, 2, 97111.30932), -- Cokes
(22350, 1885, 1, 1, 2, 291334.40889), -- High-Grade Suede
(22350, 9628, 1, 1, 2, 27419.74302), -- Leonard
(22350, 9630, 1, 1, 2, 18399.90087), -- Orichalcum
(22350, 9629, 1, 1, 2, 15200.27358), -- Adamantine
(22350, 6901, 1, 1, 2, 3495.88017), -- Recipe: Shining Arrow (100%)
(22350, 9551, 1, 1, 2, 27968.48415), -- Holy Stone
(22350, 9599, 2, 6, 2, 637300), -- Ancient Tome of the Demon
-- Chimera of Wind
(22351, 1895, 1, 29, -1, 946253), -- Metallic Fiber
(22351, 6693, 1, 1, -1, 109325), -- Dragon Hunter Axe Blade
(22351, 6901, 1, 1, -1, 49678), -- Recipe: Shining Arrow (100%)
(22351, 57, 29112, 58280, 0, 700000), -- Adena
(22351, 81, 1, 1, 1, 39.329394), -- Dragon Slayer
(22351, 5529, 1, 1, 1, 11185.126648), -- Dragon Slayer Edge
(22351, 151, 1, 1, 1, 39.329394), -- Sword of Miracles
(22351, 5546, 1, 1, 1, 12285.793296), -- Sword of Miracles Edge
(22351, 2500, 1, 1, 1, 39.329394), -- Dark Legion's Edge
(22351, 5545, 1, 1, 1, 11185.091874), -- Dark Legion's Edge Blade
(22351, 1873, 16, 48, 2, 27809.15698), -- Silver Nugget
(22351, 1868, 15, 45, 2, 148315.78414), -- Thread
(22351, 1876, 3, 9, 2, 63563.72733), -- Mithril Ore
(22351, 1895, 3, 9, 2, 105939.96592), -- Metallic Fiber
(22351, 4042, 1, 1, 2, 37078.73585), -- Enria
(22351, 959, 1, 1, 2, 89.11844), -- Scroll: Enchant Weapon (S-Grade)
(22351, 10483, 1, 1, 2, 15449.43824), -- Life Stone - Level 82
(22351, 10484, 1, 1, 2, 3862.35956), -- Mid-Grade Life Stone - Level 82
(22351, 10485, 1, 1, 2, 386.32003), -- High-Grade Life Stone - Level 82
(22351, 10486, 1, 1, 2, 77.34808), -- Top-Grade Life Stone - Level 82
(22351, 9548, 1, 1, 2, 17798.04543), -- Earth Stone
(22351, 9599, 2, 6, 2, 637300), -- Ancient Tome of the Demon
-- Chimera of Fire
(22352, 6694, 1, 1, -1, 105598), -- Saint Spear Blade
(22352, 6901, 1, 1, -1, 47985), -- Recipe: Shining Arrow (100%)
(22352, 6695, 1, 1, -1, 101764), -- Demon Splinter Blade
(22352, 57, 28120, 56293, 0, 700000), -- Adena
(22352, 81, 1, 1, 1, 37.989159), -- Dragon Slayer
(22352, 5529, 1, 1, 1, 10803.969028), -- Dragon Slayer Edge
(22352, 151, 1, 1, 1, 37.989159), -- Sword of Miracles
(22352, 5546, 1, 1, 1, 11867.128056), -- Sword of Miracles Edge
(22352, 2500, 1, 1, 1, 37.989159), -- Dark Legion's Edge
(22352, 5545, 1, 1, 1, 10803.935439), -- Dark Legion's Edge Blade
(22352, 1873, 16, 48, 2, 42210.37241), -- Silver Nugget
(22352, 1868, 135, 405, 2, 25013.62979), -- Thread
(22352, 1876, 3, 9, 2, 96481.377278), -- Mithril Ore
(22352, 1895, 3, 9, 2, 160802.022694), -- Metallic Fiber
(22352, 4042, 1, 1, 2, 56280.769316), -- Enria
(22352, 960, 1, 1, 2, 1350.617354), -- Scroll: Enchant Armor (S-Grade)
(22352, 9546, 1, 1, 2, 27015.211158), -- Fire Stone
(22352, 9599, 2, 6, 2, 615600), -- Ancient Tome of the Demon
-- Celtus
(22353, 960, 1, 1, -1, 82712), -- Scroll: Enchant Armor (S-Grade)
(22353, 1894, 1, 15, -1, 906932), -- Crafted Leather
(22353, 4042, 1, 7, -1, 861586), -- Enria
(22353, 57, 121177, 242584, 0, 700000), -- Adena
(22353, 289, 1, 1, 1, 491.1165), -- Soul Bow
(22353, 5534, 1, 1, 1, 139827.8835), -- Soul Bow Stave
(22353, 1867, 308, 924, 2, 31497.337058), -- Animal Skin
(22353, 1872, 60, 180, 2, 161685.935636), -- Animal Bone
(22353, 1882, 27, 81, 2, 59883.59555), -- Leather
(22353, 1894, 5, 15, 2, 51058.932186), -- Crafted Leather
(22353, 4042, 6, 18, 2, 20210.85578), -- Enria
(22353, 6901, 1, 1, 2, 14551.907222), -- Recipe: Shining Arrow (100%)
(22353, 9551, 1, 1, 2, 116413.436568), -- Holy Stone
(22353, 9599, 6, 18, 2, 884200), -- Ancient Tome of the Demon
-- Enceinte Defender
(22355, 6696, 1, 1, -1, 25354), -- Heavens Divider Edge
(22355, 6901, 1, 1, -1, 11547), -- Recipe: Shining Arrow (100%)
(22355, 6697, 1, 1, -1, 24488), -- Arcana Mace Head
(22355, 57, 6763, 13546, 0, 700000), -- Adena
(22355, 289, 1, 1, 1, 27.4225), -- Soul Bow
(22355, 5534, 1, 1, 1, 7807.5775), -- Soul Bow Stave
(22355, 1873, 2, 6, 2, 51709.25562), -- Silver Nugget
(22355, 1868, 3, 9, 2, 172364.676606), -- Thread
(22355, 1876, 1, 1, 2, 103418.51124), -- Mithril Ore
(22355, 1895, 1, 1, 2, 147741.011032), -- Metallic Fiber
(22355, 4042, 1, 1, 2, 8618.20927), -- Enria
(22355, 959, 1, 1, 2, 20.630652), -- Scroll: Enchant Weapon (S-Grade)
(22355, 14166, 1, 1, 2, 2498.273716), -- Life Stone - Level 84
(22355, 14167, 1, 1, 2, 623.83162), -- Mid-Grade Life Stone - Level 84
(22355, 14168, 1, 1, 2, 62.383162), -- High-Grade Life Stone - Level 84
(22355, 14169, 1, 1, 2, 12.28015), -- Top-Grade Life Stone - Level 84
(22355, 9551, 1, 1, 2, 4136.936932), -- Holy Stone
(22355, 9599, 1, 1, 2, 592500), -- Ancient Tome of the Demon
-- Town Guard
(22359, 6701, 1, 1, -1, 38411), -- Sealed Imperial Crusader Breastplate Part
(22359, 960, 1, 1, -1, 2886), -- Scroll: Enchant Armor (S-Grade)
(22359, 1895, 1, 5, -1, 687097), -- Metallic Fiber
(22359, 57, 4226, 8463, 0, 700000), -- Adena
(22359, 289, 1, 1, 1, 17.136), -- Soul Bow
(22359, 5534, 1, 1, 1, 4878.864), -- Soul Bow Stave
(22359, 1895, 1, 1, 2, 169235.775255), -- Metallic Fiber
(22359, 4040, 1, 1, 2, 11846.533341), -- Mold Lubricant
(22359, 9628, 1, 1, 2, 4645.695549), -- Leonard
(22359, 9630, 1, 1, 2, 3117.416964), -- Orichalcum
(22359, 960, 1, 1, 2, 236.849262), -- Scroll: Enchant Armor (S-Grade)
(22359, 9551, 1, 1, 2, 4738.729629), -- Holy Stone
(22359, 9599, 1, 1, 2, 370200), -- Ancient Tome of the Demon
-- Town Patrolman
(22360, 5550, 1, 1, -1, 279723), -- Durable Metal Plate
(22360, 6702, 1, 1, -1, 143782), -- Sealed Imperial Crusader Gaiters Pattern
(22360, 6901, 1, 1, -1, 20979), -- Recipe: Shining Arrow (100%)
(22360, 57, 12288, 24611, 0, 700000), -- Adena
(22360, 289, 1, 1, 1, 49.826), -- Soul Bow
(22360, 5534, 1, 1, 1, 14186.174), -- Soul Bow Stave
(22360, 1869, 9, 27, 2, 47845.393802), -- Iron Ore
(22360, 1864, 28, 84, 2, 30757.800704), -- Stem
(22360, 1880, 1, 1, 2, 86121.575716), -- Steel
(22360, 5550, 1, 1, 2, 11482.921138), -- Durable Metal Plate
(22360, 4043, 1, 1, 2, 28707.302845), -- Asofe
(22360, 6901, 1, 1, 2, 861.335572), -- Recipe: Shining Arrow (100%)
(22360, 14166, 1, 1, 2, 4160.570319), -- Life Stone - Level 84
(22360, 14167, 1, 1, 2, 1038.728099), -- Mid-Grade Life Stone - Level 84
(22360, 14168, 1, 1, 2, 103.839528), -- High-Grade Life Stone - Level 84
(22360, 14169, 1, 1, 2, 20.634778), -- Top-Grade Life Stone - Level 84
(22360, 9551, 1, 1, 2, 6889.686119), -- Holy Stone
(22360, 1345, 50, 150, 2, 114829.21138), -- Shining Arrow
(22360, 9599, 1, 3, 2, 538300), -- Ancient Tome of the Demon
-- Steel Citadel Keymaster
(22361, 6703, 1, 3, -1, 564888), -- Sealed Imperial Crusader Gauntlets Design
(22361, 6901, 1, 1, -1, 79350), -- Recipe: Shining Arrow (100%)
(22361, 6704, 1, 3, -1, 564888), -- Sealed Imperial Crusader Boots Design
(22361, 57, 46478, 93087, 0, 700000), -- Adena
(22361, 5311, 1, 1, 1, 221.994191), -- Sealed Armor of Nightmare
(22361, 5522, 1, 1, 1, 33281.505809), -- Sealed Armor of Nightmare Pattern
(22361, 5316, 1, 1, 1, 221.994191), -- Sealed Majestic Plate Armor
(22361, 5523, 1, 1, 1, 33281.505809), -- Sealed Majestic Plate Armor Pattern
(22361, 1867, 28, 84, 2, 132954.368406), -- Animal Skin
(22361, 1872, 60, 180, 2, 62045.472066), -- Animal Bone
(22361, 1882, 27, 81, 2, 22979.860104), -- Leather
(22361, 1894, 5, 15, 2, 19593.267438), -- Crafted Leather
(22361, 4042, 1, 1, 2, 93068.208099), -- Enria
(22361, 959, 1, 1, 2, 223.444515), -- Scroll: Enchant Weapon (S-Grade)
(22361, 9551, 1, 1, 2, 44672.379372), -- Holy Stone
(22361, 9599, 3, 9, 2, 678600), -- Ancient Tome of the Demon
(22361, 9714, 1, 1, 2, 500000), -- Key of the Evil Eye
-- Guzen
(22362, 959, 1, 1, -1, 8139), -- Scroll: Enchant Weapon (S-Grade)
(22362, 4040, 1, 9, -1, 813887), -- Mold Lubricant
(22362, 1895, 1, 123, -1, 937658), -- Metallic Fiber
(22362, 57, 119181, 238696, 0, 700000), -- Adena
(22362, 164, 1, 1, 1, 120.814416), -- Elysian
(22362, 5533, 1, 1, 1, 34368.391368), -- Elysian Head
(22362, 213, 1, 1, 1, 120.814416), -- Branch of the Mother Tree
(22362, 5544, 1, 1, 1, 34334.464032), -- Branch of the Mother Tree Head
(22362, 7895, 1, 1, 1, 120.814416), -- Flaming Dragon Skull
(22362, 8342, 1, 1, 1, 34368.391368), -- Flaming Dragon Skull Piece
(22362, 7902, 1, 1, 1, 120.814416), -- Doom Crusher
(22362, 8349, 1, 1, 1, 34361.495568), -- Doom Crusher Head
(22362, 1895, 12, 36, 2, 132582.592983), -- Metallic Fiber
(22362, 4040, 4, 12, 2, 27842.296345), -- Mold Lubricant
(22362, 9628, 1, 1, 2, 87348.55246), -- Leonard
(22362, 9630, 1, 1, 2, 58615.337673), -- Orichalcum
(22362, 960, 1, 1, 2, 4454.59221), -- Scroll: Enchant Armor (S-Grade)
(22362, 6897, 1, 1, 2, 1141.023865), -- Recipe: Heavens Divider (60%)
(22362, 8702, 1, 1, 2, 1577.284813), -- Recipe: Shyeed's Bow (60%)
(22362, 9551, 1, 1, 2, 89095.348304), -- Holy Stone
(22362, 1345, 2100, 6300, 2, 35355.971347), -- Shining Arrow
(22362, 9599, 6, 20, 2, 803100), -- Ancient Tome of the Demon
-- Body Destroyer
(22363, 6705, 1, 1, -1, 813293), -- Sealed Imperial Crusader Shield Part
(22363, 6901, 1, 1, -1, 58317), -- Recipe: Shining Arrow (100%)
(22363, 6706, 1, 1, -1, 946016), -- Sealed Imperial Crusader Helmet Pattern
(22363, 57, 34159, 68413, 0, 700000), -- Adena
(22363, 81, 1, 1, 1, 46.168551), -- Dragon Slayer
(22363, 5529, 1, 1, 1, 13130.156292), -- Dragon Slayer Edge
(22363, 151, 1, 1, 1, 46.168551), -- Sword of Miracles
(22363, 5546, 1, 1, 1, 14422.222584), -- Sword of Miracles Edge
(22363, 2500, 1, 1, 1, 46.168551), -- Dark Legion's Edge
(22363, 5545, 1, 1, 1, 13130.115471), -- Dark Legion's Edge Blade
(22363, 1879, 3, 9, 2, 99748.920318), -- Cokes
(22363, 1885, 1, 1, 2, 299246.760954), -- High-Grade Suede
(22363, 9628, 1, 1, 2, 28164.418569), -- Leonard
(22363, 9630, 1, 1, 2, 18900.009885), -- Orichalcum
(22363, 9629, 1, 1, 2, 15612.94362), -- Adamantine
(22363, 959, 1, 1, 2, 143.607279), -- Scroll: Enchant Weapon (S-Grade)
(22363, 6861, 1, 1, 2, 6366.920643), -- Recipe: Sealed Imperial Crusader Shield (60%)
(22363, 9551, 1, 1, 2, 28727.418732), -- Holy Stone
(22363, 9685, 1, 1, 2, 200000), -- Gate Key: Darkness
-- Soul Dominator
(22364, 6901, 1, 1, -1, 16968), -- Recipe: Shining Arrow (100%)
(22364, 6707, 1, 1, -1, 84071), -- Sealed Draconic Leather Armor Part
(22364, 960, 1, 1, -1, 6787), -- Scroll: Enchant Armor (S-Grade)
(22364, 57, 9939, 19905, 0, 700000), -- Adena
(22364, 164, 1, 1, 1, 10.074876), -- Elysian
(22364, 5533, 1, 1, 1, 2866.026198), -- Elysian Head
(22364, 213, 1, 1, 1, 10.074876), -- Branch of the Mother Tree
(22364, 5544, 1, 1, 1, 2863.196952), -- Branch of the Mother Tree Head
(22364, 7895, 1, 1, 1, 10.074876), -- Flaming Dragon Skull
(22364, 8342, 1, 1, 1, 2866.026198), -- Flaming Dragon Skull Piece
(22364, 7902, 1, 1, 1, 10.074876), -- Doom Crusher
(22364, 8349, 1, 1, 1, 2865.451148), -- Doom Crusher Head
(22364, 1879, 1, 1, 2, 174134.708555), -- Cokes
(22364, 1885, 1, 1, 2, 87067.209432), -- High-Grade Suede
(22364, 9628, 1, 1, 2, 8194.489317), -- Leonard
(22364, 9630, 1, 1, 2, 5498.914562), -- Orichalcum
(22364, 9629, 1, 1, 2, 4542.644571), -- Adamantine
(22364, 959, 1, 1, 2, 41.715504), -- Scroll: Enchant Weapon (S-Grade)
(22364, 13100, 1, 1, 2, 1852.573945), -- Recipe - Sealed Arcana Sigil (60%)
(22364, 9551, 1, 1, 2, 8358.744114), -- Holy Stone
(22364, 9685, 1, 1, 2, 30000), -- Gate Key: Darkness
-- Labyrinth Watchman
(22365, 4044, 1, 3, -1, 606472), -- Thons
(22365, 1894, 1, 3, -1, 638392), -- Crafted Leather
(22365, 6708, 1, 1, -1, 518094), -- Sealed Draconic Leather Gloves Fabric
(22365, 57, 21314, 42688, 0, 700000), -- Adena
(22365, 289, 1, 1, 1, 86.4255), -- Soul Bow
(22365, 5534, 1, 1, 1, 24606.5745), -- Soul Bow Stave
(22365, 1894, 1, 1, 2, 62895.824817), -- Crafted Leather
(22365, 4039, 1, 1, 2, 59750.939091), -- Mold Glue
(22365, 4041, 1, 1, 2, 15587.320179), -- Mold Hardener
(22365, 4044, 1, 1, 2, 59750.939091), -- Thons
(22365, 960, 1, 1, 2, 717.037305), -- Scroll: Enchant Armor (S-Grade)
(22365, 14166, 1, 1, 2, 8659.668981), -- Life Stone - Level 84
(22365, 14167, 1, 1, 2, 2162.240166), -- Mid-Grade Life Stone - Level 84
(22365, 14168, 1, 1, 2, 216.26601), -- High-Grade Life Stone - Level 84
(22365, 14169, 1, 1, 2, 43.253202), -- Top-Grade Life Stone - Level 84
(22365, 6893, 1, 1, 2, 183.511158), -- Recipe: Saint Spear (60%)
(22365, 9685, 1, 1, 2, 100000), -- Gate Key: Darkness
-- Labyrinth Watchman
(22366, 6901, 1, 1, -1, 36388), -- Recipe: Shining Arrow (100%)
(22366, 6709, 1, 1, -1, 518094), -- Sealed Draconic Leather Boots Design
(22366, 57, 21314, 42688, 0, 700000), -- Adena
(22366, 81, 1, 1, 1, 28.807701), -- Dragon Slayer
(22366, 5529, 1, 1, 1, 8192.798092), -- Dragon Slayer Edge
(22366, 151, 1, 1, 1, 28.807701), -- Sword of Miracles
(22366, 5546, 1, 1, 1, 8999.006184), -- Sword of Miracles Edge
(22366, 2500, 1, 1, 1, 28.807701), -- Dark Legion's Edge
(22366, 5545, 1, 1, 1, 8192.772621), -- Dark Legion's Edge Blade
(22366, 1879, 1, 3, 2, 186721.660755), -- Cokes
(22366, 1885, 1, 1, 2, 186721.660755), -- High-Grade Suede
(22366, 9628, 1, 1, 2, 17573.859405), -- Leonard
(22366, 9630, 1, 1, 2, 11792.842155), -- Orichalcum
(22366, 9629, 1, 1, 2, 9741.988395), -- Adamantine
(22366, 6901, 1, 1, 2, 2240.52309), -- Recipe: Shining Arrow (100%)
(22366, 8700, 1, 1, 2, 317.414655), -- Recipe: Tiphon's Spear (60%)
(22366, 9551, 1, 1, 2, 17925.05079), -- Holy Stone
-- Labyrinth Mystic
(22367, 6710, 1, 1, -1, 200569), -- Sealed Draconic Leather Helmet Pattern
(22367, 959, 1, 1, -1, 495), -- Scroll: Enchant Weapon (S-Grade)
(22367, 4042, 1, 1, -1, 206067), -- Enria
(22367, 57, 7242, 14504, 0, 700000), -- Adena
(22367, 5320, 1, 1, 1, 46.120168), -- Sealed Leather Armor of Nightmare
(22367, 5480, 1, 1, 1, 6833.379832), -- Sealed Leather Armor of Nightmare Fabric
(22367, 5323, 1, 1, 1, 46.120168), -- Sealed Majestic Leather Armor
(22367, 5481, 1, 1, 1, 6833.379832), -- Sealed Majestic Leather Armor Fabric
(22367, 1879, 1, 1, 2, 78085.482063), -- Cokes
(22367, 1885, 1, 1, 2, 39042.518843), -- High-Grade Suede
(22367, 9628, 1, 1, 2, 3674.553413), -- Leonard
(22367, 9630, 1, 1, 2, 2465.847973), -- Orichalcum
(22367, 9629, 1, 1, 2, 2037.024168), -- Adamantine
(22367, 959, 1, 1, 2, 18.663834), -- Scroll: Enchant Weapon (S-Grade)
(22367, 14166, 1, 1, 2, 2263.212061), -- Life Stone - Level 84
(22367, 14167, 1, 1, 2, 565.247544), -- Mid-Grade Life Stone - Level 84
(22367, 14168, 1, 1, 2, 56.435879), -- High-Grade Life Stone - Level 84
(22367, 14169, 1, 1, 2, 11.109425), -- Top-Grade Life Stone - Level 84
(22367, 8690, 1, 1, 2, 66.212173), -- Recipe: Sirra's Blade (60%)
(22367, 9551, 1, 1, 2, 3748.319995), -- Holy Stone
(22367, 1345, 10, 30, 2, 312342.372629), -- Shining Arrow
-- Labyrinth Captain
(22368, 4040, 1, 5, -1, 922230), -- Mold Lubricant
(22368, 6711, 1, 1, -1, 685418), -- Sealed Major Arcana Robe Part
(22368, 6901, 1, 1, -1, 138334), -- Recipe: Shining Arrow (100%)
(22368, 57, 81028, 162283, 0, 700000), -- Adena
(22368, 5313, 1, 1, 1, 1257.289356), -- Sealed Gauntlets of Nightmare
(22368, 5514, 1, 1, 1, 143859.210644), -- Sealed Gauntlets of Nightmare Design
(22368, 5314, 1, 1, 1, 1257.289356), -- Sealed Boots of Nightmare
(22368, 5502, 1, 1, 1, 143859.210644), -- Sealed Boots of Nightmare Lining
(22368, 5318, 1, 1, 1, 1257.289356), -- Sealed Majestic Gauntlets
(22368, 5515, 1, 1, 1, 143859.210644), -- Sealed Majestic Gauntlets Design
(22368, 5319, 1, 1, 1, 1257.289356), -- Sealed Majestic Boots
(22368, 5503, 1, 1, 1, 143859.210644), -- Sealed Majestic Boots Lining
(22368, 1895, 12, 36, 2, 115892.855124), -- Metallic Fiber
(22368, 4040, 2, 6, 2, 38939.905832), -- Mold Lubricant
(22368, 9628, 1, 1, 2, 76352.93555), -- Leonard
(22368, 9630, 1, 1, 2, 51236.7182), -- Orichalcum
(22368, 960, 1, 1, 2, 3894.063622), -- Scroll: Enchant Armor (S-Grade)
(22368, 6883, 1, 1, 2, 997.344814), -- Recipe: Basalt Battlehammer (60%)
(22368, 9551, 1, 1, 2, 77880.176858), -- Holy Stone
-- Labyrinth Priest
(22369, 6712, 1, 1, -1, 195038), -- Sealed Major Arcana Gloves fabric
(22369, 6901, 1, 1, -1, 13698), -- Recipe: Shining Arrow (100%)
(22369, 6713, 1, 1, -1, 195038), -- Sealed Major Arcana Boots Design
(22369, 57, 8024, 16070, 0, 700000), -- Adena
(22369, 164, 1, 1, 1, 8.13366), -- Elysian
(22369, 5533, 1, 1, 1, 2313.80343), -- Elysian Head
(22369, 213, 1, 1, 1, 8.13366), -- Branch of the Mother Tree
(22369, 5544, 1, 1, 1, 2311.51932), -- Branch of the Mother Tree Head
(22369, 7895, 1, 1, 1, 8.13366), -- Flaming Dragon Skull
(22369, 8342, 1, 1, 1, 2313.80343), -- Flaming Dragon Skull Piece
(22369, 7902, 1, 1, 1, 8.13366), -- Doom Crusher
(22369, 8349, 1, 1, 1, 2313.33918), -- Doom Crusher Head
(22369, 1868, 15, 45, 2, 56233.50542), -- Thread
(22369, 1873, 2, 6, 2, 84350.416628), -- Silver Nugget
(22369, 5549, 1, 1, 2, 84350.416628), -- Metallic Thread
(22369, 1889, 1, 1, 2, 56233.50542), -- Compound Braid
(22369, 4044, 1, 1, 2, 28116.911208), -- Thons
(22369, 6901, 1, 1, 2, 843.526356), -- Recipe: Shining Arrow (100%)
(22369, 8692, 1, 1, 2, 119.507492), -- Recipe: Sword of Ipos (60%)
(22369, 9551, 1, 1, 2, 6748.210848), -- Holy Stone
(22369, 9687, 1, 1, 2, 500000), -- Gate Key: Blood
-- Passageway Captain
(22370, 960, 1, 1, -1, 20452), -- Scroll: Enchant Armor (S-Grade)
(22370, 1885, 1, 9, -1, 852162), -- High-Grade Suede
(22370, 13099, 1, 1, -1, 713056), -- Sealed Arcana Sigil Piece
(22370, 57, 29949, 59981, 0, 700000), -- Adena
(22370, 5312, 1, 1, 1, 413.172864), -- Sealed Helm of Nightmare
(22370, 5527, 1, 1, 1, 50187.756858), -- Sealed Helm of Nightmare Design
(22370, 5315, 1, 1, 1, 590.459778), -- Sealed Shield of Nightmare
(22370, 5495, 1, 1, 1, 63741.680778), -- Sealed Shield of Nightmare Fragment
(22370, 5317, 1, 1, 1, 413.172864), -- Sealed Majestic Circlet
(22370, 5528, 1, 1, 1, 50187.756858), -- Sealed Majestic Circlet Design
(22370, 1879, 3, 9, 2, 87455.122984), -- Cokes
(22370, 1885, 1, 1, 2, 262365.368952), -- High-Grade Suede
(22370, 9628, 1, 1, 2, 24693.226572), -- Leonard
(22370, 9630, 1, 1, 2, 16570.63238), -- Orichalcum
(22370, 9629, 1, 1, 2, 13688.68856), -- Adamantine
(22370, 959, 1, 1, 2, 125.908052), -- Scroll: Enchant Weapon (S-Grade)
(22370, 6861, 1, 1, 2, 5582.214084), -- Recipe: Sealed Imperial Crusader Shield (60%)
(22370, 9551, 1, 1, 2, 25186.838416), -- Holy Stone
(22370, 9849, 1, 1, 2, 1000000), -- Fiery Demon Blood
-- Passageway Guards
(22371, 6714, 1, 1, -1, 271438), -- Sealed Major Arcana Circlet Pattern
(22371, 6901, 1, 1, -1, 16733), -- Recipe: Shining Arrow (100%)
(22371, 7579, 1, 1, -1, 36586), -- Draconic Bow Shaft
(22371, 57, 9801, 19630, 0, 700000), -- Adena
(22371, 5320, 1, 1, 1, 62.417592), -- Sealed Leather Armor of Nightmare
(22371, 5480, 1, 1, 1, 9248.082408), -- Sealed Leather Armor of Nightmare Fabric
(22371, 5323, 1, 1, 1, 62.417592), -- Sealed Majestic Leather Armor
(22371, 5481, 1, 1, 1, 9248.082408), -- Sealed Majestic Leather Armor Fabric
(22371, 1879, 1, 1, 2, 114482.7138), -- Cokes
(22371, 1885, 1, 1, 2, 57241.3569), -- High-Grade Suede
(22371, 9628, 1, 1, 2, 5387.247775), -- Leonard
(22371, 9630, 1, 1, 2, 3615.310335), -- Orichalcum
(22371, 9629, 1, 1, 2, 2986.340175), -- Adamantine
(22371, 960, 1, 1, 2, 274.75175), -- Scroll: Enchant Armor (S-Grade)
(22371, 14166, 1, 1, 2, 3318.15575), -- Life Stone - Level 84
(22371, 14167, 1, 1, 2, 828.4822), -- Mid-Grade Life Stone - Level 84
(22371, 14168, 1, 1, 2, 82.84822), -- High-Grade Life Stone - Level 84
(22371, 14169, 1, 1, 2, 16.485105), -- Top-Grade Life Stone - Level 84
(22371, 9551, 1, 1, 2, 5495.035), -- Holy Stone
(22371, 1345, 20, 60, 2, 228966.27299), -- Shining Arrow
-- Passageway Mystic
(22372, 6901, 1, 1, -1, 42646), -- Recipe: Shining Arrow (100%)
(22372, 8712, 1, 1, -1, 103509), -- Sirra's Blade Edge
(22372, 959, 1, 1, -1, 1706), -- Scroll: Enchant Weapon (S-Grade)
(22372, 57, 24979, 50028, 0, 700000), -- Adena
(22372, 81, 1, 1, 1, 33.761481), -- Dragon Slayer
(22372, 5529, 1, 1, 1, 9601.633852), -- Dragon Slayer Edge
(22372, 151, 1, 1, 1, 33.761481), -- Sword of Miracles
(22372, 5546, 1, 1, 1, 10546.477704), -- Sword of Miracles Edge
(22372, 2500, 1, 1, 1, 33.761481), -- Dark Legion's Edge
(22372, 5545, 1, 1, 1, 9601.604001), -- Dark Legion's Edge Blade
(22372, 1894, 1, 1, 2, 92139.09601), -- Crafted Leather
(22372, 4039, 1, 1, 2, 87532.3891), -- Mold Glue
(22372, 4041, 1, 1, 2, 22834.32073), -- Mold Hardener
(22372, 4044, 1, 1, 2, 87532.3891), -- Thons
(22372, 6901, 1, 1, 2, 2625.83646), -- Recipe: Shining Arrow (100%)
(22372, 6881, 1, 1, 2, 269.07387), -- Recipe: Forgotten Blade (60%)
(22372, 9551, 1, 1, 2, 21007.5931), -- Holy Stone
(22372, 1344, 240, 720, 2, 136769.30163), -- Mithril Arrow
(22372, 9849, 1, 1, 2, 1000000), -- Fiery Demon Blood
-- Cosmic Scout
(22373, 15654, 1, 1, -1, 26714), -- Sealed Moirai Gauntlet Piece
(22373, 15655, 1, 1, -1, 26714), -- Sealed Moirai Leather Gloves Piece
(22373, 15656, 1, 1, -1, 26714), -- Sealed Moirai Gloves Piece
(22373, 15657, 1, 1, -1, 26714), -- Sealed Moirai Boots Piece
(22373, 15658, 1, 1, -1, 26714), -- Sealed Moirai Leather Boots Piece
(22373, 15659, 1, 1, -1, 26714), -- Sealed Moirai Shoes Piece
(22373, 9630, 1, 1, -1, 15747), -- Orichalcum
(22373, 15784, 1, 1, -1, 3554), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22373, 15785, 1, 1, -1, 3554), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22373, 15786, 1, 1, -1, 3554), -- Recipe - Sealed Moirai Gloves (60%) 
(22373, 15787, 1, 1, -1, 3554), -- Recipe - Sealed Moirai Boots (60%) 
(22373, 15788, 1, 1, -1, 3554), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22373, 15789, 1, 1, -1, 3554), -- Recipe - Sealed Moirai Shoes (60%) 
(22373, 57, 3173, 6405, 0, 700000), -- Adena
(22373, 15703, 1, 1, 1, 25.290645), -- Sealed Moirai Gauntlet 
(22373, 15704, 1, 1, 1, 25.290645), -- Sealed Moirai Leather Gloves 
(22373, 15705, 1, 1, 1, 25.290645), -- Sealed Moirai Gloves 
(22373, 15654, 1, 1, 1, 9500.395073), -- Sealed Moirai Gauntlet Piece
(22373, 15655, 1, 1, 1, 9500.395073), -- Sealed Moirai Leather Gloves Piece
(22373, 15656, 1, 1, 1, 9500.337919), -- Sealed Moirai Gloves Piece
(22373, 1873, 2, 6, 2, 63868.598269), -- Silver Nugget
(22373, 1868, 18, 54, 2, 44353.205841), -- Thread
(22373, 1876, 1, 1, 2, 159671.268897), -- Mithril Ore
(22373, 1895, 3, 9, 2, 32585.825146), -- Metallic Fiber
(22373, 4042, 1, 1, 2, 13305.825687), -- Enria
(22373, 9551, 1, 1, 2, 6386.905182), -- Holy Stone
(22373, 960, 1, 1, 2, 319.299904), -- Scroll: Enchant Armor (S-Grade)
(22373, 1345, 40, 120, 2, 133060.071074), -- Shining Arrow
(22373, 9599, 1, 2, 2, 443500), -- Ancient Tome of the Demon
-- Cosmic Watcher
(22374, 15654, 1, 1, -1, 74628), -- Sealed Moirai Gauntlet Piece
(22374, 15655, 1, 1, -1, 74628), -- Sealed Moirai Leather Gloves Piece
(22374, 15656, 1, 1, -1, 74628), -- Sealed Moirai Gloves Piece
(22374, 15657, 1, 1, -1, 74628), -- Sealed Moirai Boots Piece
(22374, 15658, 1, 1, -1, 74628), -- Sealed Moirai Leather Boots Piece
(22374, 15659, 1, 1, -1, 74628), -- Sealed Moirai Shoes Piece
(22374, 9630, 1, 1, -1, 43991), -- Orichalcum
(22374, 15784, 1, 1, -1, 9929), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22374, 15785, 1, 1, -1, 9929), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22374, 15786, 1, 1, -1, 9929), -- Recipe - Sealed Moirai Gloves (60%) 
(22374, 15787, 1, 1, -1, 9929), -- Recipe - Sealed Moirai Boots (60%) 
(22374, 15788, 1, 1, -1, 9929), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22374, 15789, 1, 1, -1, 9929), -- Recipe - Sealed Moirai Shoes (60%) 
(22374, 57, 8864, 17893, 0, 700000), -- Adena
(22374, 15706, 1, 1, 1, 70.650435), -- Sealed Moirai Boots 
(22374, 15707, 1, 1, 1, 70.650435), -- Sealed Moirai Leather Boots 
(22374, 15708, 1, 1, 1, 70.650435), -- Sealed Moirai Shoes 
(22374, 15657, 1, 1, 1, 26539.736119), -- Sealed Moirai Boots Piece
(22374, 15658, 1, 1, 1, 26539.736119), -- Sealed Moirai Leather Boots Piece
(22374, 15659, 1, 1, 1, 26539.576457), -- Sealed Moirai Shoes Piece
(22374, 1869, 9, 27, 2, 123902.815776), -- Iron Ore
(22374, 1864, 28, 84, 2, 79651.97622), -- Stem
(22374, 1880, 4, 12, 2, 24780.485652), -- Steel
(22374, 5550, 1, 1, 2, 29736.815292), -- Durable Metal Plate
(22374, 4043, 1, 1, 2, 74341.844472), -- Asofe
(22374, 9551, 1, 1, 2, 17842.011672), -- Holy Stone
(22374, 959, 1, 1, 2, 89.12868), -- Scroll: Enchant Weapon (S-Grade)
(22374, 1345, 400, 1200, 2, 37170.922236), -- Shining Arrow
(22374, 9599, 2, 6, 2, 464600), -- Ancient Tome of the Demon
-- Cosmic Priest
(22375, 15645, 1, 1, -1, 136502), -- Sealed Moirai Helmet Piece
(22375, 15646, 1, 1, -1, 136502), -- Sealed Moirai Leather Helmet Piece
(22375, 15647, 1, 1, -1, 136502), -- Sealed Moirai Circlet Piece
(22375, 15693, 1, 1, -1, 244687), -- Sealed Moirai Shield Piece
(22375, 15692, 1, 1, -1, 244687), -- Sealed Moirai Sigil Piece
(22375, 15775, 1, 1, -1, 18215), -- Recipe - Sealed Moirai Helmet (60%) 
(22375, 15776, 1, 1, -1, 18215), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22375, 15777, 1, 1, -1, 18215), -- Recipe - Sealed Moirai Circlet (60%) 
(22375, 15791, 1, 1, -1, 26022), -- Recipe - Sealed Moirai Shield (60%) 
(22375, 15790, 1, 1, -1, 26022), -- Recipe - Sealed Moirai Sigil (60%) 
(22375, 57, 18763, 37877, 0, 700000), -- Adena
(22375, 15694, 1, 1, 1, 149.55116), -- Sealed Moirai Helmet 
(22375, 15695, 1, 1, 1, 149.55116), -- Sealed Moirai Leather Helmet 
(22375, 15645, 1, 1, 1, 56030.44884), -- Sealed Moirai Helmet Piece
(22375, 15646, 1, 1, 1, 56030.44884), -- Sealed Moirai Leather Helmet Piece
(22375, 1879, 3, 9, 2, 174850.854585), -- Cokes
(22375, 1885, 2, 6, 2, 131138.257492), -- High-Grade Suede
(22375, 9628, 1, 1, 2, 49369.625635), -- Leonard
(22375, 9630, 1, 1, 2, 33129.561993), -- Orichalcum
(22375, 9629, 1, 1, 2, 27368.101739), -- Adamantine
(22375, 9551, 1, 1, 2, 50356.598556), -- Holy Stone
(22375, 9599, 3, 9, 2, 655700), -- Ancient Tome of the Demon
-- Cosmic Lord
(22376, 15772, 1, 3, -1, 701627), -- Sealed Moirai Ring Gem
(22376, 15773, 1, 1, -1, 788650), -- Sealed Moirai Earring Gem
(22376, 15774, 1, 1, -1, 680508), -- Sealed Moirai Necklace Gem
(22376, 15812, 1, 1, -1, 185649), -- Recipe - Sealed Moirai Ring (70%) 
(22376, 15813, 1, 1, -1, 123751), -- Recipe - Sealed Moirai Earring (70%) 
(22376, 15814, 1, 1, -1, 92816), -- Recipe - Sealed Moirai Necklace (70%) 
(22376, 57, 49794, 100522, 0, 700000), -- Adena
(22376, 15766, 1, 1, 1, 609.686688), -- Sealed Moirai Ring
(22376, 15767, 1, 1, 1, 406.300128), -- Sealed Moirai Earring
(22376, 15768, 1, 1, 1, 304.606848), -- Sealed Moirai Necklace
(22376, 15772, 1, 1, 1, 230424.674688), -- Sealed Moirai Ring Gem
(22376, 15773, 1, 1, 1, 129502.371648), -- Sealed Moirai Earring Gem
(22376, 15774, 1, 1, 1, 111744.36), -- Sealed Moirai Necklace Gem
(22376, 1866, 60, 180, 2, 92807.744778), -- Suede
(22376, 1871, 240, 720, 2, 34802.779581), -- Charcoal
(22376, 5220, 4, 12, 2, 74246.295591), -- Metal Hardener
(22376, 1885, 38, 114, 2, 18079.566849), -- High-Grade Suede
(22376, 4041, 1, 1, 2, 145264.079286), -- Mold Hardener
(22376, 9551, 1, 1, 2, 133642.533915), -- Holy Stone
(22376, 9599, 7, 21, 2, 745800), -- Ancient Tome of the Demon
-- Master Zelos
(22377, 10398, 1, 1, -1, 95841), -- Icarus Disperser Piece
(22377, 959, 1, 1, -1, 8942), -- Scroll: Enchant Weapon (S-Grade)
(22377, 1894, 1, 17, -1, 871533), -- Crafted Leather
(22377, 10374, 1, 1, -1, 14408), -- Recipe - Icarus Disperser (60%)
(22377, 57, 72943, 147253, 0, 700000), -- Adena
(22377, 10216, 1, 1, 1, 94.63187), -- Icarus Disperser
(22377, 10398, 1, 1, 1, 31470.36813), -- Icarus Disperser Piece
(22377, 1895, 96, 288, 2, 43699.338086), -- Metallic Fiber
(22377, 4040, 3, 9, 2, 97886.014593), -- Mold Lubricant
(22377, 4042, 3, 9, 2, 69918.767586), -- Enria
(22377, 4043, 2, 6, 2, 195772.029186), -- Asofe
(22377, 9551, 4, 12, 2, 26102.850549), -- Holy Stone
(22377, 9599, 9, 25, 2, 899700), -- Ancient Tome of the Demon
-- Master's Minion
(22378, 10397, 1, 1, -1, 10851), -- Icarus Sawsword Piece
(22378, 10399, 1, 1, -1, 10851), -- Icarus Spirit Piece
(22378, 10400, 1, 1, -1, 10816), -- Icarus Heavy Arms Piece
(22378, 9628, 1, 1, -1, 198509), -- Leonard
(22378, 10373, 1, 1, -1, 1631), -- Recipe - Icarus Sawsword (60%)
(22378, 10375, 1, 1, -1, 1631), -- Recipe - Icarus Spirit (60%)
(22378, 10376, 1, 1, -1, 1631), -- Recipe - Icarus Heavy Arms (60%)
(22378, 57, 14453, 29176, 0, 700000), -- Adena
(22378, 10215, 1, 1, 1, 6.25), -- Icarus Sawsword
(22378, 10217, 1, 1, 1, 6.25), -- Icarus Spirit
(22378, 10218, 1, 1, 1, 6.25), -- Icarus Heavy Arms
(22378, 10397, 1, 1, 1, 2079.30625), -- Icarus Sawsword Piece
(22378, 10399, 1, 1, 1, 2079.30625), -- Icarus Spirit Piece
(22378, 10400, 1, 1, 1, 2072.6375), -- Icarus Heavy Arms Piece
(22378, 1895, 3, 9, 2, 230888.308434), -- Metallic Fiber
(22378, 4040, 1, 1, 2, 96973.063614), -- Mold Lubricant
(22378, 9628, 1, 1, 2, 38028.576138), -- Leonard
(22378, 9630, 1, 1, 2, 25519.045314), -- Orichalcum
(22378, 9551, 1, 1, 2, 38789.139018), -- Holy Stone
(22378, 960, 1, 1, 2, 1939.867482), -- Scroll: Enchant Armor (S-Grade)
(22378, 9599, 2, 6, 2, 757600), -- Ancient Tome of the Demon
-- Master's Minion
(22379, 15645, 1, 1, -1, 48618), -- Sealed Moirai Helmet Piece
(22379, 15646, 1, 1, -1, 48618), -- Sealed Moirai Leather Helmet Piece
(22379, 15647, 1, 1, -1, 48618), -- Sealed Moirai Circlet Piece
(22379, 15693, 1, 1, -1, 87150), -- Sealed Moirai Shield Piece
(22379, 15692, 1, 1, -1, 87150), -- Sealed Moirai Sigil Piece
(22379, 15775, 1, 1, -1, 6488), -- Recipe - Sealed Moirai Helmet (60%) 
(22379, 15776, 1, 1, -1, 6488), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22379, 15777, 1, 1, -1, 6488), -- Recipe - Sealed Moirai Circlet (60%) 
(22379, 15791, 1, 1, -1, 9268), -- Recipe - Sealed Moirai Shield (60%) 
(22379, 15790, 1, 1, -1, 9268), -- Recipe - Sealed Moirai Sigil (60%) 
(22379, 57, 6683, 13491, 0, 700000), -- Adena
(22379, 15694, 1, 1, 1, 21.306556), -- Sealed Moirai Helmet 
(22379, 15695, 1, 1, 1, 21.306556), -- Sealed Moirai Leather Helmet 
(22379, 15696, 1, 1, 1, 21.306556), -- Sealed Moirai Circlet 
(22379, 15710, 1, 1, 1, 30.483142), -- Sealed Moirai Shield 
(22379, 15709, 1, 1, 1, 30.483142), -- Sealed Moirai Sigil 
(22379, 15645, 1, 1, 1, 7989.853022), -- Sealed Moirai Helmet Piece
(22379, 15646, 1, 1, 1, 7989.853022), -- Sealed Moirai Leather Helmet Piece
(22379, 15647, 1, 1, 1, 7989.853022), -- Sealed Moirai Circlet Piece
(22379, 15693, 1, 1, 1, 14322.277491), -- Sealed Moirai Shield Piece
(22379, 15692, 1, 1, 1, 14322.277491), -- Sealed Moirai Sigil Piece
(22379, 1871, 24, 72, 2, 46707.513559), -- Charcoal
(22379, 1866, 7, 21, 2, 99642.865352), -- Suede
(22379, 1877, 1, 1, 2, 89678.515157), -- Adamantite Nugget
(22379, 4041, 1, 1, 2, 19495.177152), -- Mold Hardener
(22379, 4040, 1, 1, 2, 44839.098429), -- Mold Lubricant
(22379, 9551, 1, 1, 2, 17935.830351), -- Holy Stone
(22379, 9599, 1, 4, 2, 560500), -- Ancient Tome of the Demon
-- Master Festina
(22380, 10404, 1, 1, -1, 71976), -- Icarus Hall Piece
(22380, 10402, 1, 1, -1, 71976), -- Icarus Hammer Piece
(22380, 9630, 1, 1, -1, 886436), -- Orichalcum
(22380, 10380, 1, 1, -1, 10855), -- Recipe - Icarus Hall (60%)
(22380, 10378, 1, 1, -1, 10855), -- Recipe - Icarus Hammer (60%)
(22380, 57, 68695, 138677, 0, 700000), -- Adena
(22380, 10222, 1, 1, 1, 44.560512), -- Icarus Hall
(22380, 10220, 1, 1, 1, 44.560512), -- Icarus Hammer
(22380, 10404, 1, 1, 1, 14769.439488), -- Icarus Hall Piece
(22380, 10402, 1, 1, 1, 14769.439488), -- Icarus Hammer Piece
(22380, 1872, 120, 360, 2, 69837.431125), -- Animal Bone
(22380, 1882, 27, 81, 2, 51731.444875), -- Leather
(22380, 1894, 5, 15, 2, 44107.707875), -- Crafted Leather
(22380, 4042, 6, 18, 2, 17459.2605), -- Enria
(22380, 14166, 1, 1, 2, 60728.014875), -- Life Stone - Level 84
(22380, 14167, 1, 1, 2, 15163.812125), -- Mid-Grade Life Stone - Level 84
(22380, 14168, 1, 1, 2, 1516.420125), -- High-Grade Life Stone - Level 84
(22380, 14169, 1, 1, 2, 303.128375), -- Top-Grade Life Stone - Level 84
(22380, 9551, 1, 1, 2, 100565.854125), -- Holy Stone
(22380, 959, 1, 1, 2, 502.7495), -- Scroll: Enchant Weapon (S-Grade)
(22380, 1345, 3080, 9240, 2, 27209.1765), -- Shining Arrow
(22380, 9599, 9, 27, 2, 800200), -- Ancient Tome of the Demon
-- Master's Guard
(22381, 10405, 1, 1, -1, 15296), -- Icarus Spitter Piece
(22381, 959, 1, 1, -1, 1432), -- Scroll: Enchant Weapon (S-Grade)
(22381, 1894, 1, 3, -1, 627953), -- Crafted Leather
(22381, 10381, 1, 1, -1, 2307), -- Recipe - Icarus Spitter (60%)
(22381, 57, 11679, 23577, 0, 700000), -- Adena
(22381, 10223, 1, 1, 1, 15.152273), -- Icarus Spitter
(22381, 10405, 1, 1, 1, 5023.847727), -- Icarus Spitter Piece
(22381, 14166, 1, 1, 2, 18928.87112), -- Life Stone - Level 84
(22381, 14167, 1, 1, 2, 4726.518464), -- Mid-Grade Life Stone - Level 84
(22381, 14168, 1, 1, 2, 472.628992), -- High-Grade Life Stone - Level 84
(22381, 14169, 1, 1, 2, 94.502944), -- Top-Grade Life Stone - Level 84
(22381, 9551, 1, 1, 2, 31346.180864), -- Holy Stone
(22381, 960, 1, 1, 2, 1567.297616), -- Scroll: Enchant Armor (S-Grade)
(22381, 9599, 2, 6, 2, 612200), -- Ancient Tome of the Demon
-- Master's Guard
(22382, 15654, 1, 1, -1, 105016), -- Sealed Moirai Gauntlet Piece
(22382, 15655, 1, 1, -1, 105016), -- Sealed Moirai Leather Gloves Piece
(22382, 15656, 1, 1, -1, 105016), -- Sealed Moirai Gloves Piece
(22382, 15657, 1, 1, -1, 105016), -- Sealed Moirai Boots Piece
(22382, 15658, 1, 1, -1, 105016), -- Sealed Moirai Leather Boots Piece
(22382, 15659, 1, 1, -1, 105016), -- Sealed Moirai Shoes Piece
(22382, 15784, 1, 1, -1, 13972), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22382, 15785, 1, 1, -1, 13972), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22382, 15786, 1, 1, -1, 13972), -- Recipe - Sealed Moirai Gloves (60%) 
(22382, 15787, 1, 1, -1, 13972), -- Recipe - Sealed Moirai Boots (60%) 
(22382, 15788, 1, 1, -1, 13972), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22382, 15789, 1, 1, -1, 13972), -- Recipe - Sealed Moirai Shoes (60%) 
(22382, 57, 11514, 23243, 0, 700000), -- Adena
(22382, 15703, 1, 1, 1, 45.885788), -- Sealed Moirai Gauntlet 
(22382, 15704, 1, 1, 1, 45.885788), -- Sealed Moirai Leather Gloves 
(22382, 15705, 1, 1, 1, 45.885788), -- Sealed Moirai Gloves 
(22382, 15706, 1, 1, 1, 45.885788), -- Sealed Moirai Boots 
(22382, 15707, 1, 1, 1, 45.885788), -- Sealed Moirai Leather Boots 
(22382, 15708, 1, 1, 1, 45.885788), -- Sealed Moirai Shoes 
(22382, 15654, 1, 1, 1, 17256.378336), -- Sealed Moirai Gauntlet Piece
(22382, 15655, 1, 1, 1, 17256.378336), -- Sealed Moirai Leather Gloves Piece
(22382, 15656, 1, 1, 1, 17256.378336), -- Sealed Moirai Gloves Piece
(22382, 15657, 1, 1, 1, 17256.378336), -- Sealed Moirai Boots Piece
(22382, 15658, 1, 1, 1, 17256.378336), -- Sealed Moirai Leather Boots Piece
(22382, 15659, 1, 1, 1, 17256.793592), -- Sealed Moirai Shoes Piece
(22382, 1873, 16, 48, 2, 41385.578445), -- Silver Nugget
(22382, 1868, 135, 405, 2, 24524.653905), -- Thread
(22382, 1876, 3, 9, 2, 94595.72215), -- Mithril Ore
(22382, 1895, 3, 9, 2, 157659.403595), -- Metallic Fiber
(22382, 4042, 1, 1, 2, 55180.77126), -- Enria
(22382, 9551, 1, 1, 2, 26486.882195), -- Holy Stone
(22382, 959, 1, 1, 2, 131.98845), -- Scroll: Enchant Weapon (S-Grade)
(22382, 9599, 2, 6, 2, 603500), -- Ancient Tome of the Demon
-- Tully's Toy
(22383, 15649, 1, 1, -1, 17341), -- Sealed Moirai Leather Breastplate Piece
(22383, 15652, 1, 1, -1, 28134), -- Sealed Moirai Leather Legging Piece
(22383, 9630, 1, 1, -1, 28431), -- Orichalcum
(22383, 15779, 1, 1, -1, 2139), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22383, 15782, 1, 1, -1, 3422), -- Recipe - Sealed Moirai Leather Legging (60%) 
(22383, 57, 2203, 4448, 0, 700000), -- Adena
(22383, 15698, 1, 1, 1, 8.780618), -- Sealed Moirai Leather Breastplate 
(22383, 15701, 1, 1, 1, 14.050861), -- Sealed Moirai Leather Legging 
(22383, 15649, 1, 1, 1, 3560.9244), -- Sealed Moirai Leather Breastplate Piece
(22383, 15652, 1, 1, 1, 5777.244121), -- Sealed Moirai Leather Legging Piece
(22383, 1894, 1, 1, 2, 15561.21413), -- Crafted Leather
(22383, 4039, 1, 1, 2, 14783.125698), -- Mold Glue
(22383, 4041, 1, 1, 2, 3856.450697), -- Mold Hardener
(22383, 4044, 1, 1, 2, 14783.125698), -- Thons
(22383, 14166, 1, 1, 2, 2142.460287), -- Life Stone - Level 84
(22383, 14167, 1, 1, 2, 534.991248), -- Mid-Grade Life Stone - Level 84
(22383, 14168, 1, 1, 2, 53.510215), -- High-Grade Life Stone - Level 84
(22383, 14169, 1, 1, 2, 10.702043), -- Top-Grade Life Stone - Level 84
(22383, 9551, 1, 1, 2, 3547.976784), -- Holy Stone
(22383, 960, 1, 1, 2, 177.4432), -- Scroll: Enchant Armor (S-Grade)
(22383, 9599, 1, 1, 2, 462000), -- Ancient Tome of the Demon
-- Mystic's Toy
(22384, 15648, 1, 1, -1, 13458), -- Sealed Moirai Breastplate Piece
(22384, 15651, 1, 1, -1, 22556), -- Sealed Moirai Gaiter Piece
(22384, 1894, 1, 1, -1, 199044), -- Crafted Leather
(22384, 15778, 1, 1, -1, 1685), -- Recipe - Sealed Moirai Breastplate (60%) 
(22384, 15781, 1, 1, -1, 2695), -- Recipe - Sealed Moirai Gaiter (60%) 
(22384, 57, 2314, 4671, 0, 700000), -- Adena
(22384, 15697, 1, 1, 1, 6.915396), -- Sealed Moirai Breastplate 
(22384, 15700, 1, 1, 1, 11.066116), -- Sealed Moirai Gaiter 
(22384, 15648, 1, 1, 1, 2763.141716), -- Sealed Moirai Breastplate Piece
(22384, 15651, 1, 1, 1, 4630.876772), -- Sealed Moirai Gaiter Piece
(22384, 1879, 1, 1, 2, 129372.932898), -- Cokes
(22384, 1885, 1, 1, 2, 64686.573358), -- High-Grade Suede
(22384, 9628, 1, 1, 2, 6088.039914), -- Leonard
(22384, 9630, 1, 1, 2, 4085.420526), -- Orichalcum
(22384, 9629, 1, 1, 2, 3374.903312), -- Adamantine
(22384, 9551, 1, 1, 2, 6210.129992), -- Holy Stone
(22384, 9599, 1, 1, 2, 485100), -- Ancient Tome of the Demon
-- Tully's Golem Guard
(22385, 15649, 1, 1, -1, 130176), -- Sealed Moirai Leather Breastplate Piece
(22385, 15652, 1, 1, -1, 211197), -- Sealed Moirai Leather Legging Piece
(22385, 1894, 1, 3, -1, 711399), -- Crafted Leather
(22385, 15779, 1, 1, -1, 16056), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22385, 15782, 1, 1, -1, 25690), -- Recipe - Sealed Moirai Leather Legging (60%) 
(22385, 57, 16539, 33388, 0, 700000), -- Adena
(22385, 15698, 1, 1, 1, 65.912322), -- Sealed Moirai Leather Breastplate 
(22385, 15701, 1, 1, 1, 105.473769), -- Sealed Moirai Leather Legging 
(22385, 15649, 1, 1, 1, 26730.3276), -- Sealed Moirai Leather Breastplate Piece
(22385, 15652, 1, 1, 1, 43367.286309), -- Sealed Moirai Leather Legging Piece
(22385, 1866, 9, 27, 2, 154129.92012), -- Suede
(22385, 1871, 40, 120, 2, 52018.713648), -- Charcoal
(22385, 5220, 5, 15, 2, 16646.177592), -- Metal Hardener
(22385, 1885, 4, 12, 2, 38532.587544), -- High-Grade Suede
(22385, 4041, 1, 1, 2, 36187.06212), -- Mold Hardener
(22385, 9551, 1, 1, 2, 33291.925128), -- Holy Stone
(22385, 959, 1, 1, 2, 166.431672), -- Scroll: Enchant Weapon (S-Grade)
(22385, 1345, 280, 840, 2, 99083.182176), -- Shining Arrow
(22385, 9599, 2, 6, 2, 867000), -- Ancient Tome of the Demon
-- Foundry Mystic
(22386, 15650, 1, 1, -1, 83173), -- Sealed Moirai Tunic Piece
(22386, 15653, 1, 1, -1, 134939), -- Sealed Moirai Stockings Piece
(22386, 1894, 1, 1, -1, 909065), -- Crafted Leather
(22386, 15780, 1, 1, -1, 10259), -- Recipe - Sealed Moirai Tunic (60%) 
(22386, 15783, 1, 1, -1, 16414), -- Recipe - Sealed Moirai Stockings (60%) 
(22386, 57, 10567, 21333, 0, 700000), -- Adena
(22386, 15699, 1, 1, 1, 42.112448), -- Sealed Moirai Tunic 
(22386, 15702, 1, 1, 1, 67.388896), -- Sealed Moirai Stockings 
(22386, 15650, 1, 1, 1, 17078.4384), -- Sealed Moirai Tunic Piece
(22386, 15653, 1, 1, 1, 27708.060256), -- Sealed Moirai Stockings Piece
(22386, 1879, 3, 9, 2, 84409.714227), -- Cokes
(22386, 1885, 1, 1, 2, 253229.142681), -- High-Grade Suede
(22386, 9628, 1, 1, 2, 23833.448592), -- Leonard
(22386, 9630, 1, 1, 2, 15993.432681), -- Orichalcum
(22386, 9629, 1, 1, 2, 13211.948032), -- Adamantine
(22386, 9551, 1, 1, 2, 24310.001027), -- Holy Stone
(22386, 960, 1, 1, 2, 1215.31276), -- Scroll: Enchant Armor (S-Grade)
(22386, 9599, 2, 6, 2, 553900), -- Ancient Tome of the Demon
-- Foundry Mystic
(22387, 15772, 1, 1, -1, 297797), -- Sealed Moirai Ring Gem
(22387, 15773, 1, 1, -1, 167367), -- Sealed Moirai Earring Gem
(22387, 15774, 1, 1, -1, 144417), -- Sealed Moirai Necklace Gem
(22387, 15812, 1, 1, -1, 39398), -- Recipe - Sealed Moirai Ring (70%) 
(22387, 15813, 1, 1, -1, 26262), -- Recipe - Sealed Moirai Earring (70%) 
(22387, 15814, 1, 1, -1, 19697), -- Recipe - Sealed Moirai Necklace (70%) 
(22387, 57, 10567, 21333, 0, 700000), -- Adena
(22387, 15766, 1, 1, 1, 129.387242), -- Sealed Moirai Ring
(22387, 15767, 1, 1, 1, 86.224702), -- Sealed Moirai Earring
(22387, 15768, 1, 1, 1, 64.643432), -- Sealed Moirai Necklace
(22387, 15772, 1, 1, 1, 48900.547992), -- Sealed Moirai Ring Gem
(22387, 15773, 1, 1, 1, 27482.894132), -- Sealed Moirai Earring Gem
(22387, 15774, 1, 1, 1, 23714.3025), -- Sealed Moirai Necklace Gem
(22387, 1895, 3, 9, 2, 202583.000218), -- Metallic Fiber
(22387, 4040, 1, 1, 2, 85084.920485), -- Mold Lubricant
(22387, 9628, 1, 1, 2, 33366.620682), -- Leonard
(22387, 9630, 1, 1, 2, 22390.86788), -- Orichalcum
(22387, 9551, 1, 1, 2, 34033.590735), -- Holy Stone
(22387, 9599, 2, 6, 2, 553900), -- Ancient Tome of the Demon
-- Foundry Spirit Guard
(22388, 15654, 1, 1, -1, 202500), -- Sealed Moirai Gauntlet Piece
(22388, 15655, 1, 1, -1, 202500), -- Sealed Moirai Leather Gloves Piece
(22388, 15656, 1, 1, -1, 202500), -- Sealed Moirai Gloves Piece
(22388, 15657, 1, 1, -1, 202500), -- Sealed Moirai Boots Piece
(22388, 15658, 1, 1, -1, 202500), -- Sealed Moirai Leather Boots Piece
(22388, 15659, 1, 1, -1, 202500), -- Sealed Moirai Shoes Piece
(22388, 15784, 1, 1, -1, 26942), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22388, 15785, 1, 1, -1, 26942), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22388, 15786, 1, 1, -1, 26942), -- Recipe - Sealed Moirai Gloves (60%) 
(22388, 15787, 1, 1, -1, 26942), -- Recipe - Sealed Moirai Boots (60%) 
(22388, 15788, 1, 1, -1, 26942), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22388, 15789, 1, 1, -1, 26942), -- Recipe - Sealed Moirai Shoes (60%) 
(22388, 57, 22201, 44819, 0, 700000), -- Adena
(22388, 15703, 1, 1, 1, 88.480444), -- Sealed Moirai Gauntlet 
(22388, 15704, 1, 1, 1, 88.480444), -- Sealed Moirai Leather Gloves 
(22388, 15705, 1, 1, 1, 88.480444), -- Sealed Moirai Gloves 
(22388, 15706, 1, 1, 1, 88.480444), -- Sealed Moirai Boots 
(22388, 15707, 1, 1, 1, 88.480444), -- Sealed Moirai Leather Boots 
(22388, 15708, 1, 1, 1, 88.480444), -- Sealed Moirai Shoes 
(22388, 15654, 1, 1, 1, 33275.052768), -- Sealed Moirai Gauntlet Piece
(22388, 15655, 1, 1, 1, 33275.052768), -- Sealed Moirai Leather Gloves Piece
(22388, 15656, 1, 1, 1, 33275.052768), -- Sealed Moirai Gloves Piece
(22388, 15657, 1, 1, 1, 33275.052768), -- Sealed Moirai Boots Piece
(22388, 15658, 1, 1, 1, 33275.052768), -- Sealed Moirai Leather Boots Piece
(22388, 15659, 1, 1, 1, 33275.853496), -- Sealed Moirai Shoes Piece
(22388, 1879, 3, 9, 2, 112852.44836), -- Cokes
(22388, 1885, 2, 6, 2, 84639.33627), -- High-Grade Suede
(22388, 9628, 1, 1, 2, 31864.393398), -- Leonard
(22388, 9630, 1, 1, 2, 21382.534828), -- Orichalcum
(22388, 9629, 1, 1, 2, 17663.733846), -- Adamantine
(22388, 14166, 1, 1, 2, 19626.37094), -- Life Stone - Level 84
(22388, 14167, 1, 1, 2, 4900.558368), -- Mid-Grade Life Stone - Level 84
(22388, 14168, 1, 1, 2, 489.925364), -- High-Grade Life Stone - Level 84
(22388, 14169, 1, 1, 2, 97.8546), -- Top-Grade Life Stone - Level 84
(22388, 9551, 1, 1, 2, 32501.426844), -- Holy Stone
(22388, 959, 1, 1, 2, 163.417182), -- Scroll: Enchant Weapon (S-Grade)
(22388, 9599, 3, 9, 2, 775900), -- Ancient Tome of the Demon
-- Foundry Spirit Guard
(22389, 15645, 1, 1, -1, 146836), -- Sealed Moirai Helmet Piece
(22389, 15646, 1, 1, -1, 146836), -- Sealed Moirai Leather Helmet Piece
(22389, 15647, 1, 1, -1, 146836), -- Sealed Moirai Circlet Piece
(22389, 15693, 1, 1, -1, 263211), -- Sealed Moirai Shield Piece
(22389, 15692, 1, 1, -1, 263211), -- Sealed Moirai Sigil Piece
(22389, 960, 1, 1, -1, 9897), -- Scroll: Enchant Armor (S-Grade)
(22389, 15775, 1, 1, -1, 19594), -- Recipe - Sealed Moirai Helmet (60%) 
(22389, 15776, 1, 1, -1, 19594), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22389, 15777, 1, 1, -1, 19594), -- Recipe - Sealed Moirai Circlet (60%) 
(22389, 15791, 1, 1, -1, 27992), -- Recipe - Sealed Moirai Shield (60%) 
(22389, 15790, 1, 1, -1, 27992), -- Recipe - Sealed Moirai Sigil (60%) 
(22389, 57, 22201, 44819, 0, 700000), -- Adena
(22389, 15694, 1, 1, 1, 70.784436), -- Sealed Moirai Helmet 
(22389, 15695, 1, 1, 1, 70.784436), -- Sealed Moirai Leather Helmet 
(22389, 15696, 1, 1, 1, 70.784436), -- Sealed Moirai Circlet 
(22389, 15710, 1, 1, 1, 101.270802), -- Sealed Moirai Shield 
(22389, 15709, 1, 1, 1, 101.270802), -- Sealed Moirai Sigil 
(22389, 15645, 1, 1, 1, 26543.813082), -- Sealed Moirai Helmet Piece
(22389, 15646, 1, 1, 1, 26543.813082), -- Sealed Moirai Leather Helmet Piece
(22389, 15647, 1, 1, 1, 26543.813082), -- Sealed Moirai Circlet Piece
(22389, 15693, 1, 1, 1, 47581.332921), -- Sealed Moirai Shield Piece
(22389, 15692, 1, 1, 1, 47581.332921), -- Sealed Moirai Sigil Piece
(22389, 1895, 12, 36, 2, 88669.924869), -- Metallic Fiber
(22389, 4040, 1, 1, 2, 148965.664734), -- Mold Lubricant
(22389, 9628, 1, 1, 2, 58418.024745), -- Leonard
(22389, 9630, 1, 1, 2, 39201.679161), -- Orichalcum
(22389, 9551, 1, 1, 2, 59586.425022), -- Holy Stone
(22389, 960, 1, 1, 2, 2979.281469), -- Scroll: Enchant Armor (S-Grade)
(22389, 9599, 3, 9, 2, 775900), -- Ancient Tome of the Demon
-- Foundry Foreman
(22390, 10397, 1, 1, -1, 18781), -- Icarus Sawsword Piece
(22390, 10399, 1, 1, -1, 18781), -- Icarus Spirit Piece
(22390, 10400, 1, 1, -1, 18721), -- Icarus Heavy Arms Piece
(22390, 9630, 1, 1, -1, 230565), -- Orichalcum
(22390, 10373, 1, 1, -1, 2823), -- Recipe - Icarus Sawsword (60%)
(22390, 10375, 1, 1, -1, 2823), -- Recipe - Icarus Spirit (60%)
(22390, 10376, 1, 1, -1, 2823), -- Recipe - Icarus Heavy Arms (60%)
(22390, 57, 25015, 50499, 0, 700000), -- Adena
(22390, 10215, 1, 1, 1, 10.818), -- Icarus Sawsword
(22390, 10217, 1, 1, 1, 10.818), -- Icarus Spirit
(22390, 10218, 1, 1, 1, 10.818), -- Icarus Heavy Arms
(22390, 10397, 1, 1, 1, 3599.029602), -- Icarus Sawsword Piece
(22390, 10399, 1, 1, 1, 3599.029602), -- Icarus Spirit Piece
(22390, 10400, 1, 1, 1, 3587.486796), -- Icarus Heavy Arms Piece
(22390, 1864, 504, 1512, 2, 16651.239374), -- Stem
(22390, 1865, 25, 75, 2, 167842.612476), -- Varnish
(22390, 1866, 33, 99, 2, 84768.798345), -- Suede
(22390, 1873, 52, 156, 2, 32277.391993), -- Silver Nugget
(22390, 1868, 126, 378, 2, 66604.086934), -- Thread
(22390, 9551, 1, 1, 2, 67136.870878), -- Holy Stone
(22390, 9599, 9, 27, 2, 790800), -- Ancient Tome of the Demon
-- Foundry Assistant Overseer
(22391, 10404, 1, 1, -1, 11767), -- Icarus Hall Piece
(22391, 10402, 1, 1, -1, 11767), -- Icarus Hammer Piece
(22391, 9630, 1, 1, -1, 144922), -- Orichalcum
(22391, 10380, 1, 1, -1, 1775), -- Recipe - Icarus Hall (60%)
(22391, 10378, 1, 1, -1, 1775), -- Recipe - Icarus Hammer (60%)
(22391, 57, 11231, 22672, 0, 700000), -- Adena
(22391, 10222, 1, 1, 1, 7.285376), -- Icarus Hall
(22391, 10220, 1, 1, 1, 7.285376), -- Icarus Hammer
(22391, 10404, 1, 1, 1, 2414.714624), -- Icarus Hall Piece
(22391, 10402, 1, 1, 1, 2414.714624), -- Icarus Hammer Piece
(22391, 1895, 3, 9, 2, 179419.58346), -- Metallic Fiber
(22391, 4040, 1, 1, 2, 75356.158163), -- Mold Lubricant
(22391, 9628, 1, 1, 2, 29551.421458), -- Leonard
(22391, 9630, 1, 1, 2, 19830.603143), -- Orichalcum
(22391, 9551, 1, 1, 2, 30142.396375), -- Holy Stone
(22391, 959, 1, 1, 2, 150.837401), -- Scroll: Enchant Weapon (S-Grade)
(22391, 9599, 1, 1, 2, 793800), -- Ancient Tome of the Demon
-- Failed Experimental Timetwister Golem
(22392, 10403, 1, 1, -1, 2610), -- Icarus Hand Piece
(22392, 959, 1, 1, -1, 244), -- Scroll: Enchant Weapon (S-Grade)
(22392, 1894, 1, 1, -1, 214289), -- Crafted Leather
(22392, 10379, 1, 1, -1, 394), -- Recipe - Icarus Hand (60%)
(22392, 57, 1993, 4023, 0, 700000), -- Adena
(22392, 10221, 1, 1, 1, 2.58602), -- Icarus Hand
(22392, 10403, 1, 1, 1, 857.41398), -- Icarus Hand Piece
(22392, 1894, 1, 1, 2, 14074.71702), -- Crafted Leather
(22392, 4039, 1, 1, 2, 13370.956092), -- Mold Glue
(22392, 4041, 1, 1, 2, 3488.060238), -- Mold Hardener
(22392, 4044, 1, 1, 2, 13370.956092), -- Thons
(22392, 14166, 1, 1, 2, 1937.800098), -- Life Stone - Level 84
(22392, 14167, 1, 1, 2, 483.885792), -- Mid-Grade Life Stone - Level 84
(22392, 14168, 1, 1, 2, 48.39861), -- High-Grade Life Stone - Level 84
(22392, 14169, 1, 1, 2, 9.679722), -- Top-Grade Life Stone - Level 84
(22392, 9551, 1, 1, 2, 3209.053536), -- Holy Stone
(22392, 960, 1, 1, 2, 160.4928), -- Scroll: Enchant Armor (S-Grade)
(22392, 9599, 1, 1, 2, 417800), -- Ancient Tome of the Demon
-- Beleth's Follower
(22393, 6701, 1, 1, -1, 314955), -- Sealed Imperial Crusader Breastplate Part
(22393, 6901, 1, 1, -1, 59156), -- Recipe: Shining Arrow (100%)
(22393, 6702, 1, 1, -1, 405431), -- Sealed Imperial Crusader Gaiters Pattern
(22393, 57, 34666, 69427, 0, 700000), -- Adena
(22393, 5320, 1, 1, 1, 220.665512), -- Sealed Leather Armor of Nightmare
(22393, 5480, 1, 1, 1, 32694.834488), -- Sealed Leather Armor of Nightmare Fabric
(22393, 5323, 1, 1, 1, 220.665512), -- Sealed Majestic Leather Armor
(22393, 5481, 1, 1, 1, 32694.834488), -- Sealed Majestic Leather Armor Fabric
(22393, 1895, 3, 9, 2, 231278.75376), -- Metallic Fiber
(22393, 4040, 1, 1, 2, 97136.902266), -- Mold Lubricant
(22393, 9628, 1, 1, 2, 38093.099379), -- Leonard
(22393, 9630, 1, 1, 2, 25562.594997), -- Orichalcum
(22393, 6901, 1, 1, 2, 4856.801535), -- Recipe: Shining Arrow (100%)
(22393, 9551, 1, 1, 2, 38854.848063), -- Holy Stone
(22393, 9599, 2, 6, 2, 758900), -- Ancient Tome of the Demon
-- Beleth's Devotee
(22394, 959, 1, 1, -1, 2796), -- Scroll: Enchant Weapon (S-Grade)
(22394, 4041, 1, 1, -1, 607905), -- Mold Hardener
(22394, 1875, 1, 9, -1, 932122), -- Stone of Purity
(22394, 57, 40967, 82047, 0, 700000), -- Adena
(22394, 270, 1, 1, 1, 166.038697), -- Dragon Grinder
(22394, 5538, 1, 1, 1, 47232.961303), -- Dragon Grinder Edge
(22394, 1872, 24, 72, 2, 136658.7224), -- Animal Bone
(22394, 1867, 60, 180, 2, 54663.48896), -- Animal Skin
(22394, 1881, 3, 9, 2, 93708.895904), -- Coarse Bone Powder
(22394, 1875, 4, 12, 2, 36442.460576), -- Stone of Purity
(22394, 4041, 1, 1, 2, 42780.227136), -- Mold Hardener
(22394, 959, 1, 1, 2, 196.654496), -- Scroll: Enchant Weapon (S-Grade)
(22394, 9551, 1, 1, 2, 39357.550528), -- Holy Stone
(22394, 9599, 2, 6, 2, 896800), -- Ancient Tome of the Demon
-- Beleth's Projection
(22395, 6703, 1, 3, -1, 636500), -- Sealed Imperial Crusader Gauntlets Design
(22395, 6901, 1, 1, -1, 89409), -- Recipe: Shining Arrow (100%)
(22395, 6704, 1, 3, -1, 636500), -- Sealed Imperial Crusader Boots Design
(22395, 57, 52395, 104932, 0, 700000), -- Adena
(22395, 270, 1, 1, 1, 212.35186), -- Dragon Grinder
(22395, 5538, 1, 1, 1, 60407.64814), -- Dragon Grinder Edge
(22395, 1873, 16, 48, 2, 50049.920712), -- Silver Nugget
(22395, 1868, 135, 405, 2, 29659.249862), -- Thread
(22395, 1876, 3, 9, 2, 114399.528804), -- Mithril Ore
(22395, 1895, 30, 90, 2, 19066.588134), -- Metallic Fiber
(22395, 4042, 1, 1, 2, 66733.227616), -- Enria
(22395, 960, 1, 1, 2, 1601.483796), -- Scroll: Enchant Armor (S-Grade)
(22395, 14166, 1, 1, 2, 19342.974332), -- Life Stone - Level 84
(22395, 14167, 1, 1, 2, 4829.823438), -- Mid-Grade Life Stone - Level 84
(22395, 14168, 1, 1, 2, 483.083832), -- High-Grade Life Stone - Level 84
(22395, 14169, 1, 1, 2, 96.41379), -- Top-Grade Life Stone - Level 84
(22395, 9551, 1, 1, 2, 32031.705684), -- Holy Stone
(22395, 9599, 3, 9, 2, 764700), -- Ancient Tome of the Demon
-- Foundry Laborer
(22396, 6901, 1, 1, -1, 2061), -- Recipe: Shining Arrow (100%)
(22396, 6705, 1, 1, -1, 28744), -- Sealed Imperial Crusader Shield Part
(22396, 960, 1, 1, -1, 824), -- Scroll: Enchant Armor (S-Grade)
(22396, 57, 1208, 2419, 0, 700000), -- Adena
(22396, 289, 1, 1, 1, 4.8965), -- Soul Bow
(22396, 5534, 1, 1, 1, 1394.1035), -- Soul Bow Stave
(22396, 1871, 1, 1, 2, 145043.1612), -- Charcoal
(22396, 1866, 1, 1, 2, 96695.609472), -- Suede
(22396, 1877, 1, 1, 2, 5801.726448), -- Adamantite Nugget
(22396, 4041, 1, 1, 2, 1261.24488), -- Mold Hardener
(22396, 4040, 1, 1, 2, 2900.989728), -- Mold Lubricant
(22396, 6901, 1, 1, 2, 144.973584), -- Recipe: Shining Arrow (100%)
(22396, 9551, 1, 1, 2, 1160.294688), -- Holy Stone
(22396, 9599, 1, 1, 2, 105800), -- Ancient Tome of the Demon
-- Foundry Foreman  
(22397, 1894, 1, 1, -1, 735279), -- Crafted Leather
(22397, 4042, 1, 1, -1, 349258), -- Enria
(22397, 6706, 1, 1, -1, 339938), -- Sealed Imperial Crusader Helmet Pattern
(22397, 57, 12280, 24594, 0, 700000), -- Adena
(22397, 289, 1, 1, 1, 49.77), -- Soul Bow
(22397, 5534, 1, 1, 1, 14170.23), -- Soul Bow Stave
(22397, 1879, 1, 1, 2, 245782.78698), -- Cokes
(22397, 1885, 1, 1, 2, 122891.39349), -- High-Grade Suede
(22397, 9628, 1, 1, 2, 11566.10063), -- Leonard
(22397, 9630, 1, 1, 2, 7761.38208), -- Orichalcum
(22397, 9629, 1, 1, 2, 6411.75314), -- Adamantine
(22397, 959, 1, 1, 2, 58.90915), -- Scroll: Enchant Weapon (S-Grade)
(22397, 9551, 1, 1, 2, 11797.67453), -- Holy Stone
(22397, 9599, 1, 3, 2, 537700), -- Ancient Tome of the Demon
-- Lesser Evil
(22398, 6901, 1, 1, -1, 38027), -- Recipe: Shining Arrow (100%)
(22398, 6707, 1, 1, -1, 188414), -- Sealed Draconic Leather Armor Part
(22398, 57, 22284, 44629, 0, 700000), -- Adena
(22398, 5311, 1, 1, 1, 106.383743), -- Sealed Armor of Nightmare
(22398, 5522, 1, 1, 1, 15949.116257), -- Sealed Armor of Nightmare Pattern
(22398, 5316, 1, 1, 1, 106.383743), -- Sealed Majestic Plate Armor
(22398, 5523, 1, 1, 1, 15949.116257), -- Sealed Majestic Plate Armor Pattern
(22398, 1895, 1, 3, 2, 267604.605152), -- Metallic Fiber
(22398, 4040, 1, 1, 2, 37464.781056), -- Mold Lubricant
(22398, 4042, 1, 1, 2, 31220.65088), -- Enria
(22398, 4043, 1, 1, 2, 62440.875714), -- Asofe
(22398, 960, 1, 1, 2, 749.414914), -- Scroll: Enchant Armor (S-Grade)
(22398, 14166, 1, 1, 2, 9049.21704), -- Life Stone - Level 84
(22398, 14167, 1, 1, 2, 2259.747984), -- Mid-Grade Life Stone - Level 84
(22398, 14168, 1, 1, 2, 225.80438), -- High-Grade Life Stone - Level 84
(22398, 14169, 1, 1, 2, 45.160876), -- Top-Grade Life Stone - Level 84
(22398, 9551, 1, 1, 2, 14985.742004), -- Holy Stone
-- Greater Evil
(22399, 6708, 1, 1, -1, 770235), -- Sealed Draconic Leather Gloves Fabric
(22399, 959, 1, 1, -1, 2164), -- Scroll: Enchant Weapon (S-Grade)
(22399, 1885, 1, 9, -1, 901624), -- High-Grade Suede
(22399, 57, 31702, 63490, 0, 700000), -- Adena
(22399, 164, 1, 1, 1, 32.121168), -- Elysian
(22399, 5533, 1, 1, 1, 9137.592264), -- Elysian Head
(22399, 213, 1, 1, 1, 32.121168), -- Branch of the Mother Tree
(22399, 5544, 1, 1, 1, 9128.571936), -- Branch of the Mother Tree Head
(22399, 7895, 1, 1, 1, 32.121168), -- Flaming Dragon Skull
(22399, 8342, 1, 1, 1, 9137.592264), -- Flaming Dragon Skull Piece
(22399, 7902, 1, 1, 1, 32.121168), -- Doom Crusher
(22399, 8349, 1, 1, 1, 9135.758864), -- Doom Crusher Head
(22399, 1879, 3, 9, 2, 82250.019516), -- Cokes
(22399, 1885, 1, 1, 2, 246749.64019), -- High-Grade Suede
(22399, 9628, 1, 1, 2, 23223.470938), -- Leonard
(22399, 9630, 1, 1, 2, 15584.253858), -- Orichalcum
(22399, 9629, 1, 1, 2, 12873.712376), -- Adamantine
(22399, 6901, 1, 1, 2, 2961.137924), -- Recipe: Shining Arrow (100%)
(22399, 6857, 1, 1, 2, 5513.95844), -- Recipe: Sealed Imperial Crusader Gauntlets (60%)
(22399, 6877, 1, 1, 2, 5513.95844), -- Recipe: Sealed Major Arcana Boots (60%)
(22399, 9551, 1, 1, 2, 23687.848318); -- Holy Stone

INSERT INTO `droplist` VALUES
-- Parme's Healer
(22400, 4040, 1, 1, -1, 35693), -- Mold Lubricant
(22400, 5480, 1, 1, -1, 8008), -- Sealed Leather Armor of Nightmare Fabric
(22400, 1808, 1, 1, -1, 793), -- Recipe: Soulshot (S-Grade)
(22400, 57, 1195, 2447, 0, 700000), -- Adena
(22400, 81, 1, 1, 1, 1.412619), -- Dragon Slayer
(22400, 5529, 1, 1, 1, 401.743348), -- Dragon Slayer Edge
(22400, 151, 1, 1, 1, 1.412619), -- Sword of Miracles
(22400, 5546, 1, 1, 1, 441.276696), -- Sword of Miracles Edge
(22400, 2500, 1, 1, 1, 1.412619), -- Dark Legion's Edge
(22400, 5545, 1, 1, 1, 401.742099), -- Dark Legion's Edge Blade
(22400, 1895, 1, 1, 2, 50236.949896), -- Metallic Fiber
(22400, 4040, 1, 1, 2, 3516.610888), -- Mold Lubricant
(22400, 4042, 1, 1, 2, 2930.498648), -- Enria
(22400, 4043, 1, 1, 2, 5860.997296), -- Asofe
(22400, 959, 1, 1, 2, 6.943272), -- Scroll: Enchant Weapon (S-Grade)
-- Parme's Healer
(22401, 5481, 1, 1, -1, 8008), -- Sealed Majestic Leather Armor Fabric
(22401, 3036, 1, 1, -1, 793), -- Recipe: Spiritshot S
(22401, 5487, 1, 1, -1, 8037), -- Sealed Robe of Nightmare Fabric
(22401, 57, 1195, 2447, 0, 700000), -- Adena
(22401, 164, 1, 1, 1, 1.05996), -- Elysian
(22401, 5533, 1, 1, 1, 301.52958), -- Elysian Head
(22401, 213, 1, 1, 1, 1.05996), -- Branch of the Mother Tree
(22401, 5544, 1, 1, 1, 301.23192), -- Branch of the Mother Tree Head
(22401, 7895, 1, 1, 1, 1.05996), -- Flaming Dragon Skull
(22401, 8342, 1, 1, 1, 301.52958), -- Flaming Dragon Skull Piece
(22401, 7902, 1, 1, 1, 1.05996), -- Doom Crusher
(22401, 8349, 1, 1, 1, 301.46908), -- Doom Crusher Head
(22401, 1868, 1, 1, 2, 159844.672838), -- Thread
(22401, 1873, 1, 1, 2, 31968.996213), -- Silver Nugget
(22401, 5549, 1, 1, 2, 7992.32611), -- Metallic Thread
(22401, 1889, 1, 1, 2, 5328.011922), -- Compound Braid
(22401, 4044, 1, 1, 2, 2664.005961), -- Thons
(22401, 960, 1, 1, 2, 32.055608), -- Scroll: Enchant Armor (S-Grade)
(22401, 14166, 1, 1, 2, 386.208431), -- Life Stone - Level 84
(22401, 14167, 1, 1, 2, 96.475051), -- Mid-Grade Life Stone - Level 84
(22401, 14168, 1, 1, 2, 9.555037), -- High-Grade Life Stone - Level 84
(22401, 14169, 1, 1, 2, 1.849362), -- Top-Grade Life Stone - Level 84
(22401, 1344, 10, 30, 2, 99902.843467), -- Mithril Arrow
-- Shadow Column
(22402, 4040, 1, 1, -1, 34298), -- Mold Lubricant
(22402, 1895, 1, 1, -1, 489975), -- Metallic Fiber
(22402, 5488, 1, 1, -1, 7722), -- Sealed Majestic Robe Fabric
(22402, 57, 1148, 2352, 0, 700000), -- Adena
(22402, 289, 1, 1, 1, 4.074), -- Soul Bow
(22402, 5534, 1, 1, 1, 1159.926), -- Soul Bow Stave
(22402, 1895, 1, 1, 2, 48273.492888), -- Metallic Fiber
(22402, 4040, 1, 1, 2, 3379.14126), -- Mold Lubricant
(22402, 9628, 1, 1, 2, 1325.178864), -- Leonard
(22402, 9630, 1, 1, 2, 889.270452), -- Orichalcum
(22402, 6901, 1, 1, 2, 168.916536), -- Recipe: Shining Arrow (100%)
-- Foundry Foreman  
(22403, 6901, 1, 1, -1, 21189), -- Recipe: Shining Arrow (100%)
(22403, 6688, 1, 1, -1, 45799), -- Forgotten Blade Edge
(22403, 57, 12417, 24868, 0, 700000), -- Adena
(22403, 81, 1, 1, 1, 16.774992), -- Dragon Slayer
(22403, 5529, 1, 1, 1, 4770.742464), -- Dragon Slayer Edge
(22403, 151, 1, 1, 1, 16.774992), -- Sword of Miracles
(22403, 5546, 1, 1, 1, 5240.204928), -- Sword of Miracles Edge
(22403, 2500, 1, 1, 1, 16.774992), -- Dark Legion's Edge
(22403, 5545, 1, 1, 1, 4770.727632), -- Dark Legion's Edge Blade
(22403, 1873, 2, 6, 2, 69585.799283), -- Silver Nugget
(22403, 1868, 18, 54, 2, 48323.319187), -- Thread
(22403, 1876, 1, 1, 2, 173963.749388), -- Mithril Ore
(22403, 1895, 3, 9, 2, 35503.030134), -- Metallic Fiber
(22403, 4042, 1, 1, 2, 14497.14552), -- Enria
(22403, 959, 1, 1, 2, 34.94491), -- Scroll: Enchant Weapon (S-Grade)
(22403, 14166, 1, 1, 2, 4201.875821), -- Life Stone - Level 84
(22403, 14167, 1, 1, 2, 1049.345726), -- Mid-Grade Life Stone - Level 84
(22403, 14168, 1, 1, 2, 104.83473), -- High-Grade Life Stone - Level 84
(22403, 14169, 1, 1, 2, 20.966946), -- Top-Grade Life Stone - Level 84
(22403, 9551, 1, 1, 2, 6958.530007), -- Holy Stone
(22403, 1345, 40, 120, 2, 144969.458348), -- Shining Arrow
(22403, 9599, 1, 3, 2, 543600), -- Ancient Tome of the Demon
-- Arcane Captain
(22404, 6689, 1, 1, -1, 211298), -- Basalt Battlehammer Head
(22404, 960, 1, 1, -1, 39853), -- Scroll: Enchant Armor (S-Grade)
(22404, 4040, 1, 5, -1, 664223), -- Mold Lubricant
(22404, 57, 58301, 116945, 0, 700000), -- Adena
(22404, 5320, 1, 1, 1, 371.653), -- Sealed Leather Armor of Nightmare
(22404, 5480, 1, 1, 1, 55065.847), -- Sealed Leather Armor of Nightmare Fabric
(22404, 5323, 1, 1, 1, 371.653), -- Sealed Majestic Leather Armor
(22404, 5481, 1, 1, 1, 55065.847), -- Sealed Majestic Leather Armor Fabric
(22404, 1895, 12, 36, 2, 73036.560512), -- Metallic Fiber
(22404, 4040, 1, 1, 2, 122701.510896), -- Mold Lubricant
(22404, 9628, 1, 1, 2, 48118.195824), -- Leonard
(22404, 9630, 1, 1, 2, 32289.988704), -- Orichalcum
(22404, 960, 1, 1, 2, 2453.9856), -- Scroll: Enchant Armor (S-Grade)
(22404, 6871, 1, 1, 2, 7616.65076), -- Recipe: Sealed Draconic Leather Helmet (60%)
(22404, 9551, 1, 1, 2, 49080.827448), -- Holy Stone
(22404, 1344, 2100, 6300, 2, 36518.280256), -- Mithril Arrow
(22404, 9599, 4, 12, 2, 639100), -- Ancient Tome of the Demon
-- Darion's Faithful Servant
(22405, 10405, 1, 1, -1, 4807), -- Icarus Spitter Piece
(22405, 1894, 1, 1, -1, 394663), -- Crafted Leather
(22405, 960, 1, 1, -1, 4499), -- Scroll: Enchant Armor (S-Grade)
(22405, 10381, 1, 1, -1, 725), -- Recipe - Icarus Spitter (60%)
(22405, 57, 3670, 7409, 0, 700000), -- Adena
(22405, 10223, 1, 1, 1, 4.760081), -- Icarus Spitter
(22405, 10405, 1, 1, 1, 1578.239919), -- Icarus Spitter Piece
(22405, 1879, 1, 1, 2, 205216.119126), -- Cokes
(22405, 1885, 1, 1, 2, 102608.229146), -- High-Grade Suede
(22405, 9628, 1, 1, 2, 9657.073518), -- Leonard
(22405, 9630, 1, 1, 2, 6480.444762), -- Orichalcum
(22405, 9629, 1, 1, 2, 5353.396144), -- Adamantine
(22405, 9551, 1, 1, 2, 9850.737304), -- Holy Stone
(22405, 9599, 1, 3, 2, 384800), -- Ancient Tome of the Demon
-- Darion's Faithful Servant
(22406, 10398, 1, 1, -1, 11307), -- Icarus Disperser Piece
(22406, 1894, 1, 1, -1, 925387), -- Crafted Leather
(22406, 10374, 1, 1, -1, 1700), -- Recipe - Icarus Disperser (60%)
(22406, 57, 6454, 13029, 0, 700000), -- Adena
(22406, 10216, 1, 1, 1, 8.373414), -- Icarus Disperser
(22406, 10398, 1, 1, 1, 2784.626586), -- Icarus Disperser Piece
(22406, 1895, 2, 6, 2, 132570.302048), -- Metallic Fiber
(22406, 4040, 1, 1, 2, 37119.723264), -- Mold Lubricant
(22406, 4042, 1, 1, 2, 30933.10272), -- Enria
(22406, 4043, 1, 1, 2, 61866.20544), -- Asofe
(22406, 9551, 1, 1, 2, 14847.986032), -- Holy Stone
(22406, 959, 1, 1, 2, 74.479328), -- Scroll: Enchant Weapon (S-Grade)
(22406, 1345, 60, 180, 2, 206220.201168), -- Shining Arrow
(22406, 9599, 2, 6, 2, 338300), -- Ancient Tome of the Demon
-- Darion's Faithful Servant
(22407, 10401, 1, 1, -1, 19599), -- Icarus Trident Piece
(22407, 1894, 1, 3, -1, 804596), -- Crafted Leather
(22407, 10377, 1, 1, -1, 2956), -- Recipe - Icarus Trident (60%)
(22407, 57, 11224, 22657, 0, 700000), -- Adena
(22407, 10219, 1, 1, 1, 14.559894), -- Icarus Trident
(22407, 10401, 1, 1, 1, 4827.440106), -- Icarus Trident Piece
(22407, 1868, 18, 54, 2, 156889.627323), -- Thread
(22407, 1873, 22, 66, 2, 25102.188735), -- Silver Nugget
(22407, 5549, 4, 12, 2, 35300.176678), -- Metallic Thread
(22407, 1889, 5, 15, 2, 18826.957461), -- Compound Braid
(22407, 4044, 1, 1, 2, 94133.944879), -- Thons
(22407, 9551, 1, 1, 2, 22592.180468), -- Holy Stone
(22407, 960, 1, 1, 2, 1129.693266), -- Scroll: Enchant Armor (S-Grade)
(22407, 1345, 280, 840, 2, 67238.23119), -- Shining Arrow
(22407, 9599, 2, 6, 2, 588300), -- Ancient Tome of the Demon
-- Darion's Faithful Servant
(22408, 15654, 1, 1, -1, 86701), -- Sealed Moirai Gauntlet Piece
(22408, 15655, 1, 1, -1, 86701), -- Sealed Moirai Leather Gloves Piece
(22408, 15656, 1, 1, -1, 86701), -- Sealed Moirai Gloves Piece
(22408, 15657, 1, 1, -1, 86701), -- Sealed Moirai Boots Piece
(22408, 15658, 1, 1, -1, 86701), -- Sealed Moirai Leather Boots Piece
(22408, 15659, 1, 1, -1, 86701), -- Sealed Moirai Shoes Piece
(22408, 9630, 1, 1, -1, 51108), -- Orichalcum
(22408, 15784, 1, 1, -1, 11535), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22408, 15785, 1, 1, -1, 11535), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22408, 15786, 1, 1, -1, 11535), -- Recipe - Sealed Moirai Gloves (60%) 
(22408, 15787, 1, 1, -1, 11535), -- Recipe - Sealed Moirai Boots (60%) 
(22408, 15788, 1, 1, -1, 11535), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22408, 15789, 1, 1, -1, 11535), -- Recipe - Sealed Moirai Shoes (60%) 
(22408, 57, 10298, 20788, 0, 700000), -- Adena
(22408, 15703, 1, 1, 1, 41.0397), -- Sealed Moirai Gauntlet 
(22408, 15704, 1, 1, 1, 41.0397), -- Sealed Moirai Leather Gloves 
(22408, 15705, 1, 1, 1, 41.0397), -- Sealed Moirai Gloves 
(22408, 15706, 1, 1, 1, 41.0397), -- Sealed Moirai Boots 
(22408, 15707, 1, 1, 1, 41.0397), -- Sealed Moirai Leather Boots 
(22408, 15708, 1, 1, 1, 41.0397), -- Sealed Moirai Shoes 
(22408, 15654, 1, 1, 1, 15433.8984), -- Sealed Moirai Gauntlet Piece
(22408, 15655, 1, 1, 1, 15433.8984), -- Sealed Moirai Leather Gloves Piece
(22408, 15656, 1, 1, 1, 15433.8984), -- Sealed Moirai Gloves Piece
(22408, 15657, 1, 1, 1, 15433.8984), -- Sealed Moirai Boots Piece
(22408, 15658, 1, 1, 1, 15433.8984), -- Sealed Moirai Leather Boots Piece
(22408, 15659, 1, 1, 1, 15434.2698), -- Sealed Moirai Shoes Piece
(22408, 1879, 3, 9, 2, 95964.925191), -- Cokes
(22408, 1885, 1, 1, 2, 287894.775573), -- High-Grade Suede
(22408, 9628, 1, 1, 2, 27095.773507), -- Leonard
(22408, 9630, 1, 1, 2, 18183.05638), -- Orichalcum
(22408, 9629, 1, 1, 2, 15020.601089), -- Adamantine
(22408, 9551, 1, 1, 2, 27637.86826), -- Holy Stone
(22408, 9599, 2, 6, 2, 539800), -- Ancient Tome of the Demon
-- Darion's Faithful Servant
(22409, 15645, 1, 1, -1, 168991), -- Sealed Moirai Helmet Piece
(22409, 15646, 1, 1, -1, 168991), -- Sealed Moirai Leather Helmet Piece
(22409, 15647, 1, 1, -1, 168991), -- Sealed Moirai Circlet Piece
(22409, 15693, 1, 1, -1, 302925), -- Sealed Moirai Shield Piece
(22409, 15692, 1, 1, -1, 302925), -- Sealed Moirai Sigil Piece
(22409, 15775, 1, 1, -1, 22551), -- Recipe - Sealed Moirai Helmet (60%) 
(22409, 15776, 1, 1, -1, 22551), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22409, 15777, 1, 1, -1, 22551), -- Recipe - Sealed Moirai Circlet (60%) 
(22409, 15791, 1, 1, -1, 32215), -- Recipe - Sealed Moirai Shield (60%) 
(22409, 15790, 1, 1, -1, 32215), -- Recipe - Sealed Moirai Sigil (60%) 
(22409, 57, 23228, 46892, 0, 700000), -- Adena
(22409, 15694, 1, 1, 1, 74.058856), -- Sealed Moirai Helmet 
(22409, 15695, 1, 1, 1, 74.058856), -- Sealed Moirai Leather Helmet 
(22409, 15696, 1, 1, 1, 74.058856), -- Sealed Moirai Circlet 
(22409, 15710, 1, 1, 1, 105.955492), -- Sealed Moirai Shield 
(22409, 15709, 1, 1, 1, 105.955492), -- Sealed Moirai Sigil 
(22409, 15645, 1, 1, 1, 27771.704372), -- Sealed Moirai Helmet Piece
(22409, 15646, 1, 1, 1, 27771.704372), -- Sealed Moirai Leather Helmet Piece
(22409, 15647, 1, 1, 1, 27771.704372), -- Sealed Moirai Circlet Piece
(22409, 15693, 1, 1, 1, 49782.399666), -- Sealed Moirai Shield Piece
(22409, 15692, 1, 1, 1, 49782.399666), -- Sealed Moirai Sigil Piece
(22409, 1869, 60, 180, 2, 35421.931909), -- Iron Ore
(22409, 1864, 216, 648, 2, 19678.767807), -- Stem
(22409, 1880, 3, 9, 2, 60723.686485), -- Steel
(22409, 5550, 1, 1, 2, 56675.315839), -- Durable Metal Plate
(22409, 4043, 1, 1, 2, 141688.476918), -- Asofe
(22409, 14166, 1, 1, 2, 20534.447851), -- Life Stone - Level 84
(22409, 14167, 1, 1, 2, 5127.336726), -- Mid-Grade Life Stone - Level 84
(22409, 14168, 1, 1, 2, 512.883529), -- High-Grade Life Stone - Level 84
(22409, 14169, 1, 1, 2, 102.651634), -- Top-Grade Life Stone - Level 84
(22409, 9551, 1, 1, 2, 34005.039647), -- Holy Stone
(22409, 959, 1, 1, 2, 170.461655), -- Scroll: Enchant Weapon (S-Grade)
(22409, 9599, 3, 9, 2, 811800), -- Ancient Tome of the Demon
-- Darion's Faithful Servant
(22410, 15772, 1, 1, -1, 769024), -- Sealed Moirai Ring Gem
(22410, 15773, 1, 1, -1, 432203), -- Sealed Moirai Earring Gem
(22410, 15774, 1, 1, -1, 372938), -- Sealed Moirai Necklace Gem
(22410, 15812, 1, 1, -1, 101741), -- Recipe - Sealed Moirai Ring (70%) 
(22410, 15813, 1, 1, -1, 67819), -- Recipe - Sealed Moirai Earring (70%) 
(22410, 15814, 1, 1, -1, 50866), -- Recipe - Sealed Moirai Necklace (70%) 
(22410, 57, 27289, 55089, 0, 700000), -- Adena
(22410, 15766, 1, 1, 1, 334.125557), -- Sealed Moirai Ring
(22410, 15767, 1, 1, 1, 222.663967), -- Sealed Moirai Earring
(22410, 15768, 1, 1, 1, 166.933172), -- Sealed Moirai Necklace
(22410, 15772, 1, 1, 1, 126279.241932), -- Sealed Moirai Ring Gem
(22410, 15773, 1, 1, 1, 70970.964122), -- Sealed Moirai Earring Gem
(22410, 15774, 1, 1, 1, 61239.07125), -- Sealed Moirai Necklace Gem
(22410, 1879, 15, 45, 2, 43595.450019), -- Cokes
(22410, 1885, 2, 6, 2, 163482.220143), -- High-Grade Suede
(22410, 9628, 1, 1, 2, 61546.324752), -- Leonard
(22410, 9630, 1, 1, 2, 41300.909496), -- Orichalcum
(22410, 9629, 1, 1, 2, 34118.017857), -- Adamantine
(22410, 9551, 1, 1, 2, 62777.431629), -- Holy Stone
(22410, 960, 1, 1, 2, 3138.646104), -- Scroll: Enchant Armor (S-Grade)
(22410, 9599, 4, 12, 2, 715200), -- Ancient Tome of the Demon
-- Beleth's Retainer
(22411, 6901, 1, 1, -1, 64694), -- Recipe: Shining Arrow (100%)
(22411, 6698, 1, 3, -1, 635377), -- Sealed Tateossian Earring Part
(22411, 57, 37911, 75926, 0, 700000), -- Adena
(22411, 5313, 1, 1, 1, 587.988858), -- Sealed Gauntlets of Nightmare
(22411, 5514, 1, 1, 1, 67277.761142), -- Sealed Gauntlets of Nightmare Design
(22411, 5314, 1, 1, 1, 587.988858), -- Sealed Boots of Nightmare
(22411, 5502, 1, 1, 1, 67277.761142), -- Sealed Boots of Nightmare Lining
(22411, 5318, 1, 1, 1, 587.988858), -- Sealed Majestic Gauntlets
(22411, 5515, 1, 1, 1, 67277.761142), -- Sealed Majestic Gauntlets Design
(22411, 5319, 1, 1, 1, 587.988858), -- Sealed Majestic Boots
(22411, 5503, 1, 1, 1, 67277.761142), -- Sealed Majestic Boots Lining
(22411, 1868, 120, 360, 2, 37939.323365), -- Thread
(22411, 1873, 12, 36, 2, 75878.64673), -- Silver Nugget
(22411, 5549, 3, 9, 2, 65038.955858), -- Metallic Thread
(22411, 1889, 4, 12, 2, 33724.068165), -- Compound Braid
(22411, 4044, 1, 1, 2, 151757.698773), -- Thons
(22411, 6901, 1, 1, 2, 4552.880929), -- Recipe: Shining Arrow (100%)
(22411, 9551, 1, 1, 2, 36421.42618), -- Holy Stone
(22411, 9599, 3, 9, 2, 553300), -- Ancient Tome of the Demon
-- Beleth's Fighter
(22412, 6699, 1, 9, -1, 844475), -- Sealed Tateossian Ring Gem
(22412, 959, 1, 1, -1, 7749), -- Scroll: Enchant Weapon (S-Grade)
(22412, 4044, 1, 13, -1, 922488), -- Thons
(22412, 57, 113523, 227356, 0, 700000), -- Adena
(22412, 164, 1, 1, 1, 115.025808), -- Elysian
(22412, 5533, 1, 1, 1, 32721.690984), -- Elysian Head
(22412, 213, 1, 1, 1, 115.025808), -- Branch of the Mother Tree
(22412, 5544, 1, 1, 1, 32689.389216), -- Branch of the Mother Tree Head
(22412, 7895, 1, 1, 1, 115.025808), -- Flaming Dragon Skull
(22412, 8342, 1, 1, 1, 32721.690984), -- Flaming Dragon Skull Piece
(22412, 7902, 1, 1, 1, 115.025808), -- Doom Crusher
(22412, 8349, 1, 1, 1, 32715.125584), -- Doom Crusher Head
(22412, 1894, 5, 15, 2, 55806.881148), -- Crafted Leather
(22412, 4039, 9, 27, 2, 29453.631717), -- Mold Glue
(22412, 4041, 1, 1, 2, 138303.862503), -- Mold Hardener
(22412, 4044, 2, 6, 2, 132541.100736), -- Thons
(22412, 959, 1, 1, 2, 636.435015), -- Scroll: Enchant Weapon (S-Grade)
(22412, 9551, 1, 1, 2, 127239.088881), -- Holy Stone
(22412, 9599, 6, 20, 2, 764700), -- Ancient Tome of the Demon
-- Beleth's Low Servant
(22413, 1876, 1, 33, -1, 894743), -- Mithril Ore
(22413, 6700, 1, 1, -1, 910489), -- Sealed Tateossian Necklace Chain
(22413, 6901, 1, 1, -1, 76053), -- Recipe: Shining Arrow (100%)
(22413, 57, 44568, 89257, 0, 700000), -- Adena
(22413, 6326, 1, 1, 1, 625.034896), -- Sealed Majestic Necklace
(22413, 6344, 1, 1, 1, 91524.597222), -- Sealed Majestic Necklace Beads
(22413, 6327, 1, 1, 1, 833.526171), -- Sealed Majestic Earring
(22413, 6342, 1, 1, 1, 141428.629877), -- Sealed Majestic Earring Gemstone
(22413, 6328, 1, 1, 1, 1250.069792), -- Sealed Majestic Ring
(22413, 6346, 1, 1, 1, 203267.142042), -- Sealed Majestic Ring Gemstone
(22413, 1879, 3, 9, 2, 94607.5251), -- Cokes
(22413, 1885, 1, 1, 2, 283823.062842), -- High-Grade Suede
(22413, 9628, 1, 1, 2, 26712.913722), -- Leonard
(22413, 9630, 1, 1, 2, 17925.456714), -- Orichalcum
(22413, 9629, 1, 1, 2, 14808.113166), -- Adamantine
(22413, 960, 1, 1, 2, 1362.192348), -- Scroll: Enchant Armor (S-Grade)
(22413, 14166, 1, 1, 2, 16453.567416), -- Life Stone - Level 84
(22413, 14167, 1, 1, 2, 4108.516434), -- Mid-Grade Life Stone - Level 84
(22413, 14168, 1, 1, 2, 410.997906), -- High-Grade Life Stone - Level 84
(22413, 14169, 1, 1, 2, 81.907056), -- Top-Grade Life Stone - Level 84
(22413, 9551, 1, 1, 2, 27247.747296), -- Holy Stone
(22413, 9599, 2, 6, 2, 975600), -- Ancient Tome of the Demon
-- Beleth's Follower
(22414, 6701, 1, 1, -1, 314955), -- Sealed Imperial Crusader Breastplate Part
(22414, 6901, 1, 1, -1, 59156), -- Recipe: Shining Arrow (100%)
(22414, 6702, 1, 1, -1, 405431), -- Sealed Imperial Crusader Gaiters Pattern
(22414, 57, 34666, 69427, 0, 700000), -- Adena
(22414, 305, 1, 1, 1, 140.499888), -- Tallum Glaive
(22414, 5541, 1, 1, 1, 39956.500112), -- Tallum Glaive Edge
(22414, 1895, 3, 9, 2, 231278.75376), -- Metallic Fiber
(22414, 4040, 1, 1, 2, 97136.902266), -- Mold Lubricant
(22414, 9628, 1, 1, 2, 38093.099379), -- Leonard
(22414, 9630, 1, 1, 2, 25562.594997), -- Orichalcum
(22414, 6901, 1, 1, 2, 4856.801535), -- Recipe: Shining Arrow (100%)
(22414, 9551, 1, 1, 2, 38854.848063), -- Holy Stone
(22414, 9599, 2, 6, 2, 758900), -- Ancient Tome of the Demon
-- Beleth's Devotee
(22415, 960, 1, 1, -1, 27964), -- Scroll: Enchant Armor (S-Grade)
(22415, 1885, 1, 13, -1, 832251), -- High-Grade Suede
(22415, 13099, 1, 3, -1, 487477), -- Sealed Arcana Sigil Piece
(22415, 57, 40967, 82047, 0, 700000), -- Adena
(22415, 236, 1, 1, 1, 166.036824), -- Soul Separator
(22415, 5537, 1, 1, 1, 47245.963176), -- Soul Separator Head
(22415, 1879, 3, 9, 2, 136658.771834), -- Cokes
(22415, 1885, 2, 6, 2, 102494.261164), -- High-Grade Suede
(22415, 9628, 1, 1, 2, 38586.100526), -- Leonard
(22415, 9630, 1, 1, 2, 25893.352271), -- Orichalcum
(22415, 9629, 1, 1, 2, 21390.097167), -- Adamantine
(22415, 959, 1, 1, 2, 196.87158), -- Scroll: Enchant Weapon (S-Grade)
(22415, 9551, 1, 1, 2, 39357.545458), -- Holy Stone
(22415, 9599, 3, 9, 2, 597900), -- Ancient Tome of the Demon
-- Kechi's Captain
(22416, 5480, 1, 1, -1, 222823), -- Sealed Leather Armor of Nightmare Fabric
(22416, 1808, 1, 1, -1, 22070), -- Recipe: Soulshot (S-Grade)
(22416, 5481, 1, 1, -1, 222823), -- Sealed Majestic Leather Armor Fabric
(22416, 57, 33245, 68095, 0, 700000), -- Adena
(22416, 5320, 1, 1, 1, 185.23152), -- Sealed Leather Armor of Nightmare
(22416, 5480, 1, 1, 1, 27444.76848), -- Sealed Leather Armor of Nightmare Fabric
(22416, 5323, 1, 1, 1, 185.23152), -- Sealed Majestic Leather Armor
(22416, 5481, 1, 1, 1, 27444.76848), -- Sealed Majestic Leather Armor Fabric
(22416, 1873, 16, 48, 2, 43681.608475), -- Silver Nugget
(22416, 1868, 135, 405, 2, 25885.476025), -- Thread
(22416, 1876, 3, 9, 2, 99844.220905), -- Mithril Ore
(22416, 1895, 3, 9, 2, 166406.752565), -- Metallic Fiber
(22416, 4042, 1, 1, 2, 58242.42691), -- Enria
(22416, 960, 1, 1, 2, 1397.692915), -- Scroll: Enchant Armor (S-Grade)
(22416, 9547, 1, 1, 2, 27956.822205), -- Water Stone
-- Kechi's Guard
(22417, 3036, 1, 1, -1, 3541), -- Recipe: Spiritshot S
(22417, 5487, 1, 1, -1, 35877), -- Sealed Robe of Nightmare Fabric
(22417, 4041, 1, 1, -1, 69280), -- Mold Hardener
(22417, 57, 5334, 10925, 0, 700000), -- Adena
(22417, 5326, 1, 1, 1, 29.718195), -- Sealed Robe of Nightmare
(22417, 5487, 1, 1, 1, 4417.781805), -- Sealed Robe of Nightmare Fabric
(22417, 5329, 1, 1, 1, 29.718195), -- Sealed Majestic Robe
(22417, 5488, 1, 1, 1, 4417.781805), -- Sealed Majestic Robe Fabric
(22417, 1879, 1, 1, 2, 59465.822428), -- Cokes
(22417, 1885, 1, 1, 2, 29732.911214), -- High-Grade Suede
(22417, 9628, 1, 1, 2, 2798.423983), -- Leonard
(22417, 9630, 1, 1, 2, 1877.867005), -- Orichalcum
(22417, 9629, 1, 1, 2, 1551.263733), -- Adamantine
(22417, 6901, 1, 1, 2, 356.840545), -- Recipe: Shining Arrow (100%)
(22417, 10483, 1, 1, 2, 2477.725633), -- Life Stone - Level 82
(22417, 10484, 1, 1, 2, 619.405956), -- Mid-Grade Life Stone - Level 82
(22417, 10485, 1, 1, 2, 61.899872), -- High-Grade Life Stone - Level 82
(22417, 10486, 1, 1, 2, 12.420698), -- Top-Grade Life Stone - Level 82
(22417, 9547, 1, 1, 2, 2854.418933), -- Water Stone
-- Burning Iris
(22418, 1889, 1, 1, -1, 363965), -- Compound Braid
(22418, 5488, 1, 1, -1, 24584), -- Sealed Majestic Robe Fabric
(22418, 3957, 1, 1, -1, 2426), -- Recipe: Blessed Spiritshot S
(22418, 57, 3655, 7487, 0, 700000), -- Adena
(22418, 5313, 1, 1, 1, 49.620894), -- Sealed Gauntlets of Nightmare
(22418, 5514, 1, 1, 1, 5677.629106), -- Sealed Gauntlets of Nightmare Design
(22418, 5314, 1, 1, 1, 49.620894), -- Sealed Boots of Nightmare
(22418, 5502, 1, 1, 1, 5677.629106), -- Sealed Boots of Nightmare Lining
(22418, 5318, 1, 1, 1, 49.620894), -- Sealed Majestic Gauntlets
(22418, 5515, 1, 1, 1, 5677.629106), -- Sealed Majestic Gauntlets Design
(22418, 5319, 1, 1, 1, 49.620894), -- Sealed Majestic Boots
(22418, 5503, 1, 1, 1, 5677.629106), -- Sealed Majestic Boots Lining
(22418, 1868, 3, 9, 2, 128066.585775), -- Thread
(22418, 1873, 1, 1, 2, 153679.685925), -- Silver Nugget
(22418, 5549, 1, 1, 2, 38420.0119), -- Metallic Thread
(22418, 1889, 1, 1, 2, 25613.461825), -- Compound Braid
(22418, 4044, 1, 1, 2, 12806.550075), -- Thons
(22418, 959, 1, 1, 2, 15.19035), -- Scroll: Enchant Weapon (S-Grade)
(22418, 9547, 1, 1, 2, 3073.51415), -- Water Stone
-- Flame Iris
(22419, 5495, 1, 1, -1, 77761), -- Sealed Shield of Nightmare Fragment
(22419, 5157, 1, 1, -1, 2276), -- Recipe: Soulshot (S) Compressed Package (100%)
(22419, 5502, 1, 1, -1, 86487), -- Sealed Boots of Nightmare Lining
(22419, 57, 3428, 7022, 0, 700000), -- Adena
(22419, 81, 1, 1, 1, 4.054635), -- Dragon Slayer
(22419, 5529, 1, 1, 1, 1153.12242), -- Dragon Slayer Edge
(22419, 151, 1, 1, 1, 4.054635), -- Sword of Miracles
(22419, 5546, 1, 1, 1, 1266.59484), -- Sword of Miracles Edge
(22419, 2500, 1, 1, 1, 4.054635), -- Dark Legion's Edge
(22419, 5545, 1, 1, 1, 1153.118835), -- Dark Legion's Edge Blade
(22419, 1895, 1, 1, 2, 72075.141644), -- Metallic Fiber
(22419, 4040, 1, 1, 2, 5045.225152), -- Mold Lubricant
(22419, 9628, 1, 1, 2, 1978.52798), -- Leonard
(22419, 9630, 1, 1, 2, 1327.695292), -- Orichalcum
(22419, 960, 1, 1, 2, 100.89772), -- Scroll: Enchant Armor (S-Grade)
(22419, 10483, 1, 1, 2, 1751.804868), -- Life Stone - Level 82
(22419, 10484, 1, 1, 2, 437.93002), -- Mid-Grade Life Stone - Level 82
(22419, 10485, 1, 1, 2, 43.835396), -- High-Grade Life Stone - Level 82
(22419, 10486, 1, 1, 2, 8.733164), -- Top-Grade Life Stone - Level 82
(22419, 9547, 1, 1, 2, 2018.208764), -- Water Stone
-- Brimstone Iris
(22420, 1895, 1, 3, -1, 799855), -- Metallic Fiber
(22420, 4042, 1, 1, -1, 93316), -- Enria
(22420, 5503, 1, 1, -1, 94561), -- Sealed Majestic Boots Lining
(22420, 57, 3748, 7678, 0, 700000), -- Adena
(22420, 164, 1, 1, 1, 3.32442), -- Elysian
(22420, 5533, 1, 1, 1, 945.70641), -- Elysian Head
(22420, 213, 1, 1, 1, 3.32442), -- Branch of the Mother Tree
(22420, 5544, 1, 1, 1, 944.77284), -- Branch of the Mother Tree Head
(22420, 7895, 1, 1, 1, 3.32442), -- Flaming Dragon Skull
(22420, 8342, 1, 1, 1, 945.70641), -- Flaming Dragon Skull Piece
(22420, 7902, 1, 1, 1, 3.32442), -- Doom Crusher
(22420, 8349, 1, 1, 1, 945.51666), -- Doom Crusher Head
(22420, 1873, 1, 1, 2, 137906.17236), -- Silver Nugget
(22420, 1868, 3, 9, 2, 114921.8103), -- Thread
(22420, 1876, 1, 1, 2, 68953.08618), -- Mithril Ore
(22420, 1895, 1, 1, 2, 98504.547856), -- Metallic Fiber
(22420, 4042, 1, 1, 2, 5746.212164), -- Enria
(22420, 6901, 1, 1, 2, 344.996564), -- Recipe: Shining Arrow (100%)
(22420, 9547, 1, 1, 2, 2758.026128), -- Water Stone
(22420, 1345, 40, 120, 2, 57461.148448), -- Shining Arrow
-- Failan's Guard
(22422, 6689, 1, 1, -1, 25489), -- Basalt Battlehammer Head
(22422, 959, 1, 1, -1, 481), -- Scroll: Enchant Weapon (S-Grade)
(22422, 4042, 1, 1, -1, 200313), -- Enria
(22422, 57, 7033, 14107, 0, 700000), -- Adena
(22422, 5320, 1, 1, 1, 44.833), -- Sealed Leather Armor of Nightmare
(22422, 5480, 1, 1, 1, 6642.667), -- Sealed Leather Armor of Nightmare Fabric
(22422, 5323, 1, 1, 1, 44.833), -- Sealed Majestic Leather Armor
(22422, 5481, 1, 1, 1, 6642.667), -- Sealed Majestic Leather Armor Fabric
(22422, 1873, 2, 6, 2, 59205.799541), -- Silver Nugget
(22422, 1868, 18, 54, 2, 41115.150249), -- Thread
(22422, 1876, 1, 1, 2, 148014.288633), -- Mithril Ore
(22422, 1895, 3, 9, 2, 30206.860394), -- Metallic Fiber
(22422, 4042, 1, 1, 2, 12334.418943), -- Enria
(22422, 960, 1, 1, 2, 295.989056), -- Scroll: Enchant Armor (S-Grade)
(22422, 9551, 1, 1, 2, 5920.621998), -- Holy Stone
(22422, 1345, 40, 120, 2, 123345.871186), -- Shining Arrow
(22422, 9599, 1, 1, 2, 616700), -- Ancient Tome of the Demon
-- Original Sin Warden
(22423, 10405, 1, 1, -1, 11716), -- Icarus Spitter Piece
(22423, 959, 1, 1, -1, 1097), -- Scroll: Enchant Weapon (S-Grade)
(22423, 1894, 1, 3, -1, 480954), -- Crafted Leather
(22423, 10381, 1, 1, -1, 1767), -- Recipe - Icarus Spitter (60%)
(22423, 57, 8945, 18058, 0, 700000), -- Adena
(22423, 10223, 1, 1, 1, 11.604013), -- Icarus Spitter
(22423, 10405, 1, 1, 1, 3847.395987), -- Icarus Spitter Piece
(22423, 1895, 2, 6, 2, 183736.08519), -- Metallic Fiber
(22423, 4040, 1, 1, 2, 51446.07604), -- Mold Lubricant
(22423, 9628, 1, 1, 2, 20174.99995), -- Leonard
(22423, 9630, 1, 1, 2, 13538.422765), -- Orichalcum
(22423, 9551, 1, 1, 2, 20578.29135), -- Holy Stone
(22423, 960, 1, 1, 2, 1029.0884), -- Scroll: Enchant Armor (S-Grade)
(22423, 1345, 300, 900, 2, 57162.036305), -- Shining Arrow
(22423, 9599, 2, 6, 2, 468900), -- Ancient Tome of the Demon
-- Slave of Greed
(22424, 10397, 1, 1, -1, 1994), -- Icarus Sawsword Piece
(22424, 10399, 1, 1, -1, 1994), -- Icarus Spirit Piece
(22424, 10400, 1, 1, -1, 1988), -- Icarus Heavy Arms Piece
(22424, 960, 1, 1, -1, 1860), -- Scroll: Enchant Armor (S-Grade)
(22424, 10373, 1, 1, -1, 300), -- Recipe - Icarus Sawsword (60%)
(22424, 10375, 1, 1, -1, 300), -- Recipe - Icarus Spirit (60%)
(22424, 10376, 1, 1, -1, 300), -- Recipe - Icarus Heavy Arms (60%)
(22424, 57, 2656, 5362, 0, 700000), -- Adena
(22424, 10215, 1, 1, 1, 1.722351), -- Icarus Sawsword
(22424, 10217, 1, 1, 1, 1.722351), -- Icarus Spirit
(22424, 10397, 1, 1, 1, 572.777649), -- Icarus Sawsword Piece
(22424, 10399, 1, 1, 1, 572.777649), -- Icarus Spirit Piece
(22424, 1895, 1, 1, 2, 254583.83025), -- Metallic Fiber
(22424, 4040, 1, 1, 2, 17820.97389), -- Mold Lubricant
(22424, 4042, 1, 1, 2, 14850.88209), -- Enria
(22424, 4043, 1, 1, 2, 29701.34109), -- Asofe
(22424, 9551, 1, 1, 2, 7128.22032), -- Holy Stone
(22424, 1345, 60, 180, 2, 99004.75236), -- Shining Arrow
(22424, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Slave of Lust
(22425, 10400, 1, 1, -1, 4638), -- Icarus Heavy Arms Piece
(22425, 1894, 1, 1, -1, 380804), -- Crafted Leather
(22425, 10376, 1, 1, -1, 699), -- Recipe - Icarus Heavy Arms (60%)
(22425, 57, 2656, 5362, 0, 700000), -- Adena
(22425, 10218, 1, 1, 1, 3.446022), -- Icarus Heavy Arms
(22425, 10400, 1, 1, 1, 1142.553978), -- Icarus Heavy Arms Piece
(22425, 1895, 1, 1, 2, 152750.066223), -- Metallic Fiber
(22425, 4040, 1, 1, 2, 10692.438756), -- Mold Lubricant
(22425, 9628, 1, 1, 2, 4193.14815), -- Leonard
(22425, 9630, 1, 1, 2, 2813.771559), -- Orichalcum
(22425, 14166, 1, 1, 2, 2582.658765), -- Life Stone - Level 84
(22425, 14167, 1, 1, 2, 644.907966), -- Mid-Grade Life Stone - Level 84
(22425, 14168, 1, 1, 2, 64.455186), -- High-Grade Life Stone - Level 84
(22425, 14169, 1, 1, 2, 12.819816), -- Top-Grade Life Stone - Level 84
(22425, 9551, 1, 1, 2, 4277.011113), -- Holy Stone
(22425, 959, 1, 1, 2, 21.722466), -- Scroll: Enchant Weapon (S-Grade)
(22425, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Slave of Wrath
(22426, 10404, 1, 1, -1, 2783), -- Icarus Hall Piece
(22426, 10402, 1, 1, -1, 2783), -- Icarus Hammer Piece
(22426, 9630, 1, 1, -1, 34272), -- Orichalcum
(22426, 10380, 1, 1, -1, 420), -- Recipe - Icarus Hall (60%)
(22426, 10378, 1, 1, -1, 420), -- Recipe - Icarus Hammer (60%)
(22426, 57, 2656, 5362, 0, 700000), -- Adena
(22426, 10220, 1, 1, 1, 3.446022), -- Icarus Hammer
(22426, 10402, 1, 1, 1, 1142.553978), -- Icarus Hammer Piece
(22426, 1895, 1, 1, 2, 138864.054615), -- Metallic Fiber
(22426, 4040, 1, 1, 2, 9720.653943), -- Mold Lubricant
(22426, 9628, 1, 1, 2, 3812.145051), -- Leonard
(22426, 9630, 1, 1, 2, 2558.117991), -- Orichalcum
(22426, 14166, 1, 1, 2, 2348.141367), -- Life Stone - Level 84
(22426, 14167, 1, 1, 2, 586.184742), -- Mid-Grade Life Stone - Level 84
(22426, 14168, 1, 1, 2, 58.812897), -- High-Grade Life Stone - Level 84
(22426, 14169, 1, 1, 2, 11.665368), -- Top-Grade Life Stone - Level 84
(22426, 9551, 1, 1, 2, 3887.969943), -- Holy Stone
(22426, 960, 1, 1, 2, 194.4228), -- Scroll: Enchant Armor (S-Grade)
(22426, 1345, 10, 30, 2, 324014.831283), -- Shining Arrow
(22426, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Slave of Sloth
(22427, 10403, 1, 1, -1, 3478), -- Icarus Hand Piece
(22427, 959, 1, 1, -1, 326), -- Scroll: Enchant Weapon (S-Grade)
(22427, 1894, 1, 1, -1, 285603), -- Crafted Leather
(22427, 10379, 1, 1, -1, 525), -- Recipe - Icarus Hand (60%)
(22427, 57, 2656, 5362, 0, 700000), -- Adena
(22427, 10221, 1, 1, 1, 3.446022), -- Icarus Hand
(22427, 10403, 1, 1, 1, 1142.553978), -- Icarus Hand Piece
(22427, 1872, 3, 9, 2, 132006.523305), -- Animal Bone
(22427, 1882, 1, 1, 2, 132006.523305), -- Leather
(22427, 1894, 1, 1, 2, 20843.087388), -- Crafted Leather
(22427, 4042, 1, 1, 2, 9900.375555), -- Enria
(22427, 14166, 1, 1, 2, 2869.608165), -- Life Stone - Level 84
(22427, 14167, 1, 1, 2, 716.416703), -- Mid-Grade Life Stone - Level 84
(22427, 14168, 1, 1, 2, 71.550716), -- High-Grade Life Stone - Level 84
(22427, 14169, 1, 1, 2, 14.249507), -- Top-Grade Life Stone - Level 84
(22427, 9551, 1, 1, 2, 4752.665356), -- Holy Stone
(22427, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Slave of Envy
(22428, 15772, 1, 1, -1, 74848), -- Sealed Moirai Ring Gem
(22428, 15773, 1, 1, -1, 42066), -- Sealed Moirai Earring Gem
(22428, 15774, 1, 1, -1, 36297), -- Sealed Moirai Necklace Gem
(22428, 15812, 1, 1, -1, 9902), -- Recipe - Sealed Moirai Ring (70%) 
(22428, 15813, 1, 1, -1, 6601), -- Recipe - Sealed Moirai Earring (70%) 
(22428, 15814, 1, 1, -1, 4951), -- Recipe - Sealed Moirai Necklace (70%) 
(22428, 57, 2656, 5362, 0, 700000), -- Adena
(22428, 15766, 1, 1, 1, 32.520181), -- Sealed Moirai Ring
(22428, 15767, 1, 1, 1, 21.671711), -- Sealed Moirai Earring
(22428, 15768, 1, 1, 1, 16.247476), -- Sealed Moirai Necklace
(22428, 15772, 1, 1, 1, 12290.660556), -- Sealed Moirai Ring Gem
(22428, 15773, 1, 1, 1, 6907.548826), -- Sealed Moirai Earring Gem
(22428, 15774, 1, 1, 1, 5960.35125), -- Sealed Moirai Necklace Gem
(22428, 1895, 1, 1, 2, 218214.524646), -- Metallic Fiber
(22428, 4040, 1, 1, 2, 15274.951443), -- Mold Lubricant
(22428, 4042, 1, 1, 2, 12729.307542), -- Enria
(22428, 4043, 1, 1, 2, 25458.252405), -- Asofe
(22428, 9551, 1, 1, 2, 6110.053113), -- Holy Stone
(22428, 959, 1, 1, 2, 30.465036), -- Scroll: Enchant Weapon (S-Grade)
(22428, 1345, 60, 180, 2, 84861.445815), -- Shining Arrow
(22428, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Slave of Pride
(22429, 15654, 1, 1, -1, 22362), -- Sealed Moirai Gauntlet Piece
(22429, 15655, 1, 1, -1, 22362), -- Sealed Moirai Leather Gloves Piece
(22429, 15656, 1, 1, -1, 22362), -- Sealed Moirai Gloves Piece
(22429, 15657, 1, 1, -1, 22362), -- Sealed Moirai Boots Piece
(22429, 15658, 1, 1, -1, 22362), -- Sealed Moirai Leather Boots Piece
(22429, 15659, 1, 1, -1, 22362), -- Sealed Moirai Shoes Piece
(22429, 9630, 1, 1, -1, 13182), -- Orichalcum
(22429, 15784, 1, 1, -1, 2975), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22429, 15785, 1, 1, -1, 2975), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22429, 15786, 1, 1, -1, 2975), -- Recipe - Sealed Moirai Gloves (60%) 
(22429, 15787, 1, 1, -1, 2975), -- Recipe - Sealed Moirai Boots (60%) 
(22429, 15788, 1, 1, -1, 2975), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22429, 15789, 1, 1, -1, 2975), -- Recipe - Sealed Moirai Shoes (60%) 
(22429, 57, 2656, 5362, 0, 700000), -- Adena
(22429, 15703, 1, 1, 1, 21.170085), -- Sealed Moirai Gauntlet 
(22429, 15704, 1, 1, 1, 21.170085), -- Sealed Moirai Leather Gloves 
(22429, 15705, 1, 1, 1, 21.170085), -- Sealed Moirai Gloves 
(22429, 15654, 1, 1, 1, 7952.512529), -- Sealed Moirai Gauntlet Piece
(22429, 15655, 1, 1, 1, 7952.512529), -- Sealed Moirai Leather Gloves Piece
(22429, 15656, 1, 1, 1, 7952.464687), -- Sealed Moirai Gloves Piece
(22429, 1873, 2, 6, 2, 53462.637445), -- Silver Nugget
(22429, 1868, 18, 54, 2, 37126.842105), -- Thread
(22429, 1876, 1, 1, 2, 133656.403785), -- Mithril Ore
(22429, 1895, 3, 9, 2, 27276.69313), -- Metallic Fiber
(22429, 4042, 1, 1, 2, 11137.938735), -- Enria
(22429, 9551, 1, 1, 2, 5346.30171), -- Holy Stone
(22429, 960, 1, 1, 2, 267.27712), -- Scroll: Enchant Armor (S-Grade)
(22429, 1345, 40, 120, 2, 111380.90597), -- Shining Arrow
(22429, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Slave of Gluttony
(22430, 15645, 1, 1, -1, 19323), -- Sealed Moirai Helmet Piece
(22430, 15646, 1, 1, -1, 19323), -- Sealed Moirai Leather Helmet Piece
(22430, 15647, 1, 1, -1, 19323), -- Sealed Moirai Circlet Piece
(22430, 15693, 1, 1, -1, 34637), -- Sealed Moirai Shield Piece
(22430, 15692, 1, 1, -1, 34637), -- Sealed Moirai Sigil Piece
(22430, 15775, 1, 1, -1, 2579), -- Recipe - Sealed Moirai Helmet (60%) 
(22430, 15776, 1, 1, -1, 2579), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22430, 15777, 1, 1, -1, 2579), -- Recipe - Sealed Moirai Circlet (60%) 
(22430, 15791, 1, 1, -1, 3684), -- Recipe - Sealed Moirai Shield (60%) 
(22430, 15790, 1, 1, -1, 3684), -- Recipe - Sealed Moirai Sigil (60%) 
(22430, 57, 2656, 5362, 0, 700000), -- Adena
(22430, 15694, 1, 1, 1, 21.169555), -- Sealed Moirai Helmet 
(22430, 15695, 1, 1, 1, 21.169555), -- Sealed Moirai Leather Helmet 
(22430, 15645, 1, 1, 1, 7931.330445), -- Sealed Moirai Helmet Piece
(22430, 15646, 1, 1, 1, 7931.330445), -- Sealed Moirai Leather Helmet Piece
(22430, 1879, 1, 1, 2, 148507.381962), -- Cokes
(22430, 1885, 1, 1, 2, 74253.813702), -- High-Grade Suede
(22430, 9628, 1, 1, 2, 6988.470066), -- Leonard
(22430, 9630, 1, 1, 2, 4689.660294), -- Orichalcum
(22430, 9629, 1, 1, 2, 3874.056528), -- Adamantine
(22430, 9551, 1, 1, 2, 7128.617448), -- Holy Stone
(22430, 9599, 1, 1, 2, 556900), -- Ancient Tome of the Demon
-- Original Sin Warden
(22431, 15649, 1, 1, -1, 201187), -- Sealed Moirai Leather Breastplate Piece
(22431, 9630, 1, 1, -1, 329842), -- Orichalcum
(22431, 15779, 1, 1, -1, 24815), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22431, 57, 15337, 30961, 0, 700000), -- Adena
(22431, 15698, 1, 1, 1, 122.240331), -- Sealed Moirai Leather Breastplate 
(22431, 15649, 1, 1, 1, 49548.759669), -- Sealed Moirai Leather Breastplate Piece
(22431, 1871, 24, 72, 2, 91880.470746), -- Charcoal
(22431, 1866, 52, 156, 2, 28001.641086), -- Suede
(22431, 1877, 1, 1, 2, 176410.613826), -- Adamantite Nugget
(22431, 4041, 1, 1, 2, 38350.213146), -- Mold Hardener
(22431, 4040, 1, 1, 2, 88205.306913), -- Mold Lubricant
(22431, 9551, 1, 1, 2, 35282.306088), -- Holy Stone
(22431, 959, 1, 1, 2, 176.448195), -- Scroll: Enchant Weapon (S-Grade)
(22431, 9599, 3, 9, 2, 536000), -- Ancient Tome of the Demon
-- Slave of Greed
(22432, 15652, 1, 1, -1, 49141), -- Sealed Moirai Leather Legging Piece
(22432, 9630, 1, 1, -1, 49658), -- Orichalcum
(22432, 15782, 1, 1, -1, 5978), -- Recipe - Sealed Moirai Leather Legging (60%) 
(22432, 57, 2309, 4661, 0, 700000), -- Adena
(22432, 15701, 1, 1, 1, 29.446791), -- Sealed Moirai Leather Legging 
(22432, 15652, 1, 1, 1, 12103.553209), -- Sealed Moirai Leather Legging Piece
(22432, 1865, 1, 3, 2, 211264.24527), -- Varnish
(22432, 1870, 1, 3, 2, 140842.985283), -- Coal
(22432, 1879, 1, 1, 2, 70421.259987), -- Cokes
(22432, 1875, 1, 1, 2, 28168.410933), -- Stone of Purity
(22432, 4040, 1, 1, 2, 8450.476749), -- Mold Lubricant
(22432, 14166, 1, 1, 2, 2041.310583), -- Life Stone - Level 84
(22432, 14167, 1, 1, 2, 509.513355), -- Mid-Grade Life Stone - Level 84
(22432, 14168, 1, 1, 2, 51.18399), -- High-Grade Life Stone - Level 84
(22432, 14169, 1, 1, 2, 10.236798), -- Top-Grade Life Stone - Level 84
(22432, 9551, 1, 1, 2, 3380.004576), -- Holy Stone
(22432, 960, 1, 1, 2, 169.372476), -- Scroll: Enchant Armor (S-Grade)
(22432, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Slave of Lust
(22433, 15772, 1, 1, -1, 65069), -- Sealed Moirai Ring Gem
(22433, 15773, 1, 1, -1, 36570), -- Sealed Moirai Earring Gem
(22433, 15774, 1, 1, -1, 31555), -- Sealed Moirai Necklace Gem
(22433, 15812, 1, 1, -1, 8609), -- Recipe - Sealed Moirai Ring (70%) 
(22433, 15813, 1, 1, -1, 5738), -- Recipe - Sealed Moirai Earring (70%) 
(22433, 15814, 1, 1, -1, 4304), -- Recipe - Sealed Moirai Necklace (70%) 
(22433, 57, 2309, 4661, 0, 700000), -- Adena
(22433, 15766, 1, 1, 1, 28.271637), -- Sealed Moirai Ring
(22433, 15767, 1, 1, 1, 18.840447), -- Sealed Moirai Earring
(22433, 15768, 1, 1, 1, 14.124852), -- Sealed Moirai Necklace
(22433, 15772, 1, 1, 1, 10684.968012), -- Sealed Moirai Ring Gem
(22433, 15773, 1, 1, 1, 6005.123802), -- Sealed Moirai Earring Gem
(22433, 15774, 1, 1, 1, 5181.67125), -- Sealed Moirai Necklace Gem
(22433, 1866, 1, 3, 2, 172141.105266), -- Suede
(22433, 1871, 4, 12, 2, 96829.348122), -- Charcoal
(22433, 5220, 1, 1, 2, 30985.346106), -- Metal Hardener
(22433, 1885, 1, 1, 2, 64552.772934), -- High-Grade Suede
(22433, 4041, 1, 1, 2, 6735.829932), -- Mold Hardener
(22433, 9551, 1, 1, 2, 6197.59764), -- Holy Stone
(22433, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Slave of Wrath
(22434, 15654, 1, 1, -1, 19440), -- Sealed Moirai Gauntlet Piece
(22434, 15655, 1, 1, -1, 19440), -- Sealed Moirai Leather Gloves Piece
(22434, 15656, 1, 1, -1, 19440), -- Sealed Moirai Gloves Piece
(22434, 15657, 1, 1, -1, 19440), -- Sealed Moirai Boots Piece
(22434, 15658, 1, 1, -1, 19440), -- Sealed Moirai Leather Boots Piece
(22434, 15659, 1, 1, -1, 19440), -- Sealed Moirai Shoes Piece
(22434, 9630, 1, 1, -1, 11460), -- Orichalcum
(22434, 15784, 1, 1, -1, 2587), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22434, 15785, 1, 1, -1, 2587), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22434, 15786, 1, 1, -1, 2587), -- Recipe - Sealed Moirai Gloves (60%) 
(22434, 15787, 1, 1, -1, 2587), -- Recipe - Sealed Moirai Boots (60%) 
(22434, 15788, 1, 1, -1, 2587), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22434, 15789, 1, 1, -1, 2587), -- Recipe - Sealed Moirai Shoes (60%) 
(22434, 57, 2309, 4661, 0, 700000), -- Adena
(22434, 15706, 1, 1, 1, 18.40446), -- Sealed Moirai Boots 
(22434, 15707, 1, 1, 1, 18.40446), -- Sealed Moirai Leather Boots 
(22434, 15708, 1, 1, 1, 18.40446), -- Sealed Moirai Shoes 
(22434, 15657, 1, 1, 1, 6913.609404), -- Sealed Moirai Boots Piece
(22434, 15658, 1, 1, 1, 6913.609404), -- Sealed Moirai Leather Boots Piece
(22434, 15659, 1, 1, 1, 6913.567812), -- Sealed Moirai Shoes Piece
(22434, 1869, 9, 27, 2, 32276.511488), -- Iron Ore
(22434, 1864, 4, 12, 2, 145243.611968), -- Stem
(22434, 1880, 1, 1, 2, 58097.51376), -- Steel
(22434, 5550, 1, 1, 2, 7746.335168), -- Durable Metal Plate
(22434, 4043, 1, 1, 2, 19365.83792), -- Asofe
(22434, 9551, 1, 1, 2, 4647.732128), -- Holy Stone
(22434, 959, 1, 1, 2, 23.105888), -- Scroll: Enchant Weapon (S-Grade)
(22434, 1345, 50, 150, 2, 77463.35168), -- Shining Arrow
(22434, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Slave of Sloth
(22435, 15650, 1, 1, -1, 30289), -- Sealed Moirai Tunic Piece
(22435, 1894, 1, 1, -1, 331055), -- Crafted Leather
(22435, 15780, 1, 1, -1, 3736), -- Recipe - Sealed Moirai Tunic (60%) 
(22435, 57, 2309, 4661, 0, 700000), -- Adena
(22435, 15699, 1, 1, 1, 18.403358), -- Sealed Moirai Tunic 
(22435, 15650, 1, 1, 1, 7459.596642), -- Sealed Moirai Tunic Piece
(22435, 1895, 1, 1, 2, 221324.709935), -- Metallic Fiber
(22435, 4040, 1, 1, 2, 15492.767717), -- Mold Lubricant
(22435, 9628, 1, 1, 2, 6075.590213), -- Leonard
(22435, 9630, 1, 1, 2, 4076.924068), -- Orichalcum
(22435, 9551, 1, 1, 2, 6197.005696), -- Holy Stone
(22435, 960, 1, 1, 2, 310.002371), -- Scroll: Enchant Armor (S-Grade)
(22435, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Slave of Envy
(22436, 15648, 1, 1, -1, 22384), -- Sealed Moirai Breastplate Piece
(22436, 1894, 1, 1, -1, 331055), -- Crafted Leather
(22436, 15778, 1, 1, -1, 2802), -- Recipe - Sealed Moirai Breastplate (60%) 
(22436, 57, 2309, 4661, 0, 700000), -- Adena
(22436, 15697, 1, 1, 1, 13.803416), -- Sealed Moirai Breastplate 
(22436, 15648, 1, 1, 1, 5514.196584), -- Sealed Moirai Breastplate Piece
(22436, 1868, 3, 9, 2, 258211.777049), -- Thread
(22436, 1873, 2, 6, 2, 77463.384075), -- Silver Nugget
(22436, 5549, 1, 1, 2, 77463.384075), -- Metallic Thread
(22436, 1889, 1, 1, 2, 51642.25605), -- Compound Braid
(22436, 4044, 1, 1, 2, 25821.128025), -- Thons
(22436, 9551, 1, 1, 2, 6197.070726), -- Holy Stone
(22436, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Slave of Pride
(22437, 15651, 1, 1, -1, 37515), -- Sealed Moirai Gaiter Piece
(22437, 1894, 1, 1, -1, 331055), -- Crafted Leather
(22437, 15781, 1, 1, -1, 4483), -- Recipe - Sealed Moirai Gaiter (60%) 
(22437, 57, 2309, 4661, 0, 700000), -- Adena
(22437, 15700, 1, 1, 1, 22.082992), -- Sealed Moirai Gaiter 
(22437, 15651, 1, 1, 1, 9240.917008), -- Sealed Moirai Gaiter Piece
(22437, 1868, 3, 9, 2, 193658.78067), -- Thread
(22437, 1873, 2, 6, 2, 46478.290494), -- Silver Nugget
(22437, 5549, 1, 1, 2, 58097.634201), -- Metallic Thread
(22437, 1889, 1, 1, 2, 38731.756134), -- Compound Braid
(22437, 4044, 1, 1, 2, 19365.878067), -- Thons
(22437, 9551, 1, 1, 2, 4647.920616), -- Holy Stone
(22437, 959, 1, 1, 2, 23.349483), -- Scroll: Enchant Weapon (S-Grade)
(22437, 1345, 40, 120, 2, 96829.390335), -- Shining Arrow
(22437, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Slave of Gluttony
(22438, 15653, 1, 1, -1, 49141), -- Sealed Moirai Stockings Piece
(22438, 959, 1, 1, -1, 377), -- Scroll: Enchant Weapon (S-Grade)
(22438, 15783, 1, 1, -1, 5978), -- Recipe - Sealed Moirai Stockings (60%) 
(22438, 57, 2309, 4661, 0, 700000), -- Adena
(22438, 15702, 1, 1, 1, 29.446791), -- Sealed Moirai Stockings 
(22438, 15653, 1, 1, 1, 12103.553209), -- Sealed Moirai Stockings Piece
(22438, 1895, 1, 1, 2, 221324.709935), -- Metallic Fiber
(22438, 4040, 1, 1, 2, 15492.767717), -- Mold Lubricant
(22438, 9628, 1, 1, 2, 6075.590213), -- Leonard
(22438, 9630, 1, 1, 2, 4076.924068), -- Orichalcum
(22438, 9551, 1, 1, 2, 6197.005696), -- Holy Stone
(22438, 960, 1, 1, 2, 310.002371), -- Scroll: Enchant Armor (S-Grade)
(22438, 9599, 1, 1, 2, 484100), -- Ancient Tome of the Demon
-- Beleth's Assassin
(22439, 6901, 1, 1, -1, 104031), -- Recipe: Shining Arrow (100%)
(22439, 6709, 1, 3, -1, 740591), -- Sealed Draconic Leather Boots Design
(22439, 960, 1, 1, -1, 41612), -- Scroll: Enchant Armor (S-Grade)
(22439, 57, 60963, 122093, 0, 700000), -- Adena
(22439, 289, 1, 1, 1, 247.079), -- Soul Bow
(22439, 5534, 1, 1, 1, 70346.921), -- Soul Bow Stave
(22439, 1894, 2, 6, 2, 32693.312938), -- Crafted Leather
(22439, 4039, 3, 9, 2, 25882.300768), -- Mold Glue
(22439, 4041, 1, 1, 2, 40511.54586), -- Mold Hardener
(22439, 4044, 1, 1, 2, 155293.804608), -- Thons
(22439, 6901, 1, 1, 2, 4658.8505), -- Recipe: Shining Arrow (100%)
(22439, 9551, 1, 1, 2, 37270.349478), -- Holy Stone
(22439, 14166, 1, 1, 2, 22506.111352), -- Life Stone - Level 84
(22439, 14167, 1, 1, 2, 5619.710008), -- Mid-Grade Life Stone - Level 84
(22439, 14168, 1, 1, 2, 561.789192), -- High-Grade Life Stone - Level 84
(22439, 14169, 1, 1, 2, 112.266934), -- Top-Grade Life Stone - Level 84
(22439, 1345, 240, 720, 2, 129411.958362), -- Shining Arrow
(22439, 9599, 4, 8, 2, 889700), -- Ancient Tome of the Demon
-- Beleth's Assassin
(22440, 4040, 1, 5, -1, 713725), -- Mold Lubricant
(22440, 1895, 1, 65, -1, 926915), -- Metallic Fiber
(22440, 6710, 1, 3, -1, 868348), -- Sealed Draconic Leather Helmet Pattern
(22440, 57, 62737, 125646, 0, 700000), -- Adena
(22440, 164, 1, 1, 1, 63.567816), -- Elysian
(22440, 5533, 1, 1, 1, 18083.302068), -- Elysian Head
(22440, 213, 1, 1, 1, 63.567816), -- Branch of the Mother Tree
(22440, 5544, 1, 1, 1, 18065.450832), -- Branch of the Mother Tree Head
(22440, 7895, 1, 1, 1, 63.567816), -- Flaming Dragon Skull
(22440, 8342, 1, 1, 1, 18083.302068), -- Flaming Dragon Skull Piece
(22440, 7902, 1, 1, 1, 63.567816), -- Doom Crusher
(22440, 8349, 1, 1, 1, 18079.673768), -- Doom Crusher Head
(22440, 1895, 12, 36, 2, 104639.325806), -- Metallic Fiber
(22440, 4040, 1, 1, 2, 175793.899485), -- Mold Lubricant
(22440, 9628, 1, 1, 2, 68938.701823), -- Leonard
(22440, 9630, 1, 1, 2, 46261.454327), -- Orichalcum
(22440, 959, 1, 1, 2, 351.592462), -- Scroll: Enchant Weapon (S-Grade)
(22440, 9551, 1, 1, 2, 70318.026097), -- Holy Stone
(22440, 9599, 4, 12, 2, 686700), -- Ancient Tome of the Demon
-- Beleth's Minion
(22441, 6901, 1, 1, -1, 87490), -- Recipe: Shining Arrow (100%)
(22441, 6711, 1, 1, -1, 433495), -- Sealed Major Arcana Robe Part
(22441, 57, 51270, 102680, 0, 700000), -- Adena
(22441, 270, 1, 1, 1, 207.794457), -- Dragon Grinder
(22441, 5538, 1, 1, 1, 59111.205543), -- Dragon Grinder Edge
(22441, 1872, 24, 72, 2, 108834.618789), -- Animal Bone
(22441, 1867, 60, 180, 2, 43533.778071), -- Animal Skin
(22441, 1881, 3, 9, 2, 74629.333836), -- Coarse Bone Powder
(22441, 1875, 4, 12, 2, 29022.634455), -- Stone of Purity
(22441, 4041, 1, 1, 2, 34069.867983), -- Mold Hardener
(22441, 960, 1, 1, 2, 1567.364622), -- Scroll: Enchant Armor (S-Grade)
(22441, 9551, 1, 1, 2, 31344.514656), -- Holy Stone
(22441, 14166, 1, 1, 2, 18927.820176), -- Life Stone - Level 84
(22441, 14167, 1, 1, 2, 4726.399476), -- Mid-Grade Life Stone - Level 84
(22441, 14168, 1, 1, 2, 472.570503), -- High-Grade Life Stone - Level 84
(22441, 14169, 1, 1, 2, 94.097433), -- Top-Grade Life Stone - Level 84
(22441, 9599, 3, 9, 2, 748200), -- Ancient Tome of the Demon
-- Beleth's Minion
(22442, 6712, 1, 1, -1, 732969), -- Sealed Major Arcana Gloves fabric
(22442, 959, 1, 1, -1, 2059), -- Scroll: Enchant Weapon (S-Grade)
(22442, 1876, 1, 21, -1, 936002), -- Mithril Ore
(22442, 57, 30168, 60418, 0, 700000), -- Adena
(22442, 289, 1, 1, 1, 122.269), -- Soul Bow
(22442, 5534, 1, 1, 1, 34811.731), -- Soul Bow Stave
(22442, 1873, 16, 48, 2, 45285.08241), -- Silver Nugget
(22442, 1868, 135, 405, 2, 26835.70242), -- Thread
(22442, 1876, 3, 9, 2, 103508.94885), -- Mithril Ore
(22442, 1895, 3, 9, 2, 172514.91475), -- Metallic Fiber
(22442, 4042, 1, 1, 2, 60380.10988), -- Enria
(22442, 6901, 1, 1, 2, 3623.00069), -- Recipe: Shining Arrow (100%)
(22442, 9551, 1, 1, 2, 28982.241), -- Holy Stone
(22442, 9599, 2, 6, 2, 660400), -- Ancient Tome of the Demon
-- Kertang's Messenger
(22443, 1871, 1, 3, -1, 625677), -- Charcoal
(22443, 4553, 1, 1, -1, 5005), -- Greater Dye of STR (Str+1 Con-1)
(22443, 1908, 1, 1, -1, 118499), -- Moonstone Earring Wire
(22443, 57, 505, 1026, 0, 700000), -- Adena
(22443, 226, 1, 1, 1, 16.776426), -- Cursed Dagger
(22443, 2070, 1, 1, 1, 1174.223574), -- Cursed Dagger Blade
(22443, 232, 1, 1, 1, 16.776426), -- Dark Elven Dagger
(22443, 2072, 1, 1, 1, 1174.223574), -- Dark Elven Dagger Edge
(22443, 1871, 1, 1, 2, 98568.38299), -- Charcoal
(22443, 1866, 1, 1, 2, 65712.372714), -- Suede
(22443, 1877, 1, 1, 2, 3942.805752), -- Adamantite Nugget
(22443, 4041, 1, 1, 2, 857.162308), -- Mold Hardener
(22443, 4040, 1, 1, 2, 1971.402876), -- Mold Lubricant
(22443, 2163, 1, 1, 2, 5028.87336), -- Recipe: Earring of Protection
-- Kertang's Messenger
(22444, 1806, 1, 1, -1, 3775), -- Recipe: Soulshot (B-Grade)
(22444, 1918, 1, 1, -1, 81736), -- Nassen's Earring Gemstone
(22444, 3034, 1, 1, -1, 3775), -- Recipe: Spiritshot B
(22444, 57, 761, 1550, 0, 700000), -- Adena
(22444, 228, 1, 1, 1, 14.780052), -- Crystal Dagger
(22444, 2119, 1, 1, 1, 1587.219948), -- Crystal Dagger Blade
(22444, 1867, 1, 1, 2, 154854.301427), -- Animal Skin
(22444, 1872, 1, 1, 2, 154854.301427), -- Animal Bone
(22444, 1882, 1, 1, 2, 25809.107198), -- Leather
(22444, 1894, 1, 1, 2, 4075.158164), -- Crafted Leather
(22444, 4042, 1, 1, 2, 1935.734304), -- Enria
(22444, 1806, 1, 1, 2, 232.39748), -- Recipe: Soulshot (B-Grade)
-- Kertang's Messenger
(22445, 4052, 1, 1, -1, 93086), -- Earring of Black Ore Piece
(22445, 4040, 1, 1, -1, 52584), -- Mold Lubricant
(22445, 4042, 1, 1, -1, 43820), -- Enria
(22445, 57, 1063, 2155, 0, 700000), -- Adena
(22445, 97, 1, 1, 1, 7.698146), -- Lance
(22445, 4115, 1, 1, 1, 1694.301854), -- Lance Blade
(22445, 1895, 1, 1, 2, 44378.906778), -- Metallic Fiber
(22445, 4040, 1, 1, 2, 3106.504683), -- Mold Lubricant
(22445, 4042, 1, 1, 2, 2588.744691), -- Enria
(22445, 4043, 1, 1, 2, 5177.544651), -- Asofe
(22445, 729, 1, 1, 2, 17.299197), -- Scroll: Enchant Weapon (A-Grade)
-- Kertang's Messenger
(22446, 5480, 1, 1, -1, 12009), -- Sealed Leather Armor of Nightmare Fabric
(22446, 1808, 1, 1, -1, 1189), -- Recipe: Soulshot (S-Grade)
(22446, 5481, 1, 1, -1, 12009), -- Sealed Majestic Leather Armor Fabric
(22446, 57, 1347, 2748, 0, 700000), -- Adena
(22446, 288, 1, 1, 1, 7.00902), -- Carnage Bow
(22446, 5535, 1, 1, 1, 1685.99098), -- Carnage Bow Stave
(22446, 1879, 1, 1, 2, 27450.065498), -- Cokes
(22446, 1885, 1, 1, 2, 13725.032749), -- High-Grade Suede
(22446, 9628, 1, 1, 2, 1291.789071), -- Leonard
(22446, 9630, 1, 1, 2, 866.840458), -- Orichalcum
(22446, 9629, 1, 1, 2, 716.072167), -- Adamantine
(22446, 1808, 1, 1, 2, 73.200057), -- Recipe: Soulshot (S-Grade)
-- Kertang's Messenger
(22447, 3036, 1, 1, -1, 951), -- Recipe: Spiritshot S
(22447, 5487, 1, 1, -1, 9639), -- Sealed Robe of Nightmare Fabric
(22447, 4043, 1, 1, -1, 71350), -- Asofe
(22447, 57, 1436, 2932, 0, 700000), -- Adena
(22447, 5320, 1, 1, 1, 7.984464), -- Sealed Leather Armor of Nightmare
(22447, 5480, 1, 1, 1, 1183.015536), -- Sealed Leather Armor of Nightmare Fabric
(22447, 5323, 1, 1, 1, 7.984464), -- Sealed Majestic Leather Armor
(22447, 5481, 1, 1, 1, 1183.015536), -- Sealed Majestic Leather Armor Fabric
(22447, 1895, 1, 1, 2, 60253.499952), -- Metallic Fiber
(22447, 4040, 1, 1, 2, 4217.774256), -- Mold Lubricant
(22447, 4042, 1, 1, 2, 3514.799376), -- Enria
(22447, 4043, 1, 1, 2, 7029.598752), -- Asofe
(22447, 959, 1, 1, 2, 8.327664), -- Scroll: Enchant Weapon (S-Grade)
-- Leodas
(22448, 1889, 1, 31, -1, 918806), -- Compound Braid
(22448, 6688, 1, 1, -1, 476636), -- Forgotten Blade Edge
(22448, 6901, 1, 1, -1, 220513), -- Recipe: Shining Arrow (100%)
(22448, 57, 129223, 258799, 0, 700000), -- Adena
(22448, 270, 1, 1, 1, 523.73353), -- Dragon Grinder
(22448, 5538, 1, 1, 1, 148986.26647), -- Dragon Grinder Edge
(22448, 1868, 120, 360, 2, 150871.091607), -- Thread
(22448, 1873, 132, 396, 2, 27431.290089), -- Silver Nugget
(22448, 5549, 42, 126, 2, 21552.955722), -- Metallic Thread
(22448, 1889, 4, 12, 2, 134107.458516), -- Compound Braid
(22448, 4044, 5, 15, 2, 60348.597264), -- Thons
(22448, 960, 1, 1, 2, 7241.606802), -- Scroll: Enchant Armor (S-Grade)
(22448, 9599, 6, 20, 2, 870400), -- Ancient Tome of the Demon
-- Amaskari
(22449, 6689, 1, 1, -1, 74624), -- Basalt Battlehammer Head
(22449, 6901, 1, 1, -1, 35188), -- Recipe: Shining Arrow (100%)
(22449, 6690, 1, 1, -1, 76202), -- Imperial Staff Head
(22449, 57, 20620, 41297, 0, 700000), -- Adena
(22449, 270, 1, 1, 1, 83.571071), -- Dragon Grinder
(22449, 5538, 1, 1, 1, 23773.428929), -- Dragon Grinder Edge
(22449, 1895, 3, 9, 2, 137569.52336), -- Metallic Fiber
(22449, 4040, 1, 1, 2, 57779.096126), -- Mold Lubricant
(22449, 9628, 1, 1, 2, 22658.585969), -- Leonard
(22449, 9630, 1, 1, 2, 15205.175367), -- Orichalcum
(22449, 6901, 1, 1, 2, 2888.928885), -- Recipe: Shining Arrow (100%)
(22449, 9551, 1, 1, 2, 23111.690293), -- Holy Stone
(22449, 9599, 2, 4, 2, 601900), -- Ancient Tome of the Demon
-- Tortured Native
(22450, 960, 1, 1, -1, 674), -- Scroll: Enchant Armor (S-Grade)
(22450, 1895, 1, 1, -1, 481173), -- Metallic Fiber
(22450, 4042, 1, 1, -1, 28068), -- Enria
(22450, 57, 987, 1976, 0, 700000), -- Adena
(22450, 289, 1, 1, 1, 4.0005), -- Soul Bow
(22450, 5534, 1, 1, 1, 1138.9995), -- Soul Bow Stave
(22450, 1873, 1, 1, 2, 55307.214592), -- Silver Nugget
(22450, 1868, 1, 1, 2, 276536.07296), -- Thread
(22450, 1876, 1, 1, 2, 27653.607296), -- Mithril Ore
(22450, 1895, 1, 1, 2, 39505.15328), -- Metallic Fiber
(22450, 4042, 1, 1, 2, 2304.333504), -- Enria
(22450, 959, 1, 1, 2, 5.618368), -- Scroll: Enchant Weapon (S-Grade)
(22450, 9599, 1, 1, 2, 86400), -- Ancient Tome of the Demon
-- Native Elite Soldier
(22451, 4040, 1, 1, -1, 58962), -- Mold Lubricant
(22451, 1895, 1, 1, -1, 842320), -- Metallic Fiber
(22451, 6710, 1, 1, -1, 47824), -- Sealed Draconic Leather Helmet Pattern
(22451, 57, 1728, 3460, 0, 700000), -- Adena
(22451, 5320, 1, 1, 1, 10.997912), -- Sealed Leather Armor of Nightmare
(22451, 5480, 1, 1, 1, 1629.502088), -- Sealed Leather Armor of Nightmare Fabric
(22451, 5323, 1, 1, 1, 10.997912), -- Sealed Majestic Leather Armor
(22451, 5481, 1, 1, 1, 1629.502088), -- Sealed Majestic Leather Armor Fabric
(22451, 1879, 1, 1, 2, 40340.972757), -- Cokes
(22451, 1885, 1, 1, 2, 20170.518795), -- High-Grade Suede
(22451, 9628, 1, 1, 2, 1898.375073), -- Leonard
(22451, 9630, 1, 1, 2, 1273.903617), -- Orichalcum
(22451, 9629, 1, 1, 2, 1052.369256), -- Adamantine
(22451, 960, 1, 1, 2, 96.860502), -- Scroll: Enchant Armor (S-Grade)
-- White Skull Kanabion
(22452, 956, 1, 1, 2, 10126.1952), -- Scroll: Enchant Armor (D-Grade)
-- White Skull Kanabion
(22453, 956, 1, 1, 2, 10126.1952), -- Scroll: Enchant Armor (D-Grade)
-- White Skull Kanabion
(22454, 956, 1, 1, 2, 11149.0432), -- Scroll: Enchant Armor (D-Grade)
-- Begrudged Kanabion
(22455, 956, 1, 1, 2, 12811.392), -- Scroll: Enchant Armor (D-Grade)
-- Begrudged Kanabion
(22456, 956, 1, 1, 2, 12811.392), -- Scroll: Enchant Armor (D-Grade)
-- Begrudged Kanabion
(22457, 956, 1, 1, 2, 14105.472), -- Scroll: Enchant Armor (D-Grade)
-- Rotten Kanabion
(22458, 956, 1, 1, 2, 17031.168), -- Scroll: Enchant Armor (D-Grade)
-- Rotten Kanabion
(22459, 956, 1, 1, 2, 17031.168), -- Scroll: Enchant Armor (D-Grade)
-- Rotten Kanabion
(22460, 956, 1, 1, 2, 18751.488), -- Scroll: Enchant Armor (D-Grade)
-- Gluttonous Kanabion
(22461, 956, 1, 1, 2, 22011.264), -- Scroll: Enchant Armor (D-Grade)
-- Gluttonous Kanabion
(22462, 956, 1, 1, 2, 22011.264), -- Scroll: Enchant Armor (D-Grade)
-- Gluttonous Kanabion
(22463, 956, 1, 1, 2, 24234.624), -- Scroll: Enchant Armor (D-Grade)
-- Callous Kanabion
(22464, 952, 1, 1, 2, 11131.0848), -- Scroll: Enchant Armor (C-Grade)
-- Callous Kanabion
(22465, 952, 1, 1, 2, 11131.0848), -- Scroll: Enchant Armor (C-Grade)
-- Callous Kanabion
(22466, 952, 1, 1, 2, 12255.4368), -- Scroll: Enchant Armor (C-Grade)
-- Savage Kanabion
(22467, 952, 1, 1, 2, 13776.9984), -- Scroll: Enchant Armor (C-Grade)
-- Savage Kanabion
(22468, 952, 1, 1, 2, 13776.9984), -- Scroll: Enchant Armor (C-Grade)
-- Savage Kanabion
(22469, 952, 1, 1, 2, 15168.6144), -- Scroll: Enchant Armor (C-Grade)
-- Peerless Kanabion
(22470, 948, 1, 1, 2, 3147.7248), -- Scroll: Enchant Armor (B-Grade)
-- Peerless Kanabion
(22471, 948, 1, 1, 2, 3147.7248), -- Scroll: Enchant Armor (B-Grade)
-- Peerless Kanabion
(22472, 948, 1, 1, 2, 3465.6768), -- Scroll: Enchant Armor (B-Grade)
-- Massive Kanabion
(22473, 948, 1, 1, 2, 3592.4544), -- Scroll: Enchant Armor (B-Grade)
-- Massive Kanabion
(22474, 948, 1, 1, 2, 3592.4544), -- Scroll: Enchant Armor (B-Grade)
-- Massive Kanabion
(22475, 948, 1, 1, 2, 3974.6304), -- Scroll: Enchant Armor (B-Grade)
-- Fervent Kanabion
(22476, 730, 1, 1, 2, 1423.9872), -- Scroll: Enchant Armor (A-Grade)
-- Fervent Kanabion
(22477, 730, 1, 1, 2, 1423.9872), -- Scroll: Enchant Armor (A-Grade)
-- Fervent Kanabion
(22478, 730, 1, 1, 2, 1575.4752), -- Scroll: Enchant Armor (A-Grade)
-- Ruptured Kanabion
(22479, 730, 1, 1, 2, 1621.4016), -- Scroll: Enchant Armor (A-Grade)
-- Ruptured Kanabion
(22480, 730, 1, 1, 2, 1621.4016), -- Scroll: Enchant Armor (A-Grade)
-- Ruptured Kanabion
(22481, 730, 1, 1, 2, 1799.5776), -- Scroll: Enchant Armor (A-Grade)
-- Sword Kanabion
(22482, 960, 1, 1, 2, 904.909824), -- Scroll: Enchant Armor (S-Grade)
-- Sword Kanabion
(22483, 960, 1, 1, 2, 904.909824), -- Scroll: Enchant Armor (S-Grade)
-- Sword Kanabion
(22484, 960, 1, 1, 2, 1004.350464), -- Scroll: Enchant Armor (S-Grade)
-- Fanatic of Infinity
(22509, 3957, 1, 1, -1, 8877), -- Recipe: Blessed Spiritshot S
(22509, 5495, 1, 1, -1, 303308), -- Sealed Shield of Nightmare Fragment
(22509, 5157, 1, 1, -1, 8877), -- Recipe: Soulshot (S) Compressed Package (100%)
(22509, 57, 10024, 20526, 0, 700000), -- Adena
(22509, 288, 1, 1, 1, 52.31304), -- Carnage Bow
(22509, 5535, 1, 1, 1, 12583.68696), -- Carnage Bow Stave
(22509, 1894, 1, 1, 2, 51755.478638), -- Crafted Leather
(22509, 4039, 1, 1, 2, 49167.753778), -- Mold Glue
(22509, 4041, 1, 1, 2, 12826.413222), -- Mold Hardener
(22509, 4044, 1, 1, 2, 49167.753778), -- Thons
(22509, 1808, 1, 1, 2, 655.600584), -- Recipe: Soulshot (S-Grade)
-- Rotten Messenger
(22510, 5502, 1, 1, -1, 304090), -- Sealed Boots of Nightmare Lining
(22510, 1894, 1, 1, -1, 631759), -- Crafted Leather
(22510, 57, 9052, 18494, 0, 700000), -- Adena
(22510, 235, 1, 1, 1, 47.154264), -- Bloody Orchid
(22510, 5536, 1, 1, 1, 11309.845736), -- Bloody Orchid Head
(22510, 1895, 2, 6, 2, 79143.564296), -- Metallic Fiber
(22510, 4040, 1, 1, 2, 22160.108304), -- Mold Lubricant
(22510, 4042, 1, 1, 2, 18466.75692), -- Enria
(22510, 4043, 1, 1, 2, 36933.794149), -- Asofe
(22510, 3036, 1, 1, 2, 492.502913), -- Recipe: Spiritshot S
(22510, 1345, 60, 180, 2, 123112.273418), -- Shining Arrow
-- Zealot of Infinity
(22511, 5503, 1, 1, -1, 310313), -- Sealed Majestic Boots Lining
(22511, 5162, 1, 1, -1, 8166), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22511, 5514, 1, 1, -1, 310313), -- Sealed Gauntlets of Nightmare Design
(22511, 57, 9237, 18873, 0, 700000), -- Adena
(22511, 5297, 1, 1, 1, 84.664224), -- Sealed Dark Crystal Leather Armor
(22511, 5478, 1, 1, 1, 9507.286944), -- Sealed Dark Crystal Leather Armor Pattern
(22511, 5298, 1, 1, 1, 135.393696), -- Sealed Dark Crystal Leggings
(22511, 5482, 1, 1, 1, 14922.563904), -- Sealed Dark Crystal Leggings Design
(22511, 5301, 1, 1, 1, 52.079328), -- Sealed Tallum Leather Armor
(22511, 5479, 1, 1, 1, 6690.011904), -- Sealed Tallum Leather Armor Pattern
(22511, 1895, 1, 1, 2, 387663.652484), -- Metallic Fiber
(22511, 4040, 1, 1, 2, 27136.56682), -- Mold Lubricant
(22511, 4042, 1, 1, 2, 22613.886224), -- Enria
(22511, 4043, 1, 1, 2, 45227.289204), -- Asofe
(22511, 3957, 1, 1, 2, 602.605268), -- Recipe: Blessed Spiritshot S
-- Body Severer
(22512, 5167, 1, 1, -1, 8608), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22512, 5515, 1, 1, -1, 327120), -- Sealed Majestic Gauntlets Design
(22512, 1894, 1, 1, -1, 679607), -- Crafted Leather
(22512, 57, 9744, 19887, 0, 700000), -- Adena
(22512, 5287, 1, 1, 1, 66.925175), -- Sealed Dark Crystal breastplate
(22512, 5520, 1, 1, 1, 7686.816475), -- Sealed Dark Crystal Breastplate Pattern
(22512, 5288, 1, 1, 1, 107.095325), -- Sealed Dark Crystal Gaiters
(22512, 5524, 1, 1, 1, 11748.816025), -- Sealed Dark Crystal Gaiters Pattern
(22512, 5293, 1, 1, 1, 41.198225), -- Sealed Tallum Plate Armor
(22512, 5521, 1, 1, 1, 5424.148775), -- Sealed Tallum Plate Armor Pattern
(22512, 1894, 1, 1, 2, 41821.978086), -- Crafted Leather
(22512, 4039, 1, 1, 2, 39730.733644), -- Mold Glue
(22512, 4041, 1, 1, 2, 10364.665766), -- Mold Hardener
(22512, 4044, 1, 1, 2, 39730.733644), -- Thons
(22512, 5157, 1, 1, 2, 529.757228), -- Recipe: Soulshot (S) Compressed Package (100%)
(22512, 1345, 60, 180, 2, 132436.131632), -- Shining Arrow
-- Body Harvester
(22513, 1894, 1, 1, -1, 523908), -- Crafted Leather
(22513, 5522, 1, 1, -1, 50849), -- Sealed Armor of Nightmare Pattern
(22513, 5272, 1, 1, -1, 6636), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22513, 57, 10019, 20447, 0, 700000), -- Adena
(22513, 5326, 1, 1, 1, 55.697811), -- Sealed Robe of Nightmare
(22513, 5487, 1, 1, 1, 8279.802189), -- Sealed Robe of Nightmare Fabric
(22513, 5329, 1, 1, 1, 55.697811), -- Sealed Majestic Robe
(22513, 5488, 1, 1, 1, 8279.802189), -- Sealed Majestic Robe Fabric
(22513, 1895, 2, 6, 2, 87563.822256), -- Metallic Fiber
(22513, 4040, 1, 1, 2, 24517.907388), -- Mold Lubricant
(22513, 4042, 1, 1, 2, 20431.641096), -- Enria
(22513, 4043, 1, 1, 2, 40863.282192), -- Asofe
(22513, 959, 1, 1, 2, 48.922488), -- Scroll: Enchant Weapon (S-Grade)
(22513, 1345, 60, 180, 2, 136210.42458), -- Shining Arrow
-- Soul Exploiter
(22514, 5523, 1, 1, -1, 45183), -- Sealed Majestic Plate Armor Pattern
(22514, 5277, 1, 1, -1, 5897), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22514, 5527, 1, 1, -1, 158627), -- Sealed Helm of Nightmare Design
(22514, 57, 8901, 18172, 0, 700000), -- Adena
(22514, 6326, 1, 1, 1, 109.038528), -- Sealed Majestic Necklace
(22514, 6344, 1, 1, 1, 15966.640296), -- Sealed Majestic Necklace Beads
(22514, 6327, 1, 1, 1, 145.410228), -- Sealed Majestic Earring
(22514, 6342, 1, 1, 1, 24672.493836), -- Sealed Majestic Earring Gemstone
(22514, 6328, 1, 1, 1, 218.077056), -- Sealed Majestic Ring
(22514, 6346, 1, 1, 1, 35460.340056), -- Sealed Majestic Ring Gemstone
(22514, 1895, 1, 1, 2, 373471.193953), -- Metallic Fiber
(22514, 4040, 1, 1, 2, 26143.154657), -- Mold Lubricant
(22514, 9628, 1, 1, 2, 10252.29933), -- Leonard
(22514, 9630, 1, 1, 2, 6879.931272), -- Orichalcum
(22514, 960, 1, 1, 2, 522.420788), -- Scroll: Enchant Armor (S-Grade)
-- Soul Devourer
(22515, 1894, 1, 1, -1, 433117), -- Crafted Leather
(22515, 5528, 1, 1, -1, 147583), -- Sealed Majestic Circlet Design
(22515, 57, 8265, 16925, 0, 700000), -- Adena
(22515, 5313, 1, 1, 1, 112.190136), -- Sealed Gauntlets of Nightmare
(22515, 5514, 1, 1, 1, 12836.809864), -- Sealed Gauntlets of Nightmare Design
(22515, 5314, 1, 1, 1, 112.190136), -- Sealed Boots of Nightmare
(22515, 5502, 1, 1, 1, 12836.809864), -- Sealed Boots of Nightmare Lining
(22515, 5318, 1, 1, 1, 112.190136), -- Sealed Majestic Gauntlets
(22515, 5515, 1, 1, 1, 12836.809864), -- Sealed Majestic Gauntlets Design
(22515, 5319, 1, 1, 1, 112.190136), -- Sealed Majestic Boots
(22515, 5503, 1, 1, 1, 12836.809864), -- Sealed Majestic Boots Lining
(22515, 1895, 1, 1, 2, 289557.21492), -- Metallic Fiber
(22515, 4040, 1, 1, 2, 20268.983208), -- Mold Lubricant
(22515, 9628, 1, 1, 2, 7948.4496), -- Leonard
(22515, 9630, 1, 1, 2, 5333.759064), -- Orichalcum
(22515, 6901, 1, 1, 2, 1013.645688), -- Recipe: Shining Arrow (100%)
(22515, 1345, 60, 180, 2, 112605.94752), -- Shining Arrow
-- Butcher of Infinity
(22516, 5282, 1, 1, -1, 4892), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22516, 5529, 1, 1, -1, 30199), -- Dragon Slayer Edge
(22516, 1808, 1, 1, -1, 4892), -- Recipe: Soulshot (S-Grade)
(22516, 57, 7370, 15093, 0, 700000), -- Adena
(22516, 5312, 1, 1, 1, 88.952448), -- Sealed Helm of Nightmare
(22516, 5527, 1, 1, 1, 10804.978306), -- Sealed Helm of Nightmare Design
(22516, 5315, 1, 1, 1, 127.120746), -- Sealed Shield of Nightmare
(22516, 5495, 1, 1, 1, 13723.017746), -- Sealed Shield of Nightmare Fragment
(22516, 5317, 1, 1, 1, 88.952448), -- Sealed Majestic Circlet
(22516, 5528, 1, 1, 1, 10804.978306), -- Sealed Majestic Circlet Design
(22516, 1895, 1, 1, 2, 309856.290536), -- Metallic Fiber
(22516, 4040, 1, 1, 2, 21690.051606), -- Mold Lubricant
(22516, 9628, 1, 1, 2, 8505.779868), -- Leonard
(22516, 9630, 1, 1, 2, 5707.72531), -- Orichalcum
(22516, 6847, 1, 1, 2, 1954.15268), -- Recipe: Sealed Tateossian Earring (70%)
-- Disciple of Infinity
(22517, 5533, 1, 1, -1, 26706), -- Elysian Head
(22517, 1894, 1, 1, -1, 341619), -- Crafted Leather
(22517, 57, 6519, 13349, 0, 700000), -- Adena
(22517, 81, 1, 1, 1, 7.707765), -- Dragon Slayer
(22517, 5529, 1, 1, 1, 2192.05838), -- Dragon Slayer Edge
(22517, 151, 1, 1, 1, 7.707765), -- Sword of Miracles
(22517, 5546, 1, 1, 1, 2407.76676), -- Sword of Miracles Edge
(22517, 2500, 1, 1, 1, 7.707765), -- Dark Legion's Edge
(22517, 5545, 1, 1, 1, 2192.051565), -- Dark Legion's Edge Blade
(22517, 1895, 1, 1, 2, 228387.294486), -- Metallic Fiber
(22517, 4040, 1, 1, 2, 15987.190154), -- Mold Lubricant
(22517, 9628, 1, 1, 2, 6269.479554), -- Leonard
(22517, 9630, 1, 1, 2, 4206.97329), -- Orichalcum
(22517, 6849, 1, 1, 2, 2157.608414), -- Recipe: Sealed Tateossian Ring(70%)
(22517, 1345, 60, 180, 2, 88817.454102), -- Shining Arrow
-- Rotten Messenger
(22518, 5534, 1, 1, -1, 27300), -- Soul Bow Stave
(22518, 3036, 1, 1, -1, 4420), -- Recipe: Spiritshot S
(22518, 5537, 1, 1, -1, 27282), -- Soul Separator Head
(22518, 57, 6657, 13636, 0, 700000), -- Adena
(22518, 164, 1, 1, 1, 5.90424), -- Elysian
(22518, 5533, 1, 1, 1, 1679.59452), -- Elysian Head
(22518, 213, 1, 1, 1, 5.90424), -- Branch of the Mother Tree
(22518, 5544, 1, 1, 1, 1677.93648), -- Branch of the Mother Tree Head
(22518, 7895, 1, 1, 1, 5.90424), -- Flaming Dragon Skull
(22518, 8342, 1, 1, 1, 1679.59452), -- Flaming Dragon Skull Piece
(22518, 7902, 1, 1, 1, 5.90424), -- Doom Crusher
(22518, 8349, 1, 1, 1, 1679.25752), -- Doom Crusher Head
(22518, 1895, 1, 1, 2, 279919.129908), -- Metallic Fiber
(22518, 4040, 1, 1, 2, 19594.398692), -- Mold Lubricant
(22518, 9628, 1, 1, 2, 7684.120972), -- Leonard
(22518, 9630, 1, 1, 2, 5156.519764), -- Orichalcum
(22518, 6851, 1, 1, 2, 1321.830664), -- Recipe: Sealed Tateossian Necklace(70%)
-- Body Harvester
(22519, 6901, 1, 1, -1, 11053), -- Recipe: Shining Arrow (100%)
(22519, 6688, 1, 1, -1, 23892), -- Forgotten Blade Edge
(22519, 959, 1, 1, -1, 442), -- Scroll: Enchant Weapon (S-Grade)
(22519, 57, 6468, 12974, 0, 700000), -- Adena
(22519, 270, 1, 1, 1, 26.251482), -- Dragon Grinder
(22519, 5538, 1, 1, 1, 7467.748518), -- Dragon Grinder Edge
(22519, 1895, 1, 1, 2, 311146.304364), -- Metallic Fiber
(22519, 4040, 1, 1, 2, 21780.36648), -- Mold Lubricant
(22519, 9628, 1, 1, 2, 8541.422455), -- Leonard
(22519, 9630, 1, 1, 2, 5731.602188), -- Orichalcum
(22519, 6853, 1, 1, 2, 507.304513), -- Recipe: Sealed Imperial Crusader Breastplate (60%)
-- Body Severer
(22520, 1894, 1, 1, -1, 376209), -- Crafted Leather
(22520, 6689, 1, 1, -1, 22739), -- Basalt Battlehammer Head
(22520, 57, 6274, 12585, 0, 700000), -- Adena
(22520, 289, 1, 1, 1, 25.466), -- Soul Bow
(22520, 5534, 1, 1, 1, 7250.534), -- Soul Bow Stave
(22520, 1895, 1, 1, 2, 251511.62008), -- Metallic Fiber
(22520, 4040, 1, 1, 2, 17605.95368), -- Mold Lubricant
(22520, 9628, 1, 1, 2, 6904.15432), -- Leonard
(22520, 9630, 1, 1, 2, 4633.22552), -- Orichalcum
(22520, 6855, 1, 1, 2, 655.11936), -- Recipe: Sealed Imperial Crusader Gaiters (60%)
(22520, 1345, 60, 180, 2, 97809.92704), -- Shining Arrow
-- Soul Exploiter
(22521, 6847, 1, 1, -1, 19042), -- Recipe: Sealed Tateossian Earring (70%)
(22521, 6690, 1, 1, -1, 22887), -- Imperial Staff Head
(22521, 6849, 1, 1, -1, 28525), -- Recipe: Sealed Tateossian Ring(70%)
(22521, 57, 6184, 12405, 0, 700000), -- Adena
(22521, 236, 1, 1, 1, 25.102336), -- Soul Separator
(22521, 5537, 1, 1, 1, 7142.897664), -- Soul Separator Head
(22521, 1895, 1, 1, 2, 297491.990312), -- Metallic Fiber
(22521, 4040, 1, 1, 2, 20824.466034), -- Mold Lubricant
(22521, 9628, 1, 1, 2, 8166.575116), -- Leonard
(22521, 9630, 1, 1, 2, 5479.999624), -- Orichalcum
(22521, 6857, 1, 1, 2, 1938.968914), -- Recipe: Sealed Imperial Crusader Gauntlets (60%)
-- Soul Devourer
(22522, 5480, 1, 1, -1, 43988), -- Sealed Leather Armor of Nightmare Fabric
(22522, 1894, 1, 1, -1, 343962), -- Crafted Leather
(22522, 57, 6563, 13443, 0, 700000), -- Adena
(22522, 5320, 1, 1, 1, 36.566968), -- Sealed Leather Armor of Nightmare
(22522, 5480, 1, 1, 1, 5417.933032), -- Sealed Leather Armor of Nightmare Fabric
(22522, 5323, 1, 1, 1, 36.566968), -- Sealed Majestic Leather Armor
(22522, 5481, 1, 1, 1, 5417.933032), -- Sealed Majestic Leather Armor Fabric
(22522, 1895, 1, 1, 2, 229953.503084), -- Metallic Fiber
(22522, 4040, 1, 1, 2, 16096.616632), -- Mold Lubricant
(22522, 9628, 1, 1, 2, 6312.425936), -- Leonard
(22522, 9630, 1, 1, 2, 4235.970036), -- Orichalcum
(22522, 6859, 1, 1, 2, 1498.871012), -- Recipe: Sealed Imperial Crusader Boots (60%)
(22522, 1345, 60, 180, 2, 89426.6133), -- Shining Arrow
-- Soul Devourer
(22523, 5481, 1, 1, -1, 713202), -- Sealed Majestic Leather Armor Fabric
(22523, 1808, 1, 1, -1, 70640), -- Recipe: Soulshot (S-Grade)
(22523, 5487, 1, 1, -1, 715723), -- Sealed Robe of Nightmare Fabric
(22523, 57, 106409, 217956, 0, 700000), -- Adena
(22523, 5311, 1, 1, 1, 444.660921), -- Sealed Armor of Nightmare
(22523, 5522, 1, 1, 1, 66663.839079), -- Sealed Armor of Nightmare Pattern
(22523, 5316, 1, 1, 1, 444.660921), -- Sealed Majestic Plate Armor
(22523, 5523, 1, 1, 1, 66663.839079), -- Sealed Majestic Plate Armor Pattern
(22523, 1895, 12, 36, 2, 186418.958772), -- Metallic Fiber
(22523, 4040, 2, 6, 2, 62636.650598), -- Mold Lubricant
(22523, 9628, 1, 1, 2, 122817.236066), -- Leonard
(22523, 9630, 1, 1, 2, 82416.77238), -- Orichalcum
(22523, 6861, 1, 1, 2, 27764.382184), -- Recipe: Sealed Imperial Crusader Shield (60%)
-- Emissary of Death
(22524, 6901, 1, 1, -1, 10896), -- Recipe: Shining Arrow (100%)
(22524, 6688, 1, 1, -1, 23552), -- Forgotten Blade Edge
(22524, 960, 1, 1, -1, 4359), -- Scroll: Enchant Armor (S-Grade)
(22524, 57, 6376, 12790, 0, 700000), -- Adena
(22524, 5326, 1, 1, 1, 40.646606), -- Sealed Robe of Nightmare
(22524, 5487, 1, 1, 1, 6042.353394), -- Sealed Robe of Nightmare Fabric
(22524, 5329, 1, 1, 1, 40.646606), -- Sealed Majestic Robe
(22524, 5488, 1, 1, 1, 6042.353394), -- Sealed Majestic Robe Fabric
(22524, 1895, 1, 1, 2, 255604.98334), -- Metallic Fiber
(22524, 4040, 1, 1, 2, 17892.317975), -- Mold Lubricant
(22524, 9628, 1, 1, 2, 7016.51965), -- Leonard
(22524, 9630, 1, 1, 2, 4708.667145), -- Orichalcum
(22524, 6863, 1, 1, 2, 1110.531065), -- Recipe: Sealed Imperial Crusader Helmet (60%)
(22524, 1345, 60, 180, 2, 99401.980825), -- Shining Arrow
-- Emissary of Death
(22525, 1894, 1, 1, -1, 391868), -- Crafted Leather
(22525, 6689, 1, 1, -1, 23685), -- Basalt Battlehammer Head
(22525, 57, 6545, 13102, 0, 700000), -- Adena
(22525, 6326, 1, 1, 1, 91.785344), -- Sealed Majestic Necklace
(22525, 6344, 1, 1, 1, 13440.236208), -- Sealed Majestic Necklace Beads
(22525, 6327, 1, 1, 1, 122.401944), -- Sealed Majestic Earring
(22525, 6342, 1, 1, 1, 20768.561128), -- Sealed Majestic Earring Gemstone
(22525, 6328, 1, 1, 1, 183.570688), -- Sealed Majestic Ring
(22525, 6346, 1, 1, 1, 29849.444688), -- Sealed Majestic Ring Gemstone
(22525, 1895, 1, 1, 2, 314376.772984), -- Metallic Fiber
(22525, 4040, 1, 1, 2, 22006.416256), -- Mold Lubricant
(22525, 9628, 1, 1, 2, 8629.974046), -- Leonard
(22525, 9630, 1, 1, 2, 5791.014288), -- Orichalcum
(22525, 6865, 1, 1, 2, 421.822426), -- Recipe: Sealed Draconic Leather Armor (60%)
-- Emissary of Death
(22526, 6847, 1, 1, -1, 20177), -- Recipe: Sealed Tateossian Earring (70%)
(22526, 6690, 1, 1, -1, 24251), -- Imperial Staff Head
(22526, 6849, 1, 1, -1, 30225), -- Recipe: Sealed Tateossian Ring(70%)
(22526, 57, 6553, 13144, 0, 700000), -- Adena
(22526, 5313, 1, 1, 1, 101.778174), -- Sealed Gauntlets of Nightmare
(22526, 5514, 1, 1, 1, 11645.471826), -- Sealed Gauntlets of Nightmare Design
(22526, 5314, 1, 1, 1, 101.778174), -- Sealed Boots of Nightmare
(22526, 5502, 1, 1, 1, 11645.471826), -- Sealed Boots of Nightmare Lining
(22526, 5318, 1, 1, 1, 101.778174), -- Sealed Majestic Gauntlets
(22526, 5515, 1, 1, 1, 11645.471826), -- Sealed Majestic Gauntlets Design
(22526, 5319, 1, 1, 1, 101.778174), -- Sealed Majestic Boots
(22526, 5503, 1, 1, 1, 11645.471826), -- Sealed Majestic Boots Lining
(22526, 1895, 1, 1, 2, 262685.371781), -- Metallic Fiber
(22526, 4040, 1, 1, 2, 18387.829138), -- Mold Lubricant
(22526, 9628, 1, 1, 2, 7210.944524), -- Leonard
(22526, 9630, 1, 1, 2, 4838.923299), -- Orichalcum
(22526, 6867, 1, 1, 2, 1712.222183), -- Recipe: Sealed Draconic Leather Gloves (60%)
(22526, 1345, 60, 180, 2, 102155.709075), -- Shining Arrow
-- Emissary of Death
(22527, 6691, 1, 1, -1, 24809), -- Angel Slayer Blade
(22527, 959, 1, 1, -1, 459), -- Scroll: Enchant Weapon (S-Grade)
(22527, 1894, 1, 1, -1, 402724), -- Crafted Leather
(22527, 57, 6726, 13465, 0, 700000), -- Adena
(22527, 5312, 1, 1, 1, 92.748864), -- Sealed Helm of Nightmare
(22527, 5527, 1, 1, 1, 11266.125733), -- Sealed Helm of Nightmare Design
(22527, 5315, 1, 1, 1, 132.546153), -- Sealed Shield of Nightmare
(22527, 5495, 1, 1, 1, 14308.704653), -- Sealed Shield of Nightmare Fragment
(22527, 5317, 1, 1, 1, 92.748864), -- Sealed Majestic Circlet
(22527, 5528, 1, 1, 1, 11266.125733), -- Sealed Majestic Circlet Design
(22527, 1879, 1, 1, 2, 157055.719886), -- Cokes
(22527, 1885, 1, 1, 2, 78527.73305), -- High-Grade Suede
(22527, 9628, 1, 1, 2, 7390.755892), -- Leonard
(22527, 9630, 1, 1, 2, 4959.739798), -- Orichalcum
(22527, 9629, 1, 1, 2, 4097.121184), -- Adamantine
(22527, 6869, 1, 1, 2, 1754.93019), -- Recipe: Sealed Draconic Leather Boots (60%)
-- Cursed Prefect
(22528, 1894, 1, 1, -1, 495837), -- Crafted Leather
(22528, 6693, 1, 1, -1, 31098), -- Dragon Hunter Axe Blade
(22528, 6851, 1, 1, -1, 19071), -- Recipe: Sealed Tateossian Necklace(70%)
(22528, 57, 8269, 16587, 0, 700000), -- Adena
(22528, 81, 1, 1, 1, 11.187852), -- Dragon Slayer
(22528, 5529, 1, 1, 1, 3181.781584), -- Dragon Slayer Edge
(22528, 151, 1, 1, 1, 11.187852), -- Sword of Miracles
(22528, 5546, 1, 1, 1, 3494.883168), -- Sword of Miracles Edge
(22528, 2500, 1, 1, 1, 11.187852), -- Dark Legion's Edge
(22528, 5545, 1, 1, 1, 3181.771692), -- Dark Legion's Edge Blade
(22528, 1879, 1, 1, 2, 165744.06928), -- Cokes
(22528, 1885, 1, 1, 2, 82872.03464), -- High-Grade Suede
(22528, 9628, 1, 1, 2, 7799.5876), -- Leonard
(22528, 9630, 1, 1, 2, 5233.844328), -- Orichalcum
(22528, 9629, 1, 1, 2, 4323.577688), -- Adamantine
(22528, 6871, 1, 1, 2, 1234.714376), -- Recipe: Sealed Draconic Leather Helmet (60%)
(22528, 1345, 60, 180, 2, 110496.172088), -- Shining Arrow
-- Cursed Prefect
(22529, 6694, 1, 1, -1, 31874), -- Saint Spear Blade
(22529, 6853, 1, 1, -1, 6752), -- Recipe: Sealed Imperial Crusader Breastplate (60%)
(22529, 6695, 1, 1, -1, 30717), -- Demon Splinter Blade
(22529, 57, 8488, 16992, 0, 700000), -- Adena
(22529, 164, 1, 1, 1, 8.599692), -- Elysian
(22529, 5533, 1, 1, 1, 2446.376766), -- Elysian Head
(22529, 213, 1, 1, 1, 8.599692), -- Branch of the Mother Tree
(22529, 5544, 1, 1, 1, 2443.961784), -- Branch of the Mother Tree Head
(22529, 7895, 1, 1, 1, 8.599692), -- Flaming Dragon Skull
(22529, 8342, 1, 1, 1, 2446.376766), -- Flaming Dragon Skull Piece
(22529, 7902, 1, 1, 1, 8.599692), -- Doom Crusher
(22529, 8349, 1, 1, 1, 2445.885916), -- Doom Crusher Head
(22529, 1879, 1, 1, 2, 198191.735732), -- Cokes
(22529, 1885, 1, 1, 2, 99095.867866), -- High-Grade Suede
(22529, 9628, 1, 1, 2, 9326.606217), -- Leonard
(22529, 9630, 1, 1, 2, 6258.823849), -- Orichalcum
(22529, 9629, 1, 1, 2, 5170.194267), -- Adamantine
(22529, 6873, 1, 1, 2, 455.772069), -- Recipe: Sealed Major Arcana Robe (60%)
-- Cursed Prefect
(22530, 960, 1, 1, -1, 4514), -- Scroll: Enchant Armor (S-Grade)
(22530, 1894, 1, 1, -1, 395922), -- Crafted Leather
(22530, 57, 6603, 13244, 0, 700000), -- Adena
(22530, 270, 1, 1, 1, 26.79795), -- Dragon Grinder
(22530, 5538, 1, 1, 1, 7623.20205), -- Dragon Grinder Edge
(22530, 1879, 1, 1, 2, 132345.597244), -- Cokes
(22530, 1885, 1, 1, 2, 66172.798622), -- High-Grade Suede
(22530, 9628, 1, 1, 2, 6227.836686), -- Leonard
(22530, 9630, 1, 1, 2, 4179.168417), -- Orichalcum
(22530, 9629, 1, 1, 2, 3452.731035), -- Adamantine
(22530, 6875, 1, 1, 2, 1478.71641), -- Recipe: Sealed Major Arcana Gloves (60%)
(22530, 1345, 20, 60, 2, 264692.151586), -- Shining Arrow
-- Cursed Prefect
(22531, 6696, 1, 1, -1, 25395), -- Heavens Divider Edge
(22531, 6855, 1, 1, -1, 8605), -- Recipe: Sealed Imperial Crusader Gaiters (60%)
(22531, 6697, 1, 1, -1, 24527), -- Arcana Mace Head
(22531, 57, 6777, 13568, 0, 700000), -- Adena
(22531, 289, 1, 1, 1, 27.468), -- Soul Bow
(22531, 5534, 1, 1, 1, 7820.532), -- Soul Bow Stave
(22531, 1879, 1, 1, 2, 158254.434273), -- Cokes
(22531, 1885, 1, 1, 2, 79127.089275), -- High-Grade Suede
(22531, 9628, 1, 1, 2, 7447.165206), -- Leonard
(22531, 9630, 1, 1, 2, 4997.594589), -- Orichalcum
(22531, 9629, 1, 1, 2, 4128.392112), -- Adamantine
(22531, 6877, 1, 1, 2, 1768.324545), -- Recipe: Sealed Major Arcana Boots (60%)
-- Law Scholar of Conclusions
(22532, 6857, 1, 1, -1, 19862), -- Recipe: Sealed Imperial Crusader Gauntlets (60%)
(22532, 6698, 1, 1, -1, 209509), -- Sealed Tateossian Earring Part
(22532, 959, 1, 1, -1, 427), -- Scroll: Enchant Weapon (S-Grade)
(22532, 57, 6241, 12519, 0, 700000), -- Adena
(22532, 236, 1, 1, 1, 25.333468), -- Soul Separator
(22532, 5537, 1, 1, 1, 7208.666532), -- Soul Separator Head
(22532, 1879, 1, 1, 2, 125101.024012), -- Cokes
(22532, 1885, 1, 1, 2, 62550.512006), -- High-Grade Suede
(22532, 9628, 1, 1, 2, 5887.170808), -- Leonard
(22532, 9630, 1, 1, 2, 3950.387412), -- Orichalcum
(22532, 9629, 1, 1, 2, 3263.520692), -- Adamantine
(22532, 6879, 1, 1, 2, 931.788932), -- Recipe: Sealed Major Arcana Circlet (60%)
(22532, 1345, 20, 60, 2, 250201.596138), -- Shining Arrow
-- Law Scholar of Conclusions
(22533, 1894, 1, 1, -1, 383585), -- Crafted Leather
(22533, 6699, 1, 1, -1, 238278), -- Sealed Tateossian Ring Gem
(22533, 57, 6406, 12825, 0, 700000), -- Adena
(22533, 5320, 1, 1, 1, 40.780432), -- Sealed Leather Armor of Nightmare
(22533, 5480, 1, 1, 1, 6042.219568), -- Sealed Leather Armor of Nightmare Fabric
(22533, 5323, 1, 1, 1, 40.780432), -- Sealed Majestic Leather Armor
(22533, 5481, 1, 1, 1, 6042.219568), -- Sealed Majestic Leather Armor Fabric
(22533, 1879, 1, 1, 2, 149591.93229), -- Cokes
(22533, 1885, 1, 1, 2, 74795.966145), -- High-Grade Suede
(22533, 9628, 1, 1, 2, 7039.634559), -- Leonard
(22533, 9630, 1, 1, 2, 4723.943037), -- Orichalcum
(22533, 9629, 1, 1, 2, 3902.503308), -- Adamantine
(22533, 6847, 1, 1, 2, 1617.020661), -- Recipe: Sealed Tateossian Earring (70%)
-- Law Scholar of Conclusions
(22534, 6859, 1, 1, -1, 18943), -- Recipe: Sealed Imperial Crusader Boots (60%)
(22534, 6700, 1, 1, -1, 121781), -- Sealed Tateossian Necklace Chain
(22534, 6861, 1, 1, -1, 18036), -- Recipe: Sealed Imperial Crusader Shield (60%)
(22534, 57, 5952, 11940, 0, 700000), -- Adena
(22534, 5311, 1, 1, 1, 28.45867), -- Sealed Armor of Nightmare
(22534, 5522, 1, 1, 1, 4266.54133), -- Sealed Armor of Nightmare Pattern
(22534, 5316, 1, 1, 1, 28.45867), -- Sealed Majestic Plate Armor
(22534, 5523, 1, 1, 1, 4266.54133), -- Sealed Majestic Plate Armor Pattern
(22534, 1879, 1, 1, 2, 119309.49773), -- Cokes
(22534, 1885, 1, 1, 2, 59654.53286), -- High-Grade Suede
(22534, 9628, 1, 1, 2, 5614.40196), -- Leonard
(22534, 9630, 1, 1, 2, 3767.55921), -- Orichalcum
(22534, 9629, 1, 1, 2, 3112.63205), -- Adamantine
(22534, 6849, 1, 1, 2, 1931.94872), -- Recipe: Sealed Tateossian Ring(70%)
(22534, 1345, 20, 60, 2, 238619.42747), -- Shining Arrow
-- Law Scholar of Conclusions
(22535, 6701, 1, 1, -1, 55510), -- Sealed Imperial Crusader Breastplate Part
(22535, 960, 1, 1, -1, 4170), -- Scroll: Enchant Armor (S-Grade)
(22535, 1894, 1, 1, -1, 365827), -- Crafted Leather
(22535, 57, 6110, 12231, 0, 700000), -- Adena
(22535, 5326, 1, 1, 1, 38.892581), -- Sealed Robe of Nightmare
(22535, 5487, 1, 1, 1, 5781.607419), -- Sealed Robe of Nightmare Fabric
(22535, 5329, 1, 1, 1, 38.892581), -- Sealed Majestic Robe
(22535, 5488, 1, 1, 1, 5781.607419), -- Sealed Majestic Robe Fabric
(22535, 1879, 1, 1, 2, 142666.652976), -- Cokes
(22535, 1885, 1, 1, 2, 71333.441536), -- High-Grade Suede
(22535, 9628, 1, 1, 2, 6713.741088), -- Leonard
(22535, 9630, 1, 1, 2, 4505.27968), -- Orichalcum
(22535, 9629, 1, 1, 2, 3721.8028), -- Adamantine
(22535, 6851, 1, 1, 2, 1155.08192), -- Recipe: Sealed Tateossian Necklace(70%)
-- Royal Guard Captain
(22536, 1894, 1, 3, -1, 850740), -- Crafted Leather
(22536, 6702, 1, 1, -1, 332343), -- Sealed Imperial Crusader Gaiters Pattern
(22536, 6863, 1, 1, -1, 60201), -- Recipe: Sealed Imperial Crusader Helmet (60%)
(22536, 57, 28417, 56889, 0, 700000), -- Adena
(22536, 6326, 1, 1, 1, 398.52776), -- Sealed Majestic Necklace
(22536, 6344, 1, 1, 1, 58356.89007), -- Sealed Majestic Necklace Beads
(22536, 6327, 1, 1, 1, 531.463635), -- Sealed Majestic Earring
(22536, 6342, 1, 1, 1, 90176.141245), -- Sealed Majestic Earring Gemstone
(22536, 6328, 1, 1, 1, 797.05552), -- Sealed Majestic Ring
(22536, 6346, 1, 1, 1, 129604.92177), -- Sealed Majestic Ring Gemstone
(22536, 1879, 2, 6, 2, 142188.904481), -- Cokes
(22536, 1885, 3, 9, 2, 47396.192636), -- High-Grade Suede
(22536, 9628, 1, 1, 2, 26764.943361), -- Leonard
(22536, 9630, 1, 1, 2, 17960.861854), -- Orichalcum
(22536, 9629, 1, 1, 2, 14837.191109), -- Adamantine
(22536, 6853, 1, 1, 2, 1591.063656), -- Recipe: Sealed Imperial Crusader Breastplate (60%)
(22536, 1345, 300, 900, 2, 75833.842903), -- Shining Arrow
-- Dragon Steed Troop Grand Magician
(22537, 6703, 1, 1, -1, 146325), -- Sealed Imperial Crusader Gauntlets Design
(22537, 6865, 1, 1, -1, 3938), -- Recipe: Sealed Draconic Leather Armor (60%)
(22537, 6704, 1, 1, -1, 146325), -- Sealed Imperial Crusader Boots Design
(22537, 57, 6023, 12057, 0, 700000), -- Adena
(22537, 5313, 1, 1, 1, 93.406584), -- Sealed Gauntlets of Nightmare
(22537, 5514, 1, 1, 1, 10687.593416), -- Sealed Gauntlets of Nightmare Design
(22537, 5314, 1, 1, 1, 93.406584), -- Sealed Boots of Nightmare
(22537, 5502, 1, 1, 1, 10687.593416), -- Sealed Boots of Nightmare Lining
(22537, 5318, 1, 1, 1, 93.406584), -- Sealed Majestic Gauntlets
(22537, 5515, 1, 1, 1, 10687.593416), -- Sealed Majestic Gauntlets Design
(22537, 5319, 1, 1, 1, 93.406584), -- Sealed Majestic Boots
(22537, 5503, 1, 1, 1, 10687.593416), -- Sealed Majestic Boots Lining
(22537, 1879, 1, 1, 2, 140628.592438), -- Cokes
(22537, 1885, 1, 1, 2, 70314.409368), -- High-Grade Suede
(22537, 9628, 1, 1, 2, 6617.858712), -- Leonard
(22537, 9630, 1, 1, 2, 4440.871952), -- Orichalcum
(22537, 9629, 1, 1, 2, 3668.516878), -- Adamantine
(22537, 6855, 1, 1, 2, 627.750652), -- Recipe: Sealed Imperial Crusader Gaiters (60%)
-- Dragon Steed Troop Commander
(22538, 959, 1, 1, -1, 557), -- Scroll: Enchant Weapon (S-Grade)
(22538, 1894, 1, 1, -1, 488959), -- Crafted Leather
(22538, 57, 8154, 16357, 0, 700000), -- Adena
(22538, 5312, 1, 1, 1, 112.609536), -- Sealed Helm of Nightmare
(22538, 5527, 1, 1, 1, 13678.584692), -- Sealed Helm of Nightmare Design
(22538, 5315, 1, 1, 1, 160.928772), -- Sealed Shield of Nightmare
(22538, 5495, 1, 1, 1, 17372.682772), -- Sealed Shield of Nightmare Fragment
(22538, 5317, 1, 1, 1, 112.609536), -- Sealed Majestic Circlet
(22538, 5528, 1, 1, 1, 13678.584692), -- Sealed Majestic Circlet Design
(22538, 1879, 1, 1, 2, 163445.211696), -- Cokes
(22538, 1885, 1, 1, 2, 81722.605848), -- High-Grade Suede
(22538, 9628, 1, 1, 2, 7691.666658), -- Leonard
(22538, 9630, 1, 1, 2, 5161.47879), -- Orichalcum
(22538, 9629, 1, 1, 2, 4263.862746), -- Adamantine
(22538, 6857, 1, 1, 2, 1826.19723), -- Recipe: Sealed Imperial Crusader Gauntlets (60%)
(22538, 1345, 60, 180, 2, 108962.977032), -- Shining Arrow
-- Dragon Steed Troops No 1 Battalion Commander
(22539, 5480, 1, 1, -1, 64168), -- Sealed Leather Armor of Nightmare Fabric
(22539, 1808, 1, 1, -1, 6356), -- Recipe: Soulshot (S-Grade)
(22539, 5481, 1, 1, -1, 64168), -- Sealed Majestic Leather Armor Fabric
(22539, 57, 9574, 19610, 0, 700000), -- Adena
(22539, 81, 1, 1, 1, 11.32131), -- Dragon Slayer
(22539, 5529, 1, 1, 1, 3219.73652), -- Dragon Slayer Edge
(22539, 151, 1, 1, 1, 11.32131), -- Sword of Miracles
(22539, 5546, 1, 1, 1, 3536.57304), -- Sword of Miracles Edge
(22539, 2500, 1, 1, 1, 11.32131), -- Dark Legion's Edge
(22539, 5545, 1, 1, 1, 3219.72651), -- Dark Legion's Edge Blade
(22539, 1879, 1, 1, 2, 167723.73536), -- Cokes
(22539, 1885, 1, 1, 2, 83861.86768), -- High-Grade Suede
(22539, 9628, 1, 1, 2, 7893.01228), -- Leonard
(22539, 9630, 1, 1, 2, 5296.5914), -- Orichalcum
(22539, 9629, 1, 1, 2, 4375.47836), -- Adamantine
(22539, 6859, 1, 1, 2, 1874.0018), -- Recipe: Sealed Imperial Crusader Boots (60%)
(22539, 1345, 60, 180, 2, 111815.31312), -- Shining Arrow
-- White Dragon Leader
(22540, 3036, 1, 1, -1, 5346), -- Recipe: Spiritshot S
(22540, 5487, 1, 1, -1, 54170), -- Sealed Robe of Nightmare Fabric
(22540, 1894, 1, 1, -1, 422090), -- Crafted Leather
(22540, 57, 8055, 16494, 0, 700000), -- Adena
(22540, 164, 1, 1, 1, 7.142904), -- Elysian
(22540, 5533, 1, 1, 1, 2031.960492), -- Elysian Head
(22540, 213, 1, 1, 1, 7.142904), -- Branch of the Mother Tree
(22540, 5544, 1, 1, 1, 2029.954608), -- Branch of the Mother Tree Head
(22540, 7895, 1, 1, 1, 7.142904), -- Flaming Dragon Skull
(22540, 8342, 1, 1, 1, 2031.960492), -- Flaming Dragon Skull Piece
(22540, 7902, 1, 1, 1, 7.142904), -- Doom Crusher
(22540, 8349, 1, 1, 1, 2031.552792), -- Doom Crusher Head
(22540, 1879, 1, 1, 2, 164608.228512), -- Cokes
(22540, 1885, 1, 1, 2, 82304.114256), -- High-Grade Suede
(22540, 9628, 1, 1, 2, 7746.257064), -- Leonard
(22540, 9630, 1, 1, 2, 5198.118198), -- Orichalcum
(22540, 9629, 1, 1, 2, 4294.051398), -- Adamantine
(22540, 6861, 1, 1, 2, 1751.230572), -- Recipe: Sealed Imperial Crusader Shield (60%)
-- Dragon Steed Troop Infantry
(22541, 1894, 1, 1, -1, 433203), -- Crafted Leather
(22541, 5488, 1, 1, -1, 55596), -- Sealed Majestic Robe Fabric
(22541, 3957, 1, 1, -1, 5487), -- Recipe: Blessed Spiritshot S
(22541, 57, 8283, 16910, 0, 700000), -- Adena
(22541, 270, 1, 1, 1, 29.323613), -- Dragon Grinder
(22541, 5538, 1, 1, 1, 8341.676387), -- Dragon Grinder Edge
(22541, 1879, 1, 1, 2, 144807.52826), -- Cokes
(22541, 1885, 1, 1, 2, 72403.76413), -- High-Grade Suede
(22541, 9628, 1, 1, 2, 6814.35545), -- Leonard
(22541, 9630, 1, 1, 2, 4572.713001), -- Orichalcum
(22541, 9629, 1, 1, 2, 3777.429871), -- Adamantine
(22541, 6863, 1, 1, 2, 1078.747117), -- Recipe: Sealed Imperial Crusader Helmet (60%)
(22541, 1345, 60, 180, 2, 96538.462171), -- Shining Arrow
-- Dragon Steed Troop Magic Leader
(22542, 5495, 1, 1, -1, 444619), -- Sealed Shield of Nightmare Fragment
(22542, 5157, 1, 1, -1, 13014), -- Recipe: Soulshot (S) Compressed Package (100%)
(22542, 5502, 1, 1, -1, 494518), -- Sealed Boots of Nightmare Lining
(22542, 57, 19603, 40152, 0, 700000), -- Adena
(22542, 289, 1, 1, 1, 69.5415), -- Soul Bow
(22542, 5534, 1, 1, 1, 19799.4585), -- Soul Bow Stave
(22542, 1879, 1, 3, 2, 200331.066804), -- Cokes
(22542, 1885, 1, 1, 2, 200331.066804), -- High-Grade Suede
(22542, 9628, 1, 1, 2, 18854.526878), -- Leonard
(22542, 9630, 1, 1, 2, 12652.479092), -- Orichalcum
(22542, 9629, 1, 1, 2, 10452.06723), -- Adamantine
(22542, 6865, 1, 1, 2, 920.793192), -- Recipe: Sealed Draconic Leather Armor (60%)
-- Dragon Steed Troop Magician
(22543, 1894, 1, 1, -1, 406392), -- Crafted Leather
(22543, 5503, 1, 1, -1, 195612), -- Sealed Majestic Boots Lining
(22543, 57, 7755, 15880, 0, 700000), -- Adena
(22543, 236, 1, 1, 1, 27.50821), -- Soul Separator
(22543, 5537, 1, 1, 1, 7827.49179), -- Soul Separator Head
(22543, 1879, 1, 1, 2, 135845.413424), -- Cokes
(22543, 1885, 1, 1, 2, 67922.706712), -- High-Grade Suede
(22543, 9628, 1, 1, 2, 6392.528856), -- Leonard
(22543, 9630, 1, 1, 2, 4289.684532), -- Orichalcum
(22543, 9629, 1, 1, 2, 3544.03686), -- Adamantine
(22543, 6867, 1, 1, 2, 1517.82036), -- Recipe: Sealed Draconic Leather Gloves (60%)
(22543, 1345, 20, 60, 2, 271691.809256), -- Shining Arrow
-- Dragon Steed Troop Magic Soldier
(22544, 5162, 1, 1, -1, 5568), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22544, 5514, 1, 1, -1, 211591), -- Sealed Gauntlets of Nightmare Design
(22544, 5167, 1, 1, -1, 5568), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22544, 57, 8405, 17160, 0, 700000), -- Adena
(22544, 5320, 1, 1, 1, 46.733584), -- Sealed Leather Armor of Nightmare
(22544, 5480, 1, 1, 1, 6924.266416), -- Sealed Leather Armor of Nightmare Fabric
(22544, 5323, 1, 1, 1, 46.733584), -- Sealed Majestic Leather Armor
(22544, 5481, 1, 1, 1, 6924.266416), -- Sealed Majestic Leather Armor Fabric
(22544, 1879, 1, 1, 2, 171432.866318), -- Cokes
(22544, 1885, 1, 1, 2, 85716.29465), -- High-Grade Suede
(22544, 9628, 1, 1, 2, 8067.318196), -- Leonard
(22544, 9630, 1, 1, 2, 5413.762774), -- Orichalcum
(22544, 9629, 1, 1, 2, 4472.178592), -- Adamantine
(22544, 6869, 1, 1, 2, 1915.57947), -- Recipe: Sealed Draconic Leather Boots (60%)
-- Wife of the Dragon of Darkness
(22545, 6688, 1, 1, -1, 65807), -- Forgotten Blade Edge
(22545, 960, 1, 1, -1, 12178), -- Scroll: Enchant Armor (S-Grade)
(22545, 1894, 1, 3, -1, 534125), -- Crafted Leather
(22545, 57, 17815, 35735, 0, 700000), -- Adena
(22545, 5311, 1, 1, 1, 85.173917), -- Sealed Armor of Nightmare
(22545, 5522, 1, 1, 1, 12769.326083), -- Sealed Armor of Nightmare Pattern
(22545, 5316, 1, 1, 1, 85.173917), -- Sealed Majestic Plate Armor
(22545, 5523, 1, 1, 1, 12769.326083), -- Sealed Majestic Plate Armor Pattern
(22545, 1879, 1, 3, 2, 208300.16724), -- Cokes
(22545, 1885, 1, 1, 2, 208300.16724), -- High-Grade Suede
(22545, 9628, 1, 1, 2, 19604.503584), -- Leonard
(22545, 9630, 1, 1, 2, 13155.848808), -- Orichalcum
(22545, 9629, 1, 1, 2, 10867.915392), -- Adamantine
(22545, 6871, 1, 1, 2, 3103.397736), -- Recipe: Sealed Draconic Leather Helmet (60%)
-- Warrior of Light
(22546, 1894, 1, 1, -1, 428630), -- Crafted Leather
(22546, 5480, 1, 1, -1, 54816), -- Sealed Leather Armor of Nightmare Fabric
(22546, 5272, 1, 1, -1, 5429), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22546, 57, 8197, 16729, 0, 700000), -- Adena
(22546, 5326, 1, 1, 1, 45.567899), -- Sealed Robe of Nightmare
(22546, 5487, 1, 1, 1, 6773.932101), -- Sealed Robe of Nightmare Fabric
(22546, 5329, 1, 1, 1, 45.567899), -- Sealed Majestic Robe
(22546, 5488, 1, 1, 1, 6773.932101), -- Sealed Majestic Robe Fabric
(22546, 1879, 1, 1, 2, 143279.086408), -- Cokes
(22546, 1885, 1, 1, 2, 71639.543204), -- High-Grade Suede
(22546, 9628, 1, 1, 2, 6742.503084), -- Leonard
(22546, 9630, 1, 1, 2, 4524.647308), -- Orichalcum
(22546, 9629, 1, 1, 2, 3737.582156), -- Adamantine
(22546, 6873, 1, 1, 2, 329.355492), -- Recipe: Sealed Major Arcana Robe (60%)
(22546, 1345, 60, 180, 2, 95519.282348), -- Shining Arrow
-- Dragon Steed Troop Healer
(22547, 5481, 1, 1, -1, 39387), -- Sealed Majestic Leather Armor Fabric
(22547, 5277, 1, 1, -1, 3901), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22547, 5487, 1, 1, -1, 39526), -- Sealed Robe of Nightmare Fabric
(22547, 57, 5890, 12020, 0, 700000), -- Adena
(22547, 6326, 1, 1, 1, 72.138416), -- Sealed Majestic Necklace
(22547, 6344, 1, 1, 1, 10563.313362), -- Sealed Majestic Necklace Beads
(22547, 6327, 1, 1, 1, 96.201441), -- Sealed Majestic Earring
(22547, 6342, 1, 1, 1, 16322.988367), -- Sealed Majestic Earring Gemstone
(22547, 6328, 1, 1, 1, 144.276832), -- Sealed Majestic Ring
(22547, 6346, 1, 1, 1, 23460.081582), -- Sealed Majestic Ring Gemstone
(22547, 1879, 1, 1, 2, 120110.315186), -- Cokes
(22547, 1885, 1, 1, 2, 60055.06055), -- High-Grade Suede
(22547, 9628, 1, 1, 2, 5652.172492), -- Leonard
(22547, 9630, 1, 1, 2, 3793.022698), -- Orichalcum
(22547, 9629, 1, 1, 2, 3133.324384), -- Adamantine
(22547, 6875, 1, 1, 2, 1342.10469), -- Recipe: Sealed Major Arcana Gloves (60%)
-- Dragon Steed Troop Javelin Thrower
(22548, 1894, 1, 1, -1, 496499), -- Crafted Leather
(22548, 5488, 1, 1, -1, 63720), -- Sealed Majestic Robe Fabric
(22548, 57, 9493, 19381, 0, 700000), -- Adena
(22548, 5313, 1, 1, 1, 128.608416), -- Sealed Gauntlets of Nightmare
(22548, 5514, 1, 1, 1, 14715.391584), -- Sealed Gauntlets of Nightmare Design
(22548, 5314, 1, 1, 1, 128.608416), -- Sealed Boots of Nightmare
(22548, 5502, 1, 1, 1, 14715.391584), -- Sealed Boots of Nightmare Lining
(22548, 5318, 1, 1, 1, 128.608416), -- Sealed Majestic Gauntlets
(22548, 5515, 1, 1, 1, 14715.391584), -- Sealed Majestic Gauntlets Design
(22548, 5319, 1, 1, 1, 128.608416), -- Sealed Majestic Boots
(22548, 5503, 1, 1, 1, 14715.391584), -- Sealed Majestic Boots Lining
(22548, 1879, 1, 1, 2, 165965.624008), -- Cokes
(22548, 1885, 1, 1, 2, 82982.812004), -- High-Grade Suede
(22548, 9628, 1, 1, 2, 7810.276259), -- Leonard
(22548, 9630, 1, 1, 2, 5241.071545), -- Orichalcum
(22548, 9629, 1, 1, 2, 4329.613783), -- Adamantine
(22548, 6877, 1, 1, 2, 1854.358165), -- Recipe: Sealed Major Arcana Boots (60%)
(22548, 1345, 60, 180, 2, 110643.244236), -- Shining Arrow
-- Dragon Steed Troop Javelin Thrower
(22549, 5282, 1, 1, -1, 6289), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22549, 5495, 1, 1, -1, 214869), -- Sealed Shield of Nightmare Fragment
(22549, 1808, 1, 1, -1, 6289), -- Recipe: Soulshot (S-Grade)
(22549, 57, 9493, 19381, 0, 700000), -- Adena
(22549, 5312, 1, 1, 1, 114.346752), -- Sealed Helm of Nightmare
(22549, 5527, 1, 1, 1, 13889.602844), -- Sealed Helm of Nightmare Design
(22549, 5315, 1, 1, 1, 163.411404), -- Sealed Shield of Nightmare
(22549, 5495, 1, 1, 1, 17640.689404), -- Sealed Shield of Nightmare Fragment
(22549, 5317, 1, 1, 1, 114.346752), -- Sealed Majestic Circlet
(22549, 5528, 1, 1, 1, 13889.602844), -- Sealed Majestic Circlet Design
(22549, 1879, 1, 1, 2, 193626.296679), -- Cokes
(22549, 1885, 1, 1, 2, 96812.99226), -- High-Grade Suede
(22549, 9628, 1, 1, 2, 9111.92121), -- Leonard
(22549, 9630, 1, 1, 2, 6114.570492), -- Orichalcum
(22549, 9629, 1, 1, 2, 5051.044779), -- Adamantine
(22549, 6879, 1, 1, 2, 1442.17458), -- Recipe: Sealed Major Arcana Circlet (60%)
-- Savage Warrior
(22550, 5502, 1, 1, -1, 276561), -- Sealed Boots of Nightmare Lining
(22550, 1894, 1, 1, -1, 574568), -- Crafted Leather
(22550, 57, 8218, 16827, 0, 700000), -- Adena
(22550, 80, 1, 1, 1, 14.296071), -- Tallum Blade
(22550, 5548, 1, 1, 1, 3428.05931), -- Tallum Blade Edge
(22550, 150, 1, 1, 1, 14.296071), -- Elemental Sword
(22550, 5547, 1, 1, 1, 3428.05931), -- Elemental Sword Edge
(22550, 7884, 1, 1, 1, 14.296071), -- Infernal Master
(22550, 8331, 1, 1, 1, 3437.993167), -- Infernal Master Blade
(22550, 1894, 1, 1, 2, 42429.728194), -- Crafted Leather
(22550, 4039, 1, 1, 2, 40308.282014), -- Mold Glue
(22550, 4041, 1, 1, 2, 10515.238986), -- Mold Hardener
(22550, 4044, 1, 1, 2, 40308.282014), -- Thons
(22550, 1808, 1, 1, 2, 537.468792), -- Recipe: Soulshot (S-Grade)
-- Priest of Darkness
(22551, 5503, 1, 1, -1, 264734), -- Sealed Majestic Boots Lining
(22551, 3036, 1, 1, -1, 6967), -- Recipe: Spiritshot S
(22551, 5514, 1, 1, -1, 264734), -- Sealed Gauntlets of Nightmare Design
(22551, 57, 7866, 16108, 0, 700000), -- Adena
(22551, 212, 1, 1, 1, 10.262945), -- Dasparion's Staff
(22551, 5543, 1, 1, 1, 2463.018411), -- Dasparion's Staff Head
(22551, 2504, 1, 1, 1, 10.262945), -- Meteor Shower
(22551, 5532, 1, 1, 1, 2440.017629), -- Meteor Shower Head
(22551, 7894, 1, 1, 1, 10.262945), -- Spiritual Eye
(22551, 8341, 1, 1, 1, 2436.894551), -- Spiritual Eye Piece
(22551, 7899, 1, 1, 1, 10.262945), -- Destroyer Hammer
(22551, 8346, 1, 1, 1, 2440.017629), -- Hammer Piece of Destroyer
(22551, 1895, 1, 1, 2, 275602.33506), -- Metallic Fiber
(22551, 4040, 1, 1, 2, 19292.231064), -- Mold Lubricant
(22551, 4042, 1, 1, 2, 16076.708976), -- Enria
(22551, 4043, 1, 1, 2, 32153.417952), -- Asofe
(22551, 3036, 1, 1, 2, 428.646132), -- Recipe: Spiritshot S
(22551, 1345, 60, 180, 2, 107178.660816), -- Shining Arrow
-- Mutated Drake
(22552, 3957, 1, 1, -1, 7567), -- Recipe: Blessed Spiritshot S
(22552, 5515, 1, 1, -1, 287536), -- Sealed Majestic Gauntlets Design
(22552, 1894, 1, 1, -1, 597368), -- Crafted Leather
(22552, 57, 8566, 17478, 0, 700000), -- Adena
(22552, 269, 1, 1, 1, 44.587716), -- Blood Tornado
(22552, 5539, 1, 1, 1, 10599.412284), -- Blood Tornado Edge
(22552, 1894, 1, 1, 2, 44113.32452), -- Crafted Leather
(22552, 4039, 1, 1, 2, 41907.70012), -- Mold Glue
(22552, 4041, 1, 1, 2, 10932.47988), -- Mold Hardener
(22552, 4044, 1, 1, 2, 41907.70012), -- Thons
(22552, 3957, 1, 1, 2, 558.79536), -- Recipe: Blessed Spiritshot S
-- Soldiers of Bravery
(22569, 6688, 1, 1, -1, 535703), -- Forgotten Blade Edge
(22569, 960, 1, 1, -1, 99136), -- Scroll: Enchant Armor (S-Grade)
(22569, 1894, 1, 19, -1, 869615), -- Crafted Leather
(22569, 57, 145170, 290746, 0, 700000), -- Adena
(22569, 6326, 1, 1, 1, 2036.851152), -- Sealed Majestic Necklace
(22569, 6344, 1, 1, 1, 298258.517214), -- Sealed Majestic Necklace Beads
(22569, 6327, 1, 1, 1, 2716.278327), -- Sealed Majestic Earring
(22569, 6342, 1, 1, 1, 460884.775449), -- Sealed Majestic Earring Gemstone
(22569, 6328, 1, 1, 1, 4073.702304), -- Sealed Majestic Ring
(22569, 6346, 1, 1, 1, 662402.875554), -- Sealed Majestic Ring Gemstone
(22569, 1879, 15, 45, 2, 96895.97812), -- Cokes
(22569, 1885, 14, 42, 2, 51908.512872), -- High-Grade Suede
(22569, 9628, 4, 12, 2, 17099.135976), -- Leonard
(22569, 9630, 1, 1, 2, 91796.005744), -- Orichalcum
(22569, 9629, 1, 1, 2, 75831.654056), -- Adamantine
(22569, 6861, 1, 1, 2, 30924.183232), -- Recipe: Sealed Imperial Crusader Shield (60%)
(22569, 14052, 3, 9, 2, 72672.53), -- Noble Enhancement Stone
-- Royal Guard Captain
(22570, 1894, 1, 33, -1, 928942), -- Crafted Leather
(22570, 6689, 1, 3, -1, 477247), -- Basalt Battlehammer Head
(22570, 6901, 1, 1, -1, 450072), -- Recipe: Shining Arrow (100%)
(22570, 57, 263749, 528002, 0, 700000), -- Adena
(22570, 5313, 1, 1, 1, 4090.5993), -- Sealed Gauntlets of Nightmare
(22570, 5514, 1, 1, 1, 468046.9007), -- Sealed Gauntlets of Nightmare Design
(22570, 5314, 1, 1, 1, 4090.5993), -- Sealed Boots of Nightmare
(22570, 5502, 1, 1, 1, 468046.9007), -- Sealed Boots of Nightmare Lining
(22570, 5318, 1, 1, 1, 4090.5993), -- Sealed Majestic Gauntlets
(22570, 5515, 1, 1, 1, 468046.9007), -- Sealed Majestic Gauntlets Design
(22570, 5319, 1, 1, 1, 4090.5993), -- Sealed Majestic Boots
(22570, 5503, 1, 1, 1, 468046.9007), -- Sealed Majestic Boots Lining
(22570, 1879, 168, 504, 2, 13746.917866), -- Cokes
(22570, 1885, 30, 90, 2, 38491.055504), -- High-Grade Suede
(22570, 9628, 5, 15, 2, 19760.162411), -- Leonard
(22570, 9630, 6, 18, 2, 11220.136389), -- Orichalcum
(22570, 9629, 1, 1, 2, 120493.704782), -- Adamantine
(22570, 6863, 1, 1, 2, 34405.430312), -- Recipe: Sealed Imperial Crusader Helmet (60%)
(22570, 14052, 4, 12, 2, 86604.874884), -- Noble Enhancement Stone
(22570, 1345, 2700, 8100, 2, 68428.717852), -- Shining Arrow
-- Dragon Steed Troop Grand Magician
(22571, 6690, 1, 1, -1, 172097), -- Imperial Staff Head
(22571, 6847, 1, 1, -1, 143186), -- Recipe: Sealed Tateossian Earring (70%)
(22571, 6691, 1, 1, -1, 171769), -- Angel Slayer Blade
(22571, 57, 46570, 93228, 0, 700000), -- Adena
(22571, 5312, 1, 1, 1, 642.173376), -- Sealed Helm of Nightmare
(22571, 5527, 1, 1, 1, 78004.254547), -- Sealed Helm of Nightmare Design
(22571, 5315, 1, 1, 1, 917.721327), -- Sealed Shield of Nightmare
(22571, 5495, 1, 1, 1, 99070.422827), -- Sealed Shield of Nightmare Fragment
(22571, 5317, 1, 1, 1, 642.173376), -- Sealed Majestic Circlet
(22571, 5528, 1, 1, 1, 78004.254547), -- Sealed Majestic Circlet Design
(22571, 1879, 15, 45, 2, 31069.000036), -- Cokes
(22571, 1885, 2, 6, 2, 116509.137278), -- High-Grade Suede
(22571, 9628, 1, 1, 2, 43862.140471), -- Leonard
(22571, 9630, 1, 1, 2, 29433.708004), -- Orichalcum
(22571, 9629, 1, 1, 2, 24314.903258), -- Adamantine
(22571, 6865, 1, 1, 2, 2142.836505), -- Recipe: Sealed Draconic Leather Armor (60%)
(22571, 14052, 1, 1, 2, 139811.274448), -- Noble Enhancement Stone
-- Dragon Steed Troop Commander
(22572, 959, 1, 1, -1, 7406), -- Scroll: Enchant Weapon (S-Grade)
(22572, 1894, 1, 13, -1, 928078), -- Crafted Leather
(22572, 57, 108343, 217323, 0, 700000), -- Adena
(22572, 81, 1, 1, 1, 146.582124), -- Dragon Slayer
(22572, 5529, 1, 1, 1, 41687.385808), -- Dragon Slayer Edge
(22572, 151, 1, 1, 1, 146.582124), -- Sword of Miracles
(22572, 5546, 1, 1, 1, 45789.611616), -- Sword of Miracles Edge
(22572, 2500, 1, 1, 1, 146.582124), -- Dark Legion's Edge
(22572, 5545, 1, 1, 1, 41687.256204), -- Dark Legion's Edge Blade
(22572, 1879, 14, 42, 2, 67862.89656), -- Cokes
(22572, 1885, 30, 90, 2, 15834.675864), -- High-Grade Suede
(22572, 9628, 1, 1, 2, 89419.367685), -- Leonard
(22572, 9630, 1, 1, 2, 60005.12619), -- Orichalcum
(22572, 9629, 1, 1, 2, 49569.404109), -- Adamantine
(22572, 6867, 1, 1, 2, 21230.688039), -- Recipe: Sealed Draconic Leather Gloves (60%)
(22572, 14052, 4, 12, 2, 35628.020694), -- Noble Enhancement Stone
(22572, 1345, 2700, 8100, 2, 28150.820859), -- Shining Arrow
-- Dragon Steed Troops No 1 Battalion Commander
(22573, 5480, 1, 1, -1, 227357), -- Sealed Leather Armor of Nightmare Fabric
(22573, 1808, 1, 1, -1, 22519), -- Recipe: Soulshot (S-Grade)
(22573, 5481, 1, 1, -1, 227357), -- Sealed Majestic Leather Armor Fabric
(22573, 57, 33921, 69481, 0, 700000), -- Adena
(22573, 164, 1, 1, 1, 30.084468), -- Elysian
(22573, 5533, 1, 1, 1, 8558.206914), -- Elysian Head
(22573, 213, 1, 1, 1, 30.084468), -- Branch of the Mother Tree
(22573, 5544, 1, 1, 1, 8549.758536), -- Branch of the Mother Tree Head
(22573, 7895, 1, 1, 1, 30.084468), -- Flaming Dragon Skull
(22573, 8342, 1, 1, 1, 8558.206914), -- Flaming Dragon Skull Piece
(22573, 7902, 1, 1, 1, 30.084468), -- Doom Crusher
(22573, 8349, 1, 1, 1, 8556.489764), -- Doom Crusher Head
(22573, 1879, 3, 9, 2, 99045.316055), -- Cokes
(22573, 1885, 2, 6, 2, 74283.904205), -- High-Grade Suede
(22573, 9628, 1, 1, 2, 27965.849345), -- Leonard
(22573, 9630, 1, 1, 2, 18766.386765), -- Orichalcum
(22573, 9629, 1, 1, 2, 15502.638515), -- Adamantine
(22573, 6869, 1, 1, 2, 6639.822455), -- Recipe: Sealed Draconic Leather Boots (60%)
(22573, 14052, 1, 1, 2, 89141.08266), -- Noble Enhancement Stone
-- White Dragon Leader
(22574, 3036, 1, 1, -1, 18882), -- Recipe: Spiritshot S
(22574, 5487, 1, 1, -1, 191316), -- Sealed Robe of Nightmare Fabric
(22574, 1894, 1, 3, -1, 745360), -- Crafted Leather
(22574, 57, 28447, 58252, 0, 700000), -- Adena
(22574, 270, 1, 1, 1, 100.903915), -- Dragon Grinder
(22574, 5538, 1, 1, 1, 28704.096085), -- Dragon Grinder Edge
(22574, 1879, 2, 6, 2, 109004.366484), -- Cokes
(22574, 1885, 1, 1, 2, 218008.732968), -- High-Grade Suede
(22574, 9628, 1, 1, 2, 20518.357341), -- Leonard
(22574, 9630, 1, 1, 2, 13769.140848), -- Orichalcum
(22574, 9629, 1, 1, 2, 11374.225353), -- Adamantine
(22574, 6871, 1, 1, 2, 3247.994883), -- Recipe: Sealed Draconic Leather Helmet (60%)
(22574, 14052, 1, 1, 2, 65402.420106), -- Noble Enhancement Stone
(22574, 1345, 300, 900, 2, 58135.762017), -- Shining Arrow
-- Dragon Steed Troop Infantry
(22575, 1894, 1, 3, -1, 764201), -- Crafted Leather
(22575, 5488, 1, 1, -1, 196152), -- Sealed Majestic Robe Fabric
(22575, 3957, 1, 1, -1, 19360), -- Recipe: Blessed Spiritshot S
(22575, 57, 29224, 59662, 0, 700000), -- Adena
(22575, 289, 1, 1, 1, 103.4565), -- Soul Bow
(22575, 5534, 1, 1, 1, 29455.5435), -- Soul Bow Stave
(22575, 1879, 3, 9, 2, 85150.274504), -- Cokes
(22575, 1885, 1, 1, 2, 255450.351598), -- High-Grade Suede
(22575, 9628, 1, 1, 2, 24042.602558), -- Leonard
(22575, 9630, 1, 1, 2, 16133.795832), -- Orichalcum
(22575, 9629, 1, 1, 2, 13327.795188), -- Adamantine
(22575, 6873, 1, 1, 2, 1174.593946), -- Recipe: Sealed Major Arcana Robe (60%)
(22575, 14052, 1, 1, 2, 76634.586374), -- Noble Enhancement Stone
-- Dragon Steed Troop Magic Leader
(22576, 5495, 1, 1, -1, 289945), -- Sealed Shield of Nightmare Fragment
(22576, 5157, 1, 1, -1, 8486), -- Recipe: Soulshot (S) Compressed Package (100%)
(22576, 5502, 1, 1, -1, 322485), -- Sealed Boots of Nightmare Lining
(22576, 57, 12783, 26184, 0, 700000), -- Adena
(22576, 236, 1, 1, 1, 45.3509), -- Soul Separator
(22576, 5537, 1, 1, 1, 12904.6491), -- Soul Separator Head
(22576, 1879, 1, 1, 2, 195959.959965), -- Cokes
(22576, 1885, 1, 1, 2, 97979.74164), -- High-Grade Suede
(22576, 9628, 1, 1, 2, 9221.471325), -- Leonard
(22576, 9630, 1, 1, 2, 6188.32467), -- Orichalcum
(22576, 9629, 1, 1, 2, 5111.96994), -- Adamantine
(22576, 6875, 1, 1, 2, 2189.414205), -- Recipe: Sealed Major Arcana Gloves (60%)
(22576, 14052, 1, 1, 2, 29393.827155), -- Noble Enhancement Stone
(22576, 1345, 60, 180, 2, 130640.2911), -- Shining Arrow
-- Dragon Steed Troop Magician
(22577, 1894, 1, 1, -1, 673085), -- Crafted Leather
(22577, 5503, 1, 1, -1, 323981), -- Sealed Majestic Boots Lining
(22577, 57, 12844, 26302, 0, 700000), -- Adena
(22577, 5320, 1, 1, 1, 71.555144), -- Sealed Leather Armor of Nightmare
(22577, 5480, 1, 1, 1, 10601.944856), -- Sealed Leather Armor of Nightmare Fabric
(22577, 5323, 1, 1, 1, 71.555144), -- Sealed Majestic Leather Armor
(22577, 5481, 1, 1, 1, 10601.944856), -- Sealed Majestic Leather Armor Fabric
(22577, 1879, 1, 1, 2, 224993.12746), -- Cokes
(22577, 1885, 1, 1, 2, 112496.56373), -- High-Grade Suede
(22577, 9628, 1, 1, 2, 10588.047435), -- Leonard
(22577, 9630, 1, 1, 2, 7105.184145), -- Orichalcum
(22577, 9629, 1, 1, 2, 5869.534495), -- Adamantine
(22577, 6877, 1, 1, 2, 2513.812005), -- Recipe: Sealed Major Arcana Boots (60%)
(22577, 14052, 1, 1, 2, 33748.73073), -- Noble Enhancement Stone
-- Dragon Steed Troop Magic Soldier
(22578, 5162, 1, 1, -1, 9636), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22578, 5514, 1, 1, -1, 366160), -- Sealed Gauntlets of Nightmare Design
(22578, 5167, 1, 1, -1, 9636), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22578, 57, 14545, 29695, 0, 700000), -- Adena
(22578, 5311, 1, 1, 1, 60.654404), -- Sealed Armor of Nightmare
(22578, 5522, 1, 1, 1, 9093.345596), -- Sealed Armor of Nightmare Pattern
(22578, 5316, 1, 1, 1, 60.654404), -- Sealed Majestic Plate Armor
(22578, 5523, 1, 1, 1, 9093.345596), -- Sealed Majestic Plate Armor Pattern
(22578, 1879, 2, 6, 2, 55624.886304), -- Cokes
(22578, 1885, 1, 1, 2, 111250.14615), -- High-Grade Suede
(22578, 9628, 1, 1, 2, 10470.755802), -- Leonard
(22578, 9630, 1, 1, 2, 7026.32502), -- Orichalcum
(22578, 9629, 1, 1, 2, 5804.469138), -- Adamantine
(22578, 6879, 1, 1, 2, 1657.405854), -- Recipe: Sealed Major Arcana Circlet (60%)
(22578, 14052, 1, 1, 2, 33374.857074), -- Noble Enhancement Stone
(22578, 1345, 60, 180, 2, 148333.154658), -- Shining Arrow
-- Warrior of Light
(22579, 5515, 1, 1, -1, 380360), -- Sealed Majestic Gauntlets Design
(22579, 1894, 1, 1, -1, 790214), -- Crafted Leather
(22579, 57, 15112, 30841, 0, 700000), -- Adena
(22579, 5326, 1, 1, 1, 84.009445), -- Sealed Robe of Nightmare
(22579, 5487, 1, 1, 1, 12488.490555), -- Sealed Robe of Nightmare Fabric
(22579, 5329, 1, 1, 1, 84.009445), -- Sealed Majestic Robe
(22579, 5488, 1, 1, 1, 12488.490555), -- Sealed Majestic Robe Fabric
(22579, 1879, 1, 1, 2, 264146.304), -- Cokes
(22579, 1885, 1, 1, 2, 132073.152), -- High-Grade Suede
(22579, 9628, 1, 1, 2, 12430.35944), -- Leonard
(22579, 9630, 1, 1, 2, 8341.31496), -- Orichalcum
(22579, 9629, 1, 1, 2, 6890.93536), -- Adamantine
(22579, 6847, 1, 1, 2, 2855.52228), -- Recipe: Sealed Tateossian Earring (70%)
(22579, 14052, 1, 1, 2, 39622.41196), -- Noble Enhancement Stone
-- Dragon Steed Troop Healer
(22580, 5522, 1, 1, -1, 50019), -- Sealed Armor of Nightmare Pattern
(22580, 5272, 1, 1, -1, 6528), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22580, 5523, 1, 1, -1, 50019), -- Sealed Majestic Plate Armor Pattern
(22580, 57, 9856, 20114, 0, 700000), -- Adena
(22580, 6326, 1, 1, 1, 120.709632), -- Sealed Majestic Necklace
(22580, 6344, 1, 1, 1, 17675.653824), -- Sealed Majestic Necklace Beads
(22580, 6327, 1, 1, 1, 160.974432), -- Sealed Majestic Earring
(22580, 6342, 1, 1, 1, 27313.351584), -- Sealed Majestic Earring Gemstone
(22580, 6328, 1, 1, 1, 241.419264), -- Sealed Majestic Ring
(22580, 6346, 1, 1, 1, 39255.891264), -- Sealed Majestic Ring Gemstone
(22580, 1879, 1, 1, 2, 172269.356502), -- Cokes
(22580, 1885, 1, 1, 2, 86134.678251), -- High-Grade Suede
(22580, 9628, 1, 1, 2, 8106.640251), -- Leonard
(22580, 9630, 1, 1, 2, 5439.894124), -- Orichalcum
(22580, 9629, 1, 1, 2, 4494.099724), -- Adamantine
(22580, 6849, 1, 1, 2, 2789.699399), -- Recipe: Sealed Tateossian Ring(70%)
(22580, 1345, 60, 180, 2, 114846.631749), -- Shining Arrow
-- Dragon Steed Troop Javelin Thrower
(22581, 5277, 1, 1, -1, 10955), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22581, 5527, 1, 1, -1, 294709), -- Sealed Helm of Nightmare Design
(22581, 1894, 1, 1, -1, 864895), -- Crafted Leather
(22581, 57, 16537, 33762, 0, 700000), -- Adena
(22581, 5313, 1, 1, 1, 224.033712), -- Sealed Gauntlets of Nightmare
(22581, 5514, 1, 1, 1, 25633.966288), -- Sealed Gauntlets of Nightmare Design
(22581, 5314, 1, 1, 1, 224.033712), -- Sealed Boots of Nightmare
(22581, 5502, 1, 1, 1, 25633.966288), -- Sealed Boots of Nightmare Lining
(22581, 5318, 1, 1, 1, 224.033712), -- Sealed Majestic Gauntlets
(22581, 5515, 1, 1, 1, 25633.966288), -- Sealed Majestic Gauntlets Design
(22581, 5319, 1, 1, 1, 224.033712), -- Sealed Majestic Boots
(22581, 5503, 1, 1, 1, 25633.966288), -- Sealed Majestic Boots Lining
(22581, 1879, 1, 3, 2, 168647.308492), -- Cokes
(22581, 1885, 1, 1, 2, 168647.308492), -- High-Grade Suede
(22581, 9628, 1, 1, 2, 15872.758512), -- Leonard
(22581, 9630, 1, 1, 2, 10651.278573), -- Orichalcum
(22581, 9629, 1, 1, 2, 8798.931258), -- Adamantine
(22581, 6851, 1, 1, 2, 2731.414673), -- Recipe: Sealed Tateossian Necklace(70%)
-- Dragon Steed Troop Javelin Thrower
(22582, 1894, 1, 1, -1, 864895), -- Crafted Leather
(22582, 5528, 1, 1, -1, 294709), -- Sealed Majestic Circlet Design
(22582, 5282, 1, 1, -1, 10955), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22582, 57, 16537, 33762, 0, 700000), -- Adena
(22582, 5312, 1, 1, 1, 199.190784), -- Sealed Helm of Nightmare
(22582, 5527, 1, 1, 1, 24195.535348), -- Sealed Helm of Nightmare Design
(22582, 5315, 1, 1, 1, 284.660868), -- Sealed Shield of Nightmare
(22582, 5495, 1, 1, 1, 30729.886868), -- Sealed Shield of Nightmare Fragment
(22582, 5317, 1, 1, 1, 199.190784), -- Sealed Majestic Circlet
(22582, 5528, 1, 1, 1, 24195.535348), -- Sealed Majestic Circlet Design
(22582, 1879, 2, 6, 2, 72277.442454), -- Cokes
(22582, 1885, 1, 1, 2, 144554.444251), -- High-Grade Suede
(22582, 9628, 1, 1, 2, 13605.284875), -- Leonard
(22582, 9630, 1, 1, 2, 9129.972383), -- Orichalcum
(22582, 9629, 1, 1, 2, 7541.844555), -- Adamantine
(22582, 6853, 1, 1, 2, 808.605595), -- Recipe: Sealed Imperial Crusader Breastplate (60%)
(22582, 1345, 60, 180, 2, 192739.405887), -- Shining Arrow
-- Dragon Steed Troop Magic Leader
(22583, 5529, 1, 1, -1, 53926), -- Dragon Slayer Edge
(22583, 1808, 1, 1, -1, 8736), -- Recipe: Soulshot (S-Grade)
(22583, 5533, 1, 1, -1, 53915), -- Elysian Head
(22583, 57, 13159, 26954, 0, 700000), -- Adena
(22583, 81, 1, 1, 1, 15.561429), -- Dragon Slayer
(22583, 5529, 1, 1, 1, 4425.609868), -- Dragon Slayer Edge
(22583, 151, 1, 1, 1, 15.561429), -- Sword of Miracles
(22583, 5546, 1, 1, 1, 4861.109736), -- Sword of Miracles Edge
(22583, 2500, 1, 1, 1, 15.561429), -- Dark Legion's Edge
(22583, 5545, 1, 1, 1, 4425.596109), -- Dark Legion's Edge Blade
(22583, 1879, 1, 1, 2, 268964.658265), -- Cokes
(22583, 1885, 1, 1, 2, 134482.54554), -- High-Grade Suede
(22583, 9628, 1, 1, 2, 12657.24186), -- Leonard
(22583, 9630, 1, 1, 2, 8493.56156), -- Orichalcum
(22583, 9629, 1, 1, 2, 7016.363965), -- Adamantine
(22583, 6855, 1, 1, 2, 1200.62881), -- Recipe: Sealed Imperial Crusader Gaiters (60%)
-- Dragon Steed Troop Magician
(22584, 1894, 1, 1, -1, 707527), -- Crafted Leather
(22584, 5534, 1, 1, -1, 55359), -- Soul Bow Stave
(22584, 57, 13502, 27648, 0, 700000), -- Adena
(22584, 164, 1, 1, 1, 11.973168), -- Elysian
(22584, 5533, 1, 1, 1, 3406.038264), -- Elysian Head
(22584, 213, 1, 1, 1, 11.973168), -- Branch of the Mother Tree
(22584, 5544, 1, 1, 1, 3402.675936), -- Branch of the Mother Tree Head
(22584, 7895, 1, 1, 1, 11.973168), -- Flaming Dragon Skull
(22584, 8342, 1, 1, 1, 3406.038264), -- Flaming Dragon Skull Piece
(22584, 7902, 1, 1, 1, 11.973168), -- Doom Crusher
(22584, 8349, 1, 1, 1, 3405.354864), -- Doom Crusher Head
(22584, 1879, 2, 6, 2, 59126.450625), -- Cokes
(22584, 1885, 1, 1, 2, 118253.263711), -- High-Grade Suede
(22584, 9628, 1, 1, 2, 11129.727466), -- Leonard
(22584, 9630, 1, 1, 2, 7468.508905), -- Orichalcum
(22584, 9629, 1, 1, 2, 6169.811142), -- Adamantine
(22584, 6857, 1, 1, 2, 2642.703151), -- Recipe: Sealed Imperial Crusader Gauntlets (60%)
(22584, 1345, 60, 180, 2, 157670.535), -- Shining Arrow
-- Dragon Steed Troop Magic Soldier
(22585, 3036, 1, 1, -1, 5715), -- Recipe: Spiritshot S
(22585, 5537, 1, 1, -1, 35279), -- Soul Separator Head
(22585, 3957, 1, 1, -1, 5715), -- Recipe: Blessed Spiritshot S
(22585, 57, 8627, 17613, 0, 700000), -- Adena
(22585, 270, 1, 1, 1, 30.542657), -- Dragon Grinder
(22585, 5538, 1, 1, 1, 8688.457343), -- Dragon Grinder Edge
(22585, 1879, 1, 1, 2, 175962.236787), -- Cokes
(22585, 1885, 1, 1, 2, 87980.976225), -- High-Grade Suede
(22585, 9628, 1, 1, 2, 8280.462114), -- Leonard
(22585, 9630, 1, 1, 2, 5556.797991), -- Orichalcum
(22585, 9629, 1, 1, 2, 4590.336528), -- Adamantine
(22585, 6859, 1, 1, 2, 1966.190355), -- Recipe: Sealed Imperial Crusader Boots (60%)
-- Dragon Steed Troop Commander
(22586, 6688, 1, 1, -1, 406104), -- Forgotten Blade Edge
(22586, 960, 1, 1, -1, 75153), -- Scroll: Enchant Armor (S-Grade)
(22586, 1894, 1, 13, -1, 941764), -- Crafted Leather
(22586, 57, 109941, 220528, 0, 700000), -- Adena
(22586, 289, 1, 1, 1, 446.229), -- Soul Bow
(22586, 5534, 1, 1, 1, 127047.771), -- Soul Bow Stave
(22586, 1879, 15, 45, 2, 85696.912212), -- Cokes
(22586, 1885, 12, 36, 2, 53560.679094), -- High-Grade Suede
(22586, 9628, 1, 1, 2, 120984.31191), -- Leonard
(22586, 9630, 1, 1, 2, 81186.777804), -- Orichalcum
(22586, 9629, 1, 1, 2, 67067.110788), -- Adamantine
(22586, 6861, 1, 1, 2, 27350.208192), -- Recipe: Sealed Imperial Crusader Shield (60%)
-- null
(22587, 1894, 1, 3, -1, 920794), -- Crafted Leather
(22587, 5480, 1, 1, -1, 235513), -- Sealed Leather Armor of Nightmare Fabric
(22587, 5157, 1, 1, -1, 23327), -- Recipe: Soulshot (S) Compressed Package (100%)
(22587, 57, 35138, 71973, 0, 700000), -- Adena
(22587, 236, 1, 1, 1, 124.657192), -- Soul Separator
(22587, 5537, 1, 1, 1, 35471.342808), -- Soul Separator Head
(22587, 1895, 12, 36, 2, 51299.168352), -- Metallic Fiber
(22587, 4040, 1, 1, 2, 86182.579226), -- Mold Lubricant
(22587, 9628, 1, 1, 2, 33797.269247), -- Leonard
(22587, 9630, 1, 1, 2, 22679.734821), -- Orichalcum
(22587, 6863, 1, 1, 2, 5349.56471), -- Recipe: Sealed Imperial Crusader Helmet (60%)
(22587, 1345, 300, 900, 2, 95758.683644), -- Shining Arrow
-- White Dragon Leader
(22588, 5481, 1, 1, -1, 175370), -- Sealed Majestic Leather Armor Fabric
(22588, 5162, 1, 1, -1, 17370), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22588, 5487, 1, 1, -1, 175990), -- Sealed Robe of Nightmare Fabric
(22588, 57, 26168, 53586, 0, 700000), -- Adena
(22588, 5320, 1, 1, 1, 145.785184), -- Sealed Leather Armor of Nightmare
(22588, 5480, 1, 1, 1, 21600.214816), -- Sealed Leather Armor of Nightmare Fabric
(22588, 5323, 1, 1, 1, 145.785184), -- Sealed Majestic Leather Armor
(22588, 5481, 1, 1, 1, 21600.214816), -- Sealed Majestic Leather Armor Fabric
(22588, 1895, 3, 9, 2, 183355.202415), -- Metallic Fiber
(22588, 4040, 1, 1, 2, 77009.103815), -- Mold Lubricant
(22588, 9628, 1, 1, 2, 30199.581195), -- Leonard
(22588, 9630, 1, 1, 2, 20265.47145), -- Orichalcum
(22588, 6865, 1, 1, 2, 1475.641125), -- Recipe: Sealed Draconic Leather Armor (60%)
-- Dragon Steed Troop Infantry
(22589, 1894, 1, 3, -1, 703582), -- Crafted Leather
(22589, 5488, 1, 1, -1, 180592), -- Sealed Majestic Robe Fabric
(22589, 57, 26906, 54930, 0, 700000), -- Adena
(22589, 5311, 1, 1, 1, 112.198058), -- Sealed Armor of Nightmare
(22589, 5522, 1, 1, 1, 16820.801942), -- Sealed Armor of Nightmare Pattern
(22589, 5316, 1, 1, 1, 112.198058), -- Sealed Majestic Plate Armor
(22589, 5523, 1, 1, 1, 16820.801942), -- Sealed Majestic Plate Armor Pattern
(22589, 1895, 2, 6, 2, 235187.524755), -- Metallic Fiber
(22589, 4040, 1, 1, 2, 65852.62551), -- Mold Lubricant
(22589, 9628, 1, 1, 2, 25824.301605), -- Leonard
(22589, 9630, 1, 1, 2, 17329.4154), -- Orichalcum
(22589, 6867, 1, 1, 2, 6131.36061), -- Recipe: Sealed Draconic Leather Gloves (60%)
(22589, 1345, 300, 900, 2, 73169.77212), -- Shining Arrow
-- 
(22590, 8690, 1, 1, -1, 2276), -- Recipe: Sirra's Blade (60%)
(22590, 5478, 1, 1, -1, 135121), -- Sealed Dark Crystal Leather Armor Pattern
(22590, 8692, 1, 1, -1, 2276), -- Recipe: Sword of Ipos (60%)
(22590, 57, 8094, 16481, 0, 700000), -- Adena
(22590, 5304, 1, 1, 1, 74.043438), -- Sealed Tallum Tunic
(22590, 5485, 1, 1, 1, 8314.636078), -- Sealed Tallum Tunic Texture
(22590, 5305, 1, 1, 1, 118.409102), -- Sealed Tallum Stockings
(22590, 5489, 1, 1, 1, 13050.588348), -- Sealed Tallum Stockings Fabric
(22590, 5308, 1, 1, 1, 45.546186), -- Sealed Dark Crystal Robe
(22590, 5486, 1, 1, 1, 5850.776848), -- Sealed Dark Crystal Robe Fabric
(22590, 1895, 1, 1, 2, 339028.84092), -- Metallic Fiber
(22590, 4040, 1, 1, 2, 23732.05296), -- Mold Lubricant
(22590, 9628, 1, 1, 2, 9306.58344), -- Leonard
(22590, 9630, 1, 1, 2, 6245.1774), -- Orichalcum
(22590, 1808, 1, 1, 2, 527.34528), -- Recipe: Soulshot (S-Grade)
-- Dragon Steed Troop Magic Leader
(22591, 5480, 1, 1, -1, 53597), -- Sealed Leather Armor of Nightmare Fabric
(22591, 1894, 1, 1, -1, 419102), -- Crafted Leather
(22591, 57, 7997, 16379, 0, 700000), -- Adena
(22591, 6326, 1, 1, 1, 98.16344), -- Sealed Majestic Necklace
(22591, 6344, 1, 1, 1, 14374.18833), -- Sealed Majestic Necklace Beads
(22591, 6327, 1, 1, 1, 130.907565), -- Sealed Majestic Earring
(22591, 6342, 1, 1, 1, 22211.753155), -- Sealed Majestic Earring Gemstone
(22591, 6328, 1, 1, 1, 196.32688), -- Sealed Majestic Ring
(22591, 6346, 1, 1, 1, 31923.66063), -- Sealed Majestic Ring Gemstone
(22591, 1895, 1, 1, 2, 336225.883136), -- Metallic Fiber
(22591, 4040, 1, 1, 2, 23535.676736), -- Mold Lubricant
(22591, 9628, 1, 1, 2, 9229.581504), -- Leonard
(22591, 9630, 1, 1, 2, 6193.579392), -- Orichalcum
(22591, 959, 1, 1, 2, 47.279232), -- Scroll: Enchant Weapon (S-Grade)
-- Dragon Steed Troop Magician
(22592, 5481, 1, 1, -1, 53905), -- Sealed Majestic Leather Armor Fabric
(22592, 1808, 1, 1, -1, 5339), -- Recipe: Soulshot (S-Grade)
(22592, 5487, 1, 1, -1, 54096), -- Sealed Robe of Nightmare Fabric
(22592, 57, 8044, 16471, 0, 700000), -- Adena
(22592, 5313, 1, 1, 1, 109.183728), -- Sealed Gauntlets of Nightmare
(22592, 5514, 1, 1, 1, 12492.816272), -- Sealed Gauntlets of Nightmare Design
(22592, 5314, 1, 1, 1, 109.183728), -- Sealed Boots of Nightmare
(22592, 5502, 1, 1, 1, 12492.816272), -- Sealed Boots of Nightmare Lining
(22592, 5318, 1, 1, 1, 109.183728), -- Sealed Majestic Gauntlets
(22592, 5515, 1, 1, 1, 12492.816272), -- Sealed Majestic Gauntlets Design
(22592, 5319, 1, 1, 1, 109.183728), -- Sealed Majestic Boots
(22592, 5503, 1, 1, 1, 12492.816272), -- Sealed Majestic Boots Lining
(22592, 1895, 1, 1, 2, 281796.71814), -- Metallic Fiber
(22592, 4040, 1, 1, 2, 19725.855156), -- Mold Lubricant
(22592, 9628, 1, 1, 2, 7735.679406), -- Leonard
(22592, 9630, 1, 1, 2, 5190.79113), -- Orichalcum
(22592, 960, 1, 1, 2, 394.72083), -- Scroll: Enchant Armor (S-Grade)
(22592, 1345, 60, 180, 2, 109587.235338), -- Shining Arrow
-- Dragon Steed Troop Magic Soldier
(22593, 3036, 1, 1, -1, 5767), -- Recipe: Spiritshot S
(22593, 5488, 1, 1, -1, 58428), -- Sealed Majestic Robe Fabric
(22593, 1894, 1, 1, -1, 455270), -- Crafted Leather
(22593, 57, 8705, 17772, 0, 700000), -- Adena
(22593, 5312, 1, 1, 1, 104.851968), -- Sealed Helm of Nightmare
(22593, 5527, 1, 1, 1, 12736.279496), -- Sealed Helm of Nightmare Design
(22593, 5315, 1, 1, 1, 149.842536), -- Sealed Shield of Nightmare
(22593, 5495, 1, 1, 1, 16175.894536), -- Sealed Shield of Nightmare Fragment
(22593, 5317, 1, 1, 1, 104.851968), -- Sealed Majestic Circlet
(22593, 5528, 1, 1, 1, 12736.279496), -- Sealed Majestic Circlet Design
(22593, 1895, 1, 1, 2, 365240.48472), -- Metallic Fiber
(22593, 4040, 1, 1, 2, 25566.8094), -- Mold Lubricant
(22593, 9628, 1, 1, 2, 10026.39216), -- Leonard
(22593, 9630, 1, 1, 2, 6728.27988), -- Orichalcum
(22593, 6901, 1, 1, 2, 1278.03384), -- Recipe: Shining Arrow (100%)
-- Dragon Steed Troop Commander
(22594, 1894, 1, 3, -1, 928673), -- Crafted Leather
(22594, 6688, 1, 1, -1, 114417), -- Forgotten Blade Edge
(22594, 6901, 1, 1, -1, 52934), -- Recipe: Shining Arrow (100%)
(22594, 57, 30975, 62132, 0, 700000), -- Adena
(22594, 81, 1, 1, 1, 41.906943), -- Dragon Slayer
(22594, 5529, 1, 1, 1, 11918.171556), -- Dragon Slayer Edge
(22594, 151, 1, 1, 1, 41.906943), -- Sword of Miracles
(22594, 5546, 1, 1, 1, 13090.973112), -- Sword of Miracles Edge
(22594, 2500, 1, 1, 1, 41.906943), -- Dark Legion's Edge
(22594, 5545, 1, 1, 1, 11918.134503), -- Dark Legion's Edge Blade
(22594, 1895, 12, 36, 2, 51738.156015), -- Metallic Fiber
(22594, 4040, 1, 1, 2, 86920.222116), -- Mold Lubricant
(22594, 9628, 1, 1, 2, 34086.367497), -- Leonard
(22594, 9630, 1, 1, 2, 22873.758453), -- Orichalcum
(22594, 6847, 1, 1, 2, 7830.7047), -- Recipe: Sealed Tateossian Earring (70%)
(22594, 1345, 300, 900, 2, 96577.791219), -- Shining Arrow
-- Dragon Steed Troops No 1 Battalion Commander
(22595, 5480, 1, 1, -1, 242230), -- Sealed Leather Armor of Nightmare Fabric
(22595, 1808, 1, 1, -1, 23992), -- Recipe: Soulshot (S-Grade)
(22595, 5481, 1, 1, -1, 242230), -- Sealed Majestic Leather Armor Fabric
(22595, 57, 36140, 74026, 0, 700000), -- Adena
(22595, 164, 1, 1, 1, 32.05284), -- Elysian
(22595, 5533, 1, 1, 1, 9118.15482), -- Elysian Head
(22595, 213, 1, 1, 1, 32.05284), -- Branch of the Mother Tree
(22595, 5544, 1, 1, 1, 9109.15368), -- Branch of the Mother Tree Head
(22595, 7895, 1, 1, 1, 32.05284), -- Flaming Dragon Skull
(22595, 8342, 1, 1, 1, 9118.15482), -- Flaming Dragon Skull Piece
(22595, 7902, 1, 1, 1, 32.05284), -- Doom Crusher
(22595, 8349, 1, 1, 1, 9116.32532), -- Doom Crusher Head
(22595, 1895, 12, 36, 2, 52762.186253), -- Metallic Fiber
(22595, 4040, 1, 1, 2, 88640.336531), -- Mold Lubricant
(22595, 9628, 1, 1, 2, 34760.812973), -- Leonard
(22595, 9630, 1, 1, 2, 23326.469601), -- Orichalcum
(22595, 6849, 1, 1, 2, 11962.172895), -- Recipe: Sealed Tateossian Ring(70%)
(22595, 1345, 300, 900, 2, 98489.021747), -- Shining Arrow
-- White Dragon Leader
(22596, 1894, 1, 1, -1, 453485), -- Crafted Leather
(22596, 5487, 1, 1, -1, 58199), -- Sealed Robe of Nightmare Fabric
(22596, 57, 8654, 17721, 0, 700000), -- Adena
(22596, 270, 1, 1, 1, 30.696789), -- Dragon Grinder
(22596, 5538, 1, 1, 1, 8732.303211), -- Dragon Grinder Edge
(22596, 1895, 1, 1, 2, 363809.378589), -- Metallic Fiber
(22596, 4040, 1, 1, 2, 25466.733961), -- Mold Lubricant
(22596, 9628, 1, 1, 2, 9987.010451), -- Leonard
(22596, 9630, 1, 1, 2, 6701.900837), -- Orichalcum
(22596, 6851, 1, 1, 2, 1717.976162), -- Recipe: Sealed Tateossian Necklace(70%)
-- Dragon Steed Troop Infantry
(22597, 3036, 1, 1, -1, 5892), -- Recipe: Spiritshot S
(22597, 5488, 1, 1, -1, 59695), -- Sealed Majestic Robe Fabric
(22597, 3957, 1, 1, -1, 5892), -- Recipe: Blessed Spiritshot S
(22597, 57, 8894, 18157, 0, 700000), -- Adena
(22597, 289, 1, 1, 1, 31.486), -- Soul Bow
(22597, 5534, 1, 1, 1, 8964.514), -- Soul Bow Stave
(22597, 1895, 1, 1, 2, 310966.945044); -- Metallic Fiber

INSERT INTO `droplist` VALUES
(22597, 4040, 1, 1, 2, 21767.845422), -- Mold Lubricant
(22597, 9628, 1, 1, 2, 8536.345674), -- Leonard
(22597, 9630, 1, 1, 2, 5728.528302), -- Orichalcum
(22597, 6853, 1, 1, 2, 507.318354), -- Recipe: Sealed Imperial Crusader Breastplate (60%)
(22597, 1345, 60, 180, 2, 120931.017204), -- Shining Arrow
-- Spiked Stakato
(22617, 9630, 1, 1, -1, 92833), -- Orichalcum
(22617, 9617, 1, 1, -1, 9807), -- Dynasty Blade Piece
(22617, 9537, 1, 1, -1, 63422), -- Sealed Dynasty Leather Helmet Piece
(22617, 57, 4323, 8709, 0, 700000), -- Adena
(22617, 9442, 1, 1, 1, 2.576712), -- Dynasty Sword
(22617, 9443, 1, 1, 1, 2.576712), -- Dynasty Blade
(22617, 9444, 1, 1, 1, 2.576712), -- Dynasty Phantom
(22617, 9616, 1, 1, 1, 805.42248), -- Dynasty Sword Piece
(22617, 9617, 1, 1, 1, 805.42248), -- Dynasty Blade Piece
(22617, 9618, 1, 1, 1, 805.424904), -- Dynasty Phantom Piece
(22617, 1879, 1, 1, 2, 160903.572531), -- Cokes
(22617, 1885, 1, 1, 2, 80451.973277), -- High-Grade Suede
(22617, 9628, 1, 1, 2, 7572.095635), -- Leonard
(22617, 9630, 1, 1, 2, 5081.102455), -- Orichalcum
(22617, 9629, 1, 1, 2, 4197.660129), -- Adamantine
(22617, 9573, 1, 1, 2, 6704.362275), -- Life Stone - Level 80
(22617, 9574, 1, 1, 2, 1675.997063), -- Mid-Grade Life Stone - Level 80
(22617, 9575, 1, 1, 2, 167.562304), -- High-Grade Life Stone - Level 80
(22617, 1345, 60, 180, 2, 107268.674331), -- Shining Arrow
-- Spiked Stakato Worker
(22618, 1808, 1, 1, -1, 7839), -- Recipe: Soulshot (S-Grade)
(22618, 9623, 1, 1, -1, 9494), -- Dynasty Mace Piece
(22618, 3036, 1, 1, -1, 7839), -- Recipe: Spiritshot S
(22618, 57, 4323, 8709, 0, 700000), -- Adena
(22618, 9448, 1, 1, 1, 1.931892), -- Dynasty Cudgel
(22618, 9449, 1, 1, 1, 1.931892), -- Dynasty Mace
(22618, 10252, 1, 1, 1, 1.931892), -- Dynasty Staff
(22618, 10253, 1, 1, 1, 1.931892), -- Dynasty Crusher
(22618, 9622, 1, 1, 1, 584.431956), -- Dynasty Cudgel Piece
(22618, 9623, 1, 1, 1, 584.431956), -- Dynasty Mace Piece
(22618, 10546, 1, 1, 1, 605.706648), -- Dynasty Staff Fragment
(22618, 10547, 1, 1, 1, 605.701872), -- Dynasty Crusher Fragment
(22618, 1879, 1, 1, 2, 160903.638985), -- Cokes
(22618, 1885, 1, 1, 2, 80451.686019), -- High-Grade Suede
(22618, 9628, 1, 1, 2, 7571.951655), -- Leonard
(22618, 9630, 1, 1, 2, 5081.069198), -- Orichalcum
(22618, 9629, 1, 1, 2, 4197.474628), -- Adamantine
(22618, 9573, 1, 1, 2, 6704.373905), -- Life Stone - Level 80
(22618, 9574, 1, 1, 2, 1676.160213), -- Mid-Grade Life Stone - Level 80
(22618, 9575, 1, 1, 2, 167.642716), -- High-Grade Life Stone - Level 80
(22618, 9625, 1, 1, 2, 193.002681), -- Giant's Codex - Oblivion
-- Spiked Stakato Guard
(22619, 9624, 1, 1, -1, 9494), -- Dynasty Bagh-Nakh Piece
(22619, 9630, 1, 1, -1, 92833), -- Orichalcum
(22619, 9628, 1, 1, -1, 138339), -- Leonard
(22619, 57, 4323, 8709, 0, 700000), -- Adena
(22619, 9450, 1, 1, 1, 7.727724), -- Dynasty Bagh-Nakh
(22619, 9624, 1, 1, 1, 2338.272276), -- Dynasty Bagh-Nakh Piece
(22619, 1879, 1, 1, 2, 160903.7607), -- Cokes
(22619, 1885, 1, 1, 2, 80451.88035), -- High-Grade Suede
(22619, 9628, 1, 1, 2, 7572.004476), -- Leonard
(22619, 9630, 1, 1, 2, 5081.185437), -- Orichalcum
(22619, 9629, 1, 1, 2, 4197.535824), -- Adamantine
(22619, 9573, 1, 1, 2, 6704.367843), -- Life Stone - Level 80
(22619, 9574, 1, 1, 2, 1676.02524), -- Mid-Grade Life Stone - Level 80
(22619, 9575, 1, 1, 2, 167.602524), -- High-Grade Life Stone - Level 80
(22619, 9626, 1, 1, 2, 128.637606), -- Giant's Codex - Discipline
-- Female Spiked Stakato
(22620, 9992, 1, 1, -1, 32739), -- Sealed Dynasty Necklace Gemstone
(22620, 3957, 1, 1, -1, 8086), -- Recipe: Blessed Spiritshot S
(22620, 9537, 1, 1, -1, 65418), -- Sealed Dynasty Leather Helmet Piece
(22620, 57, 4459, 8983, 0, 700000), -- Adena
(22620, 9445, 1, 1, 1, 7.970688), -- Dynasty Bow
(22620, 9619, 1, 1, 1, 2508.029312), -- Dynasty Bow Piece
(22620, 1895, 1, 1, 2, 320079.12226), -- Metallic Fiber
(22620, 4040, 1, 1, 2, 22405.37578), -- Mold Lubricant
(22620, 4042, 1, 1, 2, 18671.4943), -- Enria
(22620, 4043, 1, 1, 2, 37342.57122), -- Asofe
(22620, 9573, 1, 1, 2, 7779.54582), -- Life Stone - Level 80
(22620, 9574, 1, 1, 2, 1944.9908), -- Mid-Grade Life Stone - Level 80
(22620, 9575, 1, 1, 2, 194.49908), -- High-Grade Life Stone - Level 80
(22620, 9546, 1, 1, 2, 8962.40074), -- Fire Stone
-- Male Spiked Stakato
(22621, 5157, 1, 1, -1, 7660), -- Recipe: Soulshot (S) Compressed Package (100%)
(22621, 9622, 1, 1, -1, 9277), -- Dynasty Cudgel Piece
(22621, 9628, 1, 1, -1, 135170), -- Leonard
(22621, 57, 4224, 8509, 0, 700000), -- Adena
(22621, 9446, 1, 1, 1, 7.552272), -- Dynasty Knife
(22621, 9620, 1, 1, 1, 2358.447728), -- Dynasty Knife Piece
(22621, 1895, 1, 1, 2, 303205.527629), -- Metallic Fiber
(22621, 4040, 1, 1, 2, 21224.232737), -- Mold Lubricant
(22621, 4042, 1, 1, 2, 17687.190095), -- Enria
(22621, 4043, 1, 1, 2, 35373.984813), -- Asofe
(22621, 9573, 1, 1, 2, 7369.431903), -- Life Stone - Level 80
(22621, 9574, 1, 1, 2, 1842.45682), -- Mid-Grade Life Stone - Level 80
(22621, 9575, 1, 1, 2, 184.245682), -- High-Grade Life Stone - Level 80
(22621, 9547, 1, 1, 2, 8489.930321), -- Water Stone
-- Male Spiked Stakato
(22622, 1894, 1, 1, -1, 900504), -- Crafted Leather
(22622, 9993, 1, 1, -1, 84567), -- Sealed Dynasty Ring Gemstone
(22622, 5162, 1, 1, -1, 11406), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22622, 57, 6281, 12679, 0, 700000), -- Adena
(22622, 9447, 1, 1, 1, 11.24585), -- Dynasty Halberd
(22622, 9621, 1, 1, 1, 3530.75415), -- Dynasty Halberd Piece
(22622, 1895, 1, 3, 2, 225759.728709), -- Metallic Fiber
(22622, 4040, 1, 1, 2, 31606.355925), -- Mold Lubricant
(22622, 9628, 1, 1, 2, 12394.505988), -- Leonard
(22622, 9630, 1, 1, 2, 8317.446048), -- Orichalcum
(22622, 9573, 1, 1, 2, 10974.543408), -- Life Stone - Level 80
(22622, 9574, 1, 1, 2, 2743.635852), -- Mid-Grade Life Stone - Level 80
(22622, 9575, 1, 1, 2, 274.2417), -- High-Grade Life Stone - Level 80
(22622, 9548, 1, 1, 2, 12642.54237), -- Earth Stone
-- Spiked Stakato Sorcerer
(22623, 9992, 1, 1, -1, 30626), -- Sealed Dynasty Necklace Gemstone
(22623, 5167, 1, 1, -1, 7564), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22623, 9530, 1, 1, -1, 24787), -- Sealed Dynasty Breast Plate Piece
(22623, 57, 4172, 8403, 0, 700000), -- Adena
(22623, 9514, 1, 1, 1, 11.454168), -- Sealed Dynasty Breast Plate
(22623, 9515, 1, 1, 1, 18.319404), -- Sealed Dynasty Gaiter
(22623, 9530, 1, 1, 1, 3051.651888), -- Sealed Dynasty Breast Plate Piece
(22623, 9531, 1, 1, 1, 9026.57454), -- Sealed Dynasty Gaiters Piece
(22623, 1879, 1, 1, 2, 155258.078646), -- Cokes
(22623, 1885, 1, 1, 2, 77629.039323), -- High-Grade Suede
(22623, 9628, 1, 1, 2, 7306.334189), -- Leonard
(22623, 9630, 1, 1, 2, 4902.847664), -- Orichalcum
(22623, 9629, 1, 1, 2, 4050.305171), -- Adamantine
(22623, 9573, 1, 1, 2, 6469.152822), -- Life Stone - Level 80
(22623, 9574, 1, 1, 2, 1617.155782), -- Mid-Grade Life Stone - Level 80
(22623, 9575, 1, 1, 2, 161.821517), -- High-Grade Life Stone - Level 80
(22623, 9549, 1, 1, 2, 7452.264886), -- Wind Stone
-- Cannibalistic Stakato Follower
(22624, 1894, 1, 1, -1, 604709), -- Crafted Leather
(22624, 9530, 1, 1, -1, 25100), -- Sealed Dynasty Breast Plate Piece
(22624, 57, 4224, 8509, 0, 700000), -- Adena
(22624, 9519, 1, 1, 1, 15.465998), -- Sealed Dynasty Leather Armor
(22624, 9520, 1, 1, 1, 24.743713), -- Sealed Dynasty Leather Leggings
(22624, 9535, 1, 1, 1, 3797.166241), -- Sealed Dynasty Leather Armor Piece
(22624, 9536, 1, 1, 1, 5581.624048), -- Sealed Dynasty Leather Leggings Piece
(22624, 1894, 1, 1, 2, 37235.845858), -- Crafted Leather
(22624, 4039, 1, 1, 2, 35374.06032), -- Mold Glue
(22624, 4041, 1, 1, 2, 9228.003988), -- Mold Hardener
(22624, 4044, 1, 1, 2, 35374.06032), -- Thons
(22624, 9573, 1, 1, 2, 7369.5959), -- Life Stone - Level 80
(22624, 9574, 1, 1, 2, 1842.466524), -- Mid-Grade Life Stone - Level 80
(22624, 9575, 1, 1, 2, 184.273672), -- High-Grade Life Stone - Level 80
(22624, 9550, 1, 1, 2, 8489.693418), -- Dark Stone
-- Cannibalistic Stakato Leader
(22625, 5272, 1, 1, -1, 8235), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22625, 9619, 1, 1, -1, 10371), -- Dynasty Bow Piece
(22625, 5277, 1, 1, -1, 8235), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22625, 57, 4534, 9153, 0, 700000), -- Adena
(22625, 9524, 1, 1, 1, 16.626892), -- Sealed Dynasty Tunic
(22625, 9525, 1, 1, 1, 26.601002), -- Sealed Dynasty Stockings
(22625, 9540, 1, 1, 1, 4082.185514), -- Sealed Dynasty Tunic Piece
(22625, 9541, 1, 1, 1, 6000.586592), -- Sealed Dynasty Stocking Piece
(22625, 1895, 1, 1, 2, 325964.903235), -- Metallic Fiber
(22625, 4040, 1, 1, 2, 22817.377455), -- Mold Lubricant
(22625, 4042, 1, 1, 2, 19014.835425), -- Enria
(22625, 4043, 1, 1, 2, 38029.245795), -- Asofe
(22625, 9573, 1, 1, 2, 7922.600145), -- Life Stone - Level 80
(22625, 9574, 1, 1, 2, 1980.7563), -- Mid-Grade Life Stone - Level 80
(22625, 9575, 1, 1, 2, 198.07563), -- High-Grade Life Stone - Level 80
(22625, 9551, 1, 1, 2, 9127.206015), -- Holy Stone
-- Cannibalistic Stakato Leader
(22626, 9624, 1, 1, -1, 13815), -- Dynasty Bagh-Nakh Piece
(22626, 960, 1, 1, -1, 10266), -- Scroll: Enchant Armor (S-Grade)
(22626, 9630, 1, 1, -1, 135076), -- Orichalcum
(22626, 57, 6281, 12679, 0, 700000), -- Adena
(22626, 9452, 1, 1, 1, 69.678182), -- Sealed Dynasty Earring
(22626, 9453, 1, 1, 1, 52.250686), -- Sealed Dynasty Necklace
(22626, 9454, 1, 1, 1, 104.517273), -- Sealed Dynasty Ring
(22626, 9991, 1, 1, 1, 4940.249888), -- Sealed Dynasty Earring Gemstone
(22626, 9992, 1, 1, 1, 3791.513945), -- Sealed Dynasty Necklace Gemstone
(22626, 9993, 1, 1, 1, 6942.790026), -- Sealed Dynasty Ring Gemstone
(22626, 1879, 1, 1, 2, 234121.354176), -- Cokes
(22626, 1885, 1, 1, 2, 117060.677088), -- High-Grade Suede
(22626, 9628, 1, 1, 2, 11017.333914), -- Leonard
(22626, 9630, 1, 1, 2, 7393.15473), -- Orichalcum
(22626, 9629, 1, 1, 2, 6107.456202), -- Adamantine
(22626, 9573, 1, 1, 2, 9754.927026), -- Life Stone - Level 80
(22626, 9574, 1, 1, 2, 2438.634708), -- Mid-Grade Life Stone - Level 80
(22626, 9575, 1, 1, 2, 243.785832), -- High-Grade Life Stone - Level 80
(22626, 959, 1, 1, 2, 56.676324), -- Scroll: Enchant Weapon (S-Grade)
-- Spiked Stakato Soldier
(22627, 1894, 1, 1, -1, 620178), -- Crafted Leather
(22627, 9624, 1, 1, -1, 9514), -- Dynasty Bagh-Nakh Piece
(22627, 6901, 1, 1, -1, 17675), -- Recipe: Shining Arrow (100%)
(22627, 57, 4326, 8732, 0, 700000), -- Adena
(22627, 9517, 1, 1, 1, 15.861908), -- Sealed Dynasty Gauntlets
(22627, 9518, 1, 1, 1, 15.861908), -- Sealed Dynasty Boots
(22627, 9522, 1, 1, 1, 15.861908), -- Sealed Dynasty Leather Gloves
(22627, 9523, 1, 1, 1, 15.861908), -- Sealed Dynasty Leather Boots
(22627, 9527, 1, 1, 1, 15.861908), -- Sealed Dynasty Gloves
(22627, 9528, 1, 1, 1, 15.861908), -- Sealed Dynasty Shoes
(22627, 9533, 1, 1, 1, 3471.811734), -- Sealed Dynasty Gauntlet Piece
(22627, 9534, 1, 1, 1, 3471.811734), -- Sealed Dynasty Boot Piece
(22627, 9538, 1, 1, 1, 3471.811734), -- Sealed Dynasty Leather Glove Piece
(22627, 9539, 1, 1, 1, 3471.811734), -- Sealed Dynasty Leather Boots Piece
(22627, 9543, 1, 1, 1, 3471.811734), -- Sealed Dynasty Glove Piece
(22627, 9544, 1, 1, 1, 3471.769882), -- Sealed Dynasty Shoes Piece
(22627, 1894, 1, 1, 2, 38188.25984), -- Crafted Leather
(22627, 4039, 1, 1, 2, 36278.846848), -- Mold Glue
(22627, 4041, 1, 1, 2, 9464.075326), -- Mold Hardener
(22627, 4044, 1, 1, 2, 36278.846848), -- Thons
(22627, 9573, 1, 1, 2, 7558.049666), -- Life Stone - Level 80
(22627, 9574, 1, 1, 2, 1889.479846), -- Mid-Grade Life Stone - Level 80
(22627, 9575, 1, 1, 2, 188.9089), -- High-Grade Life Stone - Level 80
(22627, 960, 1, 1, 2, 435.532726), -- Scroll: Enchant Armor (S-Grade)
-- Spiked Stakato Drone
(22628, 9992, 1, 1, -1, 31806), -- Sealed Dynasty Necklace Gemstone
(22628, 9624, 1, 1, -1, 9514), -- Dynasty Bagh-Nakh Piece
(22628, 9530, 1, 1, -1, 25742), -- Sealed Dynasty Breast Plate Piece
(22628, 57, 4326, 8732, 0, 700000), -- Adena
(22628, 9516, 1, 1, 1, 12.688732), -- Sealed Dynasty Helmet
(22628, 9529, 1, 1, 1, 18.121516), -- Sealed Dynasty Shield
(22628, 13886, 1, 1, 1, 18.121516), -- Sealed Dynasty Sigil
(22628, 9521, 1, 1, 1, 12.688732), -- Sealed Dynasty Leather Helmet
(22628, 9526, 1, 1, 1, 12.688732), -- Sealed Dynasty Circlet
(22628, 9532, 1, 1, 1, 3129.981036), -- Sealed Dynasty Helmet Piece
(22628, 9542, 1, 1, 1, 3129.981036), -- Sealed Dynasty Circlet Piece
(22628, 9545, 1, 1, 1, 3730.842052), -- Sealed Dynasty Shield Piece
(22628, 10114, 1, 1, 1, 2158.197916), -- Sealed Dynasty Sigil Piece
(22628, 1894, 1, 1, 2, 38188.416641), -- Crafted Leather
(22628, 4039, 1, 1, 2, 36279.067491), -- Mold Glue
(22628, 4041, 1, 1, 2, 9464.115896), -- Mold Hardener
(22628, 4044, 1, 1, 2, 36279.067491), -- Thons
(22628, 9573, 1, 1, 2, 7558.155352), -- Life Stone - Level 80
(22628, 9574, 1, 1, 2, 1889.538838), -- Mid-Grade Life Stone - Level 80
(22628, 9575, 1, 1, 2, 188.97995), -- High-Grade Life Stone - Level 80
(22628, 5272, 1, 1, 2, 483.658341), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Spiked Stakato Captain
(22629, 959, 1, 1, -1, 707), -- Scroll: Enchant Weapon (S-Grade)
(22629, 1894, 1, 1, -1, 620178), -- Crafted Leather
(22629, 57, 4326, 8732, 0, 700000), -- Adena
(22629, 9450, 1, 1, 1, 7.744194), -- Dynasty Bagh-Nakh
(22629, 9624, 1, 1, 1, 2343.255806), -- Dynasty Bagh-Nakh Piece
(22629, 1894, 1, 1, 2, 38188.416641), -- Crafted Leather
(22629, 4039, 1, 1, 2, 36279.067491), -- Mold Glue
(22629, 4041, 1, 1, 2, 9464.115896), -- Mold Hardener
(22629, 4044, 1, 1, 2, 36279.067491), -- Thons
(22629, 9573, 1, 1, 2, 7558.155352), -- Life Stone - Level 80
(22629, 9574, 1, 1, 2, 1889.538838), -- Mid-Grade Life Stone - Level 80
(22629, 9575, 1, 1, 2, 188.97995), -- High-Grade Life Stone - Level 80
(22629, 5277, 1, 1, 2, 483.658341), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
-- Spiked Stakato Nurse
(22630, 9622, 1, 1, -1, 9396), -- Dynasty Cudgel Piece
(22630, 1808, 1, 1, -1, 7758), -- Recipe: Soulshot (S-Grade)
(22630, 9530, 1, 1, -1, 25421), -- Sealed Dynasty Breast Plate Piece
(22630, 57, 4272, 8623, 0, 700000), -- Adena
(22630, 9442, 1, 1, 1, 2.549074), -- Dynasty Sword
(22630, 9443, 1, 1, 1, 2.549074), -- Dynasty Blade
(22630, 9444, 1, 1, 1, 2.549074), -- Dynasty Phantom
(22630, 9616, 1, 1, 1, 796.78346), -- Dynasty Sword Piece
(22630, 9617, 1, 1, 1, 796.78346), -- Dynasty Blade Piece
(22630, 9618, 1, 1, 1, 796.785858), -- Dynasty Phantom Piece
(22630, 1879, 1, 1, 2, 159229.905688), -- Cokes
(22630, 1885, 1, 1, 2, 79614.952844), -- High-Grade Suede
(22630, 9628, 1, 1, 2, 7493.20936), -- Leonard
(22630, 9630, 1, 1, 2, 5028.435272), -- Orichalcum
(22630, 9629, 1, 1, 2, 4153.78684), -- Adamantine
(22630, 9573, 1, 1, 2, 6634.689572), -- Life Stone - Level 80
(22630, 9574, 1, 1, 2, 1658.606292), -- Mid-Grade Life Stone - Level 80
(22630, 9575, 1, 1, 2, 165.781308), -- High-Grade Life Stone - Level 80
(22630, 5282, 1, 1, 2, 424.632824), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Spiked Stakato Nurse
(22631, 3036, 1, 1, -1, 10702), -- Recipe: Spiritshot S
(22631, 9624, 1, 1, -1, 12962), -- Dynasty Bagh-Nakh Piece
(22631, 1894, 1, 1, -1, 844904), -- Crafted Leather
(22631, 57, 5893, 11896, 0, 700000), -- Adena
(22631, 9442, 1, 1, 1, 3.517467), -- Dynasty Sword
(22631, 9443, 1, 1, 1, 3.517467), -- Dynasty Blade
(22631, 9444, 1, 1, 1, 3.517467), -- Dynasty Phantom
(22631, 9616, 1, 1, 1, 1099.48143), -- Dynasty Sword Piece
(22631, 9617, 1, 1, 1, 1099.48143), -- Dynasty Blade Piece
(22631, 9618, 1, 1, 1, 1099.484739), -- Dynasty Phantom Piece
(22631, 1879, 1, 1, 2, 219665.938856), -- Cokes
(22631, 1885, 1, 1, 2, 109832.969428), -- High-Grade Suede
(22631, 9628, 1, 1, 2, 10337.181953), -- Leonard
(22631, 9630, 1, 1, 2, 6936.653689), -- Orichalcum
(22631, 9629, 1, 1, 2, 5730.533389), -- Adamantine
(22631, 9573, 1, 1, 2, 9152.625622), -- Life Stone - Level 80
(22631, 9574, 1, 1, 2, 2288.339151), -- Mid-Grade Life Stone - Level 80
(22631, 9575, 1, 1, 2, 228.797366), -- High-Grade Life Stone - Level 80
(22631, 6901, 1, 1, 2, 1317.960546), -- Recipe: Shining Arrow (100%)
-- Spiked Stakato Baby
(22632, 1894, 1, 1, -1, 692161), -- Crafted Leather
(22632, 9623, 1, 1, -1, 10619), -- Dynasty Mace Piece
(22632, 3957, 1, 1, -1, 8767), -- Recipe: Blessed Spiritshot S
(22632, 57, 4835, 9740, 0, 700000), -- Adena
(22632, 9448, 1, 1, 1, 2.160839), -- Dynasty Cudgel
(22632, 9449, 1, 1, 1, 2.160839), -- Dynasty Mace
(22632, 10252, 1, 1, 1, 2.160839), -- Dynasty Staff
(22632, 10253, 1, 1, 1, 2.160839), -- Dynasty Crusher
(22632, 9622, 1, 1, 1, 653.692527), -- Dynasty Cudgel Piece
(22632, 9623, 1, 1, 1, 653.692527), -- Dynasty Mace Piece
(22632, 10546, 1, 1, 1, 677.488466), -- Dynasty Staff Fragment
(22632, 10547, 1, 1, 1, 677.483124), -- Dynasty Crusher Fragment
(22632, 1895, 1, 1, 2, 347055.182896), -- Metallic Fiber
(22632, 4040, 1, 1, 2, 24293.671492), -- Mold Lubricant
(22632, 9628, 1, 1, 2, 9526.875292), -- Leonard
(22632, 9630, 1, 1, 2, 6392.96656), -- Orichalcum
(22632, 9573, 1, 1, 2, 8435.208496), -- Life Stone - Level 80
(22632, 9574, 1, 1, 2, 2108.802124), -- Mid-Grade Life Stone - Level 80
(22632, 9575, 1, 1, 2, 210.840356), -- High-Grade Life Stone - Level 80
(22632, 5157, 1, 1, 2, 540.452784), -- Recipe: Soulshot (S) Compressed Package (100%)
-- Spiked Stakato Shaman
(22633, 9992, 1, 1, -1, 31410), -- Sealed Dynasty Necklace Gemstone
(22633, 5157, 1, 1, -1, 7758), -- Recipe: Soulshot (S) Compressed Package (100%)
(22633, 9623, 1, 1, -1, 9396), -- Dynasty Mace Piece
(22633, 57, 4272, 8623, 0, 700000), -- Adena
(22633, 9448, 1, 1, 1, 1.912476), -- Dynasty Cudgel
(22633, 9449, 1, 1, 1, 1.912476), -- Dynasty Mace
(22633, 10252, 1, 1, 1, 1.912476), -- Dynasty Staff
(22633, 10253, 1, 1, 1, 1.912476), -- Dynasty Crusher
(22633, 9622, 1, 1, 1, 578.558268), -- Dynasty Cudgel Piece
(22633, 9623, 1, 1, 1, 578.558268), -- Dynasty Mace Piece
(22633, 10546, 1, 1, 1, 599.619144), -- Dynasty Staff Fragment
(22633, 10547, 1, 1, 1, 599.614416), -- Dynasty Crusher Fragment
(22633, 1879, 1, 1, 2, 159229.905688), -- Cokes
(22633, 1885, 1, 1, 2, 79614.952844), -- High-Grade Suede
(22633, 9628, 1, 1, 2, 7493.20936), -- Leonard
(22633, 9630, 1, 1, 2, 5028.435272), -- Orichalcum
(22633, 9629, 1, 1, 2, 4153.78684), -- Adamantine
(22633, 9573, 1, 1, 2, 6634.689572), -- Life Stone - Level 80
(22633, 9574, 1, 1, 2, 1658.606292), -- Mid-Grade Life Stone - Level 80
(22633, 9575, 1, 1, 2, 165.781308), -- High-Grade Life Stone - Level 80
(22633, 5162, 1, 1, 2, 424.632824), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Scarlet Stakato Worker
(22634, 1894, 1, 1, -1, 354245), -- Crafted Leather
(22634, 9992, 1, 1, -1, 18168), -- Sealed Dynasty Necklace Gemstone
(22634, 57, 1883, 3706, 0, 700000), -- Adena
(22634, 6371, 1, 1, 1, 8.718161), -- Demon Splinter
(22634, 6695, 1, 1, 1, 3952.281839), -- Demon Splinter Blade
(22634, 1895, 1, 1, 2, 213014.351564), -- Metallic Fiber
(22634, 4040, 1, 1, 2, 14911.026032), -- Mold Lubricant
(22634, 9628, 1, 1, 2, 5847.395848), -- Leonard
(22634, 9630, 1, 1, 2, 3923.89158), -- Orichalcum
(22634, 5167, 1, 1, 2, 331.334976), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
-- Scarlet Stakato Soldier
(22635, 5162, 1, 1, -1, 4382), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22635, 6701, 1, 1, -1, 52494), -- Sealed Imperial Crusader Breastplate Part
(22635, 6702, 1, 1, -1, 67573), -- Sealed Imperial Crusader Gaiters Pattern
(22635, 57, 1839, 3620, 0, 700000), -- Adena
(22635, 6364, 1, 1, 1, 4.257225), -- Forgotten Blade
(22635, 6372, 1, 1, 1, 4.257225), -- Heaven's Divider
(22635, 6688, 1, 1, 1, 1967.613075), -- Forgotten Blade Edge
(22635, 6696, 1, 1, 1, 1998.872475), -- Heavens Divider Edge
(22635, 1895, 1, 1, 2, 208026.816646), -- Metallic Fiber
(22635, 4040, 1, 1, 2, 14561.909684), -- Mold Lubricant
(22635, 9628, 1, 1, 2, 5710.530045), -- Leonard
(22635, 9630, 1, 1, 2, 3832.105946), -- Orichalcum
(22635, 9625, 1, 1, 2, 145.637679), -- Giant's Codex - Oblivion
-- Scarlet Stakato Noble
(22636, 6688, 1, 1, -1, 22016), -- Forgotten Blade Edge
(22636, 6696, 1, 1, -1, 22366), -- Heavens Divider Edge
(22636, 6711, 1, 1, -1, 50468), -- Sealed Major Arcana Robe Part
(22636, 57, 1900, 3739, 0, 700000), -- Adena
(22636, 6676, 1, 1, 1, 33.633684), -- Sealed Imperial Crusader Gauntlet
(22636, 6677, 1, 1, 1, 33.633684), -- Sealed Imperial Crusader Boots
(22636, 6681, 1, 1, 1, 33.633684), -- Sealed Draconic Leather Glove
(22636, 6682, 1, 1, 1, 33.633684), -- Sealed Draconic Leather Boots
(22636, 6685, 1, 1, 1, 33.633684), -- Sealed Major Arcana Glove
(22636, 6686, 1, 1, 1, 33.633684), -- Sealed Major Arcana Boots
(22636, 6703, 1, 1, 1, 7649.197896), -- Sealed Imperial Crusader Gauntlets Design
(22636, 1879, 1, 1, 2, 104467.971374), -- Cokes
(22636, 1885, 1, 1, 2, 52234.06955), -- High-Grade Suede
(22636, 9628, 1, 1, 2, 4916.216786), -- Leonard
(22636, 9630, 1, 1, 2, 3299.002694), -- Orichalcum
(22636, 9629, 1, 1, 2, 2725.212048), -- Adamantine
(22636, 9626, 1, 1, 2, 83.527548), -- Giant's Codex - Discipline
-- Tepra Scorpion
(22637, 6694, 1, 1, -1, 22218), -- Saint Spear Blade
(22637, 5272, 1, 1, -1, 4487), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22637, 6691, 1, 1, -1, 21822), -- Angel Slayer Blade
(22637, 57, 1883, 3706, 0, 700000), -- Adena
(22637, 7575, 1, 1, 1, 8.717205), -- Draconic Bow
(22637, 7579, 1, 1, 1, 4074.282795), -- Draconic Bow Shaft
(22637, 1895, 1, 1, 2, 213014.294064), -- Metallic Fiber
(22637, 4040, 1, 1, 2, 14911.078556), -- Mold Lubricant
(22637, 9628, 1, 1, 2, 5847.376678), -- Leonard
(22637, 9630, 1, 1, 2, 3923.916744), -- Orichalcum
(22637, 9546, 1, 1, 2, 5964.333958), -- Fire Stone
-- Tepra Scarab
(22638, 5277, 1, 1, -1, 4487), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22638, 6689, 1, 1, -1, 21411), -- Basalt Battlehammer Head
(22638, 6690, 1, 1, -1, 21864), -- Imperial Staff Head
(22638, 57, 1883, 3706, 0, 700000), -- Adena
(22638, 6367, 1, 1, 1, 8.718042), -- Angel Slayer
(22638, 6691, 1, 1, 1, 4029.281958), -- Angel Slayer Blade
(22638, 1879, 1, 1, 2, 103548.324357), -- Cokes
(22638, 1885, 1, 1, 2, 51774.247747), -- High-Grade Suede
(22638, 9628, 1, 1, 2, 4872.783801), -- Leonard
(22638, 9630, 1, 1, 2, 3269.914659), -- Orichalcum
(22638, 9629, 1, 1, 2, 2701.226408), -- Adamantine
(22638, 9547, 1, 1, 2, 4970.503028), -- Water Stone
-- Assassin Beetle
(22639, 6695, 1, 1, -1, 21515), -- Demon Splinter Blade
(22639, 7579, 1, 1, -1, 22182), -- Draconic Bow Shaft
(22639, 5282, 1, 1, -1, 4509), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22639, 57, 1892, 3724, 0, 700000), -- Adena
(22639, 6679, 1, 1, 1, 22.329622), -- Sealed Imperial Crusader Helmet
(22639, 6683, 1, 1, 1, 22.329622), -- Sealed Draconic Leather Helmet
(22639, 6687, 1, 1, 1, 22.329622), -- Sealed Major Arcana Circlet
(22639, 6678, 1, 1, 1, 31.91195), -- Sealed Imperial Crusader Shield
(22639, 13885, 1, 1, 1, 21.280462), -- Sealed Arcana Sigil
(22639, 6706, 1, 1, 1, 8682.900618), -- Sealed Imperial Crusader Helmet Pattern
(22639, 6710, 1, 1, 1, 8682.918104), -- Sealed Draconic Leather Helmet Pattern
(22639, 1895, 1, 1, 2, 214045.57408), -- Metallic Fiber
(22639, 4040, 1, 1, 2, 14983.13024), -- Mold Lubricant
(22639, 4042, 1, 1, 2, 12486.12352), -- Enria
(22639, 4043, 1, 1, 2, 24971.97456), -- Asofe
(22639, 9548, 1, 1, 2, 5993.1976), -- Earth Stone
-- Mercenary of Destruction
(22640, 5529, 1, 1, -1, 27117), -- Dragon Slayer Edge
(22640, 1808, 1, 1, -1, 4393), -- Recipe: Soulshot (S-Grade)
(22640, 5533, 1, 1, -1, 27112), -- Elysian Head
(22640, 57, 1843, 3629, 0, 700000), -- Adena
(22640, 6371, 1, 1, 1, 8.535478), -- Demon Splinter
(22640, 6695, 1, 1, 1, 3869.464522), -- Demon Splinter Blade
(22640, 1895, 1, 1, 2, 208543.512528), -- Metallic Fiber
(22640, 4040, 1, 1, 2, 14598.122212), -- Mold Lubricant
(22640, 9628, 1, 1, 2, 5724.650906), -- Leonard
(22640, 9630, 1, 1, 2, 3841.560888), -- Orichalcum
(22640, 9549, 1, 1, 2, 5839.153466), -- Wind Stone
-- Knight of Destruction
(22641, 6703, 1, 1, -1, 144268), -- Sealed Imperial Crusader Gauntlets Design
(22641, 6704, 1, 1, -1, 144268), -- Sealed Imperial Crusader Boots Design
(22641, 5277, 1, 1, -1, 4503), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22641, 57, 1890, 3720, 0, 700000), -- Adena
(22641, 6364, 1, 1, 1, 4.375035), -- Forgotten Blade
(22641, 6372, 1, 1, 1, 4.375035), -- Heaven's Divider
(22641, 6688, 1, 1, 1, 2022.062745), -- Forgotten Blade Edge
(22641, 6696, 1, 1, 1, 2054.187185), -- Heavens Divider Edge
(22641, 1879, 1, 1, 2, 103924.672299), -- Cokes
(22641, 1885, 1, 1, 2, 51962.422029), -- High-Grade Suede
(22641, 9628, 1, 1, 2, 4890.494007), -- Leonard
(22641, 9630, 1, 1, 2, 3281.799213), -- Orichalcum
(22641, 9629, 1, 1, 2, 2711.044056), -- Adamantine
(22641, 9550, 1, 1, 2, 4988.568396), -- Dark Stone
-- Lavastone Golem
(22642, 3036, 1, 1, -1, 5783), -- Recipe: Spiritshot S
(22642, 959, 1, 1, -1, 520), -- Scroll: Enchant Weapon (S-Grade)
(22642, 3957, 1, 1, -1, 5783), -- Recipe: Blessed Spiritshot S
(22642, 57, 2427, 4777, 0, 700000), -- Adena
(22642, 6370, 1, 1, 1, 11.234937), -- Saint Spear
(22642, 6694, 1, 1, 1, 5285.765063), -- Saint Spear Blade
(22642, 1894, 1, 1, 2, 33714.438336), -- Crafted Leather
(22642, 4039, 1, 1, 2, 32028.739182), -- Mold Glue
(22642, 4041, 1, 1, 2, 8355.313368), -- Mold Hardener
(22642, 4044, 1, 1, 2, 32028.739182), -- Thons
(22642, 9551, 1, 1, 2, 7686.769932), -- Holy Stone
-- Magma Golem
(22643, 6688, 1, 1, -1, 29596), -- Forgotten Blade Edge
(22643, 960, 1, 1, -1, 5477), -- Scroll: Enchant Armor (S-Grade)
(22643, 1894, 1, 1, -1, 480429), -- Crafted Leather
(22643, 57, 2554, 5027, 0, 700000), -- Adena
(22643, 6684, 1, 1, 1, 32.454675), -- Sealed Major Arcana Robe
(22643, 6711, 1, 1, 1, 12522.545325), -- Sealed Major Arcana Robe Part
(22643, 1895, 1, 1, 2, 240742.26592), -- Metallic Fiber
(22643, 4040, 1, 1, 2, 16852.00582), -- Mold Lubricant
(22643, 4042, 1, 1, 2, 14043.27262), -- Enria
(22643, 4043, 1, 1, 2, 28086.54524), -- Asofe
(22643, 959, 1, 1, 2, 33.83068), -- Scroll: Enchant Weapon (S-Grade)
(22643, 1345, 60, 180, 2, 93622.07972), -- Shining Arrow
-- Arimanes of Destruction
(22644, 6708, 1, 1, -1, 196689), -- Sealed Draconic Leather Gloves Fabric
(22644, 6709, 1, 1, -1, 196689), -- Sealed Draconic Leather Boots Design
(22644, 5157, 1, 1, -1, 6140), -- Recipe: Soulshot (S) Compressed Package (100%)
(22644, 57, 2576, 5071, 0, 700000), -- Adena
(22644, 6365, 1, 1, 1, 3.97607), -- Basalt Battlehammer
(22644, 6366, 1, 1, 1, 3.97607), -- Imperial Staff
(22644, 6369, 1, 1, 1, 3.97607), -- Dragon Hunter Axe
(22644, 6689, 1, 1, 1, 1803.98554), -- Basalt Battlehammer Head
(22644, 6690, 1, 1, 1, 1842.13148), -- Imperial Staff Head
(22644, 6693, 1, 1, 1, 1871.95477), -- Dragon Hunter Axe Blade
(22644, 1895, 1, 1, 2, 291470.589124), -- Metallic Fiber
(22644, 4040, 1, 1, 2, 20403.074756), -- Mold Lubricant
(22644, 9628, 1, 1, 2, 8001.26964), -- Leonard
(22644, 9630, 1, 1, 2, 5369.350176), -- Orichalcum
(22644, 960, 1, 1, 2, 407.716304), -- Scroll: Enchant Armor (S-Grade)
-- Balor of Destruction
(22645, 6712, 1, 1, -1, 186681), -- Sealed Major Arcana Gloves fabric
(22645, 5162, 1, 1, -1, 5827), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22645, 6713, 1, 1, -1, 186681), -- Sealed Major Arcana Boots Design
(22645, 57, 2445, 4813, 0, 700000), -- Adena
(22645, 6371, 1, 1, 1, 11.321944), -- Demon Splinter
(22645, 6695, 1, 1, 1, 5132.678056), -- Demon Splinter Blade
(22645, 1894, 1, 1, 2, 33973.145032), -- Crafted Leather
(22645, 4039, 1, 1, 2, 32274.519992), -- Mold Glue
(22645, 4041, 1, 1, 2, 8419.468008), -- Mold Hardener
(22645, 4044, 1, 1, 2, 32274.519992), -- Thons
(22645, 5272, 1, 1, 2, 430.346976), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Ashuras of Destruction
(22646, 6706, 1, 1, -1, 328015), -- Sealed Imperial Crusader Helmet Pattern
(22646, 6710, 1, 1, -1, 328015), -- Sealed Draconic Leather Helmet Pattern
(22646, 57, 2514, 4949, 0, 700000), -- Adena
(22646, 6680, 1, 1, 1, 31.953185), -- Sealed Draconic Leather Armor
(22646, 6707, 1, 1, 1, 12329.046815), -- Sealed Draconic Leather Armor Part
(22646, 1895, 1, 1, 2, 284419.898995), -- Metallic Fiber
(22646, 4040, 1, 1, 2, 19909.474475), -- Mold Lubricant
(22646, 4042, 1, 1, 2, 16591.28782), -- Enria
(22646, 4043, 1, 1, 2, 33182.221095), -- Asofe
(22646, 5277, 1, 1, 2, 442.117615), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
-- Lavasillisk
(22647, 6706, 1, 1, -1, 343236), -- Sealed Imperial Crusader Helmet Pattern
(22647, 6710, 1, 1, -1, 343236), -- Sealed Draconic Leather Helmet Pattern
(22647, 57, 2631, 5178, 0, 700000), -- Adena
(22647, 6674, 1, 1, 1, 20.375586), -- Sealed Imperial Crusader Breastplate
(22647, 6675, 1, 1, 1, 32.591394), -- Sealed Imperial Crusader Gaiters
(22647, 6701, 1, 1, 1, 6930.991782), -- Sealed Imperial Crusader Breastplate Part
(22647, 6702, 1, 1, 1, 8922.041238), -- Sealed Imperial Crusader Gaiters Pattern
(22647, 1879, 1, 1, 2, 144675.4013), -- Cokes
(22647, 1885, 1, 1, 2, 72337.70065), -- High-Grade Suede
(22647, 9628, 1, 1, 2, 6808.36635), -- Leonard
(22647, 9630, 1, 1, 2, 4568.6773), -- Orichalcum
(22647, 9629, 1, 1, 2, 3774.05395), -- Adamantine
(22647, 5282, 1, 1, 2, 385.80045), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Blazing Ifrit
(22648, 5282, 1, 1, -1, 6136), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22648, 5529, 1, 1, -1, 37877), -- Dragon Slayer Edge
(22648, 1808, 1, 1, -1, 6136), -- Recipe: Soulshot (S-Grade)
(22648, 57, 2575, 5068, 0, 700000), -- Adena
(22648, 6370, 1, 1, 1, 11.922141), -- Saint Spear
(22648, 6694, 1, 1, 1, 5609.077859), -- Saint Spear Blade
(22648, 1895, 1, 1, 2, 291298.136418), -- Metallic Fiber
(22648, 4040, 1, 1, 2, 20390.849985), -- Mold Lubricant
(22648, 9628, 1, 1, 2, 7996.565204), -- Leonard
(22648, 9630, 1, 1, 2, 5366.150447), -- Orichalcum
(22648, 6901, 1, 1, 2, 1019.297946), -- Recipe: Shining Arrow (100%)
-- Magma Drake
(22649, 5533, 1, 1, -1, 39094), -- Elysian Head
(22649, 1894, 1, 1, -1, 500089), -- Crafted Leather
(22649, 57, 2658, 5232, 0, 700000), -- Adena
(22649, 6724, 1, 1, 1, 53.644115), -- Sealed Tateossian Earring
(22649, 6725, 1, 1, 1, 80.442665), -- Sealed Tateossian Ring
(22649, 6726, 1, 1, 1, 40.197825), -- Sealed Tateossian Necklace
(22649, 6698, 1, 1, 1, 17226.437045), -- Sealed Tateossian Earring Part
(22649, 6699, 1, 1, 1, 19115.029595), -- Sealed Tateossian Ring Gem
(22649, 6700, 1, 1, 1, 10499.248755), -- Sealed Tateossian Necklace Chain
(22649, 1895, 1, 1, 2, 300712.804405), -- Metallic Fiber
(22649, 4040, 1, 1, 2, 21049.982525), -- Mold Lubricant
(22649, 4042, 1, 1, 2, 17541.71458), -- Enria
(22649, 4043, 1, 1, 2, 35083.054305), -- Asofe
(22649, 5157, 1, 1, 2, 467.444185), -- Recipe: Soulshot (S) Compressed Package (100%)
-- Mucrokian Fanatic
(22650, 959, 1, 1, -1, 241), -- Scroll: Enchant Weapon (S-Grade)
(22650, 3036, 1, 1, -1, 2680), -- Recipe: Spiritshot S
(22650, 10397, 1, 1, -1, 2585), -- Icarus Sawsword Piece
(22650, 57, 1476, 2979, 0, 700000), -- Adena
(22650, 9442, 1, 1, 1, 0.881227), -- Dynasty Sword
(22650, 9443, 1, 1, 1, 0.881227), -- Dynasty Blade
(22650, 9444, 1, 1, 1, 0.881227), -- Dynasty Phantom
(22650, 9616, 1, 1, 1, 275.45183), -- Dynasty Sword Piece
(22650, 9617, 1, 1, 1, 275.45183), -- Dynasty Blade Piece
(22650, 9618, 1, 1, 1, 275.452659), -- Dynasty Phantom Piece
(22650, 1895, 1, 1, 2, 169743.034334), -- Metallic Fiber
(22650, 4040, 1, 1, 2, 11882.06107), -- Mold Lubricant
(22650, 4042, 1, 1, 2, 9901.752824), -- Enria
(22650, 4043, 1, 1, 2, 19803.294054), -- Asofe
(22650, 5162, 1, 1, 2, 263.857718), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Mucrokian Ascetic
(22651, 10405, 1, 1, -1, 2666), -- Icarus Spitter Piece
(22651, 9630, 1, 1, -1, 32839), -- Orichalcum
(22651, 959, 1, 1, -1, 250), -- Scroll: Enchant Weapon (S-Grade)
(22651, 57, 1527, 3083, 0, 700000), -- Adena
(22651, 9448, 1, 1, 1, 0.683605), -- Dynasty Cudgel
(22651, 9449, 1, 1, 1, 0.683605), -- Dynasty Mace
(22651, 10252, 1, 1, 1, 0.683605), -- Dynasty Staff
(22651, 10253, 1, 1, 1, 0.683605), -- Dynasty Crusher
(22651, 9622, 1, 1, 1, 206.802765), -- Dynasty Cudgel Piece
(22651, 9623, 1, 1, 1, 206.802765), -- Dynasty Mace Piece
(22651, 10546, 1, 1, 1, 214.33087), -- Dynasty Staff Fragment
(22651, 10547, 1, 1, 1, 214.32918), -- Dynasty Crusher Fragment
(22651, 1879, 1, 1, 2, 85378.705862), -- Cokes
(22651, 1885, 1, 1, 2, 42689.352931), -- High-Grade Suede
(22651, 9628, 1, 1, 2, 4017.887649), -- Leonard
(22651, 9630, 1, 1, 2, 2696.158102), -- Orichalcum
(22651, 9629, 1, 1, 2, 2227.219273), -- Adamantine
(22651, 5167, 1, 1, 2, 227.676183), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
-- Mucrokian Savior
(22652, 9532, 1, 1, -1, 22224), -- Sealed Dynasty Helmet Piece
(22652, 9630, 1, 1, -1, 32529), -- Orichalcum
(22652, 10402, 1, 1, -1, 2641), -- Icarus Hammer Piece
(22652, 57, 1500, 3065, 0, 700000), -- Adena
(22652, 10221, 1, 1, 1, 1.963571), -- Icarus Hand
(22652, 10403, 1, 1, 1, 651.036429), -- Icarus Hand Piece
(22652, 1894, 1, 1, 2, 13353.42828), -- Crafted Leather
(22652, 4039, 1, 1, 2, 12685.7364), -- Mold Glue
(22652, 4041, 1, 1, 2, 3309.30672), -- Mold Hardener
(22652, 4044, 1, 1, 2, 12685.7364), -- Thons
(22652, 9573, 1, 1, 2, 2642.8428), -- Life Stone - Level 80
(22652, 9574, 1, 1, 2, 660.73344), -- Mid-Grade Life Stone - Level 80
(22652, 9575, 1, 1, 2, 66.08244), -- High-Grade Life Stone - Level 80
(22652, 9625, 1, 1, 2, 76.13352), -- Giant's Codex - Oblivion
-- Mucrokian Preacher
(22653, 10397, 1, 1, -1, 2742), -- Icarus Sawsword Piece
(22653, 10403, 1, 1, -1, 2733), -- Icarus Hand Piece
(22653, 10400, 1, 1, -1, 2733), -- Icarus Heavy Arms Piece
(22653, 57, 1552, 3172, 0, 700000), -- Adena
(22653, 10223, 1, 1, 1, 2.029725), -- Icarus Spitter
(22653, 10405, 1, 1, 1, 672.970275), -- Icarus Spitter Piece
(22653, 1894, 1, 1, 2, 13817.119575), -- Crafted Leather
(22653, 4039, 1, 1, 2, 13126.251838), -- Mold Glue
(22653, 4041, 1, 1, 2, 3424.237565), -- Mold Hardener
(22653, 4044, 1, 1, 2, 13126.251838), -- Thons
(22653, 9573, 1, 1, 2, 2734.639719), -- Life Stone - Level 80
(22653, 9574, 1, 1, 2, 683.671688), -- Mid-Grade Life Stone - Level 80
(22653, 9575, 1, 1, 2, 68.385982), -- High-Grade Life Stone - Level 80
(22653, 9626, 1, 1, 2, 52.441795), -- Giant's Codex - Discipline
-- Contaminated Mucrokian
(22654, 9542, 1, 1, -1, 7860), -- Sealed Dynasty Circlet Piece
(22654, 9630, 1, 1, -1, 11505), -- Orichalcum
(22654, 9991, 1, 1, -1, 5125), -- Sealed Dynasty Earring Gemstone
(22654, 57, 535, 1080, 0, 700000), -- Adena
(22654, 9446, 1, 1, 1, 0.9576), -- Dynasty Knife
(22654, 9620, 1, 1, 1, 299.0424), -- Dynasty Knife Piece
(22654, 1879, 1, 1, 2, 17946.696859), -- Cokes
(22654, 1885, 1, 1, 2, 8973.297229), -- High-Grade Suede
(22654, 9628, 1, 1, 2, 844.501047), -- Leonard
(22654, 9630, 1, 1, 2, 566.687134), -- Orichalcum
(22654, 9629, 1, 1, 2, 468.177372), -- Adamantine
(22654, 9573, 1, 1, 2, 747.732102), -- Life Stone - Level 80
(22654, 9574, 1, 1, 2, 186.984226), -- Mid-Grade Life Stone - Level 80
(22654, 9575, 1, 1, 2, 18.739383), -- High-Grade Life Stone - Level 80
(22654, 9546, 1, 1, 2, 861.397212), -- Fire Stone
(22654, 1345, 10, 30, 2, 71786.787436), -- Shining Arrow
-- Awakened Mucrokian
(22655, 9542, 1, 1, -1, 40033), -- Sealed Dynasty Circlet Piece
(22655, 1808, 1, 1, -1, 4948), -- Recipe: Soulshot (S-Grade)
(22655, 9530, 1, 1, -1, 16215), -- Sealed Dynasty Breast Plate Piece
(22655, 57, 2702, 5522, 0, 700000), -- Adena
(22655, 9447, 1, 1, 1, 4.879975), -- Dynasty Halberd
(22655, 9621, 1, 1, 1, 1532.120025), -- Dynasty Halberd Piece
(22655, 1894, 1, 1, 2, 24054.822775), -- Crafted Leather
(22655, 4039, 1, 1, 2, 22852.086), -- Mold Glue
(22655, 4041, 1, 1, 2, 5961.40615), -- Mold Hardener
(22655, 4044, 1, 1, 2, 22852.086), -- Thons
(22655, 9573, 1, 1, 2, 4760.85125), -- Life Stone - Level 80
(22655, 9574, 1, 1, 2, 1190.25645), -- Mid-Grade Life Stone - Level 80
(22655, 9575, 1, 1, 2, 119.0431), -- High-Grade Life Stone - Level 80
(22655, 9547, 1, 1, 2, 5484.448275), -- Water Stone
-- Suppressor
(22656, 6901, 1, 1, -1, 6030), -- Recipe: Shining Arrow (100%)
(22656, 10114, 1, 1, -1, 14951), -- Sealed Dynasty Sigil Piece
(22656, 960, 1, 1, -1, 2412), -- Scroll: Enchant Armor (S-Grade)
(22656, 57, 1476, 2979, 0, 700000), -- Adena
(22656, 9514, 1, 1, 1, 4.05834), -- Sealed Dynasty Breast Plate
(22656, 9515, 1, 1, 1, 6.49077), -- Sealed Dynasty Gaiter
(22656, 9530, 1, 1, 1, 1081.23444), -- Sealed Dynasty Breast Plate Piece
(22656, 9531, 1, 1, 1, 3198.21645), -- Sealed Dynasty Gaiters Piece
(22656, 1879, 1, 1, 2, 55009.524684), -- Cokes
(22656, 1885, 1, 1, 2, 27504.762342), -- High-Grade Suede
(22656, 9628, 1, 1, 2, 2588.708906), -- Leonard
(22656, 9630, 1, 1, 2, 1737.129056), -- Orichalcum
(22656, 9629, 1, 1, 2, 1435.064534), -- Adamantine
(22656, 9573, 1, 1, 2, 2292.086988), -- Life Stone - Level 80
(22656, 9574, 1, 1, 2, 572.974828), -- Mid-Grade Life Stone - Level 80
(22656, 9575, 1, 1, 2, 57.335018), -- High-Grade Life Stone - Level 80
(22656, 9548, 1, 1, 2, 2640.413644), -- Earth Stone
-- Executioner
(22657, 9532, 1, 1, -1, 22224), -- Sealed Dynasty Helmet Piece
(22657, 10399, 1, 1, -1, 2650), -- Icarus Spirit Piece
(22657, 10401, 1, 1, -1, 2641), -- Icarus Trident Piece
(22657, 57, 1500, 3065, 0, 700000), -- Adena
(22657, 9519, 1, 1, 1, 5.546676), -- Sealed Dynasty Leather Armor
(22657, 9520, 1, 1, 1, 8.874006), -- Sealed Dynasty Leather Leggings
(22657, 9535, 1, 1, 1, 1361.803542), -- Sealed Dynasty Leather Armor Piece
(22657, 9536, 1, 1, 1, 2001.775776), -- Sealed Dynasty Leather Leggings Piece
(22657, 1879, 1, 1, 2, 56381.274804), -- Cokes
(22657, 1885, 1, 1, 2, 28190.637402), -- High-Grade Suede
(22657, 9628, 1, 1, 2, 2653.262486), -- Leonard
(22657, 9630, 1, 1, 2, 1780.447136), -- Orichalcum
(22657, 9629, 1, 1, 2, 1470.850154), -- Adamantine
(22657, 9573, 1, 1, 2, 2349.243828), -- Life Stone - Level 80
(22657, 9574, 1, 1, 2, 587.262868), -- Mid-Grade Life Stone - Level 80
(22657, 9575, 1, 1, 2, 58.764758), -- High-Grade Life Stone - Level 80
(22657, 9549, 1, 1, 2, 2706.256564), -- Wind Stone
-- Sentinel Waterspirit
(22658, 10399, 1, 1, -1, 2675), -- Icarus Spirit Piece
(22658, 10398, 1, 1, -1, 2675), -- Icarus Disperser Piece
(22658, 10404, 1, 1, -1, 2666), -- Icarus Hall Piece
(22658, 57, 1527, 3083, 0, 700000), -- Adena
(22658, 9524, 1, 1, 1, 5.59922), -- Sealed Dynasty Tunic
(22658, 9525, 1, 1, 1, 8.95807), -- Sealed Dynasty Stockings
(22658, 9540, 1, 1, 1, 1374.70399), -- Sealed Dynasty Tunic Piece
(22658, 9541, 1, 1, 1, 2020.73872), -- Sealed Dynasty Stocking Piece
(22658, 1894, 1, 1, 2, 13480.898731), -- Crafted Leather
(22658, 4039, 1, 1, 2, 12806.85624), -- Mold Glue
(22658, 4041, 1, 1, 2, 3340.914766), -- Mold Hardener
(22658, 4044, 1, 1, 2, 12806.85624), -- Thons
(22658, 9573, 1, 1, 2, 2668.09505), -- Life Stone - Level 80
(22658, 9574, 1, 1, 2, 667.048218), -- Mid-Grade Life Stone - Level 80
(22658, 9575, 1, 1, 2, 66.714604), -- High-Grade Life Stone - Level 80
(22658, 9550, 1, 1, 2, 3073.616151), -- Dark Stone
-- Guardian Waterspirit
(22659, 9630, 1, 1, -1, 33659), -- Orichalcum
(22659, 959, 1, 1, -1, 256), -- Scroll: Enchant Weapon (S-Grade)
(22659, 9991, 1, 1, -1, 14995), -- Sealed Dynasty Earring Gemstone
(22659, 57, 1552, 3172, 0, 700000), -- Adena
(22659, 9452, 1, 1, 1, 17.361484), -- Sealed Dynasty Earring
(22659, 9453, 1, 1, 1, 13.019132), -- Sealed Dynasty Necklace
(22659, 9454, 1, 1, 1, 26.042226), -- Sealed Dynasty Ring
(22659, 9991, 1, 1, 1, 1230.945856), -- Sealed Dynasty Earring Gemstone
(22659, 9992, 1, 1, 1, 944.71909), -- Sealed Dynasty Necklace Gemstone
(22659, 9993, 1, 1, 1, 1729.912212), -- Sealed Dynasty Ring Gemstone
(22659, 1879, 1, 1, 2, 58339.242924), -- Cokes
(22659, 1885, 1, 1, 2, 29169.621462), -- High-Grade Suede
(22659, 9628, 1, 1, 2, 2745.403066), -- Leonard
(22659, 9630, 1, 1, 2, 1842.277216), -- Orichalcum
(22659, 9629, 1, 1, 2, 1521.928774), -- Adamantine
(22659, 9573, 1, 1, 2, 2430.826668), -- Life Stone - Level 80
(22659, 9574, 1, 1, 2, 607.656908), -- Mid-Grade Life Stone - Level 80
(22659, 9575, 1, 1, 2, 60.805498), -- High-Grade Life Stone - Level 80
(22659, 9551, 1, 1, 2, 2800.237484), -- Holy Stone
-- Lesser Giant
(22660, 9630, 1, 1, -1, 263370), -- Orichalcum
(22660, 9991, 1, 1, -1, 117329), -- Sealed Dynasty Earring Gemstone
(22660, 9619, 1, 1, -1, 28010), -- Dynasty Bow Piece
(22660, 57, 12255, 24722, 0, 700000), -- Adena
(22660, 9517, 1, 1, 1, 44.90771), -- Sealed Dynasty Gauntlets
(22660, 9518, 1, 1, 1, 44.90771), -- Sealed Dynasty Boots
(22660, 9522, 1, 1, 1, 44.90771), -- Sealed Dynasty Leather Gloves
(22660, 9523, 1, 1, 1, 44.90771), -- Sealed Dynasty Leather Boots
(22660, 9527, 1, 1, 1, 44.90771), -- Sealed Dynasty Gloves
(22660, 9528, 1, 1, 1, 44.90771), -- Sealed Dynasty Shoes
(22660, 9533, 1, 1, 1, 9829.278705), -- Sealed Dynasty Gauntlet Piece
(22660, 9534, 1, 1, 1, 9829.278705), -- Sealed Dynasty Boot Piece
(22660, 9538, 1, 1, 1, 9829.278705), -- Sealed Dynasty Leather Glove Piece
(22660, 9539, 1, 1, 1, 9829.278705), -- Sealed Dynasty Leather Boots Piece
(22660, 9543, 1, 1, 1, 9829.278705), -- Sealed Dynasty Glove Piece
(22660, 9544, 1, 1, 1, 9829.160215), -- Sealed Dynasty Shoes Piece
(22660, 1879, 3, 9, 2, 76081.50336), -- Cokes
(22660, 1885, 1, 1, 2, 228244.51008), -- High-Grade Suede
(22660, 9628, 1, 1, 2, 21481.880536), -- Leonard
(22660, 9630, 1, 1, 2, 14415.502188), -- Orichalcum
(22660, 9629, 1, 1, 2, 11908.44196), -- Adamantine
(22660, 9573, 1, 1, 2, 19020.37584), -- Life Stone - Level 80
(22660, 9574, 1, 1, 2, 4755.09396), -- Mid-Grade Life Stone - Level 80
(22660, 9575, 1, 1, 2, 475.509396), -- High-Grade Life Stone - Level 80
(22660, 959, 1, 1, 2, 109.18268), -- Scroll: Enchant Weapon (S-Grade)
-- Lesser Giant Soldier
(22661, 9541, 1, 1, -1, 134861), -- Sealed Dynasty Stocking Piece
(22661, 1808, 1, 1, -1, 22792), -- Recipe: Soulshot (S-Grade)
(22661, 9620, 1, 1, -1, 28491), -- Dynasty Knife Piece
(22661, 57, 12560, 25336, 0, 700000), -- Adena
(22661, 9516, 1, 1, 1, 36.816472), -- Sealed Dynasty Helmet
(22661, 9529, 1, 1, 1, 52.59496), -- Sealed Dynasty Shield
(22661, 13886, 1, 1, 1, 52.59496), -- Sealed Dynasty Sigil
(22661, 9521, 1, 1, 1, 36.816472), -- Sealed Dynasty Leather Helmet
(22661, 9526, 1, 1, 1, 36.816472), -- Sealed Dynasty Circlet
(22661, 9532, 1, 1, 1, 9086.626208), -- Sealed Dynasty Helmet Piece
(22661, 9537, 1, 1, 1, 9086.626208), -- Sealed Dynasty Leather Helmet Piece
(22661, 9542, 1, 1, 1, 9086.626208), -- Sealed Dynasty Circlet Piece
(22661, 9545, 1, 1, 1, 10830.951428), -- Sealed Dynasty Shield Piece
(22661, 10114, 1, 1, 1, 6265.530612), -- Sealed Dynasty Sigil Piece
(22661, 1879, 3, 9, 2, 77970.995856), -- Cokes
(22661, 1885, 1, 1, 2, 233912.987568), -- High-Grade Suede
(22661, 9628, 1, 1, 2, 22015.417377), -- Leonard
(22661, 9630, 1, 1, 2, 14773.529217), -- Orichalcum
(22661, 9629, 1, 1, 2, 12204.051591), -- Adamantine
(22661, 9573, 1, 1, 2, 19492.748964), -- Life Stone - Level 80
(22661, 9574, 1, 1, 2, 4873.187241), -- Mid-Grade Life Stone - Level 80
(22661, 9575, 1, 1, 2, 487.43478), -- High-Grade Life Stone - Level 80
(22661, 960, 1, 1, 2, 1122.647406), -- Scroll: Enchant Armor (S-Grade)
-- Lesser Giant Shooter
(22662, 960, 1, 1, -1, 19489), -- Scroll: Enchant Armor (S-Grade)
(22662, 1894, 1, 3, -1, 854794), -- Crafted Leather
(22662, 9545, 1, 1, -1, 208828), -- Sealed Dynasty Shield Piece
(22662, 57, 11942, 24057, 0, 700000), -- Adena
(22662, 9442, 1, 1, 1, 7.116785), -- Dynasty Sword
(22662, 9443, 1, 1, 1, 7.116785), -- Dynasty Blade
(22662, 9444, 1, 1, 1, 7.116785), -- Dynasty Phantom
(22662, 9616, 1, 1, 1, 2224.54765), -- Dynasty Sword Piece
(22662, 9617, 1, 1, 1, 2224.54765), -- Dynasty Blade Piece
(22662, 9618, 1, 1, 1, 2224.554345), -- Dynasty Phantom Piece
(22662, 1879, 3, 9, 2, 74078.911907), -- Cokes
(22662, 1885, 1, 1, 2, 222236.735721), -- High-Grade Suede
(22662, 9628, 1, 1, 2, 20916.23429), -- Leonard
(22662, 9630, 1, 1, 2, 14035.826336), -- Orichalcum
(22662, 9629, 1, 1, 2, 11594.924957), -- Adamantine
(22662, 9573, 1, 1, 2, 18519.819892), -- Life Stone - Level 80
(22662, 9574, 1, 1, 2, 4629.954973), -- Mid-Grade Life Stone - Level 80
(22662, 9575, 1, 1, 2, 462.885199), -- High-Grade Life Stone - Level 80
(22662, 5272, 1, 1, 2, 1185.706725), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Lesser Giant Scout
(22663, 9992, 1, 1, -1, 87677), -- Sealed Dynasty Necklace Gemstone
(22663, 9624, 1, 1, -1, 26227), -- Dynasty Bagh-Nakh Piece
(22663, 9530, 1, 1, -1, 70960), -- Sealed Dynasty Breast Plate Piece
(22663, 57, 11942, 24057, 0, 700000), -- Adena
(22663, 9448, 1, 1, 1, 5.337782), -- Dynasty Cudgel
(22663, 9449, 1, 1, 1, 5.337782), -- Dynasty Mace
(22663, 10252, 1, 1, 1, 5.337782), -- Dynasty Staff
(22663, 10253, 1, 1, 1, 5.337782), -- Dynasty Crusher
(22663, 9622, 1, 1, 1, 1614.774726), -- Dynasty Cudgel Piece
(22663, 9623, 1, 1, 1, 1614.774726), -- Dynasty Mace Piece
(22663, 10546, 1, 1, 1, 1673.556308), -- Dynasty Staff Fragment
(22663, 10547, 1, 1, 1, 1673.543112), -- Dynasty Crusher Fragment
(22663, 1879, 3, 9, 2, 74078.911907), -- Cokes
(22663, 1885, 1, 1, 2, 222236.735721), -- High-Grade Suede
(22663, 9628, 1, 1, 2, 20916.23429), -- Leonard
(22663, 9630, 1, 1, 2, 14035.826336), -- Orichalcum
(22663, 9629, 1, 1, 2, 11594.924957), -- Adamantine
(22663, 9573, 1, 1, 2, 18519.819892), -- Life Stone - Level 80
(22663, 9574, 1, 1, 2, 4629.954973), -- Mid-Grade Life Stone - Level 80
(22663, 9575, 1, 1, 2, 462.885199), -- High-Grade Life Stone - Level 80
(22663, 5277, 1, 1, 2, 1185.706725), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
-- Lesser Giant Mage
(22664, 9630, 1, 1, -1, 262026), -- Orichalcum
(22664, 9617, 1, 1, -1, 27681), -- Dynasty Blade Piece
(22664, 9537, 1, 1, -1, 179013), -- Sealed Dynasty Leather Helmet Piece
(22664, 57, 12203, 24581, 0, 700000), -- Adena
(22664, 9450, 1, 1, 1, 21.816162), -- Dynasty Bagh-Nakh
(22664, 9624, 1, 1, 1, 6601.183838), -- Dynasty Bagh-Nakh Piece
(22664, 1895, 3, 9, 2, 145979.736), -- Metallic Fiber
(22664, 4040, 1, 1, 2, 61311.433925), -- Mold Lubricant
(22664, 9628, 1, 1, 2, 24043.769925), -- Leonard
(22664, 9630, 1, 1, 2, 16134.6024), -- Orichalcum
(22664, 9573, 1, 1, 2, 21288.7115), -- Life Stone - Level 80
(22664, 9574, 1, 1, 2, 5322.177875), -- Mid-Grade Life Stone - Level 80
(22664, 9575, 1, 1, 2, 532.0798), -- High-Grade Life Stone - Level 80
(22664, 5282, 1, 1, 2, 1362.488575), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Lesser Giant Elder
(22665, 1808, 1, 1, -1, 21861), -- Recipe: Soulshot (S-Grade)
(22665, 9623, 1, 1, -1, 26477), -- Dynasty Mace Piece
(22665, 3036, 1, 1, -1, 21861), -- Recipe: Spiritshot S
(22665, 57, 12056, 24286, 0, 700000), -- Adena
(22665, 9445, 1, 1, 1, 21.555072), -- Dynasty Bow
(22665, 9619, 1, 1, 1, 6782.444928), -- Dynasty Bow Piece
(22665, 1895, 3, 9, 2, 144228.85882), -- Metallic Fiber
(22665, 4040, 1, 1, 2, 60576.0384), -- Mold Lubricant
(22665, 9628, 1, 1, 2, 23755.244624), -- Leonard
(22665, 9630, 1, 1, 2, 15940.99054), -- Orichalcum
(22665, 9573, 1, 1, 2, 21033.438116), -- Life Stone - Level 80
(22665, 9574, 1, 1, 2, 5258.428116), -- Mid-Grade Life Stone - Level 80
(22665, 9575, 1, 1, 2, 525.925116), -- High-Grade Life Stone - Level 80
(22665, 6901, 1, 1, 2, 3029.076268), -- Recipe: Shining Arrow (100%)
-- Barif
(22666, 9624, 1, 1, -1, 3146), -- Dynasty Bagh-Nakh Piece
(22666, 9630, 1, 1, -1, 30758), -- Orichalcum
(22666, 9628, 1, 1, -1, 45835), -- Leonard
(22666, 57, 1432, 2885, 0, 700000), -- Adena
(22666, 9446, 1, 1, 1, 2.559984), -- Dynasty Knife
(22666, 9620, 1, 1, 1, 799.440016), -- Dynasty Knife Piece
(22666, 1879, 1, 1, 2, 53311.100328), -- Cokes
(22666, 1885, 1, 1, 2, 26655.550164), -- High-Grade Suede
(22666, 9628, 1, 1, 2, 2508.77016), -- Leonard
(22666, 9630, 1, 1, 2, 1683.549432), -- Orichalcum
(22666, 9629, 1, 1, 2, 1390.71204), -- Adamantine
(22666, 9573, 1, 1, 2, 2221.332732), -- Life Stone - Level 80
(22666, 9574, 1, 1, 2, 555.311052), -- Mid-Grade Life Stone - Level 80
(22666, 9575, 1, 1, 2, 55.504548), -- High-Grade Life Stone - Level 80
(22666, 5157, 1, 1, 2, 142.169544), -- Recipe: Soulshot (S) Compressed Package (100%)
-- Barif's Pet
(22667, 9992, 1, 1, -1, 10850), -- Sealed Dynasty Necklace Gemstone
(22667, 3957, 1, 1, -1, 2680), -- Recipe: Blessed Spiritshot S
(22667, 9537, 1, 1, -1, 21680), -- Sealed Dynasty Leather Helmet Piece
(22667, 57, 1477, 2979, 0, 700000), -- Adena
(22667, 9447, 1, 1, 1, 2.6416), -- Dynasty Halberd
(22667, 9621, 1, 1, 1, 829.3584), -- Dynasty Halberd Piece
(22667, 1894, 1, 1, 2, 13026.976049), -- Crafted Leather
(22667, 4039, 1, 1, 2, 12375.651699), -- Mold Glue
(22667, 4041, 1, 1, 2, 3228.434744), -- Mold Hardener
(22667, 4044, 1, 1, 2, 12375.651699), -- Thons
(22667, 9573, 1, 1, 2, 2578.266328), -- Life Stone - Level 80
(22667, 9574, 1, 1, 2, 644.566582), -- Mid-Grade Life Stone - Level 80
(22667, 9575, 1, 1, 2, 64.46555), -- High-Grade Life Stone - Level 80
(22667, 5162, 1, 1, 2, 164.987349), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Gamlin
(22668, 5157, 1, 1, -1, 2259), -- Recipe: Soulshot (S) Compressed Package (100%)
(22668, 9622, 1, 1, -1, 2736), -- Dynasty Cudgel Piece
(22668, 9628, 1, 1, -1, 39865), -- Leonard
(22668, 57, 1245, 2511, 0, 700000), -- Adena
(22668, 9514, 1, 1, 1, 3.420736), -- Sealed Dynasty Breast Plate
(22668, 9515, 1, 1, 1, 5.471008), -- Sealed Dynasty Gaiter
(22668, 9530, 1, 1, 1, 911.362176), -- Sealed Dynasty Breast Plate Piece
(22668, 9531, 1, 1, 1, 2695.74608), -- Sealed Dynasty Gaiters Piece
(22668, 1879, 1, 1, 2, 46366.878446), -- Cokes
(22668, 1885, 1, 1, 2, 23183.439223), -- High-Grade Suede
(22668, 9628, 1, 1, 2, 2181.98162), -- Leonard
(22668, 9630, 1, 1, 2, 1464.252874), -- Orichalcum
(22668, 9629, 1, 1, 2, 1209.56003), -- Adamantine
(22668, 9573, 1, 1, 2, 1931.985349), -- Life Stone - Level 80
(22668, 9574, 1, 1, 2, 482.977089), -- Mid-Grade Life Stone - Level 80
(22668, 9575, 1, 1, 2, 48.274611), -- High-Grade Life Stone - Level 80
(22668, 5167, 1, 1, 2, 123.650758), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
-- Leogul
(22669, 9628, 1, 1, -1, 39865), -- Leonard
(22669, 9993, 1, 1, -1, 16748), -- Sealed Dynasty Ring Gemstone
(22669, 5162, 1, 1, -1, 2259), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22669, 57, 1245, 2511, 0, 700000), -- Adena
(22669, 9519, 1, 1, 1, 4.561476), -- Sealed Dynasty Leather Armor
(22669, 9520, 1, 1, 1, 7.297806), -- Sealed Dynasty Leather Leggings
(22669, 9535, 1, 1, 1, 1119.920142), -- Sealed Dynasty Leather Armor Piece
(22669, 9536, 1, 1, 1, 1646.220576), -- Sealed Dynasty Leather Leggings Piece
(22669, 1894, 1, 1, 2, 10981.638622), -- Crafted Leather
(22669, 4039, 1, 1, 2, 10432.53986), -- Mold Glue
(22669, 4041, 1, 1, 2, 2721.519128), -- Mold Hardener
(22669, 4044, 1, 1, 2, 10432.53986), -- Thons
(22669, 9573, 1, 1, 2, 2173.43022), -- Life Stone - Level 80
(22669, 9574, 1, 1, 2, 543.376256), -- Mid-Grade Life Stone - Level 80
(22669, 9575, 1, 1, 2, 54.345106), -- High-Grade Life Stone - Level 80
(22669, 9625, 1, 1, 2, 62.610948), -- Giant's Codex - Oblivion
-- Cursed Lord
(22670, 959, 1, 1, -1, 251), -- Scroll: Enchant Weapon (S-Grade)
(22670, 1894, 1, 1, -1, 220275), -- Crafted Leather
(22670, 9545, 1, 1, -1, 26907), -- Sealed Dynasty Shield Piece
(22670, 57, 1536, 3100, 0, 700000), -- Adena
(22670, 9524, 1, 1, 1, 5.633702), -- Sealed Dynasty Tunic
(22670, 9525, 1, 1, 1, 9.013237), -- Sealed Dynasty Stockings
(22670, 9540, 1, 1, 1, 1383.169909), -- Sealed Dynasty Tunic Piece
(22670, 9541, 1, 1, 1, 2033.183152), -- Sealed Dynasty Stocking Piece
(22670, 1879, 1, 1, 2, 57268.8681), -- Cokes
(22670, 1885, 1, 1, 2, 28634.43405), -- High-Grade Suede
(22670, 9628, 1, 1, 2, 2695.027908), -- Leonard
(22670, 9630, 1, 1, 2, 1808.495571), -- Orichalcum
(22670, 9629, 1, 1, 2, 1493.986992), -- Adamantine
(22670, 9573, 1, 1, 2, 2386.218669), -- Life Stone - Level 80
(22670, 9574, 1, 1, 2, 596.53092), -- Mid-Grade Life Stone - Level 80
(22670, 9575, 1, 1, 2, 59.653092), -- High-Grade Life Stone - Level 80
(22670, 9626, 1, 1, 2, 45.784698), -- Giant's Codex - Discipline
-- Cursed Guardian!
(22671, 9541, 1, 1, -1, 15745), -- Sealed Dynasty Stocking Piece
(22671, 1808, 1, 1, -1, 2661), -- Recipe: Soulshot (S-Grade)
(22671, 9620, 1, 1, -1, 3326), -- Dynasty Knife Piece
(22671, 57, 1465, 2956, 0, 700000), -- Adena
(22671, 9452, 1, 1, 1, 16.25722), -- Sealed Dynasty Earring
(22671, 9453, 1, 1, 1, 12.19106), -- Sealed Dynasty Necklace
(22671, 9454, 1, 1, 1, 24.38583), -- Sealed Dynasty Ring
(22671, 9991, 1, 1, 1, 1152.65248), -- Sealed Dynasty Earring Gemstone
(22671, 9992, 1, 1, 1, 884.63095), -- Sealed Dynasty Necklace Gemstone
(22671, 9993, 1, 1, 1, 1619.88246), -- Sealed Dynasty Ring Gemstone
(22671, 1894, 1, 1, 2, 17247.955158), -- Crafted Leather
(22671, 4039, 1, 1, 2, 16385.769666), -- Mold Glue
(22671, 4041, 1, 1, 2, 4274.649288), -- Mold Hardener
(22671, 4044, 1, 1, 2, 16385.769666), -- Thons
(22671, 9546, 1, 1, 2, 3932.70822), -- Fire Stone
(22671, 1345, 10, 30, 2, 327711.148002), -- Shining Arrow
-- Cursed Seer
(22672, 3036, 1, 1, -1, 2652), -- Recipe: Spiritshot S
(22672, 9992, 1, 1, -1, 10739), -- Sealed Dynasty Necklace Gemstone
(22672, 9628, 1, 1, -1, 46807), -- Leonard
(22672, 57, 1460, 2947, 0, 700000), -- Adena
(22672, 9517, 1, 1, 1, 5.356028), -- Sealed Dynasty Gauntlets
(22672, 9518, 1, 1, 1, 5.356028), -- Sealed Dynasty Boots
(22672, 9522, 1, 1, 1, 5.356028), -- Sealed Dynasty Leather Gloves
(22672, 9523, 1, 1, 1, 5.356028), -- Sealed Dynasty Leather Boots
(22672, 9527, 1, 1, 1, 5.356028), -- Sealed Dynasty Gloves
(22672, 9528, 1, 1, 1, 5.356028), -- Sealed Dynasty Shoes
(22672, 9533, 1, 1, 1, 1172.312994), -- Sealed Dynasty Gauntlet Piece
(22672, 9534, 1, 1, 1, 1172.312994), -- Sealed Dynasty Boot Piece
(22672, 9538, 1, 1, 1, 1172.312994), -- Sealed Dynasty Leather Glove Piece
(22672, 9539, 1, 1, 1, 1172.312994), -- Sealed Dynasty Leather Boots Piece
(22672, 9543, 1, 1, 1, 1172.312994), -- Sealed Dynasty Glove Piece
(22672, 9544, 1, 1, 1, 1172.298862), -- Sealed Dynasty Shoes Piece
(22672, 1879, 1, 1, 2, 81662.662926), -- Cokes
(22672, 1885, 1, 1, 2, 40831.398946), -- High-Grade Suede
(22672, 9628, 1, 1, 2, 3842.886918), -- Leonard
(22672, 9630, 1, 1, 2, 2578.795362), -- Orichalcum
(22672, 9629, 1, 1, 2, 2130.303344), -- Adamantine
(22672, 9547, 1, 1, 2, 3919.952504), -- Water Stone
-- Hirokai
(22673, 1894, 1, 1, -1, 180004), -- Crafted Leather
(22673, 9535, 1, 1, -1, 9178), -- Sealed Dynasty Leather Armor Piece
(22673, 3957, 1, 1, -1, 2280), -- Recipe: Blessed Spiritshot S
(22673, 57, 1255, 2533, 0, 700000), -- Adena
(22673, 9516, 1, 1, 1, 3.683424), -- Sealed Dynasty Helmet
(22673, 9529, 1, 1, 1, 5.260512), -- Sealed Dynasty Shield
(22673, 13886, 1, 1, 1, 5.260512), -- Sealed Dynasty Sigil
(22673, 9521, 1, 1, 1, 3.683424), -- Sealed Dynasty Leather Helmet
(22673, 9526, 1, 1, 1, 3.683424), -- Sealed Dynasty Circlet
(22673, 9532, 1, 1, 1, 908.605152), -- Sealed Dynasty Helmet Piece
(22673, 9542, 1, 1, 1, 908.605152), -- Sealed Dynasty Circlet Piece
(22673, 9545, 1, 1, 1, 1083.029664), -- Sealed Dynasty Shield Piece
(22673, 10114, 1, 1, 1, 626.505312), -- Sealed Dynasty Sigil Piece
(22673, 1879, 1, 1, 2, 70198.572159), -- Cokes
(22673, 1885, 1, 1, 2, 35099.344089), -- High-Grade Suede
(22673, 9628, 1, 1, 2, 3303.408987), -- Leonard
(22673, 9630, 1, 1, 2, 2216.775033), -- Orichalcum
(22673, 9629, 1, 1, 2, 1831.243896), -- Adamantine
(22673, 9548, 1, 1, 2, 3369.655836), -- Earth Stone
-- Imagro
(22674, 9992, 1, 1, -1, 8941), -- Sealed Dynasty Necklace Gemstone
(22674, 5157, 1, 1, -1, 2208), -- Recipe: Soulshot (S) Compressed Package (100%)
(22674, 9537, 1, 1, -1, 17866), -- Sealed Dynasty Leather Helmet Piece
(22674, 57, 1216, 2453, 0, 700000), -- Adena
(22674, 9442, 1, 1, 1, 0.726029), -- Dynasty Sword
(22674, 9443, 1, 1, 1, 0.726029), -- Dynasty Blade
(22674, 9444, 1, 1, 1, 0.726029), -- Dynasty Phantom
(22674, 9616, 1, 1, 1, 226.94041), -- Dynasty Sword Piece
(22674, 9617, 1, 1, 1, 226.94041), -- Dynasty Blade Piece
(22674, 9618, 1, 1, 1, 226.941093), -- Dynasty Phantom Piece
(22674, 1895, 1, 1, 2, 139864.108662), -- Metallic Fiber
(22674, 4040, 1, 1, 2, 9790.448436), -- Mold Lubricant
(22674, 4042, 1, 1, 2, 8158.825728), -- Enria
(22674, 4043, 1, 1, 2, 16317.473409), -- Asofe
(22674, 9549, 1, 1, 2, 3916.143765), -- Wind Stone
-- Palit
(22675, 1894, 1, 1, -1, 183232), -- Crafted Leather
(22675, 9628, 1, 1, -1, 40958), -- Leonard
(22675, 9536, 1, 1, -1, 13733), -- Sealed Dynasty Leather Leggings Piece
(22675, 57, 1278, 2578, 0, 700000), -- Adena
(22675, 9448, 1, 1, 1, 0.571963), -- Dynasty Cudgel
(22675, 9449, 1, 1, 1, 0.571963), -- Dynasty Mace
(22675, 10252, 1, 1, 1, 0.571963), -- Dynasty Staff
(22675, 10253, 1, 1, 1, 0.571963), -- Dynasty Crusher
(22675, 9622, 1, 1, 1, 173.029059), -- Dynasty Cudgel Piece
(22675, 9623, 1, 1, 1, 173.029059), -- Dynasty Mace Piece
(22675, 10546, 1, 1, 1, 179.327722), -- Dynasty Staff Fragment
(22675, 10547, 1, 1, 1, 179.326308), -- Dynasty Crusher Fragment
(22675, 1894, 1, 1, 2, 18052.483008), -- Crafted Leather
(22675, 4039, 1, 1, 2, 17149.871046), -- Mold Glue
(22675, 4041, 1, 1, 2, 4473.874104), -- Mold Hardener
(22675, 4044, 1, 1, 2, 17149.871046), -- Thons
(22675, 9550, 1, 1, 2, 4115.900796), -- Dark Stone
-- Hamlet
(22676, 5162, 1, 1, -1, 2280), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22676, 9622, 1, 1, -1, 2761), -- Dynasty Cudgel Piece
(22676, 5167, 1, 1, -1, 2280), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22676, 57, 1255, 2533, 0, 700000), -- Adena
(22676, 9450, 1, 1, 1, 2.246508), -- Dynasty Bagh-Nakh
(22676, 9624, 1, 1, 1, 679.753492), -- Dynasty Bagh-Nakh Piece
(22676, 1879, 1, 1, 2, 70198.572159), -- Cokes
(22676, 1885, 1, 1, 2, 35099.344089), -- High-Grade Suede
(22676, 9628, 1, 1, 2, 3303.408987), -- Leonard
(22676, 9630, 1, 1, 2, 2216.775033), -- Orichalcum
(22676, 9629, 1, 1, 2, 1831.243896), -- Adamantine
(22676, 9551, 1, 1, 2, 3369.655836), -- Holy Stone
-- Klennot
(22677, 1894, 1, 1, -1, 185045), -- Crafted Leather
(22677, 9993, 1, 1, -1, 17378), -- Sealed Dynasty Ring Gemstone
(22677, 5162, 1, 1, -1, 2344), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22677, 57, 1290, 2604, 0, 700000), -- Adena
(22677, 9445, 1, 1, 1, 2.309472), -- Dynasty Bow
(22677, 9619, 1, 1, 1, 726.690528), -- Dynasty Bow Piece
(22677, 1879, 1, 1, 2, 72164.243007), -- Cokes
(22677, 1885, 1, 1, 2, 36082.063593), -- High-Grade Suede
(22677, 9628, 1, 1, 2, 3395.987541), -- Leonard
(22677, 9630, 1, 1, 2, 2278.893996), -- Orichalcum
(22677, 9629, 1, 1, 2, 1882.554534), -- Adamantine
(22677, 959, 1, 1, 2, 17.257329), -- Scroll: Enchant Weapon (S-Grade)
-- Grave Robber Summoner
(22678, 9992, 1, 1, -1, 5104), -- Sealed Dynasty Necklace Gemstone
(22678, 5167, 1, 1, -1, 1261), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22678, 9530, 1, 1, -1, 4131), -- Sealed Dynasty Breast Plate Piece
(22678, 57, 695, 1401, 0, 700000), -- Adena
(22678, 9446, 1, 1, 1, 1.241688), -- Dynasty Knife
(22678, 9620, 1, 1, 1, 387.758312), -- Dynasty Knife Piece
(22678, 1879, 1, 1, 2, 33268.297955), -- Cokes
(22678, 1885, 1, 1, 2, 16634.055708), -- High-Grade Suede
(22678, 9628, 1, 1, 2, 1565.621827), -- Leonard
(22678, 9630, 1, 1, 2, 1050.587648), -- Orichalcum
(22678, 9629, 1, 1, 2, 867.779428), -- Adamantine
(22678, 960, 1, 1, 2, 79.838692), -- Scroll: Enchant Armor (S-Grade)
(22678, 1345, 10, 30, 2, 133072.818742), -- Shining Arrow
-- Grave Robber Magician
(22679, 9540, 1, 1, -1, 5208), -- Sealed Dynasty Tunic Piece
(22679, 9628, 1, 1, -1, 22831), -- Leonard
(22679, 9536, 1, 1, -1, 7655), -- Sealed Dynasty Leather Leggings Piece
(22679, 57, 713, 1437, 0, 700000), -- Adena
(22679, 9447, 1, 1, 1, 1.27635), -- Dynasty Halberd
(22679, 9621, 1, 1, 1, 400.72365), -- Dynasty Halberd Piece
(22679, 1879, 1, 1, 2, 39832.239276), -- Cokes
(22679, 1885, 1, 1, 2, 19916.119638), -- High-Grade Suede
(22679, 9628, 1, 1, 2, 1874.489202), -- Leonard
(22679, 9630, 1, 1, 2, 1257.854796), -- Orichalcum
(22679, 9629, 1, 1, 2, 1039.077954), -- Adamantine
(22679, 5272, 1, 1, 2, 106.219134), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Grave Robber Worker
(22680, 5272, 1, 1, -1, 1321), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22680, 9619, 1, 1, -1, 1664), -- Dynasty Bow Piece
(22680, 5277, 1, 1, -1, 1321), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22680, 57, 728, 1468, 0, 700000), -- Adena
(22680, 9514, 1, 1, 1, 2.00079), -- Sealed Dynasty Breast Plate
(22680, 9515, 1, 1, 1, 3.199995), -- Sealed Dynasty Gaiter
(22680, 9530, 1, 1, 1, 533.05614), -- Sealed Dynasty Breast Plate Piece
(22680, 9531, 1, 1, 1, 1576.743075), -- Sealed Dynasty Gaiters Piece
(22680, 1894, 1, 1, 2, 8562.784625), -- Crafted Leather
(22680, 4039, 1, 1, 2, 8134.692833), -- Mold Glue
(22680, 4041, 1, 1, 2, 2122.052531), -- Mold Hardener
(22680, 4044, 1, 1, 2, 8134.692833), -- Thons
(22680, 5277, 1, 1, 2, 108.541004), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22680, 1345, 10, 30, 2, 162694.236174), -- Shining Arrow
-- Grave Robber Warrior
(22681, 9992, 1, 1, -1, 5489), -- Sealed Dynasty Necklace Gemstone
(22681, 9628, 1, 1, -1, 23925), -- Leonard
(22681, 9545, 1, 1, -1, 13074), -- Sealed Dynasty Shield Piece
(22681, 57, 748, 1506, 0, 700000), -- Adena
(22681, 9519, 1, 1, 1, 2.737214), -- Sealed Dynasty Leather Armor
(22681, 9520, 1, 1, 1, 4.379209), -- Sealed Dynasty Leather Leggings
(22681, 9535, 1, 1, 1, 672.032713), -- Sealed Dynasty Leather Armor Piece
(22681, 9536, 1, 1, 1, 987.850864), -- Sealed Dynasty Leather Leggings Piece
(22681, 1879, 1, 1, 2, 41740.921844), -- Cokes
(22681, 1885, 1, 1, 2, 20870.460922), -- High-Grade Suede
(22681, 9628, 1, 1, 2, 1964.311038), -- Leonard
(22681, 9630, 1, 1, 2, 1318.128724), -- Orichalcum
(22681, 9629, 1, 1, 2, 1088.868526), -- Adamantine
(22681, 5282, 1, 1, 2, 111.308946), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Grave Robber Warrior of Light
(22682, 9540, 1, 1, -1, 6036), -- Sealed Dynasty Tunic Piece
(22682, 3957, 1, 1, -1, 1499), -- Recipe: Blessed Spiritshot S
(22682, 9622, 1, 1, -1, 1816), -- Dynasty Cudgel Piece
(22682, 57, 827, 1666, 0, 700000), -- Adena
(22682, 9524, 1, 1, 1, 3.027848), -- Sealed Dynasty Tunic
(22682, 9525, 1, 1, 1, 4.844188), -- Sealed Dynasty Stockings
(22682, 9540, 1, 1, 1, 743.388316), -- Sealed Dynasty Tunic Piece
(22682, 9541, 1, 1, 1, 1092.739648), -- Sealed Dynasty Stocking Piece
(22682, 1894, 1, 1, 2, 11662.525476), -- Crafted Leather
(22682, 4039, 1, 1, 2, 11079.415872), -- Mold Glue
(22682, 4041, 1, 1, 2, 2890.284012), -- Mold Hardener
(22682, 4044, 1, 1, 2, 11079.415872), -- Thons
(22682, 6901, 1, 1, 2, 332.358768), -- Recipe: Shining Arrow (100%)
-- Servitor of Darkness
(22683, 5157, 1, 1, -1, 1409), -- Recipe: Soulshot (S) Compressed Package (100%)
(22683, 9535, 1, 1, -1, 5674), -- Sealed Dynasty Leather Armor Piece
(22683, 1894, 1, 1, -1, 111275), -- Crafted Leather
(22683, 57, 777, 1567, 0, 700000), -- Adena
(22683, 9452, 1, 1, 1, 8.61063), -- Sealed Dynasty Earring
(22683, 9453, 1, 1, 1, 6.45699), -- Sealed Dynasty Necklace
(22683, 9454, 1, 1, 1, 12.915945), -- Sealed Dynasty Ring
(22683, 9991, 1, 1, 1, 610.50192), -- Sealed Dynasty Earring Gemstone
(22683, 9992, 1, 1, 1, 468.544425), -- Sealed Dynasty Necklace Gemstone
(22683, 9993, 1, 1, 1, 857.97009), -- Sealed Dynasty Ring Gemstone
(22683, 1894, 1, 1, 2, 9135.872125), -- Crafted Leather
(22683, 4039, 1, 1, 2, 8679.129133), -- Mold Glue
(22683, 4041, 1, 1, 2, 2264.076631), -- Mold Hardener
(22683, 4044, 1, 1, 2, 8679.129133), -- Thons
(22683, 5157, 1, 1, 2, 115.805404), -- Recipe: Soulshot (S) Compressed Package (100%)
(22683, 1345, 10, 30, 2, 173582.987574), -- Shining Arrow
-- Servitor of Darkness
(22684, 1894, 1, 1, -1, 104295), -- Crafted Leather
(22684, 9620, 1, 1, -1, 1651), -- Dynasty Knife Piece
(22684, 5162, 1, 1, -1, 1321), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22684, 57, 728, 1468, 0, 700000), -- Adena
(22684, 9517, 1, 1, 1, 2.667402), -- Sealed Dynasty Gauntlets
(22684, 9518, 1, 1, 1, 2.667402), -- Sealed Dynasty Boots
(22684, 9522, 1, 1, 1, 2.667402), -- Sealed Dynasty Leather Gloves
(22684, 9523, 1, 1, 1, 2.667402), -- Sealed Dynasty Leather Boots
(22684, 9527, 1, 1, 1, 2.667402), -- Sealed Dynasty Gloves
(22684, 9528, 1, 1, 1, 2.667402), -- Sealed Dynasty Shoes
(22684, 9533, 1, 1, 1, 583.833771), -- Sealed Dynasty Gauntlet Piece
(22684, 9534, 1, 1, 1, 583.833771), -- Sealed Dynasty Boot Piece
(22684, 9538, 1, 1, 1, 583.833771), -- Sealed Dynasty Leather Glove Piece
(22684, 9539, 1, 1, 1, 583.833771), -- Sealed Dynasty Leather Boots Piece
(22684, 9543, 1, 1, 1, 583.833771), -- Sealed Dynasty Glove Piece
(22684, 9544, 1, 1, 1, 583.826733), -- Sealed Dynasty Shoes Piece
(22684, 1879, 1, 1, 2, 40673.353628), -- Cokes
(22684, 1885, 1, 1, 2, 20336.676814), -- High-Grade Suede
(22684, 9628, 1, 1, 2, 1914.071706), -- Leonard
(22684, 9630, 1, 1, 2, 1284.416188), -- Orichalcum
(22684, 9629, 1, 1, 2, 1061.019562), -- Adamantine
(22684, 5162, 1, 1, 2, 108.462102), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Servitor of Darkness
(22685, 9531, 1, 1, -1, 13141), -- Sealed Dynasty Gaiters Piece
(22685, 5167, 1, 1, -1, 1356), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22685, 9622, 1, 1, -1, 1642), -- Dynasty Cudgel Piece
(22685, 57, 748, 1506, 0, 700000), -- Adena
(22685, 9516, 1, 1, 1, 2.190144), -- Sealed Dynasty Helmet
(22685, 9529, 1, 1, 1, 3.127872), -- Sealed Dynasty Shield
(22685, 13886, 1, 1, 1, 3.127872), -- Sealed Dynasty Sigil
(22685, 9521, 1, 1, 1, 2.190144), -- Sealed Dynasty Leather Helmet
(22685, 9526, 1, 1, 1, 2.190144), -- Sealed Dynasty Circlet
(22685, 9532, 1, 1, 1, 540.251712), -- Sealed Dynasty Helmet Piece
(22685, 9542, 1, 1, 1, 540.251712), -- Sealed Dynasty Circlet Piece
(22685, 9545, 1, 1, 1, 643.963584), -- Sealed Dynasty Shield Piece
(22685, 10114, 1, 1, 1, 372.516672), -- Sealed Dynasty Sigil Piece
(22685, 1879, 1, 1, 2, 41740.921844), -- Cokes
(22685, 1885, 1, 1, 2, 20870.460922), -- High-Grade Suede
(22685, 9628, 1, 1, 2, 1964.311038), -- Leonard
(22685, 9630, 1, 1, 2, 1318.128724), -- Orichalcum
(22685, 9629, 1, 1, 2, 1088.868526), -- Adamantine
(22685, 5167, 1, 1, 2, 111.308946), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
-- Servitor of Darkness
(22686, 9541, 1, 1, -1, 8022), -- Sealed Dynasty Stocking Piece
(22686, 1894, 1, 1, -1, 107033), -- Crafted Leather
(22686, 9530, 1, 1, -1, 4443), -- Sealed Dynasty Breast Plate Piece
(22686, 57, 748, 1506, 0, 700000), -- Adena
(22686, 9442, 1, 1, 1, 0.445397), -- Dynasty Sword
(22686, 9443, 1, 1, 1, 0.445397), -- Dynasty Blade
(22686, 9444, 1, 1, 1, 0.445397), -- Dynasty Phantom
(22686, 9616, 1, 1, 1, 139.22113), -- Dynasty Sword Piece
(22686, 9617, 1, 1, 1, 139.22113), -- Dynasty Blade Piece
(22686, 9618, 1, 1, 1, 139.221549), -- Dynasty Phantom Piece
(22686, 1879, 1, 1, 2, 35778.099927), -- Cokes
(22686, 1885, 1, 1, 2, 17888.949679), -- High-Grade Suede
(22686, 9628, 1, 1, 2, 1683.576186), -- Leonard
(22686, 9630, 1, 1, 2, 1129.805177), -- Orichalcum
(22686, 9629, 1, 1, 2, 933.247557), -- Adamantine
(22686, 9625, 1, 1, 2, 42.921766), -- Giant's Codex - Oblivion
(22686, 1345, 10, 30, 2, 143112.399708), -- Shining Arrow
-- Phantoms of the Mine
(22687, 5272, 1, 1, -1, 1505), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22687, 9623, 1, 1, -1, 1823), -- Dynasty Mace Piece
(22687, 5277, 1, 1, -1, 1505), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22687, 57, 829, 1673, 0, 700000), -- Adena
(22687, 9448, 1, 1, 1, 0.55706), -- Dynasty Cudgel
(22687, 9449, 1, 1, 1, 0.55706), -- Dynasty Mace
(22687, 10252, 1, 1, 1, 0.55706), -- Dynasty Staff
(22687, 10253, 1, 1, 1, 0.55706), -- Dynasty Crusher
(22687, 9622, 1, 1, 1, 112.39686), -- Dynasty Cudgel Piece
(22687, 9623, 1, 1, 1, 112.39686), -- Dynasty Mace Piece
(22687, 10546, 1, 1, 1, 116.48856), -- Dynasty Staff Fragment
(22687, 10547, 1, 1, 1, 116.48948), -- Dynasty Crusher Fragment
(22687, 1895, 1, 1, 2, 79447.503321), -- Metallic Fiber
(22687, 4040, 1, 1, 2, 5561.43612), -- Mold Lubricant
(22687, 4042, 1, 1, 2, 4634.5301), -- Enria
(22687, 4043, 1, 1, 2, 9268.775873), -- Asofe
(22687, 9626, 1, 1, 2, 36.96251), -- Giant's Codex - Discipline
(22687, 1345, 10, 30, 2, 185377.792076), -- Shining Arrow
-- Evil Spirits of the Mine
(22688, 9620, 1, 1, -1, 1931), -- Dynasty Knife Piece
(22688, 960, 1, 1, -1, 1390), -- Scroll: Enchant Armor (S-Grade)
(22688, 9991, 1, 1, -1, 8150), -- Sealed Dynasty Earring Gemstone
(22688, 57, 852, 1716, 0, 700000), -- Adena
(22688, 9450, 1, 1, 1, 2.283979), -- Dynasty Bagh-Nakh
(22688, 9624, 1, 1, 1, 460.716021), -- Dynasty Bagh-Nakh Piece
(22688, 1894, 1, 1, 2, 7509.688547), -- Crafted Leather
(22688, 4039, 1, 1, 2, 7134.19261), -- Mold Glue
(22688, 4041, 1, 1, 2, 1861.084828), -- Mold Hardener
(22688, 4044, 1, 1, 2, 7134.19261), -- Thons
(22688, 9573, 1, 1, 2, 1486.27947), -- Life Stone - Level 80
(22688, 9574, 1, 1, 2, 371.582656), -- Mid-Grade Life Stone - Level 80
(22688, 9575, 1, 1, 2, 37.163381), -- High-Grade Life Stone - Level 80
(22688, 9625, 1, 1, 2, 42.815898), -- Giant's Codex - Oblivion
-- Mine Bug
(22689, 9618, 1, 1, -1, 894), -- Dynasty Phantom Piece
(22689, 9621, 1, 1, -1, 898), -- Dynasty Halberd Piece
(22689, 6901, 1, 1, -1, 1608), -- Recipe: Shining Arrow (100%)
(22689, 57, 394, 794, 0, 700000), -- Adena
(22689, 9445, 1, 1, 1, 1.058135), -- Dynasty Bow
(22689, 9619, 1, 1, 1, 221.941865), -- Dynasty Bow Piece
(22689, 1879, 1, 1, 2, 14666.1454), -- Cokes
(22689, 1885, 1, 1, 2, 7333.0727), -- High-Grade Suede
(22689, 9628, 1, 1, 2, 690.177272), -- Leonard
(22689, 9630, 1, 1, 2, 463.142714), -- Orichalcum
(22689, 9629, 1, 1, 2, 382.599328), -- Adamantine
(22689, 9573, 1, 1, 2, 611.093446), -- Life Stone - Level 80
(22689, 9574, 1, 1, 2, 152.76728), -- Mid-Grade Life Stone - Level 80
(22689, 9575, 1, 1, 2, 15.276728), -- High-Grade Life Stone - Level 80
(22689, 9626, 1, 1, 2, 11.725132), -- Giant's Codex - Discipline
-- Earth Wyrm's Descendant
(22690, 1894, 1, 1, -1, 127926), -- Crafted Leather
(22690, 9620, 1, 1, -1, 2025), -- Dynasty Knife Piece
(22690, 5162, 1, 1, -1, 1620), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22690, 57, 894, 1800, 0, 700000), -- Adena
(22690, 9446, 1, 1, 1, 1.599192), -- Dynasty Knife
(22690, 9620, 1, 1, 1, 499.400808), -- Dynasty Knife Piece
(22690, 1879, 1, 1, 2, 29933.360905), -- Cokes
(22690, 1885, 1, 1, 2, 14966.595055), -- High-Grade Suede
(22690, 9628, 1, 1, 2, 1408.546365), -- Leonard
(22690, 9630, 1, 1, 2, 945.17953), -- Orichalcum
(22690, 9629, 1, 1, 2, 780.87474), -- Adamantine
(22690, 9573, 1, 1, 2, 1247.14509), -- Life Stone - Level 80
(22690, 9574, 1, 1, 2, 311.87167), -- Mid-Grade Life Stone - Level 80
(22690, 9575, 1, 1, 2, 31.255485), -- High-Grade Life Stone - Level 80
(22690, 9546, 1, 1, 2, 1436.72754), -- Fire Stone
(22690, 1345, 10, 30, 2, 119733.44362), -- Shining Arrow
-- Ragna Orc
(22691, 959, 1, 1, -1, 135), -- Scroll: Enchant Weapon (S-Grade)
(22691, 9628, 1, 1, -1, 26563), -- Leonard
(22691, 9630, 1, 1, -1, 17825), -- Orichalcum
(22691, 57, 829, 1673, 0, 700000), -- Adena
(22691, 9447, 1, 1, 1, 1.482725), -- Dynasty Halberd
(22691, 9621, 1, 1, 1, 465.517275), -- Dynasty Halberd Piece
(22691, 1879, 1, 1, 2, 30896.033472), -- Cokes
(22691, 1885, 1, 1, 2, 15448.016736), -- High-Grade Suede
(22691, 9628, 1, 1, 2, 1453.945248), -- Leonard
(22691, 9630, 1, 1, 2, 975.656448), -- Orichalcum
(22691, 9629, 1, 1, 2, 806.002272), -- Adamantine
(22691, 9573, 1, 1, 2, 1287.347904), -- Life Stone - Level 80
(22691, 9574, 1, 1, 2, 321.810624), -- Mid-Grade Life Stone - Level 80
(22691, 9575, 1, 1, 2, 32.202144), -- High-Grade Life Stone - Level 80
(22691, 9547, 1, 1, 2, 1482.985152), -- Water Stone
-- Ragna Orc Warrior
(22692, 9533, 1, 1, -1, 17174), -- Sealed Dynasty Gauntlet Piece
(22692, 1808, 1, 1, -1, 1595), -- Recipe: Soulshot (S-Grade)
(22692, 9531, 1, 1, -1, 15464), -- Sealed Dynasty Gaiters Piece
(22692, 57, 880, 1772, 0, 700000), -- Adena
(22692, 9514, 1, 1, 1, 2.416084), -- Sealed Dynasty Breast Plate
(22692, 9515, 1, 1, 1, 3.864202), -- Sealed Dynasty Gaiter
(22692, 9530, 1, 1, 1, 643.699944), -- Sealed Dynasty Breast Plate Piece
(22692, 9531, 1, 1, 1, 1904.01977), -- Sealed Dynasty Gaiters Piece
(22692, 1894, 1, 1, 2, 7755.97494), -- Crafted Leather
(22692, 4039, 1, 1, 2, 7368.1776), -- Mold Glue
(22692, 4041, 1, 1, 2, 1922.13084), -- Mold Hardener
(22692, 4044, 1, 1, 2, 7368.1776), -- Thons
(22692, 9573, 1, 1, 2, 1535.037), -- Life Stone - Level 80
(22692, 9574, 1, 1, 2, 383.77332), -- Mid-Grade Life Stone - Level 80
(22692, 9575, 1, 1, 2, 38.38296), -- High-Grade Life Stone - Level 80
(22692, 9548, 1, 1, 2, 1768.34574), -- Earth Stone
-- Ragna Orc Hero
(22693, 3036, 1, 1, -1, 1595), -- Recipe: Spiritshot S
(22693, 9536, 1, 1, -1, 9440), -- Sealed Dynasty Leather Leggings Piece
(22693, 1894, 1, 1, -1, 125956), -- Crafted Leather
(22693, 57, 880, 1772, 0, 700000), -- Adena
(22693, 9519, 1, 1, 1, 3.221604), -- Sealed Dynasty Leather Armor
(22693, 9520, 1, 1, 1, 5.154174), -- Sealed Dynasty Leather Leggings
(22693, 9535, 1, 1, 1, 790.958718), -- Sealed Dynasty Leather Armor Piece
(22693, 9536, 1, 1, 1, 1162.665504), -- Sealed Dynasty Leather Leggings Piece
(22693, 1879, 1, 1, 2, 32747.309916), -- Cokes
(22693, 1885, 1, 1, 2, 16373.654958), -- High-Grade Suede
(22693, 9628, 1, 1, 2, 1541.064994), -- Leonard
(22693, 9630, 1, 1, 2, 1034.117344), -- Orichalcum
(22693, 9629, 1, 1, 2, 854.297566), -- Adamantine
(22693, 9573, 1, 1, 2, 1364.485212), -- Life Stone - Level 80
(22693, 9574, 1, 1, 2, 341.093372), -- Mid-Grade Life Stone - Level 80
(22693, 9575, 1, 1, 2, 34.131682), -- High-Grade Life Stone - Level 80
(22693, 9549, 1, 1, 2, 1571.844956), -- Wind Stone
-- Ragna Orc Commander
(22694, 9532, 1, 1, -1, 12498), -- Sealed Dynasty Helmet Piece
(22694, 9533, 1, 1, -1, 16628), -- Sealed Dynasty Gauntlet Piece
(22694, 3957, 1, 1, -1, 1545), -- Recipe: Blessed Spiritshot S
(22694, 57, 852, 1716, 0, 700000), -- Adena
(22694, 9524, 1, 1, 1, 3.1198), -- Sealed Dynasty Tunic
(22694, 9525, 1, 1, 1, 4.9913), -- Sealed Dynasty Stockings
(22694, 9540, 1, 1, 1, 765.9641), -- Sealed Dynasty Tunic Piece
(22694, 9541, 1, 1, 1, 1125.9248), -- Sealed Dynasty Stocking Piece
(22694, 1879, 1, 1, 2, 31707.359184), -- Cokes
(22694, 1885, 1, 1, 2, 15853.679592), -- High-Grade Suede
(22694, 9628, 1, 1, 2, 1492.125656), -- Leonard
(22694, 9630, 1, 1, 2, 1001.277056), -- Orichalcum
(22694, 9629, 1, 1, 2, 827.167784), -- Adamantine
(22694, 9573, 1, 1, 2, 1321.153488), -- Life Stone - Level 80
(22694, 9574, 1, 1, 2, 330.261328), -- Mid-Grade Life Stone - Level 80
(22694, 9575, 1, 1, 2, 33.047768), -- High-Grade Life Stone - Level 80
(22694, 9550, 1, 1, 2, 1521.928144), -- Dark Stone
-- Ragna Orc Healer
(22695, 9534, 1, 1, -1, 16282), -- Sealed Dynasty Boot Piece
(22695, 5157, 1, 1, -1, 1513), -- Recipe: Soulshot (S) Compressed Package (100%)
(22695, 9622, 1, 1, -1, 1832), -- Dynasty Cudgel Piece
(22695, 57, 834, 1681, 0, 700000), -- Adena
(22695, 9452, 1, 1, 1, 9.241638), -- Sealed Dynasty Earring
(22695, 9453, 1, 1, 1, 6.930174), -- Sealed Dynasty Necklace
(22695, 9454, 1, 1, 1, 13.862457), -- Sealed Dynasty Ring
(22695, 9991, 1, 1, 1, 655.240992), -- Sealed Dynasty Earring Gemstone
(22695, 9992, 1, 1, 1, 502.880505), -- Sealed Dynasty Necklace Gemstone
(22695, 9993, 1, 1, 1, 920.844234), -- Sealed Dynasty Ring Gemstone
(22695, 1894, 1, 1, 2, 6536.321472), -- Crafted Leather
(22695, 4039, 1, 1, 2, 6209.453632), -- Mold Glue
(22695, 4041, 1, 1, 2, 1619.844608), -- Mold Hardener
(22695, 4044, 1, 1, 2, 6209.453632), -- Thons
(22695, 9573, 1, 1, 2, 1293.568384), -- Life Stone - Level 80
(22695, 9574, 1, 1, 2, 323.466048), -- Mid-Grade Life Stone - Level 80
(22695, 9575, 1, 1, 2, 32.390976), -- High-Grade Life Stone - Level 80
(22695, 9551, 1, 1, 2, 1490.280704), -- Holy Stone
(22695, 1345, 10, 30, 2, 124189.220544), -- Shining Arrow
-- Ragna Orc Shaman
(22696, 1894, 1, 1, -1, 118546), -- Crafted Leather
(22696, 9993, 1, 1, -1, 11133), -- Sealed Dynasty Ring Gemstone
(22696, 57, 827, 1669, 0, 700000), -- Adena
(22696, 9517, 1, 1, 1, 3.032), -- Sealed Dynasty Gauntlets
(22696, 9518, 1, 1, 1, 3.032), -- Sealed Dynasty Boots
(22696, 9522, 1, 1, 1, 3.032), -- Sealed Dynasty Leather Gloves
(22696, 9523, 1, 1, 1, 3.032), -- Sealed Dynasty Leather Boots
(22696, 9527, 1, 1, 1, 3.032), -- Sealed Dynasty Gloves
(22696, 9528, 1, 1, 1, 3.032), -- Sealed Dynasty Shoes
(22696, 9533, 1, 1, 1, 663.636), -- Sealed Dynasty Gauntlet Piece
(22696, 9534, 1, 1, 1, 663.636), -- Sealed Dynasty Boot Piece
(22696, 9538, 1, 1, 1, 663.636), -- Sealed Dynasty Leather Glove Piece
(22696, 9539, 1, 1, 1, 663.636), -- Sealed Dynasty Leather Boots Piece
(22696, 9543, 1, 1, 1, 663.636), -- Sealed Dynasty Glove Piece
(22696, 9544, 1, 1, 1, 663.628), -- Sealed Dynasty Shoes Piece
(22696, 1879, 1, 1, 2, 30820.423712), -- Cokes
(22696, 1885, 1, 1, 2, 15410.211856), -- High-Grade Suede
(22696, 9628, 1, 1, 2, 1450.354243), -- Leonard
(22696, 9630, 1, 1, 2, 973.256635), -- Orichalcum
(22696, 9629, 1, 1, 2, 804.003499), -- Adamantine
(22696, 9573, 1, 1, 2, 1284.167287), -- Life Stone - Level 80
(22696, 9574, 1, 1, 2, 321.029046), -- Mid-Grade Life Stone - Level 80
(22696, 9575, 1, 1, 2, 32.092684), -- High-Grade Life Stone - Level 80
(22696, 959, 1, 1, 2, 7.461038), -- Scroll: Enchant Weapon (S-Grade)
-- Ragna Orc Priest
(22697, 5162, 1, 1, -1, 1390), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22697, 9542, 1, 1, -1, 11244), -- Sealed Dynasty Circlet Piece
(22697, 5167, 1, 1, -1, 1390), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22697, 57, 766, 1544, 0, 700000), -- Adena
(22697, 9516, 1, 1, 1, 2.245105), -- Sealed Dynasty Helmet
(22697, 9529, 1, 1, 1, 3.206365), -- Sealed Dynasty Shield
(22697, 13886, 1, 1, 1, 3.206365), -- Sealed Dynasty Sigil
(22697, 9521, 1, 1, 1, 2.245105), -- Sealed Dynasty Leather Helmet
(22697, 9526, 1, 1, 1, 2.245105), -- Sealed Dynasty Circlet
(22697, 9532, 1, 1, 1, 553.809165), -- Sealed Dynasty Helmet Piece
(22697, 9542, 1, 1, 1, 553.809165), -- Sealed Dynasty Circlet Piece
(22697, 9545, 1, 1, 1, 660.123655), -- Sealed Dynasty Shield Piece
(22697, 10114, 1, 1, 1, 381.864865), -- Sealed Dynasty Sigil Piece
(22697, 1879, 1, 1, 2, 28525.82784), -- Cokes
(22697, 1885, 1, 1, 2, 14262.9376), -- High-Grade Suede
(22697, 9628, 1, 1, 2, 1342.37184), -- Leonard
(22697, 9630, 1, 1, 2, 900.83456), -- Orichalcum
(22697, 9629, 1, 1, 2, 744.16768), -- Adamantine
(22697, 9573, 1, 1, 2, 1188.59392), -- Life Stone - Level 80
(22697, 9574, 1, 1, 2, 297.13664), -- Mid-Grade Life Stone - Level 80
(22697, 9575, 1, 1, 2, 29.69472), -- High-Grade Life Stone - Level 80
(22697, 960, 1, 1, 2, 68.4352), -- Scroll: Enchant Armor (S-Grade)
-- Ragna Orc Archer
(22698, 9541, 1, 1, -1, 9177), -- Sealed Dynasty Stocking Piece
(22698, 1894, 1, 1, -1, 122443), -- Crafted Leather
(22698, 9533, 1, 1, -1, 16695), -- Sealed Dynasty Gauntlet Piece
(22698, 57, 855, 1724, 0, 700000), -- Adena
(22698, 9442, 1, 1, 1, 0.509177), -- Dynasty Sword
(22698, 9443, 1, 1, 1, 0.509177), -- Dynasty Blade
(22698, 9444, 1, 1, 1, 0.509177), -- Dynasty Phantom
(22698, 9616, 1, 1, 1, 159.15733), -- Dynasty Sword Piece
(22698, 9617, 1, 1, 1, 159.15733), -- Dynasty Blade Piece
(22698, 9618, 1, 1, 1, 159.157809), -- Dynasty Phantom Piece
(22698, 1894, 1, 1, 2, 7539.466041), -- Crafted Leather
(22698, 4039, 1, 1, 2, 7162.506891), -- Mold Glue
(22698, 4041, 1, 1, 2, 1868.482296), -- Mold Hardener
(22698, 4044, 1, 1, 2, 7162.506891), -- Thons
(22698, 9573, 1, 1, 2, 1492.192152), -- Life Stone - Level 80
(22698, 9574, 1, 1, 2, 373.048038), -- Mid-Grade Life Stone - Level 80
(22698, 9575, 1, 1, 2, 37.30995), -- High-Grade Life Stone - Level 80
(22698, 5272, 1, 1, 2, 95.487741), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Ragna Orc Sniper
(22699, 9620, 1, 1, -1, 1990), -- Dynasty Knife Piece
(22699, 5272, 1, 1, -1, 1592), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22699, 9531, 1, 1, -1, 15428), -- Sealed Dynasty Gaiters Piece
(22699, 57, 878, 1768, 0, 700000), -- Adena
(22699, 9448, 1, 1, 1, 0.392365), -- Dynasty Cudgel
(22699, 9449, 1, 1, 1, 0.392365), -- Dynasty Mace
(22699, 10252, 1, 1, 1, 0.392365), -- Dynasty Staff
(22699, 10253, 1, 1, 1, 0.392365), -- Dynasty Crusher
(22699, 9622, 1, 1, 1, 118.697445), -- Dynasty Cudgel Piece
(22699, 9623, 1, 1, 1, 118.697445), -- Dynasty Mace Piece
(22699, 10546, 1, 1, 1, 123.01831), -- Dynasty Staff Fragment
(22699, 10547, 1, 1, 1, 123.01734), -- Dynasty Crusher Fragment
(22699, 1894, 1, 1, 2, 7737.541477), -- Crafted Leather
(22699, 4039, 1, 1, 2, 7350.678927), -- Mold Glue
(22699, 4041, 1, 1, 2, 1917.570712), -- Mold Hardener
(22699, 4044, 1, 1, 2, 7350.678927), -- Thons
(22699, 9573, 1, 1, 2, 1531.394744), -- Life Stone - Level 80
(22699, 9574, 1, 1, 2, 382.848686), -- Mid-Grade Life Stone - Level 80
(22699, 9575, 1, 1, 2, 38.29015), -- High-Grade Life Stone - Level 80
(22699, 5277, 1, 1, 2, 97.996377), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
-- Varangka's Dre Vanul
(22701, 9543, 1, 1, -1, 16679), -- Sealed Dynasty Glove Piece
(22701, 9530, 1, 1, -1, 5077), -- Sealed Dynasty Breast Plate Piece
(22701, 5282, 1, 1, -1, 1549), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22701, 57, 854, 1722, 0, 700000), -- Adena
(22701, 9445, 1, 1, 1, 1.526976), -- Dynasty Bow
(22701, 9619, 1, 1, 1, 480.473024), -- Dynasty Bow Piece
(22701, 1895, 1, 1, 2, 61335.504936), -- Metallic Fiber
(22701, 4040, 1, 1, 2, 4293.4543), -- Mold Lubricant
(22701, 9628, 1, 1, 2, 1683.725554), -- Leonard
(22701, 9630, 1, 1, 2, 1129.845254), -- Orichalcum
(22701, 9573, 1, 1, 2, 1490.819982), -- Life Stone - Level 80
(22701, 9574, 1, 1, 2, 372.687356), -- Mid-Grade Life Stone - Level 80
(22701, 9575, 1, 1, 2, 37.254624), -- High-Grade Life Stone - Level 80
(22701, 6901, 1, 1, 2, 214.707994), -- Recipe: Shining Arrow (100%)
-- Varangka's Destroyer
(22702, 9530, 1, 1, -1, 4703), -- Sealed Dynasty Breast Plate Piece
(22702, 1808, 1, 1, -1, 1435), -- Recipe: Soulshot (S-Grade)
(22702, 9621, 1, 1, -1, 1804), -- Dynasty Halberd Piece
(22702, 57, 791, 1594, 0, 700000), -- Adena
(22702, 9446, 1, 1, 1, 1.414056), -- Dynasty Knife
(22702, 9620, 1, 1, 1, 441.585944), -- Dynasty Knife Piece
(22702, 1895, 1, 1, 2, 56809.514124), -- Metallic Fiber
(22702, 4040, 1, 1, 2, 3976.634673), -- Mold Lubricant
(22702, 9628, 1, 1, 2, 1559.455623), -- Leonard
(22702, 9630, 1, 1, 2, 1046.46564), -- Orichalcum
(22702, 9573, 1, 1, 2, 1380.760524), -- Life Stone - Level 80
(22702, 9574, 1, 1, 2, 345.190131), -- Mid-Grade Life Stone - Level 80
(22702, 9575, 1, 1, 2, 34.512489), -- High-Grade Life Stone - Level 80
(22702, 5157, 1, 1, 2, 88.466796), -- Recipe: Soulshot (S) Compressed Package (100%)
-- Contaminated Morek Warrior
(22703, 9630, 1, 1, -1, 49236), -- Orichalcum
(22703, 9617, 1, 1, -1, 5201), -- Dynasty Blade Piece
(22703, 9537, 1, 1, -1, 33638), -- Sealed Dynasty Leather Helmet Piece
(22703, 57, 2291, 4622, 0, 700000), -- Adena
(22703, 9447, 1, 1, 1, 4.098925), -- Dynasty Halberd
(22703, 9621, 1, 1, 1, 1286.901075), -- Dynasty Halberd Piece
(22703, 1895, 1, 1, 2, 164582.232876), -- Metallic Fiber
(22703, 4040, 1, 1, 2, 11520.665577), -- Mold Lubricant
(22703, 9628, 1, 1, 2, 4517.882127), -- Leonard
(22703, 9630, 1, 1, 2, 3031.70436), -- Orichalcum
(22703, 9573, 1, 1, 2, 4000.186476), -- Life Stone - Level 80
(22703, 9574, 1, 1, 2, 1000.046619), -- Mid-Grade Life Stone - Level 80
(22703, 9575, 1, 1, 2, 99.985761), -- High-Grade Life Stone - Level 80
(22703, 5162, 1, 1, 2, 256.296204), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Contaminated Batur Warrior
(22704, 1808, 1, 1, -1, 5156), -- Recipe: Soulshot (S-Grade)
(22704, 9623, 1, 1, -1, 6245), -- Dynasty Mace Piece
(22704, 3036, 1, 1, -1, 5156), -- Recipe: Spiritshot S
(22704, 57, 2841, 5731, 0, 700000), -- Adena
(22704, 9514, 1, 1, 1, 7.807338), -- Sealed Dynasty Breast Plate
(22704, 9515, 1, 1, 1, 12.486789), -- Sealed Dynasty Gaiter
(22704, 9530, 1, 1, 1, 2080.053108), -- Sealed Dynasty Breast Plate Piece
(22704, 9531, 1, 1, 1, 6152.652765), -- Sealed Dynasty Gaiters Piece
(22704, 1895, 1, 1, 2, 204101.857016), -- Metallic Fiber
(22704, 4040, 1, 1, 2, 14287.017482), -- Mold Lubricant
(22704, 9628, 1, 1, 2, 5602.719782), -- Leonard
(22704, 9630, 1, 1, 2, 3759.67976), -- Orichalcum
(22704, 9573, 1, 1, 2, 4960.714616), -- Life Stone - Level 80
(22704, 9574, 1, 1, 2, 1240.178654), -- Mid-Grade Life Stone - Level 80
(22704, 9575, 1, 1, 2, 123.994426), -- High-Grade Life Stone - Level 80
(22704, 5167, 1, 1, 2, 317.838264), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
-- Contaminated Batur Commander
(22705, 9624, 1, 1, -1, 6442), -- Dynasty Bagh-Nakh Piece
(22705, 9630, 1, 1, -1, 62984), -- Orichalcum
(22705, 9628, 1, 1, -1, 93859), -- Leonard
(22705, 57, 2933, 5909, 0, 700000), -- Adena
(22705, 9519, 1, 1, 1, 10.73868), -- Sealed Dynasty Leather Armor
(22705, 9520, 1, 1, 1, 17.18058), -- Sealed Dynasty Leather Leggings
(22705, 9535, 1, 1, 1, 2636.52906), -- Sealed Dynasty Leather Armor Piece
(22705, 9536, 1, 1, 1, 3875.55168), -- Sealed Dynasty Leather Leggings Piece
(22705, 1895, 1, 1, 2, 210537.539316), -- Metallic Fiber
(22705, 4040, 1, 1, 2, 14737.541739), -- Mold Lubricant
(22705, 4042, 1, 1, 2, 12281.329581), -- Enria
(22705, 4043, 1, 1, 2, 24562.659162), -- Asofe
(22705, 9573, 1, 1, 2, 5117.243058), -- Life Stone - Level 80
(22705, 9574, 1, 1, 2, 1279.176369), -- Mid-Grade Life Stone - Level 80
(22705, 9575, 1, 1, 2, 127.944516), -- High-Grade Life Stone - Level 80
(22705, 9625, 1, 1, 2, 147.566259), -- Giant's Codex - Oblivion
-- Turka Follower's Ghost
(22706, 1894, 1, 1, -1, 450159), -- Crafted Leather
(22706, 9623, 1, 1, -1, 6906), -- Dynasty Mace Piece
(22706, 5157, 1, 1, -1, 5702), -- Recipe: Soulshot (S) Compressed Package (100%)
(22706, 57, 3145, 6334, 0, 700000), -- Adena
(22706, 9524, 1, 1, 1, 11.513704), -- Sealed Dynasty Tunic
(22706, 9525, 1, 1, 1, 18.420524), -- Sealed Dynasty Stockings
(22706, 9540, 1, 1, 1, 2826.810668), -- Sealed Dynasty Tunic Piece
(22706, 9541, 1, 1, 1, 4155.255104), -- Sealed Dynasty Stocking Piece
(22706, 1895, 1, 1, 2, 225713.198347), -- Metallic Fiber
(22706, 4040, 1, 1, 2, 15799.828807), -- Mold Lubricant
(22706, 4042, 1, 1, 2, 13166.475987), -- Enria
(22706, 4043, 1, 1, 2, 26333.240087), -- Asofe
(22706, 9573, 1, 1, 2, 5485.959633), -- Life Stone - Level 80
(22706, 9574, 1, 1, 2, 1371.41788), -- Mid-Grade Life Stone - Level 80
(22706, 9575, 1, 1, 2, 137.141788), -- High-Grade Life Stone - Level 80
(22706, 9626, 1, 1, 2, 105.737471), -- Giant's Codex - Discipline
-- Turka Commander's Ghost
(22707, 9624, 1, 1, -1, 6683), -- Dynasty Bagh-Nakh Piece
(22707, 5162, 1, 1, -1, 5518), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22707, 9622, 1, 1, -1, 6683), -- Dynasty Cudgel Piece
(22707, 57, 3043, 6130, 0, 700000), -- Adena
(22707, 9452, 1, 1, 1, 33.710726), -- Sealed Dynasty Earring
(22707, 9453, 1, 1, 1, 25.279198), -- Sealed Dynasty Necklace
(22707, 9454, 1, 1, 1, 50.566089), -- Sealed Dynasty Ring
(22707, 9991, 1, 1, 1, 2390.122784), -- Sealed Dynasty Earring Gemstone
(22707, 9992, 1, 1, 1, 1834.357385), -- Sealed Dynasty Necklace Gemstone
(22707, 9993, 1, 1, 1, 3358.963818), -- Sealed Dynasty Ring Gemstone
(22707, 1895, 1, 1, 2, 349503.555228), -- Metallic Fiber
(22707, 4040, 1, 1, 2, 24465.150984), -- Mold Lubricant
(22707, 4042, 1, 1, 2, 20387.922432), -- Enria
(22707, 4043, 1, 1, 2, 40775.399946), -- Asofe
(22707, 9546, 1, 1, 2, 9785.97141), -- Fire Stone
-- Invader Warrior of Nightmare
(22708, 9544, 1, 1, -1, 76233), -- Sealed Dynasty Shoes Piece
(22708, 10114, 1, 1, -1, 39508), -- Sealed Dynasty Sigil Piece
(22708, 9542, 1, 1, -1, 57296), -- Sealed Dynasty Circlet Piece
(22708, 57, 3902, 7872, 0, 700000), -- Adena
(22708, 9517, 1, 1, 1, 14.300428), -- Sealed Dynasty Gauntlets
(22708, 9518, 1, 1, 1, 14.300428), -- Sealed Dynasty Boots
(22708, 9522, 1, 1, 1, 14.300428), -- Sealed Dynasty Leather Gloves
(22708, 9523, 1, 1, 1, 14.300428), -- Sealed Dynasty Leather Boots
(22708, 9527, 1, 1, 1, 14.300428), -- Sealed Dynasty Gloves
(22708, 9528, 1, 1, 1, 14.300428), -- Sealed Dynasty Shoes
(22708, 9533, 1, 1, 1, 3130.039194), -- Sealed Dynasty Gauntlet Piece
(22708, 9534, 1, 1, 1, 3130.039194), -- Sealed Dynasty Boot Piece
(22708, 9538, 1, 1, 1, 3130.039194), -- Sealed Dynasty Leather Glove Piece
(22708, 9539, 1, 1, 1, 3130.039194), -- Sealed Dynasty Leather Boots Piece
(22708, 9543, 1, 1, 1, 3130.039194), -- Sealed Dynasty Glove Piece
(22708, 9544, 1, 1, 1, 3130.001462), -- Sealed Dynasty Shoes Piece
(22708, 1879, 1, 1, 2, 218042.807265), -- Cokes
(22708, 1885, 1, 1, 2, 109021.583815), -- High-Grade Suede
(22708, 9628, 1, 1, 2, 10260.672645), -- Leonard
(22708, 9630, 1, 1, 2, 6885.494055), -- Orichalcum
(22708, 9629, 1, 1, 2, 5688.00116), -- Adamantine
(22708, 9547, 1, 1, 2, 10466.44106), -- Water Stone
-- Invader Healer of Nightmare
(22709, 5277, 1, 1, -1, 7097), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22709, 9530, 1, 1, -1, 23255), -- Sealed Dynasty Breast Plate Piece
(22709, 1894, 1, 1, -1, 560271), -- Crafted Leather
(22709, 57, 3911, 7889, 0, 700000), -- Adena
(22709, 9516, 1, 1, 1, 11.462998), -- Sealed Dynasty Helmet
(22709, 9529, 1, 1, 1, 16.370974), -- Sealed Dynasty Shield
(22709, 13886, 1, 1, 1, 16.370974), -- Sealed Dynasty Sigil
(22709, 9521, 1, 1, 1, 11.462998), -- Sealed Dynasty Leather Helmet
(22709, 9526, 1, 1, 1, 11.462998), -- Sealed Dynasty Circlet
(22709, 9532, 1, 1, 1, 2827.624254), -- Sealed Dynasty Helmet Piece
(22709, 9542, 1, 1, 1, 2827.624254), -- Sealed Dynasty Circlet Piece
(22709, 9545, 1, 1, 1, 3370.441978), -- Sealed Dynasty Shield Piece
(22709, 10114, 1, 1, 1, 1949.715574), -- Sealed Dynasty Sigil Piece
(22709, 1895, 1, 3, 2, 224739.490457), -- Metallic Fiber
(22709, 4040, 1, 1, 2, 31463.410532), -- Mold Lubricant
(22709, 4042, 1, 1, 2, 26219.740408), -- Enria
(22709, 4043, 1, 1, 2, 52439.133369), -- Asofe
(22709, 9548, 1, 1, 2, 12585.225234), -- Earth Stone
-- Invader Guide of Nightmare
(22710, 9531, 1, 1, -1, 44463), -- Sealed Dynasty Gaiters Piece
(22710, 1894, 1, 1, -1, 362152), -- Crafted Leather
(22710, 9628, 1, 1, -1, 80952), -- Leonard
(22710, 57, 2528, 5099, 0, 700000), -- Adena
(22710, 9442, 1, 1, 1, 1.507334), -- Dynasty Sword
(22710, 9443, 1, 1, 1, 1.507334), -- Dynasty Blade
(22710, 9444, 1, 1, 1, 1.507334), -- Dynasty Phantom
(22710, 9616, 1, 1, 1, 471.15886), -- Dynasty Sword Piece
(22710, 9617, 1, 1, 1, 471.15886), -- Dynasty Blade Piece
(22710, 9618, 1, 1, 1, 471.160278), -- Dynasty Phantom Piece
(22710, 1879, 1, 1, 2, 141233.33862), -- Cokes
(22710, 1885, 1, 1, 2, 70616.78602), -- High-Grade Suede
(22710, 9628, 1, 1, 2, 6646.16766), -- Leonard
(22710, 9630, 1, 1, 2, 4459.95594), -- Orichalcum
(22710, 9629, 1, 1, 2, 3684.30128), -- Adamantine
(22710, 9549, 1, 1, 2, 6779.45048), -- Wind Stone
-- Invader Destroyer of Nightmare
(22711, 9535, 1, 1, -1, 25343), -- Sealed Dynasty Leather Armor Piece
(22711, 1808, 1, 1, -1, 6296), -- Recipe: Soulshot (S-Grade)
(22711, 9993, 1, 1, -1, 46678), -- Sealed Dynasty Ring Gemstone
(22711, 57, 3469, 6998, 0, 700000), -- Adena
(22711, 9448, 1, 1, 1, 1.551662), -- Dynasty Cudgel
(22711, 9449, 1, 1, 1, 1.551662), -- Dynasty Mace
(22711, 10252, 1, 1, 1, 1.551662), -- Dynasty Staff
(22711, 10253, 1, 1, 1, 1.551662), -- Dynasty Crusher
(22711, 9622, 1, 1, 1, 469.405566), -- Dynasty Cudgel Piece
(22711, 9623, 1, 1, 1, 469.405566), -- Dynasty Mace Piece
(22711, 10546, 1, 1, 1, 486.493028), -- Dynasty Staff Fragment
(22711, 10547, 1, 1, 1, 486.489192), -- Dynasty Crusher Fragment
(22711, 1895, 1, 1, 2, 398753.673552), -- Metallic Fiber
(22711, 4040, 1, 1, 2, 27912.903108), -- Mold Lubricant
(22711, 9628, 1, 1, 2, 10946.039754), -- Leonard
(22711, 9630, 1, 1, 2, 7345.404792), -- Orichalcum
(22711, 9550, 1, 1, 2, 11164.978794), -- Dark Stone
-- Invader Assassin of Nightmare
(22712, 3036, 1, 1, -1, 4713), -- Recipe: Spiritshot S
(22712, 9531, 1, 1, -1, 45677), -- Sealed Dynasty Gaiters Piece
(22712, 9628, 1, 1, -1, 83162), -- Leonard
(22712, 57, 2597, 5238, 0, 700000), -- Adena
(22712, 9450, 1, 1, 1, 4.647834), -- Dynasty Bagh-Nakh
(22712, 9624, 1, 1, 1, 1406.352166), -- Dynasty Bagh-Nakh Piece
(22712, 1895, 1, 1, 2, 298470.564288), -- Metallic Fiber
(22712, 4040, 1, 1, 2, 20893.048752), -- Mold Lubricant
(22712, 9628, 1, 1, 2, 8193.205176), -- Leonard
(22712, 9630, 1, 1, 2, 5498.098848), -- Orichalcum
(22712, 9551, 1, 1, 2, 8357.082936), -- Holy Stone
-- Invader Shaman of Nightmare
(22713, 9543, 1, 1, -1, 63329), -- Sealed Dynasty Glove Piece
(22713, 9617, 1, 1, -1, 7360), -- Dynasty Blade Piece
(22713, 6901, 1, 1, -1, 13237), -- Recipe: Shining Arrow (100%)
(22713, 57, 3242, 6540, 0, 700000), -- Adena
(22713, 9445, 1, 1, 1, 5.800608), -- Dynasty Bow
(22713, 9619, 1, 1, 1, 1825.199392), -- Dynasty Bow Piece
(22713, 1895, 1, 1, 2, 310517.651808), -- Metallic Fiber
(22713, 4040, 1, 1, 2, 21736.36647), -- Mold Lubricant
(22713, 9628, 1, 1, 2, 8523.982818), -- Leonard
(22713, 9630, 1, 1, 2, 5720.194818), -- Orichalcum
(22713, 959, 1, 1, 2, 43.458714), -- Scroll: Enchant Weapon (S-Grade)
(22713, 1345, 60, 180, 2, 120756.345372), -- Shining Arrow
-- Invader Archer of Nightmare
(22714, 9535, 1, 1, -1, 18011), -- Sealed Dynasty Leather Armor Piece
(22714, 1808, 1, 1, -1, 4475), -- Recipe: Soulshot (S-Grade)
(22714, 9620, 1, 1, -1, 5593), -- Dynasty Knife Piece
(22714, 57, 2466, 4974, 0, 700000), -- Adena
(22714, 9446, 1, 1, 1, 4.411344), -- Dynasty Knife
(22714, 9620, 1, 1, 1, 1377.588656), -- Dynasty Knife Piece
(22714, 1895, 1, 1, 2, 283397.355384), -- Metallic Fiber
(22714, 4040, 1, 1, 2, 19837.944696), -- Mold Lubricant
(22714, 9628, 1, 1, 2, 7779.64824), -- Leonard
(22714, 9630, 1, 1, 2, 5220.628416), -- Orichalcum
(22714, 960, 1, 1, 2, 396.423264), -- Scroll: Enchant Armor (S-Grade)
-- Invader Soldier of Nightmare
(22715, 1894, 1, 1, -1, 559108), -- Crafted Leather
(22715, 9541, 1, 1, -1, 41904), -- Sealed Dynasty Stocking Piece
(22715, 9534, 1, 1, -1, 76233), -- Sealed Dynasty Boot Piece
(22715, 57, 3902, 7872, 0, 700000), -- Adena
(22715, 9447, 1, 1, 1, 6.981825), -- Dynasty Halberd
(22715, 9621, 1, 1, 1, 2192.018175), -- Dynasty Halberd Piece
(22715, 1879, 1, 1, 2, 218042.72048), -- Cokes
(22715, 1885, 1, 1, 2, 109021.36024), -- High-Grade Suede
(22715, 9628, 1, 1, 2, 10261.00296), -- Leonard
(22715, 9630, 1, 1, 2, 6885.53008), -- Orichalcum
(22715, 9629, 1, 1, 2, 5687.93992), -- Adamantine
(22715, 5272, 1, 1, 2, 581.44632), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Invader Soldier of Nightmare
(22716, 3036, 1, 1, -1, 1815), -- Recipe: Spiritshot S
(22716, 9530, 1, 1, -1, 5949), -- Sealed Dynasty Breast Plate Piece
(22716, 3957, 1, 1, -1, 1815), -- Recipe: Blessed Spiritshot S
(22716, 57, 1000, 2018, 0, 700000), -- Adena
(22716, 9514, 1, 1, 1, 2.749076), -- Sealed Dynasty Breast Plate
(22716, 9515, 1, 1, 1, 4.396778), -- Sealed Dynasty Gaiter
(22716, 9530, 1, 1, 1, 732.416616), -- Sealed Dynasty Breast Plate Piece
(22716, 9531, 1, 1, 1, 2166.43753), -- Sealed Dynasty Gaiters Piece
(22716, 1879, 1, 1, 2, 55894.288344), -- Cokes
(22716, 1885, 1, 1, 2, 27947.144172), -- High-Grade Suede
(22716, 9628, 1, 1, 2, 2630.362788), -- Leonard
(22716, 9630, 1, 1, 2, 1765.075224), -- Orichalcum
(22716, 9629, 1, 1, 2, 1458.078276), -- Adamantine
(22716, 5277, 1, 1, 2, 149.051196), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
-- Invader Disciple of Nightmare
(22717, 6901, 1, 1, -1, 16957), -- Recipe: Shining Arrow (100%)
(22717, 9619, 1, 1, -1, 9492), -- Dynasty Bow Piece
(22717, 959, 1, 1, -1, 678), -- Scroll: Enchant Weapon (S-Grade)
(22717, 57, 4153, 8378, 0, 700000), -- Adena
(22717, 9519, 1, 1, 1, 15.218056), -- Sealed Dynasty Leather Armor
(22717, 9520, 1, 1, 1, 24.347036), -- Sealed Dynasty Leather Leggings
(22717, 9535, 1, 1, 1, 3736.292252), -- Sealed Dynasty Leather Armor Piece
(22717, 9536, 1, 1, 1, 5492.142656), -- Sealed Dynasty Leather Leggings Piece
(22717, 1895, 1, 3, 2, 238668.602452), -- Metallic Fiber
(22717, 4040, 1, 1, 2, 33413.698654), -- Mold Lubricant
(22717, 9628, 1, 1, 2, 13103.29566), -- Leonard
(22717, 9630, 1, 1, 2, 8793.001035), -- Orichalcum
(22717, 5282, 1, 1, 2, 742.402199), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Invader Elite Soldier of Nightmare
(22718, 9543, 1, 1, -1, 87915), -- Sealed Dynasty Glove Piece
(22718, 9628, 1, 1, -1, 144129), -- Leonard
(22718, 9535, 1, 1, -1, 32876), -- Sealed Dynasty Leather Armor Piece
(22718, 57, 4501, 9079, 0, 700000), -- Adena
(22718, 9524, 1, 1, 1, 16.490606), -- Sealed Dynasty Tunic
(22718, 9525, 1, 1, 1, 26.382961), -- Sealed Dynasty Stockings
(22718, 9540, 1, 1, 1, 4048.724977), -- Sealed Dynasty Tunic Piece
(22718, 9541, 1, 1, 1, 5951.401456), -- Sealed Dynasty Stocking Piece
(22718, 1895, 1, 3, 2, 258641.722179), -- Metallic Fiber
(22718, 4040, 1, 1, 2, 36209.950038), -- Mold Lubricant
(22718, 9628, 1, 1, 2, 14200.049511), -- Leonard
(22718, 9630, 1, 1, 2, 9528.748731), -- Orichalcum
(22718, 6901, 1, 1, 2, 1810.529541), -- Recipe: Shining Arrow (100%)
-- Nihil Invader Warrior
(22719, 1808, 1, 1, -1, 13052), -- Recipe: Soulshot (S-Grade)
(22719, 9624, 1, 1, -1, 15808), -- Dynasty Bagh-Nakh Piece
(22719, 3036, 1, 1, -1, 13052), -- Recipe: Spiritshot S
(22719, 57, 7198, 14500, 0, 700000), -- Adena
(22719, 9452, 1, 1, 1, 79.73049), -- Sealed Dynasty Earring
(22719, 9453, 1, 1, 1, 59.78877), -- Sealed Dynasty Necklace
(22719, 9454, 1, 1, 1, 119.595735), -- Sealed Dynasty Ring
(22719, 9991, 1, 1, 1, 5652.96816), -- Sealed Dynasty Earring Gemstone
(22719, 9992, 1, 1, 1, 4338.506775), -- Sealed Dynasty Necklace Gemstone
(22719, 9993, 1, 1, 1, 7944.41007), -- Sealed Dynasty Ring Gemstone
(22719, 1879, 1, 3, 2, 200924.194536), -- Cokes
(22719, 1885, 1, 1, 2, 200924.194536), -- High-Grade Suede
(22719, 9628, 1, 1, 2, 18910.402485), -- Leonard
(22719, 9630, 1, 1, 2, 12690.150551), -- Orichalcum
(22719, 9629, 1, 1, 2, 10482.935671), -- Adamantine
(22719, 5157, 1, 1, 2, 1071.122221), -- Recipe: Soulshot (S) Compressed Package (100%)
-- Nihil Invader Healer
(22720, 9534, 1, 1, -1, 134390), -- Sealed Dynasty Boot Piece
(22720, 9628, 1, 1, -1, 220320), -- Leonard
(22720, 9630, 1, 1, -1, 147846), -- Orichalcum
(22720, 57, 6885, 13870, 0, 700000), -- Adena
(22720, 9517, 1, 1, 1, 25.209564), -- Sealed Dynasty Gauntlets
(22720, 9518, 1, 1, 1, 25.209564), -- Sealed Dynasty Boots
(22720, 9522, 1, 1, 1, 25.209564), -- Sealed Dynasty Leather Gloves
(22720, 9523, 1, 1, 1, 25.209564), -- Sealed Dynasty Leather Boots
(22720, 9527, 1, 1, 1, 25.209564), -- Sealed Dynasty Gloves
(22720, 9528, 1, 1, 1, 25.209564), -- Sealed Dynasty Shoes
(22720, 9533, 1, 1, 1, 5517.801522), -- Sealed Dynasty Gauntlet Piece
(22720, 9534, 1, 1, 1, 5517.801522), -- Sealed Dynasty Boot Piece
(22720, 9538, 1, 1, 1, 5517.801522), -- Sealed Dynasty Leather Glove Piece
(22720, 9539, 1, 1, 1, 5517.801522), -- Sealed Dynasty Leather Boots Piece
(22720, 9543, 1, 1, 1, 5517.801522), -- Sealed Dynasty Glove Piece
(22720, 9544, 1, 1, 1, 5517.735006), -- Sealed Dynasty Shoes Piece
(22720, 1879, 1, 3, 2, 192191.952456), -- Cokes
(22720, 1885, 1, 1, 2, 192191.952456), -- High-Grade Suede
(22720, 9628, 1, 1, 2, 18088.549185), -- Leonard
(22720, 9630, 1, 1, 2, 12138.631771), -- Orichalcum
(22720, 9629, 1, 1, 2, 10027.343291), -- Adamantine
(22720, 5162, 1, 1, 2, 1024.570841), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Nihil Invader Guide
(22721, 9534, 1, 1, -1, 64545), -- Sealed Dynasty Boot Piece
(22721, 3957, 1, 1, -1, 5996), -- Recipe: Blessed Spiritshot S
(22721, 9538, 1, 1, -1, 64545), -- Sealed Dynasty Leather Glove Piece
(22721, 57, 3307, 6661, 0, 700000), -- Adena
(22721, 9516, 1, 1, 1, 9.68558), -- Sealed Dynasty Helmet
(22721, 9529, 1, 1, 1, 13.83254), -- Sealed Dynasty Shield
(22721, 13886, 1, 1, 1, 13.83254), -- Sealed Dynasty Sigil
(22721, 9521, 1, 1, 1, 9.68558), -- Sealed Dynasty Leather Helmet
(22721, 9526, 1, 1, 1, 9.68558), -- Sealed Dynasty Circlet
(22721, 9532, 1, 1, 1, 2389.18134), -- Sealed Dynasty Helmet Piece
(22721, 9542, 1, 1, 1, 2389.18134), -- Sealed Dynasty Circlet Piece
(22721, 9545, 1, 1, 1, 2847.83138), -- Sealed Dynasty Shield Piece
(22721, 10114, 1, 1, 1, 1647.39854), -- Sealed Dynasty Sigil Piece
(22721, 1895, 1, 1, 2, 379775.124723), -- Metallic Fiber
(22721, 4040, 1, 1, 2, 26584.296924), -- Mold Lubricant
(22721, 9628, 1, 1, 2, 10425.097986), -- Leonard
(22721, 9630, 1, 1, 2, 6995.755935), -- Orichalcum
(22721, 5167, 1, 1, 2, 590.724432), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
-- Nihil Invader Destroyer
(22722, 5157, 1, 1, -1, 12451), -- Recipe: Soulshot (S) Compressed Package (100%)
(22722, 9538, 1, 1, -1, 134027), -- Sealed Dynasty Leather Glove Piece
(22722, 1894, 1, 3, -1, 491490), -- Crafted Leather
(22722, 57, 6867, 13832, 0, 700000), -- Adena
(22722, 9442, 1, 1, 1, 4.091487), -- Dynasty Sword
(22722, 9443, 1, 1, 1, 4.091487), -- Dynasty Blade
(22722, 9444, 1, 1, 1, 4.091487), -- Dynasty Phantom
(22722, 9616, 1, 1, 1, 1278.90723), -- Dynasty Sword Piece
(22722, 9617, 1, 1, 1, 1278.90723), -- Dynasty Blade Piece
(22722, 9618, 1, 1, 1, 1278.911079), -- Dynasty Phantom Piece
(22722, 1895, 3, 9, 2, 131433.175832), -- Metallic Fiber
(22722, 4040, 1, 1, 2, 55201.992384), -- Mold Lubricant
(22722, 4042, 1, 1, 2, 46001.66032), -- Enria
(22722, 4043, 1, 1, 2, 92003.32064), -- Asofe
(22722, 9625, 1, 1, 2, 551.850824), -- Giant's Codex - Oblivion
-- Nihil Invader Assassin
(22723, 1894, 1, 1, -1, 482268), -- Crafted Leather
(22723, 9530, 1, 1, -1, 20017), -- Sealed Dynasty Breast Plate Piece
(22723, 5162, 1, 1, -1, 6109), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22723, 57, 3369, 6786, 0, 700000), -- Adena
(22723, 9448, 1, 1, 1, 1.505549), -- Dynasty Cudgel
(22723, 9449, 1, 1, 1, 1.505549), -- Dynasty Mace
(22723, 10252, 1, 1, 1, 1.505549), -- Dynasty Staff
(22723, 10253, 1, 1, 1, 1.505549), -- Dynasty Crusher
(22723, 9622, 1, 1, 1, 455.455557), -- Dynasty Cudgel Piece
(22723, 9623, 1, 1, 1, 455.455557), -- Dynasty Mace Piece
(22723, 10546, 1, 1, 1, 472.035206), -- Dynasty Staff Fragment
(22723, 10547, 1, 1, 1, 472.031484), -- Dynasty Crusher Fragment
(22723, 1879, 1, 1, 2, 188076.729738), -- Cokes
(22723, 1885, 1, 1, 2, 94038.51585), -- High-Grade Suede
(22723, 9628, 1, 1, 2, 8850.808182), -- Leonard
(22723, 9630, 1, 1, 2, 5939.290578), -- Orichalcum
(22723, 9629, 1, 1, 2, 4906.278576), -- Adamantine
(22723, 9626, 1, 1, 2, 150.377076), -- Giant's Codex - Discipline
-- Nihil Invader Shaman
(22724, 9535, 1, 1, -1, 50390), -- Sealed Dynasty Leather Armor Piece
(22724, 5167, 1, 1, -1, 12518), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22724, 9622, 1, 1, -1, 15162), -- Dynasty Cudgel Piece
(22724, 57, 6904, 13907, 0, 700000), -- Adena
(22724, 9450, 1, 1, 1, 12.342618), -- Dynasty Bagh-Nakh
(22724, 9624, 1, 1, 1, 3734.657382), -- Dynasty Bagh-Nakh Piece
(22724, 1895, 1, 3, 2, 247770.866556), -- Metallic Fiber
(22724, 4040, 1, 1, 2, 34687.875132), -- Mold Lubricant
(22724, 4042, 1, 1, 2, 28906.56261), -- Enria
(22724, 4043, 1, 1, 2, 57813.12522), -- Asofe
(22724, 9573, 1, 1, 2, 12044.497308), -- Life Stone - Level 80
(22724, 9574, 1, 1, 2, 3010.931886), -- Mid-Grade Life Stone - Level 80
(22724, 9575, 1, 1, 2, 300.977724), -- High-Grade Life Stone - Level 80
(22724, 9625, 1, 1, 2, 347.163564), -- Giant's Codex - Oblivion
-- Nihil Invader Archer
(22725, 9539, 1, 1, -1, 131850), -- Sealed Dynasty Leather Boots Piece
(22725, 1894, 1, 3, -1, 483509), -- Crafted Leather
(22725, 9533, 1, 1, -1, 131850), -- Sealed Dynasty Gauntlet Piece
(22725, 57, 6755, 13607, 0, 700000), -- Adena
(22725, 9445, 1, 1, 1, 12.076416), -- Dynasty Bow
(22725, 9619, 1, 1, 1, 3799.923584), -- Dynasty Bow Piece
(22725, 1895, 1, 3, 2, 242435.07122), -- Metallic Fiber
(22725, 4040, 1, 1, 2, 33940.96019), -- Mold Lubricant
(22725, 9628, 1, 1, 2, 13310.28509), -- Leonard
(22725, 9630, 1, 1, 2, 8931.79859), -- Orichalcum
(22725, 9573, 1, 1, 2, 11784.87689), -- Life Stone - Level 80
(22725, 9574, 1, 1, 2, 2946.29769), -- Mid-Grade Life Stone - Level 80
(22725, 9575, 1, 1, 2, 294.72393), -- High-Grade Life Stone - Level 80
(22725, 9626, 1, 1, 2, 225.9864), -- Giant's Codex - Discipline
-- Nihil Invader Soldier
(22726, 5272, 1, 1, -1, 12451), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22726, 9623, 1, 1, -1, 15080), -- Dynasty Mace Piece
(22726, 5277, 1, 1, -1, 12451), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22726, 57, 6867, 13832, 0, 700000), -- Adena
(22726, 9446, 1, 1, 1, 12.276432), -- Dynasty Knife
(22726, 9620, 1, 1, 1, 3833.723568), -- Dynasty Knife Piece
(22726, 1879, 1, 1, 2, 255564.081972), -- Cokes
(22726, 1885, 1, 1, 2, 127782.040986), -- High-Grade Suede
(22726, 9628, 1, 1, 2, 12026.662998), -- Leonard
(22726, 9630, 1, 1, 2, 8070.380448), -- Orichalcum
(22726, 9629, 1, 1, 2, 6667.044522), -- Adamantine
(22726, 9573, 1, 1, 2, 10648.612404), -- Life Stone - Level 80
(22726, 9574, 1, 1, 2, 2661.935124), -- Mid-Grade Life Stone - Level 80
(22726, 9575, 1, 1, 2, 266.367894), -- High-Grade Life Stone - Level 80
(22726, 9546, 1, 1, 2, 12266.873652), -- Fire Stone
-- Nihil Invader Soldier
(22727, 9622, 1, 1, -1, 2884), -- Dynasty Cudgel Piece
(22727, 960, 1, 1, -1, 2143), -- Scroll: Enchant Armor (S-Grade)
(22727, 9533, 1, 1, -1, 25633), -- Sealed Dynasty Gauntlet Piece
(22727, 57, 1313, 2645, 0, 700000), -- Adena
(22727, 9447, 1, 1, 1, 2.346325), -- Dynasty Halberd
(22727, 9621, 1, 1, 1, 736.653675), -- Dynasty Halberd Piece
(22727, 1879, 1, 1, 2, 48876.511968), -- Cokes
(22727, 1885, 1, 1, 2, 24438.255984), -- High-Grade Suede
(22727, 9628, 1, 1, 2, 2300.093712), -- Leonard
(22727, 9630, 1, 1, 2, 1543.456512), -- Orichalcum
(22727, 9629, 1, 1, 2, 1275.069168), -- Adamantine
(22727, 9573, 1, 1, 2, 2036.542176), -- Life Stone - Level 80
(22727, 9574, 1, 1, 2, 509.093856), -- Mid-Grade Life Stone - Level 80
(22727, 9575, 1, 1, 2, 50.942736), -- High-Grade Life Stone - Level 80
(22727, 9547, 1, 1, 2, 2346.033888), -- Water Stone
-- Nihil Invader Disciple
(22728, 5277, 1, 1, -1, 12451), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22728, 9530, 1, 1, -1, 40801), -- Sealed Dynasty Breast Plate Piece
(22728, 1894, 1, 3, -1, 491490), -- Crafted Leather
(22728, 57, 6867, 13832, 0, 700000), -- Adena
(22728, 9514, 1, 1, 1, 18.854726), -- Sealed Dynasty Breast Plate
(22728, 9515, 1, 1, 1, 30.155603), -- Sealed Dynasty Gaiter
(22728, 9530, 1, 1, 1, 5023.329516), -- Sealed Dynasty Breast Plate Piece
(22728, 9531, 1, 1, 1, 14858.660155), -- Sealed Dynasty Gaiters Piece
(22728, 1895, 1, 3, 2, 246436.570553), -- Metallic Fiber
(22728, 4040, 1, 1, 2, 34501.113225), -- Mold Lubricant
(22728, 9628, 1, 1, 2, 13529.691796), -- Leonard
(22728, 9630, 1, 1, 2, 9079.222816), -- Orichalcum
(22728, 9573, 1, 1, 2, 11979.677936), -- Life Stone - Level 80
(22728, 9574, 1, 1, 2, 2994.919484), -- Mid-Grade Life Stone - Level 80
(22728, 9575, 1, 1, 2, 299.3589), -- High-Grade Life Stone - Level 80
(22728, 9548, 1, 1, 2, 13800.44529), -- Earth Stone
-- Nihil Invader Elite Soldier
(22729, 9623, 1, 1, -1, 27813), -- Dynasty Mace Piece
(22729, 10546, 1, 1, -1, 28826), -- Dynasty Staff Fragment
(22729, 9993, 1, 1, -1, 170259), -- Sealed Dynasty Ring Gemstone
(22729, 57, 12665, 25512, 0, 700000), -- Adena
(22729, 9519, 1, 1, 1, 46.368438), -- Sealed Dynasty Leather Armor
(22729, 9520, 1, 1, 1, 74.183853), -- Sealed Dynasty Leather Leggings
(22729, 9535, 1, 1, 1, 11384.242221), -- Sealed Dynasty Leather Armor Piece
(22729, 9536, 1, 1, 1, 16734.205488), -- Sealed Dynasty Leather Leggings Piece
(22729, 1895, 3, 9, 2, 151508.10275), -- Metallic Fiber
(22729, 4040, 1, 1, 2, 63633.70265), -- Mold Lubricant
(22729, 4042, 1, 1, 2, 53027.729), -- Enria
(22729, 4043, 1, 1, 2, 106055.88585), -- Asofe
(22729, 9573, 1, 1, 2, 22095.0297), -- Life Stone - Level 80
(22729, 9574, 1, 1, 2, 5523.5435), -- Mid-Grade Life Stone - Level 80
(22729, 9575, 1, 1, 2, 552.35435), -- High-Grade Life Stone - Level 80
(22729, 9549, 1, 1, 2, 25453.6522), -- Wind Stone
-- Mutant Warrior
(22730, 10405, 1, 1, -1, 21933), -- Icarus Spitter Piece
(22730, 9630, 1, 1, -1, 270125), -- Orichalcum
(22730, 959, 1, 1, -1, 2053), -- Scroll: Enchant Weapon (S-Grade)
(22730, 57, 12455, 25456, 0, 700000), -- Adena
(22730, 9524, 1, 1, 1, 46.056458), -- Sealed Dynasty Tunic
(22730, 9525, 1, 1, 1, 73.684723), -- Sealed Dynasty Stockings
(22730, 9540, 1, 1, 1, 11307.645811), -- Sealed Dynasty Tunic Piece
(22730, 9541, 1, 1, 1, 16621.613008), -- Sealed Dynasty Stocking Piece
(22730, 1879, 3, 9, 2, 78032.76318), -- Cokes
(22730, 1885, 1, 1, 2, 234098.69805), -- High-Grade Suede
(22730, 9628, 1, 1, 2, 22032.98685), -- Leonard
(22730, 9630, 1, 1, 2, 14785.20243), -- Orichalcum
(22730, 9629, 1, 1, 2, 12214.04049), -- Adamantine
(22730, 9573, 1, 1, 2, 19508.39505), -- Life Stone - Level 80
(22730, 9574, 1, 1, 2, 4877.20089), -- Mid-Grade Life Stone - Level 80
(22730, 9575, 1, 1, 2, 487.76094), -- High-Grade Life Stone - Level 80
(22730, 9550, 1, 1, 2, 22472.95212), -- Dark Stone
-- Mutant Healer
(22731, 9532, 1, 1, -1, 174214), -- Sealed Dynasty Helmet Piece
(22731, 9630, 1, 1, -1, 255001), -- Orichalcum
(22731, 10402, 1, 1, -1, 20705), -- Icarus Hammer Piece
(22731, 57, 11758, 24031, 0, 700000), -- Adena
(22731, 9452, 1, 1, 1, 131.543258), -- Sealed Dynasty Earring
(22731, 9453, 1, 1, 1, 98.642434), -- Sealed Dynasty Necklace
(22731, 9454, 1, 1, 1, 197.314887), -- Sealed Dynasty Ring
(22731, 9991, 1, 1, 1, 9326.543072), -- Sealed Dynasty Earring Gemstone
(22731, 9992, 1, 1, 1, 7157.880455), -- Sealed Dynasty Necklace Gemstone
(22731, 9993, 1, 1, 1, 13107.075894), -- Sealed Dynasty Ring Gemstone
(22731, 1895, 3, 9, 2, 142065.98039), -- Metallic Fiber
(22731, 4040, 1, 1, 2, 59667.992594), -- Mold Lubricant
(22731, 4042, 1, 1, 2, 49722.99284), -- Enria
(22731, 4043, 1, 1, 2, 99446.386866), -- Asofe
(22731, 9573, 1, 1, 2, 20718.047412), -- Life Stone - Level 80
(22731, 9574, 1, 1, 2, 5179.31126), -- Mid-Grade Life Stone - Level 80
(22731, 9575, 1, 1, 2, 517.931126), -- High-Grade Life Stone - Level 80
(22731, 9551, 1, 1, 2, 23867.357512), -- Holy Stone
-- Mutant Guide
(22732, 10397, 1, 1, -1, 20829), -- Icarus Sawsword Piece
(22732, 10403, 1, 1, -1, 20762), -- Icarus Hand Piece
(22732, 10400, 1, 1, -1, 20762), -- Icarus Heavy Arms Piece
(22732, 57, 11790, 24097, 0, 700000), -- Adena
(22732, 9517, 1, 1, 1, 43.600918), -- Sealed Dynasty Gauntlets
(22732, 9518, 1, 1, 1, 43.600918), -- Sealed Dynasty Boots
(22732, 9522, 1, 1, 1, 43.600918), -- Sealed Dynasty Leather Gloves
(22732, 9523, 1, 1, 1, 43.600918), -- Sealed Dynasty Leather Boots
(22732, 9527, 1, 1, 1, 43.600918), -- Sealed Dynasty Gloves
(22732, 9528, 1, 1, 1, 43.600918), -- Sealed Dynasty Shoes
(22732, 9533, 1, 1, 1, 9543.251589), -- Sealed Dynasty Gauntlet Piece
(22732, 9534, 1, 1, 1, 9543.251589), -- Sealed Dynasty Boot Piece
(22732, 9538, 1, 1, 1, 9543.251589), -- Sealed Dynasty Leather Glove Piece
(22732, 9539, 1, 1, 1, 9543.251589), -- Sealed Dynasty Leather Boots Piece
(22732, 9543, 1, 1, 1, 9543.251589), -- Sealed Dynasty Glove Piece
(22732, 9544, 1, 1, 1, 9543.136547), -- Sealed Dynasty Shoes Piece
(22732, 1895, 3, 9, 2, 142457.850129), -- Metallic Fiber
(22732, 4040, 1, 1, 2, 59832.366762), -- Mold Lubricant
(22732, 9628, 1, 1, 2, 23463.652212), -- Leonard
(22732, 9630, 1, 1, 2, 15745.387896), -- Orichalcum
(22732, 9573, 1, 1, 2, 20775.075216), -- Life Stone - Level 80
(22732, 9574, 1, 1, 2, 5193.768804), -- Mid-Grade Life Stone - Level 80
(22732, 9575, 1, 1, 2, 519.323259), -- High-Grade Life Stone - Level 80
(22732, 959, 1, 1, 2, 119.575722), -- Scroll: Enchant Weapon (S-Grade)
-- Mutant Destroyer
(22733, 9542, 1, 1, -1, 184066), -- Sealed Dynasty Circlet Piece
(22733, 9630, 1, 1, -1, 269421), -- Orichalcum
(22733, 9991, 1, 1, -1, 120025), -- Sealed Dynasty Earring Gemstone
(22733, 57, 12423, 25390, 0, 700000), -- Adena
(22733, 9516, 1, 1, 1, 36.750243), -- Sealed Dynasty Helmet
(22733, 9529, 1, 1, 1, 52.485159), -- Sealed Dynasty Shield
(22733, 13886, 1, 1, 1, 52.485159), -- Sealed Dynasty Sigil
(22733, 9521, 1, 1, 1, 36.750243), -- Sealed Dynasty Leather Helmet
(22733, 9526, 1, 1, 1, 36.750243), -- Sealed Dynasty Circlet
(22733, 9532, 1, 1, 1, 9065.331639), -- Sealed Dynasty Helmet Piece
(22733, 9542, 1, 1, 1, 9065.331639), -- Sealed Dynasty Circlet Piece
(22733, 9545, 1, 1, 1, 10805.599173), -- Sealed Dynasty Shield Piece
(22733, 10114, 1, 1, 1, 6250.766259), -- Sealed Dynasty Sigil Piece
(22733, 1879, 3, 9, 2, 77829.506352), -- Cokes
(22733, 1885, 1, 1, 2, 233488.519056), -- High-Grade Suede
(22733, 9628, 1, 1, 2, 21975.467259), -- Leonard
(22733, 9630, 1, 1, 2, 14746.720539), -- Orichalcum
(22733, 9629, 1, 1, 2, 12181.905597), -- Adamantine
(22733, 9573, 1, 1, 2, 19457.376588), -- Life Stone - Level 80
(22733, 9574, 1, 1, 2, 4864.344147), -- Mid-Grade Life Stone - Level 80
(22733, 9575, 1, 1, 2, 486.55026), -- High-Grade Life Stone - Level 80
(22733, 960, 1, 1, 2, 1120.610202), -- Scroll: Enchant Armor (S-Grade)
-- Mutant Assassin
(22734, 9542, 1, 1, -1, 84536), -- Sealed Dynasty Circlet Piece
(22734, 1808, 1, 1, -1, 10449), -- Recipe: Soulshot (S-Grade)
(22734, 9530, 1, 1, -1, 34240), -- Sealed Dynasty Breast Plate Piece
(22734, 57, 5705, 11661, 0, 700000), -- Adena
(22734, 10215, 1, 1, 1, 2.488), -- Icarus Sawsword
(22734, 10217, 1, 1, 1, 2.488), -- Icarus Spirit
(22734, 10218, 1, 1, 1, 2.488), -- Icarus Heavy Arms
(22734, 10397, 1, 1, 1, 827.730232), -- Icarus Sawsword Piece
(22734, 10399, 1, 1, 1, 827.730232), -- Icarus Spirit Piece
(22734, 10400, 1, 1, 1, 825.075536), -- Icarus Heavy Arms Piece
(22734, 1879, 1, 1, 2, 214469.32086), -- Cokes
(22734, 1885, 1, 1, 2, 107234.66043), -- High-Grade Suede
(22734, 9628, 1, 1, 2, 10092.7242), -- Leonard
(22734, 9630, 1, 1, 2, 6772.88034), -- Orichalcum
(22734, 9629, 1, 1, 2, 5594.8023), -- Adamantine
(22734, 9573, 1, 1, 2, 8936.37009), -- Life Stone - Level 80
(22734, 9574, 1, 1, 2, 2234.00349), -- Mid-Grade Life Stone - Level 80
(22734, 9575, 1, 1, 2, 223.29351), -- High-Grade Life Stone - Level 80
(22734, 5272, 1, 1, 2, 571.94478), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
-- Mutant Shaman
(22735, 6901, 1, 1, -1, 48584), -- Recipe: Shining Arrow (100%)
(22735, 10114, 1, 1, -1, 120457), -- Sealed Dynasty Sigil Piece
(22735, 960, 1, 1, -1, 19434), -- Scroll: Enchant Armor (S-Grade)
(22735, 57, 11790, 24097, 0, 700000), -- Adena
(22735, 10220, 1, 1, 1, 7.712512), -- Icarus Hammer
(22735, 10222, 1, 1, 1, 7.712512), -- Icarus Hall
(22735, 10402, 1, 1, 1, 2556.287488), -- Icarus Hammer Piece
(22735, 10404, 1, 1, 1, 2556.287488), -- Icarus Hall Piece
(22735, 1895, 3, 9, 2, 142457.92032), -- Metallic Fiber
(22735, 4040, 1, 1, 2, 59832.272671), -- Mold Lubricant
(22735, 9628, 1, 1, 2, 23463.704991), -- Leonard
(22735, 9630, 1, 1, 2, 15745.349088), -- Orichalcum
(22735, 9573, 1, 1, 2, 20775.11338), -- Life Stone - Level 80
(22735, 9574, 1, 1, 2, 5193.778345), -- Mid-Grade Life Stone - Level 80
(22735, 9575, 1, 1, 2, 519.243176), -- High-Grade Life Stone - Level 80
(22735, 5277, 1, 1, 2, 1329.618029), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
-- Mutant Overlord
(22736, 9532, 1, 1, -1, 80776), -- Sealed Dynasty Helmet Piece
(22736, 10399, 1, 1, -1, 9631), -- Icarus Spirit Piece
(22736, 9630, 1, 1, -1, 118234), -- Orichalcum
(22736, 57, 5452, 11142, 0, 700000), -- Adena
(22736, 10221, 1, 1, 1, 7.132604), -- Icarus Hand
(22736, 10403, 1, 1, 1, 2364.867396), -- Icarus Hand Piece
(22736, 1895, 1, 1, 2, 395223.235084), -- Metallic Fiber
(22736, 4040, 1, 1, 2, 27665.408593), -- Mold Lubricant
(22736, 9628, 1, 1, 2, 10849.117543), -- Leonard
(22736, 9630, 1, 1, 2, 7280.25124), -- Orichalcum
(22736, 9573, 1, 1, 2, 9605.937484), -- Life Stone - Level 80
(22736, 9574, 1, 1, 2, 2401.484371), -- Mid-Grade Life Stone - Level 80
(22736, 9575, 1, 1, 2, 240.103049), -- High-Grade Life Stone - Level 80
(22736, 5282, 1, 1, 2, 615.462636), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
-- Mutant Soldier
(22737, 10399, 1, 1, -1, 20714), -- Icarus Spirit Piece
(22737, 10398, 1, 1, -1, 20714), -- Icarus Disperser Piece
(22737, 10404, 1, 1, -1, 20648), -- Icarus Hall Piece
(22737, 57, 11726, 23964, 0, 700000), -- Adena
(22737, 10223, 1, 1, 1, 15.338707), -- Icarus Spitter
(22737, 10405, 1, 1, 1, 5085.661293), -- Icarus Spitter Piece
(22737, 1879, 3, 9, 2, 73460.590036), -- Cokes
(22737, 1885, 1, 1, 2, 220382.13617), -- High-Grade Suede
(22737, 9628, 1, 1, 2, 20741.805044), -- Leonard
(22737, 9630, 1, 1, 2, 13918.775426), -- Orichalcum
(22737, 9629, 1, 1, 2, 11498.373482), -- Adamantine
(22737, 9573, 1, 1, 2, 18365.33054), -- Life Stone - Level 80
(22737, 9574, 1, 1, 2, 4591.149604), -- Mid-Grade Life Stone - Level 80
(22737, 9575, 1, 1, 2, 459.041748), -- High-Grade Life Stone - Level 80
(22737, 6901, 1, 1, 2, 2644.79795), -- Recipe: Shining Arrow (100%)
-- Mutant Soldier
(22738, 9622, 1, 1, -1, 4976), -- Dynasty Cudgel Piece
(22738, 5272, 1, 1, -1, 4109), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22738, 9545, 1, 1, -1, 39622), -- Sealed Dynasty Shield Piece
(22738, 57, 2243, 4585, 0, 700000), -- Adena
(22738, 10216, 1, 1, 1, 2.935042), -- Icarus Disperser
(22738, 10398, 1, 1, 1, 976.064958), -- Icarus Disperser Piece
(22738, 1895, 1, 1, 2, 162641.29992), -- Metallic Fiber
(22738, 4040, 1, 1, 2, 11384.80134), -- Mold Lubricant
(22738, 9628, 1, 1, 2, 4464.60234), -- Leonard
(22738, 9630, 1, 1, 2, 2995.9512), -- Orichalcum
(22738, 9573, 1, 1, 2, 3953.01192), -- Life Stone - Level 80
(22738, 9574, 1, 1, 2, 988.25298), -- Mid-Grade Life Stone - Level 80
(22738, 9575, 1, 1, 2, 98.80662), -- High-Grade Life Stone - Level 80
(22738, 5157, 1, 1, 2, 253.27368), -- Recipe: Soulshot (S) Compressed Package (100%)
-- Mutant Disciple
(22739, 5277, 1, 1, -1, 38839), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22739, 10398, 1, 1, -1, 37466), -- Icarus Disperser Piece
(22739, 9619, 1, 1, -1, 48916), -- Dynasty Bow Piece
(22739, 57, 21208, 43344, 0, 700000), -- Adena
(22739, 10219, 1, 1, 1, 27.745589), -- Icarus Trident
(22739, 10401, 1, 1, 1, 9199.254411), -- Icarus Trident Piece
(22739, 1879, 3, 9, 2, 132865.702196), -- Cokes
(22739, 1885, 2, 6, 2, 99649.456886), -- High-Grade Suede
(22739, 9628, 1, 1, 2, 37514.94546), -- Leonard
(22739, 9630, 1, 1, 2, 25174.702086), -- Orichalcum
(22739, 9629, 1, 1, 2, 20796.336298), -- Adamantine
(22739, 9573, 1, 1, 2, 33216.605788), -- Life Stone - Level 80
(22739, 9574, 1, 1, 2, 8303.971208), -- Mid-Grade Life Stone - Level 80
(22739, 9575, 1, 1, 2, 830.541312), -- High-Grade Life Stone - Level 80
(22739, 5162, 1, 1, 2, 2125.738766), -- Recipe: Spiritshot (S) Compressed Package (100%)
-- Mutant Elite Soldier
(22740, 10401, 1, 1, -1, 39326), -- Icarus Trident Piece
(22740, 9620, 1, 1, -1, 51123), -- Dynasty Knife Piece
(22740, 5282, 1, 1, -1, 40899), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22740, 57, 22332, 45642, 0, 700000), -- Adena
(22740, 9514, 1, 1, 1, 61.932728), -- Sealed Dynasty Breast Plate
(22740, 9515, 1, 1, 1, 99.053084), -- Sealed Dynasty Gaiter
(22740, 9530, 1, 1, 1, 16500.292848), -- Sealed Dynasty Breast Plate Piece
(22740, 9531, 1, 1, 1, 48806.72134), -- Sealed Dynasty Gaiters Piece
(22740, 1879, 2, 6, 2, 188878.806368), -- Cokes
(22740, 1885, 3, 9, 2, 62959.444174), -- High-Grade Suede
(22740, 9628, 1, 1, 2, 35553.613072), -- Leonard
(22740, 9630, 1, 1, 2, 23858.1461), -- Orichalcum
(22740, 9629, 1, 1, 2, 19709.150524), -- Adamantine
(22740, 9573, 1, 1, 2, 31479.95901), -- Life Stone - Level 80
(22740, 9574, 1, 1, 2, 7870.108214), -- Mid-Grade Life Stone - Level 80
(22740, 9575, 1, 1, 2, 787.058206), -- High-Grade Life Stone - Level 80
(22740, 5167, 1, 1, 2, 2014.793192), -- Recipe: Blessed Spiritshot (S) Compressed Package (100%)
(22740, 1345, 300, 900, 2, 100734.92114), -- Shining Arrow
-- Grave Robber Warrior
(22741, 9991, 1, 1, -1, 6526), -- Sealed Dynasty Earring Gemstone
(22741, 1808, 1, 1, -1, 1237), -- Recipe: Soulshot (S-Grade)
(22741, 9630, 1, 1, -1, 14650), -- Orichalcum
(22741, 57, 682, 1375, 0, 700000), -- Adena
(22741, 9519, 1, 1, 1, 2.497482), -- Sealed Dynasty Leather Armor
(22741, 9520, 1, 1, 1, 3.995667), -- Sealed Dynasty Leather Leggings
(22741, 9535, 1, 1, 1, 613.174419), -- Sealed Dynasty Leather Armor Piece
(22741, 9536, 1, 1, 1, 901.332432), -- Sealed Dynasty Leather Leggings Piece
(22741, 1879, 1, 1, 2, 25391.65713), -- Cokes
(22741, 1885, 1, 1, 2, 12695.807502), -- High-Grade Suede
(22741, 9628, 1, 1, 2, 1194.90399), -- Leonard
(22741, 9630, 1, 1, 2, 801.826284), -- Orichalcum
(22741, 9629, 1, 1, 2, 662.389224), -- Adamantine
(22741, 9573, 1, 1, 2, 1057.99449), -- Life Stone - Level 80
(22741, 9574, 1, 1, 2, 264.509154), -- Mid-Grade Life Stone - Level 80
(22741, 9575, 1, 1, 2, 26.455128), -- High-Grade Life Stone - Level 80
(22741, 9625, 1, 1, 2, 30.457098), -- Giant's Codex - Oblivion
-- Ornithomimus
(22742, 9536, 1, 1, -1, 4245), -- Sealed Dynasty Leather Leggings Piece
(22742, 9531, 1, 1, -1, 6954), -- Sealed Dynasty Gaiters Piece
(22742, 960, 1, 1, -1, 646), -- Scroll: Enchant Armor (S-Grade)
(22742, 57, 395, 797, 0, 700000); -- Adena

INSERT INTO `droplist` VALUES
(22742, 9448, 1, 1, 1, 0.177171), -- Dynasty Cudgel
(22742, 9449, 1, 1, 1, 0.177171), -- Dynasty Mace
(22742, 10252, 1, 1, 1, 0.177171), -- Dynasty Staff
(22742, 10253, 1, 1, 1, 0.177171), -- Dynasty Crusher
(22742, 9622, 1, 1, 1, 53.597403), -- Dynasty Cudgel Piece
(22742, 9623, 1, 1, 1, 53.597403), -- Dynasty Mace Piece
(22742, 10546, 1, 1, 1, 55.548474), -- Dynasty Staff Fragment
(22742, 10547, 1, 1, 1, 55.548036), -- Dynasty Crusher Fragment
(22742, 1879, 1, 1, 2, 14725.65584), -- Cokes
(22742, 1885, 1, 1, 2, 7362.840128), -- High-Grade Suede
(22742, 9628, 1, 1, 2, 692.974912), -- Leonard
(22742, 9630, 1, 1, 2, 465.027136), -- Orichalcum
(22742, 9629, 1, 1, 2, 384.136928), -- Adamantine
(22742, 9573, 1, 1, 2, 613.57408), -- Life Stone - Level 80
(22742, 9574, 1, 1, 2, 153.381312), -- Mid-Grade Life Stone - Level 80
(22742, 9575, 1, 1, 2, 15.333248), -- High-Grade Life Stone - Level 80
(22742, 9576, 1, 1, 2, 3.076416), -- Top-Grade Life Stone - Level 80
-- Deinonychus
(22743, 9531, 1, 1, -1, 6954), -- Sealed Dynasty Gaiters Piece
(22743, 959, 1, 1, -1, 65), -- Scroll: Enchant Weapon (S-Grade)
(22743, 1875, 1, 1, -1, 107617), -- Stone of Purity
(22743, 57, 395, 797, 0, 700000), -- Adena
(22743, 9445, 1, 1, 1, 0.706464), -- Dynasty Bow
(22743, 9619, 1, 1, 1, 222.293536), -- Dynasty Bow Piece
(22743, 1879, 1, 1, 2, 14725.65584), -- Cokes
(22743, 1885, 1, 1, 2, 7362.840128), -- High-Grade Suede
(22743, 9628, 1, 1, 2, 692.974912), -- Leonard
(22743, 9630, 1, 1, 2, 465.027136), -- Orichalcum
(22743, 9629, 1, 1, 2, 384.136928), -- Adamantine
(22743, 9573, 1, 1, 2, 613.57408), -- Life Stone - Level 80
(22743, 9574, 1, 1, 2, 153.381312), -- Mid-Grade Life Stone - Level 80
(22743, 9575, 1, 1, 2, 15.333248), -- High-Grade Life Stone - Level 80
(22743, 9576, 1, 1, 2, 3.076416), -- Top-Grade Life Stone - Level 80
-- Ornithomimus
(22744, 6901, 1, 1, -1, 1614), -- Recipe: Shining Arrow (100%)
(22744, 9630, 1, 1, -1, 8496), -- Orichalcum
(22744, 960, 1, 1, -1, 646), -- Scroll: Enchant Armor (S-Grade)
(22744, 57, 395, 797, 0, 700000), -- Adena
(22744, 9448, 1, 1, 1, 0.177171), -- Dynasty Cudgel
(22744, 9449, 1, 1, 1, 0.177171), -- Dynasty Mace
(22744, 10252, 1, 1, 1, 0.177171), -- Dynasty Staff
(22744, 10253, 1, 1, 1, 0.177171), -- Dynasty Crusher
(22744, 9622, 1, 1, 1, 53.597403), -- Dynasty Cudgel Piece
(22744, 9623, 1, 1, 1, 53.597403), -- Dynasty Mace Piece
(22744, 10546, 1, 1, 1, 55.548474), -- Dynasty Staff Fragment
(22744, 10547, 1, 1, 1, 55.548036), -- Dynasty Crusher Fragment
(22744, 1879, 1, 1, 2, 14725.65584), -- Cokes
(22744, 1885, 1, 1, 2, 7362.840128), -- High-Grade Suede
(22744, 9628, 1, 1, 2, 692.974912), -- Leonard
(22744, 9630, 1, 1, 2, 465.027136), -- Orichalcum
(22744, 9629, 1, 1, 2, 384.136928), -- Adamantine
(22744, 9573, 1, 1, 2, 613.57408), -- Life Stone - Level 80
(22744, 9574, 1, 1, 2, 153.381312), -- Mid-Grade Life Stone - Level 80
(22744, 9575, 1, 1, 2, 15.333248), -- High-Grade Life Stone - Level 80
(22744, 9576, 1, 1, 2, 3.076416), -- Top-Grade Life Stone - Level 80
-- Deinonychus
(22745, 9628, 1, 1, -1, 12661), -- Leonard
(22745, 959, 1, 1, -1, 65), -- Scroll: Enchant Weapon (S-Grade)
(22745, 9630, 1, 1, -1, 8496), -- Orichalcum
(22745, 57, 395, 797, 0, 700000), -- Adena
(22745, 9445, 1, 1, 1, 0.706464), -- Dynasty Bow
(22745, 9619, 1, 1, 1, 222.293536), -- Dynasty Bow Piece
(22745, 1879, 1, 1, 2, 14725.65584), -- Cokes
(22745, 1885, 1, 1, 2, 7362.840128), -- High-Grade Suede
(22745, 9628, 1, 1, 2, 692.974912), -- Leonard
(22745, 9630, 1, 1, 2, 465.027136), -- Orichalcum
(22745, 9629, 1, 1, 2, 384.136928), -- Adamantine
(22745, 9573, 1, 1, 2, 613.57408), -- Life Stone - Level 80
(22745, 9574, 1, 1, 2, 153.381312), -- Mid-Grade Life Stone - Level 80
(22745, 9575, 1, 1, 2, 15.333248), -- High-Grade Life Stone - Level 80
(22745, 9576, 1, 1, 2, 3.076416), -- Top-Grade Life Stone - Level 80
-- Bgurent
(22746, 15663, 1, 1, -1, 146185), -- Sealed Vesper Breastplate Piece
(22746, 15666, 1, 1, -1, 235474), -- Sealed Vesper Gaiter Piece
(22746, 959, 1, 1, -1, 3231), -- Scroll: Enchant Weapon (S-Grade)
(22746, 9628, 1, 1, -1, 633470), -- Leonard
(22746, 15795, 1, 1, -1, 17307), -- Recipe - Sealed Vesper Breastplate (60%) 
(22746, 15798, 1, 1, -1, 27690), -- Recipe - Sealed Vesper Gaiter (60%) 
(22746, 57, 38976, 80332, 0, 700000), -- Adena
(22746, 14105, 1, 1, 1, 85.255525), -- Sealed Vesper Breastplate
(22746, 15663, 1, 1, 1, 35998.085625), -- Sealed Vesper Breastplate Piece
(22746, 14108, 1, 1, 1, 136.40884), -- Sealed Vesper Gaiters
(22746, 15666, 1, 1, 1, 57985.25001), -- Sealed Vesper Gaiter Piece
(22746, 1879, 14, 42, 2, 47365.443484), -- Cokes
(22746, 1885, 3, 9, 2, 110519.0993), -- High-Grade Suede
(22746, 9628, 1, 1, 2, 62410.880368), -- Leonard
(22746, 9630, 1, 1, 2, 41880.92184), -- Orichalcum
(22746, 9629, 1, 1, 2, 34597.528712), -- Adamantine
(22746, 14166, 1, 1, 2, 38441.653764), -- Life Stone - Level 84
(22746, 14167, 1, 1, 2, 9598.820176), -- Mid-Grade Life Stone - Level 84
(22746, 14168, 1, 1, 2, 959.72072), -- High-Grade Life Stone - Level 84
(22746, 15486, 1, 1, 2, 35366.111776), -- Spirit Stone Fragment 
(22746, 1345, 2400, 7200, 2, 22103.81986), -- Shining Arrow
-- Brakian
(22747, 15664, 1, 1, -1, 229943), -- Sealed Vesper Leather Breastplate Piece
(22747, 15670, 1, 1, -1, 354373), -- Sealed Vesper Leather Legging Piece
(22747, 9630, 1, 1, -1, 510110), -- Orichalcum
(22747, 15796, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Leather Breastplate (60%) 
(22747, 15799, 1, 1, -1, 44305), -- Recipe - Sealed Vesper Leather Legging (60%) 
(22747, 57, 38976, 80332, 0, 700000), -- Adena
(22747, 14106, 1, 1, 1, 113.677036), -- Sealed Vesper Leather Breastplate
(22747, 14112, 1, 1, 1, 181.811158), -- Sealed Vesper Leather Leggings
(22747, 15664, 1, 1, 1, 47172.124628), -- Sealed Vesper Leather Breastplate Piece
(22747, 15670, 1, 1, 1, 72698.387178), -- Sealed Vesper Leather Legging Piece
(22747, 1879, 15, 45, 2, 49119.635859), -- Cokes
(22747, 1885, 2, 6, 2, 184198.995507), -- High-Grade Suede
(22747, 9628, 1, 1, 2, 69345.339955), -- Leonard
(22747, 9630, 1, 1, 2, 46534.619889), -- Orichalcum
(22747, 9629, 1, 1, 2, 38441.642517), -- Adamantine
(22747, 14166, 1, 1, 2, 42712.93613), -- Life Stone - Level 84
(22747, 14167, 1, 1, 2, 10665.477436), -- Mid-Grade Life Stone - Level 84
(22747, 14168, 1, 1, 2, 1066.740296), -- High-Grade Life Stone - Level 84
(22747, 15486, 1, 1, 2, 39295.612411), -- Spirit Stone Fragment 
-- Groikan
(22748, 15665, 1, 1, -1, 229983), -- Sealed Vesper Tunic Piece
(22748, 15673, 1, 1, -1, 354435), -- Sealed Vesper Stockings Piece
(22748, 9630, 1, 1, -1, 510199), -- Orichalcum
(22748, 15797, 1, 1, -1, 27697), -- Recipe - Sealed Vesper Tunic (60%) 
(22748, 15800, 1, 1, -1, 44312), -- Recipe - Sealed Vesper Stockings (60%) 
(22748, 57, 38982, 80346, 0, 700000), -- Adena
(22748, 14107, 1, 1, 1, 113.696902), -- Sealed Vesper Tunic
(22748, 14115, 1, 1, 1, 181.842931), -- Sealed Vesper Stockings
(22748, 15665, 1, 1, 1, 47180.368346), -- Sealed Vesper Tunic Piece
(22748, 15673, 1, 1, 1, 72711.091821), -- Sealed Vesper Stockings Piece
(22748, 1879, 14, 42, 2, 43067.01392), -- Cokes
(22748, 1885, 3, 9, 2, 100489.82146), -- High-Grade Suede
(22748, 9628, 1, 1, 2, 56747.271), -- Leonard
(22748, 9630, 1, 1, 2, 38080.29932), -- Orichalcum
(22748, 9629, 1, 1, 2, 31457.7662), -- Adamantine
(22748, 14166, 1, 1, 2, 34952.8697), -- Life Stone - Level 84
(22748, 14167, 1, 1, 2, 8727.6679), -- Mid-Grade Life Stone - Level 84
(22748, 14168, 1, 1, 2, 872.95026), -- High-Grade Life Stone - Level 84
(22748, 959, 1, 1, 2, 289.51566), -- Scroll: Enchant Weapon (S-Grade)
(22748, 15486, 1, 1, 2, 32156.7869), -- Spirit Stone Fragment 
(22748, 1345, 2400, 7200, 2, 20098.03768), -- Shining Arrow
-- Treykan
(22749, 15667, 1, 1, -1, 287295), -- Sealed Vesper Gauntlet Piece
(22749, 15671, 1, 1, -1, 287295), -- Sealed Vesper Leather Gloves Piece
(22749, 15674, 1, 1, -1, 287295), -- Sealed Vesper Gloves Piece
(22749, 15668, 1, 1, -1, 287295), -- Sealed Vesper Boots Piece
(22749, 15672, 1, 1, -1, 287295), -- Sealed Vesper Leather Boots Piece
(22749, 15675, 1, 1, -1, 287295), -- Sealed Vesper Shoes Piece
(22749, 9628, 1, 1, -1, 294054), -- Leonard
(22749, 15801, 1, 1, -1, 32135), -- Recipe - Sealed Vesper Gauntlet (60%) 
(22749, 15802, 1, 1, -1, 32135), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(22749, 15803, 1, 1, -1, 32135), -- Recipe - Sealed Vesper Gloves (60%) 
(22749, 15804, 1, 1, -1, 32135), -- Recipe - Sealed Vesper Boots (60%) 
(22749, 15805, 1, 1, -1, 32135), -- Recipe - Sealed Vesper Leather Boots (60%) 
(22749, 15806, 1, 1, -1, 32135), -- Recipe - Sealed Vesper Shoes (60%) 
(22749, 57, 39200, 80795, 0, 700000), -- Adena
(22749, 14109, 1, 1, 1, 114.328248), -- Sealed Vesper Gauntlet
(22749, 14113, 1, 1, 1, 114.328248), -- Sealed Vesper Leather Gloves
(22749, 14116, 1, 1, 1, 114.328248), -- Sealed Vesper Gloves
(22749, 14110, 1, 1, 1, 114.328248), -- Sealed Vesper Boots
(22749, 14114, 1, 1, 1, 114.328248), -- Sealed Vesper Leather Boots
(22749, 14117, 1, 1, 1, 114.328248), -- Sealed Vesper Shoes
(22749, 15667, 1, 1, 1, 51108.10753), -- Sealed Vesper Gauntlet Piece
(22749, 15671, 1, 1, 1, 51108.10753), -- Sealed Vesper Leather Gloves Piece
(22749, 15674, 1, 1, 1, 51108.10753), -- Sealed Vesper Gloves Piece
(22749, 15668, 1, 1, 1, 51108.10753), -- Sealed Vesper Boots Piece
(22749, 15672, 1, 1, 1, 51108.10753), -- Sealed Vesper Leather Boots Piece
(22749, 15675, 1, 1, 1, 51107.492862), -- Sealed Vesper Shoes Piece
(22749, 1879, 15, 45, 2, 44462.22471), -- Cokes
(22749, 1885, 2, 6, 2, 166733.671866), -- High-Grade Suede
(22749, 9628, 1, 1, 2, 62770.32869), -- Leonard
(22749, 9630, 1, 1, 2, 42122.246232), -- Orichalcum
(22749, 9629, 1, 1, 2, 34796.371012), -- Adamantine
(22749, 14166, 1, 1, 2, 38662.975854), -- Life Stone - Level 84
(22749, 14167, 1, 1, 2, 9654.002372), -- Mid-Grade Life Stone - Level 84
(22749, 14168, 1, 1, 2, 965.224662), -- High-Grade Life Stone - Level 84
(22749, 960, 1, 1, 2, 3201.174834), -- Scroll: Enchant Armor (S-Grade)
(22749, 15486, 1, 1, 2, 35569.779768), -- Spirit Stone Fragment 
-- Elite Bgurent
(22750, 15634, 1, 1, -1, 87220), -- Vesper Cutter Piece
(22750, 15635, 1, 1, -1, 87064), -- Vesper Slasher Piece
(22750, 15636, 1, 1, -1, 87220), -- Vesper Buster Piece
(22750, 9630, 1, 1, -1, 772812), -- Orichalcum
(22750, 15815, 1, 1, -1, 10243), -- Recipe - Sealed Vesper Cutter (60%)
(22750, 15816, 1, 1, -1, 10243), -- Recipe - Sealed Vesper Slasher (60%)
(22750, 15817, 1, 1, -1, 10243), -- Recipe - Vesper Buster (60%)
(22750, 57, 82667, 170383, 0, 700000), -- Adena
(22750, 13457, 1, 1, 1, 39.243888), -- Vesper Cutter
(22750, 13458, 1, 1, 1, 39.243888), -- Vesper Slasher
(22750, 13459, 1, 1, 1, 39.243888), -- Vesper Buster
(22750, 15634, 1, 1, 1, 16698.675816), -- Vesper Cutter Piece
(22750, 15635, 1, 1, 1, 16668.966888), -- Vesper Slasher Piece
(22750, 15636, 1, 1, 1, 16698.625632), -- Vesper Buster Piece
(22750, 1895, 72, 216, 2, 30442.803253), -- Metallic Fiber
(22750, 4040, 2, 6, 2, 61372.293912), -- Mold Lubricant
(22750, 9628, 1, 1, 2, 120338.291207), -- Leonard
(22750, 9630, 1, 1, 2, 80753.308836), -- Orichalcum
(22750, 16160, 1, 1, 2, 74121.387917), -- Life Stone - Level 85
(22750, 16161, 1, 1, 2, 18507.921638), -- Mid-Grade Life Stone - Level 85
(22750, 9554, 1, 1, 2, 3068.706697), -- Earth Crystal
(22750, 15815, 1, 1, 2, 1070.436289), -- Recipe - Sealed Vesper Cutter (60%)
(22750, 15816, 1, 1, 2, 1070.436289), -- Recipe - Sealed Vesper Slasher (60%)
(22750, 15817, 1, 1, 2, 1070.436289), -- Recipe - Vesper Buster (60%)
(22750, 15486, 1, 1, 2, 68190.977673), -- Spirit Stone Fragment 
-- Elite Brakian
(22751, 15640, 1, 1, -1, 75665), -- Vesper Avenger Piece
(22751, 15641, 1, 1, -1, 76544), -- Vesper Retributer Piece
(22751, 15642, 1, 1, -1, 75665), -- Vesper Caster Piece
(22751, 15643, 1, 1, -1, 75867), -- Vesper Singer Piece
(22751, 15821, 1, 1, -1, 8962), -- Recipe - Vesper Avenger (60%)
(22751, 15822, 1, 1, -1, 8962), -- Recipe - Vesper Retributer (60%)
(22751, 15823, 1, 1, -1, 8962), -- Recipe - Vesper Caster (60%)
(22751, 15824, 1, 1, -1, 8962), -- Recipe - Vesper Singer (60%)
(22751, 57, 82667, 170383, 0, 700000), -- Adena
(22751, 13463, 1, 1, 1, 29.432919), -- Vesper Avenger
(22751, 13464, 1, 1, 1, 29.432919), -- Vesper Retributer
(22751, 13465, 1, 1, 1, 29.432919), -- Vesper Caster
(22751, 13466, 1, 1, 1, 29.432919), -- Vesper Singer
(22751, 15640, 1, 1, 1, 12418.992804), -- Vesper Avenger Piece
(22751, 15641, 1, 1, 1, 12563.309052), -- Vesper Retributer Piece
(22751, 15642, 1, 1, 1, 12418.992804), -- Vesper Caster Piece
(22751, 15643, 1, 1, 1, 12451.973664), -- Vesper Singer Piece
(22751, 1895, 72, 216, 2, 27905.928425), -- Metallic Fiber
(22751, 4040, 2, 6, 2, 56258.605299), -- Mold Lubricant
(22751, 9628, 1, 1, 2, 110310.518401), -- Leonard
(22751, 9630, 1, 1, 2, 74024.14698), -- Orichalcum
(22751, 16160, 1, 1, 2, 67945.071349), -- Life Stone - Level 85
(22751, 16161, 1, 1, 2, 16965.874637), -- Mid-Grade Life Stone - Level 85
(22751, 9554, 1, 1, 2, 2812.782335), -- Earth Crystal
(22751, 15821, 1, 1, 2, 980.986897), -- Recipe - Vesper Avenger (60%)
(22751, 15822, 1, 1, 2, 980.986897), -- Recipe - Vesper Retributer (60%)
(22751, 15823, 1, 1, 2, 980.986897), -- Recipe - Vesper Caster (60%)
(22751, 15824, 1, 1, 2, 980.986897), -- Recipe - Vesper Singer (60%)
(22751, 15486, 1, 1, 2, 62510.124986), -- Spirit Stone Fragment 
-- Elite Groikan
(22752, 15638, 1, 1, -1, 151155), -- Vesper Fighter Piece
(22752, 959, 1, 1, -1, 10266), -- Scroll: Enchant Weapon (S-Grade)
(22752, 9628, 1, 5, -1, 671007), -- Leonard
(22752, 15819, 1, 1, -1, 17904), -- Recipe - Vesper Fighter (60%)
(22752, 57, 82570, 170185, 0, 700000), -- Adena
(22752, 13461, 1, 1, 1, 117.594695), -- Vesper Fighter
(22752, 15638, 1, 1, 1, 49647.405305), -- Vesper Fighter Piece
(22752, 1895, 72, 216, 2, 37164.530524), -- Metallic Fiber
(22752, 4040, 2, 6, 2, 74923.627714), -- Mold Lubricant
(22752, 9628, 3, 9, 2, 20986.947488), -- Leonard
(22752, 9630, 1, 1, 2, 98583.743468), -- Orichalcum
(22752, 16160, 1, 1, 2, 90487.590236), -- Life Stone - Level 85
(22752, 16161, 1, 1, 2, 22594.399392), -- Mid-Grade Life Stone - Level 85
(22752, 9554, 1, 1, 2, 3746.246342), -- Earth Crystal
(22752, 15819, 1, 1, 2, 1306.487714), -- Recipe - Vesper Fighter (60%)
(22752, 15486, 1, 1, 2, 83248.427122), -- Spirit Stone Fragment 
-- Elite Treykan
(22753, 15644, 1, 1, -1, 204362), -- Vesper Thrower Piece
(22753, 959, 1, 1, -1, 13705), -- Scroll: Enchant Weapon (S-Grade)
(22753, 15825, 1, 1, -1, 23899), -- Recipe - Vesper Thrower (60%)
(22753, 57, 82667, 170383, 0, 700000), -- Adena
(22753, 13467, 1, 1, 1, 117.730179), -- Vesper Thrower
(22753, 15644, 1, 1, 1, 50345.269821), -- Vesper Thrower Piece
(22753, 1895, 72, 216, 2, 41858.896491), -- Metallic Fiber
(22753, 4040, 2, 6, 2, 84387.469567), -- Mold Lubricant
(22753, 9628, 3, 9, 2, 23637.891127), -- Leonard
(22753, 9630, 1, 1, 2, 111035.76244), -- Orichalcum
(22753, 16160, 1, 1, 2, 101917.039901), -- Life Stone - Level 85
(22753, 16161, 1, 1, 2, 25448.677272), -- Mid-Grade Life Stone - Level 85
(22753, 15825, 1, 1, 2, 1471.837924), -- Recipe - Vesper Thrower (60%)
(22753, 15486, 1, 1, 2, 93763.425278), -- Spirit Stone Fragment 
-- Turtlelian
(22754, 15667, 1, 1, -1, 309454), -- Sealed Vesper Gauntlet Piece
(22754, 15671, 1, 1, -1, 309454), -- Sealed Vesper Leather Gloves Piece
(22754, 15674, 1, 1, -1, 309454), -- Sealed Vesper Gloves Piece
(22754, 15668, 1, 1, -1, 309454), -- Sealed Vesper Boots Piece
(22754, 15672, 1, 1, -1, 309454), -- Sealed Vesper Leather Boots Piece
(22754, 15675, 1, 1, -1, 309454), -- Sealed Vesper Shoes Piece
(22754, 15801, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Gauntlet (60%) 
(22754, 15802, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(22754, 15803, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Gloves (60%) 
(22754, 15804, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Boots (60%) 
(22754, 15805, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Leather Boots (60%) 
(22754, 15806, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Shoes (60%) 
(22754, 57, 38976, 80332, 0, 700000), -- Adena
(22754, 14109, 1, 1, 1, 113.673528), -- Sealed Vesper Gauntlet
(22754, 14113, 1, 1, 1, 113.673528), -- Sealed Vesper Leather Gloves
(22754, 14116, 1, 1, 1, 113.673528), -- Sealed Vesper Gloves
(22754, 14110, 1, 1, 1, 113.673528), -- Sealed Vesper Boots
(22754, 14114, 1, 1, 1, 113.673528), -- Sealed Vesper Leather Boots
(22754, 14117, 1, 1, 1, 113.673528), -- Sealed Vesper Shoes
(22754, 15667, 1, 1, 1, 50815.42833), -- Sealed Vesper Gauntlet Piece
(22754, 15671, 1, 1, 1, 50815.42833), -- Sealed Vesper Leather Gloves Piece
(22754, 15674, 1, 1, 1, 50815.42833), -- Sealed Vesper Gloves Piece
(22754, 15668, 1, 1, 1, 50815.42833), -- Sealed Vesper Boots Piece
(22754, 15672, 1, 1, 1, 50815.42833), -- Sealed Vesper Leather Boots Piece
(22754, 15675, 1, 1, 1, 50814.817182), -- Sealed Vesper Shoes Piece
(22754, 1879, 14, 42, 2, 47365.443484), -- Cokes
(22754, 1885, 3, 9, 2, 110519.0993), -- High-Grade Suede
(22754, 9628, 1, 1, 2, 62410.880368), -- Leonard
(22754, 9630, 1, 1, 2, 41880.92184), -- Orichalcum
(22754, 9629, 1, 1, 2, 34597.528712), -- Adamantine
(22754, 14166, 1, 1, 2, 38441.653764), -- Life Stone - Level 84
(22754, 14167, 1, 1, 2, 9598.820176), -- Mid-Grade Life Stone - Level 84
(22754, 14168, 1, 1, 2, 959.72072), -- High-Grade Life Stone - Level 84
(22754, 15486, 1, 1, 2, 35366.111776), -- Spirit Stone Fragment 
(22754, 1345, 2400, 7200, 2, 22103.81986), -- Shining Arrow
-- Krajian
(22755, 15660, 1, 1, -1, 222296), -- Sealed Vesper Helmet Piece
(22755, 15661, 1, 1, -1, 222296), -- Sealed Vesper Leather Helmet Piece
(22755, 15662, 1, 1, -1, 222296), -- Sealed Vesper Circlet Piece
(22755, 15669, 1, 1, -1, 328546), -- Sealed Vesper Verteidiger Piece
(22755, 15691, 1, 1, -1, 328546), -- Sealed Vesper Sigil Piece
(22755, 15792, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Helmet (60%) 
(22755, 15793, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Leather Helmet (60%) 
(22755, 15794, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Circlet (60%) 
(22755, 15808, 1, 1, -1, 39560), -- Recipe - Sealed Vesper Shield (60%) 
(22755, 15807, 1, 1, -1, 39560), -- Recipe - Sealed Vesper Sigil (60%) 
(22755, 57, 38976, 80332, 0, 700000), -- Adena
(22755, 13143, 1, 1, 1, 90.941445), -- Sealed Vesper Helmet
(22755, 13144, 1, 1, 1, 90.941445), -- Sealed Vesper Leather Helmet
(22755, 13145, 1, 1, 1, 90.941445), -- Sealed Vesper Circlet
(22755, 14111, 1, 1, 1, 129.97866), -- Sealed Vesper Shield
(22755, 13887, 1, 1, 1, 129.97866), -- Sealed Vesper Sigil
(22755, 15660, 1, 1, 1, 36526.838565), -- Sealed Vesper Helmet Piece
(22755, 15661, 1, 1, 1, 36526.838565), -- Sealed Vesper Leather Helmet Piece
(22755, 15662, 1, 1, 1, 36526.838565), -- Sealed Vesper Circlet Piece
(22755, 15669, 1, 1, 1, 53985.63324), -- Sealed Vesper Verteidiger Piece
(22755, 15691, 1, 1, 1, 53986.06941), -- Sealed Vesper Sigil Piece
(22755, 1879, 15, 45, 2, 49119.635859), -- Cokes
(22755, 1885, 2, 6, 2, 184198.995507), -- High-Grade Suede
(22755, 9628, 1, 1, 2, 69345.339955), -- Leonard
(22755, 9630, 1, 1, 2, 46534.619889), -- Orichalcum
(22755, 9629, 1, 1, 2, 38441.642517), -- Adamantine
(22755, 14166, 1, 1, 2, 42712.93613), -- Life Stone - Level 84
(22755, 14167, 1, 1, 2, 10665.477436), -- Mid-Grade Life Stone - Level 84
(22755, 14168, 1, 1, 2, 1066.740296), -- High-Grade Life Stone - Level 84
(22755, 15486, 1, 1, 2, 39295.612411), -- Spirit Stone Fragment 
-- Tardyon
(22756, 15770, 1, 1, -1, 435480), -- Sealed Vesper Earring Gem
(22756, 15771, 1, 1, -1, 313309), -- Sealed Vesper Necklace Gem
(22756, 15769, 1, 1, -1, 725040), -- Sealed Vesper Ring Gem
(22756, 9630, 1, 1, -1, 364428), -- Orichalcum
(22756, 15810, 1, 1, -1, 60770), -- Recipe - Sealed Vesper Earring (70%) 
(22756, 15811, 1, 1, -1, 45577), -- Recipe - Sealed Vesper Necklace (70%) 
(22756, 15809, 1, 1, -1, 91155), -- Recipe - Sealed Vesper Ring (70%) 
(22756, 57, 38982, 80346, 0, 700000), -- Adena
(22756, 14160, 1, 1, 1, 232.83561), -- Sealed Vesper Earring
(22756, 14161, 1, 1, 1, 174.768335), -- Sealed Vesper Necklace
(22756, 14162, 1, 1, 1, 349.53667), -- Sealed Vesper Ring
(22756, 15770, 1, 1, 1, 83470.999675), -- Sealed Vesper Earring Gem
(22756, 15771, 1, 1, 1, 60054.02557), -- Sealed Vesper Necklace Gem
(22756, 15769, 1, 1, 1, 138972.83414), -- Sealed Vesper Ring Gem
(22756, 1879, 14, 42, 2, 33838.344612), -- Cokes
(22756, 1885, 3, 9, 2, 78955.999074), -- High-Grade Suede
(22756, 9628, 1, 1, 2, 44586.790164), -- Leonard
(22756, 9630, 1, 1, 2, 29920.159332), -- Orichalcum
(22756, 9629, 1, 1, 2, 24716.527038), -- Adamantine
(22756, 14166, 1, 1, 2, 27462.992292), -- Life Stone - Level 84
(22756, 14167, 1, 1, 2, 6857.654364), -- Mid-Grade Life Stone - Level 84
(22756, 14168, 1, 1, 2, 685.682424), -- High-Grade Life Stone - Level 84
(22756, 959, 1, 1, 2, 227.453976), -- Scroll: Enchant Weapon (S-Grade)
(22756, 15809, 1, 1, 2, 7483.982922), -- Recipe - Sealed Vesper Ring (70%) 
(22756, 15810, 1, 1, 2, 4989.460302), -- Recipe - Sealed Vesper Earring (70%) 
(22756, 15811, 1, 1, 2, 3741.78393), -- Recipe - Sealed Vesper Necklace (70%) 
(22756, 15486, 1, 1, 2, 25266.069126), -- Spirit Stone Fragment 
(22756, 1345, 300, 900, 2, 126329.100444), -- Shining Arrow
-- Elite Turtlelian
(22757, 15637, 1, 1, -1, 203512), -- Vesper Shaper Piece
(22757, 9630, 1, 3, -1, 901613), -- Orichalcum
(22757, 15818, 1, 1, -1, 23899), -- Recipe - Vesper Shaper (60%)
(22757, 57, 82667, 170383, 0, 700000), -- Adena
(22757, 13460, 1, 1, 1, 117.731064), -- Vesper Shaper
(22757, 15637, 1, 1, 1, 50130.268936), -- Vesper Shaper Piece
(22757, 1895, 72, 216, 2, 37207.870634), -- Metallic Fiber
(22757, 4040, 2, 6, 2, 75011.001299), -- Mold Lubricant
(22757, 9628, 3, 9, 2, 21011.421808), -- Leonard
(22757, 9630, 1, 1, 2, 98698.708738), -- Orichalcum
(22757, 16160, 1, 1, 2, 90593.114026), -- Life Stone - Level 85
(22757, 16161, 1, 1, 2, 22620.748272), -- Mid-Grade Life Stone - Level 85
(22757, 9554, 1, 1, 2, 3750.615097), -- Earth Crystal
(22757, 15818, 1, 1, 2, 1308.011299), -- Recipe - Vesper Shaper (60%)
(22757, 15486, 1, 1, 2, 83345.508827), -- Spirit Stone Fragment 
-- Elite Krajian
(22758, 15639, 1, 1, -1, 203881), -- Vesper Stormer Piece
(22758, 9630, 1, 3, -1, 900563), -- Orichalcum
(22758, 15820, 1, 1, -1, 23872), -- Recipe - Vesper Stormer (60%)
(22758, 57, 82570, 170185, 0, 700000), -- Adena
(22758, 13462, 1, 1, 1, 117.59424), -- Vesper Stormer
(22758, 15639, 1, 1, 1, 50222.40576), -- Vesper Stormer Piece
(22758, 1895, 72, 216, 2, 37164.530524), -- Metallic Fiber
(22758, 4040, 2, 6, 2, 74923.627714), -- Mold Lubricant
(22758, 9628, 3, 9, 2, 20986.947488), -- Leonard
(22758, 9630, 1, 1, 2, 98583.743468), -- Orichalcum
(22758, 16160, 1, 1, 2, 90487.590236), -- Life Stone - Level 85
(22758, 16161, 1, 1, 2, 22594.399392), -- Mid-Grade Life Stone - Level 85
(22758, 9554, 1, 1, 2, 3746.246342), -- Earth Crystal
(22758, 15820, 1, 1, 2, 1306.487714), -- Recipe - Vesper Stormer (60%)
(22758, 15486, 1, 1, 2, 83248.427122), -- Spirit Stone Fragment 
-- Elite Tardyon
(22759, 15638, 1, 1, -1, 201775), -- Vesper Fighter Piece
(22759, 1894, 1, 25, -1, 924732), -- Crafted Leather
(22759, 15819, 1, 1, -1, 23899), -- Recipe - Vesper Fighter (60%)
(22759, 57, 82667, 170383, 0, 700000), -- Adena
(22759, 13461, 1, 1, 1, 117.731749), -- Vesper Fighter
(22759, 15638, 1, 1, 1, 49705.268251), -- Vesper Fighter Piece
(22759, 1895, 72, 216, 2, 37207.870634), -- Metallic Fiber
(22759, 4040, 2, 6, 2, 75011.001299), -- Mold Lubricant
(22759, 9628, 3, 9, 2, 21011.421808), -- Leonard
(22759, 9630, 1, 1, 2, 98698.708738), -- Orichalcum
(22759, 16160, 1, 1, 2, 90593.114026), -- Life Stone - Level 85
(22759, 16161, 1, 1, 2, 22620.748272), -- Mid-Grade Life Stone - Level 85
(22759, 9554, 1, 1, 2, 3750.615097), -- Earth Crystal
(22759, 15819, 1, 1, 2, 1308.011299), -- Recipe - Vesper Fighter (60%)
(22759, 15486, 1, 1, 2, 83345.508827), -- Spirit Stone Fragment 
-- Kanibi
(22760, 15667, 1, 1, -1, 309454), -- Sealed Vesper Gauntlet Piece
(22760, 15671, 1, 1, -1, 309454), -- Sealed Vesper Leather Gloves Piece
(22760, 15674, 1, 1, -1, 309454), -- Sealed Vesper Gloves Piece
(22760, 15668, 1, 1, -1, 309454), -- Sealed Vesper Boots Piece
(22760, 15672, 1, 1, -1, 309454), -- Sealed Vesper Leather Boots Piece
(22760, 15675, 1, 1, -1, 309454), -- Sealed Vesper Shoes Piece
(22760, 15801, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Gauntlet (60%) 
(22760, 15802, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(22760, 15803, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Gloves (60%) 
(22760, 15804, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Boots (60%) 
(22760, 15805, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Leather Boots (60%) 
(22760, 15806, 1, 1, -1, 34614), -- Recipe - Sealed Vesper Shoes (60%) 
(22760, 57, 38976, 80332, 0, 700000), -- Adena
(22760, 14109, 1, 1, 1, 113.673528), -- Sealed Vesper Gauntlet
(22760, 14113, 1, 1, 1, 113.673528), -- Sealed Vesper Leather Gloves
(22760, 14116, 1, 1, 1, 113.673528), -- Sealed Vesper Gloves
(22760, 14110, 1, 1, 1, 113.673528), -- Sealed Vesper Boots
(22760, 14114, 1, 1, 1, 113.673528), -- Sealed Vesper Leather Boots
(22760, 14117, 1, 1, 1, 113.673528), -- Sealed Vesper Shoes
(22760, 15667, 1, 1, 1, 50815.42833), -- Sealed Vesper Gauntlet Piece
(22760, 15671, 1, 1, 1, 50815.42833), -- Sealed Vesper Leather Gloves Piece
(22760, 15674, 1, 1, 1, 50815.42833), -- Sealed Vesper Gloves Piece
(22760, 15668, 1, 1, 1, 50815.42833), -- Sealed Vesper Boots Piece
(22760, 15672, 1, 1, 1, 50815.42833), -- Sealed Vesper Leather Boots Piece
(22760, 15675, 1, 1, 1, 50814.817182), -- Sealed Vesper Shoes Piece
(22760, 1879, 15, 45, 2, 44207.670375), -- Cokes
(22760, 1885, 2, 6, 2, 165779.091225), -- High-Grade Suede
(22760, 9628, 1, 1, 2, 62410.957125), -- Leonard
(22760, 9630, 1, 1, 2, 41881.0887), -- Orichalcum
(22760, 9629, 1, 1, 2, 34597.15545), -- Adamantine
(22760, 14166, 1, 1, 2, 38441.623275), -- Life Stone - Level 84
(22760, 14167, 1, 1, 2, 9598.73145), -- Mid-Grade Life Stone - Level 84
(22760, 14168, 1, 1, 2, 959.698575), -- High-Grade Life Stone - Level 84
(22760, 960, 1, 1, 2, 3182.847525), -- Scroll: Enchant Armor (S-Grade)
(22760, 15486, 1, 1, 2, 35366.1363), -- Spirit Stone Fragment 
-- Kiriona
(22761, 15660, 1, 1, -1, 222296), -- Sealed Vesper Helmet Piece
(22761, 15661, 1, 1, -1, 222296), -- Sealed Vesper Leather Helmet Piece
(22761, 15662, 1, 1, -1, 222296), -- Sealed Vesper Circlet Piece
(22761, 15669, 1, 1, -1, 328546), -- Sealed Vesper Verteidiger Piece
(22761, 15691, 1, 1, -1, 328546), -- Sealed Vesper Sigil Piece
(22761, 15792, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Helmet (60%) 
(22761, 15793, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Leather Helmet (60%) 
(22761, 15794, 1, 1, -1, 27692), -- Recipe - Sealed Vesper Circlet (60%) 
(22761, 15808, 1, 1, -1, 39560), -- Recipe - Sealed Vesper Shield (60%) 
(22761, 15807, 1, 1, -1, 39560), -- Recipe - Sealed Vesper Sigil (60%) 
(22761, 57, 38976, 80332, 0, 700000), -- Adena
(22761, 13143, 1, 1, 1, 90.941445), -- Sealed Vesper Helmet
(22761, 13144, 1, 1, 1, 90.941445), -- Sealed Vesper Leather Helmet
(22761, 13145, 1, 1, 1, 90.941445), -- Sealed Vesper Circlet
(22761, 14111, 1, 1, 1, 129.97866), -- Sealed Vesper Shield
(22761, 13887, 1, 1, 1, 129.97866), -- Sealed Vesper Sigil
(22761, 15660, 1, 1, 1, 36526.838565), -- Sealed Vesper Helmet Piece
(22761, 15661, 1, 1, 1, 36526.838565), -- Sealed Vesper Leather Helmet Piece
(22761, 15662, 1, 1, 1, 36526.838565), -- Sealed Vesper Circlet Piece
(22761, 15669, 1, 1, 1, 53985.63324), -- Sealed Vesper Verteidiger Piece
(22761, 15691, 1, 1, 1, 53986.06941), -- Sealed Vesper Sigil Piece
(22761, 1879, 14, 42, 2, 43059.502368), -- Cokes
(22761, 1885, 3, 9, 2, 100472.294484), -- High-Grade Suede
(22761, 9628, 1, 1, 2, 56737.3734), -- Leonard
(22761, 9630, 1, 1, 2, 38073.657528), -- Orichalcum
(22761, 9629, 1, 1, 2, 31452.27948), -- Adamantine
(22761, 14166, 1, 1, 2, 34946.77338), -- Life Stone - Level 84
(22761, 14167, 1, 1, 2, 8726.14566), -- Mid-Grade Life Stone - Level 84
(22761, 14168, 1, 1, 2, 872.798004), -- High-Grade Life Stone - Level 84
(22761, 959, 1, 1, 2, 289.465164), -- Scroll: Enchant Weapon (S-Grade)
(22761, 15486, 1, 1, 2, 32151.17826), -- Spirit Stone Fragment 
(22761, 1345, 2400, 7200, 2, 20094.532272), -- Shining Arrow
-- Kaiona
(22762, 15770, 1, 1, -1, 435480), -- Sealed Vesper Earring Gem
(22762, 15771, 1, 1, -1, 313309), -- Sealed Vesper Necklace Gem
(22762, 15769, 1, 1, -1, 725040), -- Sealed Vesper Ring Gem
(22762, 9628, 1, 1, -1, 543069), -- Leonard
(22762, 15810, 1, 1, -1, 60770), -- Recipe - Sealed Vesper Earring (70%) 
(22762, 15811, 1, 1, -1, 45577), -- Recipe - Sealed Vesper Necklace (70%) 
(22762, 15809, 1, 1, -1, 91155), -- Recipe - Sealed Vesper Ring (70%) 
(22762, 57, 38982, 80346, 0, 700000), -- Adena
(22762, 14160, 1, 1, 1, 232.83561), -- Sealed Vesper Earring
(22762, 14161, 1, 1, 1, 174.768335), -- Sealed Vesper Necklace
(22762, 14162, 1, 1, 1, 349.53667), -- Sealed Vesper Ring
(22762, 15770, 1, 1, 1, 83470.999675), -- Sealed Vesper Earring Gem
(22762, 15771, 1, 1, 1, 60054.02557), -- Sealed Vesper Necklace Gem
(22762, 15769, 1, 1, 1, 138972.83414), -- Sealed Vesper Ring Gem
(22762, 1879, 3, 9, 2, 170059.39717), -- Cokes
(22762, 1885, 2, 6, 2, 127544.792518), -- High-Grade Suede
(22762, 9628, 1, 1, 2, 48017.058778), -- Leonard
(22762, 9630, 1, 1, 2, 32221.600255), -- Orichalcum
(22762, 9629, 1, 1, 2, 26617.864962), -- Adamantine
(22762, 14166, 1, 1, 2, 29575.568607), -- Life Stone - Level 84
(22762, 14167, 1, 1, 2, 7385.207414), -- Mid-Grade Life Stone - Level 84
(22762, 14168, 1, 1, 2, 738.325029), -- High-Grade Life Stone - Level 84
(22762, 960, 1, 1, 2, 2448.851405), -- Scroll: Enchant Armor (S-Grade)
(22762, 15809, 1, 1, 2, 8059.925913), -- Recipe - Sealed Vesper Ring (70%) 
(22762, 15810, 1, 1, 2, 5373.283942), -- Recipe - Sealed Vesper Earring (70%) 
(22762, 15811, 1, 1, 2, 4029.718316), -- Recipe - Sealed Vesper Necklace (70%) 
(22762, 15486, 1, 1, 2, 27209.405691), -- Spirit Stone Fragment 
-- Elite Kanibi
(22763, 15634, 1, 1, -1, 87220), -- Vesper Cutter Piece
(22763, 15635, 1, 1, -1, 87064), -- Vesper Slasher Piece
(22763, 15636, 1, 1, -1, 87220), -- Vesper Buster Piece
(22763, 9628, 1, 3, -1, 575820), -- Leonard
(22763, 15815, 1, 1, -1, 10243), -- Recipe - Sealed Vesper Cutter (60%)
(22763, 15816, 1, 1, -1, 10243), -- Recipe - Sealed Vesper Slasher (60%)
(22763, 15817, 1, 1, -1, 10243), -- Recipe - Vesper Buster (60%)
(22763, 57, 82667, 170383, 0, 700000), -- Adena
(22763, 13457, 1, 1, 1, 39.243888), -- Vesper Cutter
(22763, 13458, 1, 1, 1, 39.243888), -- Vesper Slasher
(22763, 13459, 1, 1, 1, 39.243888), -- Vesper Buster
(22763, 15634, 1, 1, 1, 16698.675816), -- Vesper Cutter Piece
(22763, 15635, 1, 1, 1, 16668.966888), -- Vesper Slasher Piece
(22763, 15636, 1, 1, 1, 16698.625632), -- Vesper Buster Piece
(22763, 1895, 72, 216, 2, 30442.803253), -- Metallic Fiber
(22763, 4040, 2, 6, 2, 61372.293912), -- Mold Lubricant
(22763, 9628, 1, 1, 2, 120338.291207), -- Leonard
(22763, 9630, 1, 1, 2, 80753.308836), -- Orichalcum
(22763, 16160, 1, 1, 2, 74121.387917), -- Life Stone - Level 85
(22763, 16161, 1, 1, 2, 18507.921638), -- Mid-Grade Life Stone - Level 85
(22763, 9554, 1, 1, 2, 3068.706697), -- Earth Crystal
(22763, 15815, 1, 1, 2, 1070.436289), -- Recipe - Sealed Vesper Cutter (60%)
(22763, 15816, 1, 1, 2, 1070.436289), -- Recipe - Sealed Vesper Slasher (60%)
(22763, 15817, 1, 1, 2, 1070.436289), -- Recipe - Vesper Buster (60%)
(22763, 15486, 1, 1, 2, 68190.977673), -- Spirit Stone Fragment 
-- Elite Kiriona
(22764, 15640, 1, 1, -1, 67180), -- Vesper Avenger Piece
(22764, 15641, 1, 1, -1, 67960), -- Vesper Retributer Piece
(22764, 15642, 1, 1, -1, 67180), -- Vesper Caster Piece
(22764, 15643, 1, 1, -1, 67358), -- Vesper Singer Piece
(22764, 9630, 1, 1, -1, 600375), -- Orichalcum
(22764, 15821, 1, 1, -1, 7957), -- Recipe - Vesper Avenger (60%)
(22764, 15822, 1, 1, -1, 7957), -- Recipe - Vesper Retributer (60%)
(22764, 15823, 1, 1, -1, 7957), -- Recipe - Vesper Caster (60%)
(22764, 15824, 1, 1, -1, 7957), -- Recipe - Vesper Singer (60%)
(22764, 57, 82570, 170185, 0, 700000), -- Adena
(22764, 13463, 1, 1, 1, 29.398757), -- Vesper Avenger
(22764, 13464, 1, 1, 1, 29.398757), -- Vesper Retributer
(22764, 13465, 1, 1, 1, 29.398757), -- Vesper Caster
(22764, 13466, 1, 1, 1, 29.398757), -- Vesper Singer
(22764, 15640, 1, 1, 1, 12404.578412), -- Vesper Avenger Piece
(22764, 15641, 1, 1, 1, 12548.727156), -- Vesper Retributer Piece
(22764, 15642, 1, 1, 1, 12404.578412), -- Vesper Caster Piece
(22764, 15643, 1, 1, 1, 12437.520992), -- Vesper Singer Piece
(22764, 1895, 72, 216, 2, 27873.3781), -- Metallic Fiber
(22764, 4040, 2, 6, 2, 56192.983548), -- Mold Lubricant
(22764, 9628, 1, 1, 2, 110181.848852), -- Leonard
(22764, 9630, 1, 1, 2, 73937.80296), -- Orichalcum
(22764, 16160, 1, 1, 2, 67865.818148), -- Life Stone - Level 85
(22764, 16161, 1, 1, 2, 16946.085124), -- Mid-Grade Life Stone - Level 85
(22764, 9554, 1, 1, 2, 2809.50142), -- Earth Crystal
(22764, 15821, 1, 1, 2, 979.842644), -- Recipe - Vesper Avenger (60%)
(22764, 15822, 1, 1, 2, 979.842644), -- Recipe - Vesper Retributer (60%)
(22764, 15823, 1, 1, 2, 979.842644), -- Recipe - Vesper Caster (60%)
(22764, 15824, 1, 1, 2, 979.842644), -- Recipe - Vesper Singer (60%)
(22764, 15486, 1, 1, 2, 62437.211272), -- Spirit Stone Fragment 
-- Elite Kaiona
(22765, 15644, 1, 1, -1, 153272), -- Vesper Thrower Piece
(22765, 959, 1, 1, -1, 10278), -- Scroll: Enchant Weapon (S-Grade)
(22765, 9628, 1, 5, -1, 671790), -- Leonard
(22765, 15825, 1, 1, -1, 17925), -- Recipe - Vesper Thrower (60%)
(22765, 57, 82667, 170383, 0, 700000), -- Adena
(22765, 13467, 1, 1, 1, 117.730179), -- Vesper Thrower
(22765, 15644, 1, 1, 1, 50345.269821), -- Vesper Thrower Piece
(22765, 1895, 72, 216, 2, 41858.896491), -- Metallic Fiber
(22765, 4040, 2, 6, 2, 84387.469567), -- Mold Lubricant
(22765, 9628, 3, 9, 2, 23637.891127), -- Leonard
(22765, 9630, 1, 1, 2, 111035.76244), -- Orichalcum
(22765, 16160, 1, 1, 2, 101917.039901), -- Life Stone - Level 85
(22765, 16161, 1, 1, 2, 25448.677272), -- Mid-Grade Life Stone - Level 85
(22765, 15825, 1, 1, 2, 1471.837924), -- Recipe - Vesper Thrower (60%)
(22765, 15486, 1, 1, 2, 93763.425278), -- Spirit Stone Fragment 
-- Mithril Millipede
(22766, 57, 203, 419, 0, 700000), -- Adena
(22766, 1894, 1, 1, 1, 18206.2408), -- Crafted Leather
(22766, 4039, 1, 1, 1, 17295.92876), -- Mold Glue
(22766, 4041, 1, 1, 1, 4511.95899), -- Mold Hardener
(22766, 4044, 1, 1, 1, 17295.87145), -- Thons
-- Archery Knight
(22767, 57, 1395, 2875, 0, 700000), -- Adena
(22767, 1895, 3, 9, 1, 169522.14176), -- Metallic Fiber
(22767, 4040, 1, 1, 1, 71199.1488), -- Mold Lubricant
(22767, 4042, 1, 1, 1, 59332.624), -- Enria
(22767, 4043, 1, 1, 1, 118666.08544), -- Asofe
-- Tanta Lizardman Scout
(22768, 10398, 1, 1, -1, 582), -- Icarus Disperser Piece
(22768, 959, 1, 1, -1, 54), -- Scroll: Enchant Weapon (S-Grade)
(22768, 1894, 1, 1, -1, 47666), -- Crafted Leather
(22768, 10374, 1, 1, -1, 88), -- Recipe - Icarus Disperser (60%)
(22768, 10379, 1, 1, -1, 88), -- Recipe - Icarus Hand (60%)
(22768, 10403, 1, 1, -1, 581), -- Icarus Hand Piece
(22768, 57, 666, 1341, 0, 700000), -- Adena
(22768, 10216, 1, 1, 1, 0.430787), -- Icarus Disperser
(22768, 10398, 1, 1, 1, 143.298813), -- Icarus Disperser Piece
(22768, 10221, 1, 1, 1, 0.430787), -- Icarus Hand
(22768, 10403, 1, 1, 1, 142.839613), -- Icarus Hand Piece
(22768, 1895, 1, 1, 2, 38240.389152), -- Metallic Fiber
(22768, 4040, 1, 1, 2, 2676.794112), -- Mold Lubricant
(22768, 4042, 1, 1, 2, 2230.66176), -- Enria
(22768, 4043, 1, 1, 2, 4461.32352), -- Asofe
(22768, 10483, 1, 1, 2, 929.396388), -- Life Stone - Level 82
(22768, 10484, 1, 1, 2, 232.314588), -- Mid-Grade Life Stone - Level 82
(22768, 10485, 1, 1, 2, 23.190048), -- High-Grade Life Stone - Level 82
(22768, 959, 1, 1, 2, 5.383404), -- Scroll: Enchant Weapon (S-Grade)
(22768, 10379, 1, 1, 2, 8.558232), -- Recipe - Icarus Hand (60%)
(22768, 1345, 10, 30, 2, 89227.988796), -- Shining Arrow
-- Tanta Lizardman Warrior
(22769, 10397, 1, 1, -1, 664), -- Icarus Sawsword Piece
(22769, 10399, 1, 1, -1, 664), -- Icarus Spirit Piece
(22769, 10400, 1, 1, -1, 662), -- Icarus Heavy Arms Piece
(22769, 9628, 1, 1, -1, 12152), -- Leonard
(22769, 10373, 1, 1, -1, 100), -- Recipe - Icarus Sawsword (60%)
(22769, 10375, 1, 1, -1, 100), -- Recipe - Icarus Spirit (60%)
(22769, 10376, 1, 1, -1, 100), -- Recipe - Icarus Heavy Arms (60%)
(22769, 57, 885, 1786, 0, 700000), -- Adena
(22769, 10215, 1, 1, 1, 0.383), -- Icarus Sawsword
(22769, 10217, 1, 1, 1, 0.383), -- Icarus Spirit
(22769, 10218, 1, 1, 1, 0.383), -- Icarus Heavy Arms
(22769, 10397, 1, 1, 1, 127.419887), -- Icarus Sawsword Piece
(22769, 10399, 1, 1, 1, 127.419887), -- Icarus Spirit Piece
(22769, 10400, 1, 1, 1, 127.011226), -- Icarus Heavy Arms Piece
(22769, 1895, 1, 1, 2, 63604.86687), -- Metallic Fiber
(22769, 4040, 1, 1, 2, 4452.35967), -- Mold Lubricant
(22769, 9628, 1, 1, 2, 1746.047745), -- Leonard
(22769, 9630, 1, 1, 2, 1171.700505), -- Orichalcum
(22769, 10483, 1, 1, 2, 1545.931845), -- Life Stone - Level 82
(22769, 10484, 1, 1, 2, 386.50122), -- Mid-Grade Life Stone - Level 82
(22769, 10485, 1, 1, 2, 38.635515), -- High-Grade Life Stone - Level 82
(22769, 960, 1, 1, 2, 88.95663), -- Scroll: Enchant Armor (S-Grade)
-- Tanta Lizardman Soldier
(22770, 15645, 1, 1, -1, 10600), -- Sealed Moirai Helmet Piece
(22770, 15646, 1, 1, -1, 10600), -- Sealed Moirai Leather Helmet Piece
(22770, 15647, 1, 1, -1, 10600), -- Sealed Moirai Circlet Piece
(22770, 15693, 1, 1, -1, 19000), -- Sealed Moirai Shield Piece
(22770, 15692, 1, 1, -1, 19000), -- Sealed Moirai Sigil Piece
(22770, 15775, 1, 1, -1, 1414), -- Recipe - Sealed Moirai Helmet (60%) 
(22770, 15776, 1, 1, -1, 1414), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22770, 15777, 1, 1, -1, 1414), -- Recipe - Sealed Moirai Circlet (60%) 
(22770, 15791, 1, 1, -1, 2021), -- Recipe - Sealed Moirai Shield (60%) 
(22770, 15790, 1, 1, -1, 2021), -- Recipe - Sealed Moirai Sigil (60%) 
(22770, 57, 1445, 2953, 0, 700000), -- Adena
(22770, 15694, 1, 1, 1, 4.645192), -- Sealed Moirai Helmet 
(22770, 15695, 1, 1, 1, 4.645192), -- Sealed Moirai Leather Helmet 
(22770, 15696, 1, 1, 1, 4.645192), -- Sealed Moirai Circlet 
(22770, 15710, 1, 1, 1, 6.645844), -- Sealed Moirai Shield 
(22770, 15709, 1, 1, 1, 6.645844), -- Sealed Moirai Sigil 
(22770, 15645, 1, 1, 1, 1741.924004), -- Sealed Moirai Helmet Piece
(22770, 15646, 1, 1, 1, 1741.924004), -- Sealed Moirai Leather Helmet Piece
(22770, 15647, 1, 1, 1, 1741.924004), -- Sealed Moirai Circlet Piece
(22770, 15693, 1, 1, 1, 3122.500362), -- Sealed Moirai Shield Piece
(22770, 15692, 1, 1, 1, 3122.500362), -- Sealed Moirai Sigil Piece
(22770, 1879, 1, 1, 2, 34913.54495), -- Cokes
(22770, 1885, 1, 1, 2, 17456.772475), -- High-Grade Suede
(22770, 9628, 1, 1, 2, 1642.993815), -- Leonard
(22770, 9630, 1, 1, 2, 1102.5144), -- Orichalcum
(22770, 9629, 1, 1, 2, 910.811175), -- Adamantine
(22770, 10483, 1, 1, 2, 1454.7065), -- Life Stone - Level 82
(22770, 10484, 1, 1, 2, 363.676625), -- Mid-Grade Life Stone - Level 82
(22770, 10485, 1, 1, 2, 36.39711), -- High-Grade Life Stone - Level 82
(22770, 9554, 1, 1, 2, 41.874345), -- Earth Crystal
(22770, 15775, 1, 1, 2, 165.907215), -- Recipe - Sealed Moirai Helmet (60%) 
(22770, 15776, 1, 1, 2, 165.907215), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22770, 15777, 1, 1, 2, 165.907215), -- Recipe - Sealed Moirai Circlet (60%) 
(22770, 15791, 1, 1, 2, 236.99348), -- Recipe - Sealed Moirai Shield (60%) 
(22770, 15790, 1, 1, 2, 236.99348), -- Recipe - Sealed Moirai Sigil (60%) 
-- Tanta Lizardman Berserker
(22771, 10404, 1, 1, -1, 1572), -- Icarus Hall Piece
(22771, 10402, 1, 1, -1, 1572), -- Icarus Hammer Piece
(22771, 9630, 1, 1, -1, 19365), -- Orichalcum
(22771, 10380, 1, 1, -1, 237), -- Recipe - Icarus Hall (60%)
(22771, 10378, 1, 1, -1, 237), -- Recipe - Icarus Hammer (60%)
(22771, 57, 1488, 3042, 0, 700000), -- Adena
(22771, 10222, 1, 1, 1, 0.486652), -- Icarus Hall
(22771, 10220, 1, 1, 1, 0.486652), -- Icarus Hammer
(22771, 10404, 1, 1, 1, 161.795386), -- Icarus Hall Piece
(22771, 10402, 1, 1, 1, 161.795386), -- Icarus Hammer Piece
(22771, 15697, 1, 1, 1, 2.247348), -- Sealed Moirai Breastplate 
(22771, 15700, 1, 1, 1, 3.597944), -- Sealed Moirai Gaiter 
(22771, 15648, 1, 1, 1, 898.220158), -- Sealed Moirai Breastplate Piece
(22771, 15651, 1, 1, 1, 1505.370474), -- Sealed Moirai Gaiter Piece
(22771, 1879, 1, 1, 2, 45770.134172), -- Cokes
(22771, 1885, 1, 1, 2, 22885.067086), -- High-Grade Suede
(22771, 9628, 1, 1, 2, 2153.894042), -- Leonard
(22771, 9630, 1, 1, 2, 1445.346207), -- Orichalcum
(22771, 9629, 1, 1, 2, 1193.98496), -- Adamantine
(22771, 10483, 1, 1, 2, 1907.101615), -- Life Stone - Level 82
(22771, 10484, 1, 1, 2, 476.756367), -- Mid-Grade Life Stone - Level 82
(22771, 10485, 1, 1, 2, 47.668022), -- High-Grade Life Stone - Level 82
(22771, 9554, 1, 1, 2, 54.901987), -- Earth Crystal
(22771, 15778, 1, 1, 2, 81.553437), -- Recipe - Sealed Moirai Breastplate (60%) 
(22771, 15781, 1, 1, 2, 130.592105), -- Recipe - Sealed Moirai Gaiter (60%) 
-- Tanta Lizardman Archer
(22772, 10405, 1, 1, -1, 495), -- Icarus Spitter Piece
(22772, 959, 1, 1, -1, 46), -- Scroll: Enchant Weapon (S-Grade)
(22772, 1894, 1, 1, -1, 40627), -- Crafted Leather
(22772, 10381, 1, 1, -1, 75), -- Recipe - Icarus Spitter (60%)
(22772, 15772, 1, 1, -1, 15971), -- Sealed Moirai Ring Gem
(22772, 15773, 1, 1, -1, 8976), -- Sealed Moirai Earring Gem
(22772, 15774, 1, 1, -1, 7745), -- Sealed Moirai Necklace Gem
(22772, 15812, 1, 1, -1, 2113), -- Recipe - Sealed Moirai Ring (70%) 
(22772, 15813, 1, 1, -1, 1408), -- Recipe - Sealed Moirai Earring (70%) 
(22772, 15814, 1, 1, -1, 1056), -- Recipe - Sealed Moirai Necklace (70%) 
(22772, 57, 945, 1907, 0, 700000), -- Adena
(22772, 10223, 1, 1, 1, 0.30636), -- Icarus Spitter
(22772, 10405, 1, 1, 1, 101.228152), -- Icarus Spitter Piece
(22772, 15766, 1, 1, 1, 8.64616), -- Sealed Moirai Ring
(22772, 15767, 1, 1, 1, 5.759568), -- Sealed Moirai Earring
(22772, 15768, 1, 1, 1, 4.32308), -- Sealed Moirai Necklace
(22772, 15772, 1, 1, 1, 3267.145584), -- Sealed Moirai Ring Gem
(22772, 15773, 1, 1, 1, 1836.18568), -- Sealed Moirai Earring Gem
(22772, 15774, 1, 1, 1, 1584.405416), -- Sealed Moirai Necklace Gem
(22772, 1895, 1, 1, 2, 49383.296494), -- Metallic Fiber
(22772, 4040, 1, 1, 2, 3456.806598), -- Mold Lubricant
(22772, 9628, 1, 1, 2, 1355.701779), -- Leonard
(22772, 9630, 1, 1, 2, 909.667784), -- Orichalcum
(22772, 10483, 1, 1, 2, 1200.236932), -- Life Stone - Level 82
(22772, 10484, 1, 1, 2, 300.059233), -- Mid-Grade Life Stone - Level 82
(22772, 10485, 1, 1, 2, 30.023178), -- High-Grade Life Stone - Level 82
(22772, 15812, 1, 1, 2, 315.415916), -- Recipe - Sealed Moirai Ring (70%) 
(22772, 15813, 1, 1, 2, 210.162246), -- Recipe - Sealed Moirai Earring (70%) 
(22772, 15814, 1, 1, 2, 157.707958), -- Recipe - Sealed Moirai Necklace (70%) 
(22772, 1345, 10, 30, 2, 115227.921882), -- Shining Arrow
-- Tanta Lizardman Magician
(22773, 15654, 1, 1, -1, 8561), -- Sealed Moirai Gauntlet Piece
(22773, 15655, 1, 1, -1, 8561), -- Sealed Moirai Leather Gloves Piece
(22773, 15656, 1, 1, -1, 8561), -- Sealed Moirai Gloves Piece
(22773, 15657, 1, 1, -1, 8561), -- Sealed Moirai Boots Piece
(22773, 15658, 1, 1, -1, 8561), -- Sealed Moirai Leather Boots Piece
(22773, 15659, 1, 1, -1, 8561), -- Sealed Moirai Shoes Piece
(22773, 15784, 1, 1, -1, 1139), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22773, 15785, 1, 1, -1, 1139), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22773, 15786, 1, 1, -1, 1139), -- Recipe - Sealed Moirai Gloves (60%) 
(22773, 15787, 1, 1, -1, 1139), -- Recipe - Sealed Moirai Boots (60%) 
(22773, 15788, 1, 1, -1, 1139), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22773, 15789, 1, 1, -1, 1139), -- Recipe - Sealed Moirai Shoes (60%) 
(22773, 57, 939, 1895, 0, 700000), -- Adena
(22773, 15703, 1, 1, 1, 3.740646), -- Sealed Moirai Gauntlet 
(22773, 15704, 1, 1, 1, 3.740646), -- Sealed Moirai Leather Gloves 
(22773, 15705, 1, 1, 1, 3.740646), -- Sealed Moirai Gloves 
(22773, 15706, 1, 1, 1, 3.740646), -- Sealed Moirai Boots 
(22773, 15707, 1, 1, 1, 3.740646), -- Sealed Moirai Leather Boots 
(22773, 15708, 1, 1, 1, 3.740646), -- Sealed Moirai Shoes 
(22773, 15654, 1, 1, 1, 1406.753712), -- Sealed Moirai Gauntlet Piece
(22773, 15655, 1, 1, 1, 1406.753712), -- Sealed Moirai Leather Gloves Piece
(22773, 15656, 1, 1, 1, 1406.753712), -- Sealed Moirai Gloves Piece
(22773, 15657, 1, 1, 1, 1406.753712), -- Sealed Moirai Boots Piece
(22773, 15658, 1, 1, 1, 1406.753712), -- Sealed Moirai Leather Boots Piece
(22773, 15659, 1, 1, 1, 1406.787564), -- Sealed Moirai Shoes Piece
(22773, 1895, 1, 1, 2, 38555.689276), -- Metallic Fiber
(22773, 4040, 1, 1, 2, 2698.889842), -- Mold Lubricant
(22773, 4042, 1, 1, 2, 2249.098222), -- Enria
(22773, 4043, 1, 1, 2, 4498.196444), -- Asofe
(22773, 10483, 1, 1, 2, 937.135936), -- Life Stone - Level 82
(22773, 10484, 1, 1, 2, 234.283984), -- Mid-Grade Life Stone - Level 82
(22773, 10485, 1, 1, 2, 23.400374), -- High-Grade Life Stone - Level 82
(22773, 15784, 1, 1, 2, 160.299568), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22773, 15785, 1, 1, 2, 160.299568), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22773, 15786, 1, 1, 2, 160.299568), -- Recipe - Sealed Moirai Gloves (60%) 
(22773, 15787, 1, 1, 2, 160.299568), -- Recipe - Sealed Moirai Boots (60%) 
(22773, 15788, 1, 1, 2, 160.299568), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22773, 15789, 1, 1, 2, 160.299568), -- Recipe - Sealed Moirai Shoes (60%) 
(22773, 1345, 10, 30, 2, 89963.508514), -- Shining Arrow
-- Tanta Lizardman Summoner
(22774, 15649, 1, 1, -1, 9227), -- Sealed Moirai Leather Breastplate Piece
(22774, 15652, 1, 1, -1, 14969), -- Sealed Moirai Leather Legging Piece
(22774, 9630, 1, 1, -1, 15127), -- Orichalcum
(22774, 15779, 1, 1, -1, 1138), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22774, 15782, 1, 1, -1, 1821), -- Recipe - Sealed Moirai Leather Legging (60%) 
(22774, 15780, 1, 1, -1, 1138), -- Recipe - Sealed Moirai Tunic (60%) 
(22774, 15783, 1, 1, -1, 1821), -- Recipe - Sealed Moirai Stockings (60%) 
(22774, 57, 1628, 3326, 0, 700000), -- Adena
(22774, 15698, 1, 1, 1, 3.270337), -- Sealed Moirai Leather Breastplate 
(22774, 15701, 1, 1, 1, 5.236723), -- Sealed Moirai Leather Legging 
(22774, 15649, 1, 1, 1, 1326.2646), -- Sealed Moirai Leather Breastplate Piece
(22774, 15652, 1, 1, 1, 2151.72834), -- Sealed Moirai Leather Legging Piece
(22774, 15699, 1, 1, 1, 3.270337), -- Sealed Moirai Tunic 
(22774, 15650, 1, 1, 1, 1326.2646), -- Sealed Moirai Tunic Piece
(22774, 15702, 1, 1, 1, 5.236723), -- Sealed Moirai Stockings 
(22774, 15653, 1, 1, 1, 2151.72834), -- Sealed Moirai Stockings Piece
(22774, 1879, 1, 1, 2, 45883.596915), -- Cokes
(22774, 1885, 1, 1, 2, 22941.836775), -- High-Grade Suede
(22774, 9628, 1, 1, 2, 2159.191125), -- Leonard
(22774, 9630, 1, 1, 2, 1448.937945), -- Orichalcum
(22774, 9629, 1, 1, 2, 1196.962065), -- Adamantine
(22774, 10483, 1, 1, 2, 1911.813345), -- Life Stone - Level 82
(22774, 10484, 1, 1, 2, 477.972495), -- Mid-Grade Life Stone - Level 82
(22774, 10485, 1, 1, 2, 47.82024), -- High-Grade Life Stone - Level 82
(22774, 15780, 1, 1, 2, 108.97497), -- Recipe - Sealed Moirai Tunic (60%) 
(22774, 15783, 1, 1, 2, 174.42126), -- Recipe - Sealed Moirai Stockings (60%) 
(22774, 15779, 1, 1, 2, 108.97497), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22774, 15782, 1, 1, 2, 174.497895), -- Recipe - Sealed Moirai Leather Legging (60%) 
-- Sel Mahum Drill Sergeant
(22775, 15648, 1, 1, -1, 6036), -- Sealed Moirai Breastplate Piece
(22775, 15651, 1, 1, -1, 10116), -- Sealed Moirai Gaiter Piece
(22775, 1894, 1, 1, -1, 89267), -- Crafted Leather
(22775, 15778, 1, 1, -1, 756), -- Recipe - Sealed Moirai Breastplate (60%) 
(22775, 15781, 1, 1, -1, 1209), -- Recipe - Sealed Moirai Gaiter (60%) 
(22775, 57, 1029, 2103, 0, 700000), -- Adena
(22775, 15697, 1, 1, 1, 3.101292), -- Sealed Moirai Breastplate 
(22775, 15700, 1, 1, 1, 4.962732), -- Sealed Moirai Gaiter 
(22775, 15648, 1, 1, 1, 1239.163932), -- Sealed Moirai Breastplate Piece
(22775, 15651, 1, 1, 1, 2076.772044), -- Sealed Moirai Gaiter Piece
(22775, 1895, 1, 1, 2, 59678.832657), -- Metallic Fiber
(22775, 4040, 1, 1, 2, 4177.502505), -- Mold Lubricant
(22775, 9628, 1, 1, 2, 1638.272601), -- Leonard
(22775, 9630, 1, 1, 2, 1099.317486), -- Orichalcum
(22775, 10483, 1, 1, 2, 1450.547433), -- Life Stone - Level 82
(22775, 10484, 1, 1, 2, 362.619705), -- Mid-Grade Life Stone - Level 82
(22775, 10485, 1, 1, 2, 36.296277), -- High-Grade Life Stone - Level 82
(22775, 959, 1, 1, 2, 8.370786), -- Scroll: Enchant Weapon (S-Grade)
(22775, 15778, 1, 1, 2, 62.026152), -- Recipe - Sealed Moirai Breastplate (60%) 
(22775, 15781, 1, 1, 2, 99.214398), -- Recipe - Sealed Moirai Gaiter (60%) 
-- Sel Mahum Training Officer
(22776, 15649, 1, 1, -1, 12239), -- Sealed Moirai Leather Breastplate Piece
(22776, 15652, 1, 1, -1, 19856), -- Sealed Moirai Leather Legging Piece
(22776, 1894, 1, 1, -1, 133768), -- Crafted Leather
(22776, 15779, 1, 1, -1, 1510), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22776, 15782, 1, 1, -1, 2415), -- Recipe - Sealed Moirai Leather Legging (60%) 
(22776, 57, 1542, 3152, 0, 700000), -- Adena
(22776, 15698, 1, 1, 1, 6.196428), -- Sealed Moirai Leather Breastplate 
(22776, 15701, 1, 1, 1, 9.915606), -- Sealed Moirai Leather Legging 
(22776, 15649, 1, 1, 1, 2512.9224), -- Sealed Moirai Leather Breastplate Piece
(22776, 15652, 1, 1, 1, 4076.965566), -- Sealed Moirai Leather Legging Piece
(22776, 1895, 1, 1, 2, 81299.95658), -- Metallic Fiber
(22776, 4040, 1, 1, 2, 5691.034401), -- Mold Lubricant
(22776, 9628, 1, 1, 2, 2231.728643), -- Leonard
(22776, 9630, 1, 1, 2, 1497.616), -- Orichalcum
(22776, 10483, 1, 1, 2, 1976.010711), -- Life Stone - Level 82
(22776, 10484, 1, 1, 2, 494.026078), -- Mid-Grade Life Stone - Level 82
(22776, 10485, 1, 1, 2, 49.421328), -- High-Grade Life Stone - Level 82
(22776, 9552, 1, 1, 2, 56.909408), -- Fire Crystal
(22776, 959, 1, 1, 2, 11.419322), -- Scroll: Enchant Weapon (S-Grade)
(22776, 15779, 1, 1, 2, 112.695604), -- Recipe - Sealed Moirai Leather Breastplate (60%) 
(22776, 15782, 1, 1, 2, 180.181925), -- Recipe - Sealed Moirai Leather Legging (60%) 
-- Sel Mahum Drill Sergeant
(22777, 15650, 1, 1, -1, 8167), -- Sealed Moirai Tunic Piece
(22777, 15653, 1, 1, -1, 13251), -- Sealed Moirai Stockings Piece
(22777, 1894, 1, 1, -1, 89267), -- Crafted Leather
(22777, 15780, 1, 1, -1, 1007), -- Recipe - Sealed Moirai Tunic (60%) 
(22777, 15783, 1, 1, -1, 1612), -- Recipe - Sealed Moirai Stockings (60%) 
(22777, 57, 1029, 2103, 0, 700000), -- Adena
(22777, 15699, 1, 1, 1, 4.135642), -- Sealed Moirai Tunic 
(22777, 15702, 1, 1, 1, 6.617909), -- Sealed Moirai Stockings 
(22777, 15650, 1, 1, 1, 1677.1836), -- Sealed Moirai Tunic Piece
(22777, 15653, 1, 1, 1, 2721.062849), -- Sealed Moirai Stockings Piece
(22777, 1895, 1, 1, 2, 59678.6595), -- Metallic Fiber
(22777, 4040, 1, 1, 2, 4177.5096), -- Mold Lubricant
(22777, 9628, 1, 1, 2, 1638.2202), -- Leonard
(22777, 9630, 1, 1, 2, 1099.3374), -- Orichalcum
(22777, 10483, 1, 1, 2, 1450.5318), -- Life Stone - Level 82
(22777, 10484, 1, 1, 2, 362.5986), -- Mid-Grade Life Stone - Level 82
(22777, 10485, 1, 1, 2, 36.2736), -- High-Grade Life Stone - Level 82
(22777, 9552, 1, 1, 2, 41.7696), -- Fire Crystal
(22777, 15780, 1, 1, 2, 82.7148), -- Recipe - Sealed Moirai Tunic (60%) 
(22777, 15783, 1, 1, 2, 132.3849), -- Recipe - Sealed Moirai Stockings (60%) 
-- Sel Mahum Drill Sergeant
(22778, 15772, 1, 1, -1, 29243), -- Sealed Moirai Ring Gem
(22778, 15773, 1, 1, -1, 16435), -- Sealed Moirai Earring Gem
(22778, 15774, 1, 1, -1, 14181), -- Sealed Moirai Necklace Gem
(22778, 15812, 1, 1, -1, 3869), -- Recipe - Sealed Moirai Ring (70%) 
(22778, 15813, 1, 1, -1, 2579), -- Recipe - Sealed Moirai Earring (70%) 
(22778, 15814, 1, 1, -1, 1934), -- Recipe - Sealed Moirai Necklace (70%) 
(22778, 57, 1029, 2103, 0, 700000), -- Adena
(22778, 15766, 1, 1, 1, 12.705673), -- Sealed Moirai Ring
(22778, 15767, 1, 1, 1, 8.467163), -- Sealed Moirai Earring
(22778, 15768, 1, 1, 1, 6.347908), -- Sealed Moirai Necklace
(22778, 15772, 1, 1, 1, 4801.975548), -- Sealed Moirai Ring Gem
(22778, 15773, 1, 1, 1, 2698.787458), -- Sealed Moirai Earring Gem
(22778, 15774, 1, 1, 1, 2328.71625), -- Sealed Moirai Necklace Gem
(22778, 1895, 1, 1, 2, 54253.560576), -- Metallic Fiber
(22778, 4040, 1, 1, 2, 3797.759328), -- Mold Lubricant
(22778, 9628, 1, 1, 2, 1489.319856), -- Leonard
(22778, 9630, 1, 1, 2, 999.436896), -- Orichalcum
(22778, 10483, 1, 1, 2, 1318.64892), -- Life Stone - Level 82
(22778, 10484, 1, 1, 2, 329.677992), -- Mid-Grade Life Stone - Level 82
(22778, 10485, 1, 1, 2, 32.974104), -- High-Grade Life Stone - Level 82
(22778, 960, 1, 1, 2, 75.97284), -- Scroll: Enchant Armor (S-Grade)
(22778, 15812, 1, 1, 2, 346.511808), -- Recipe - Sealed Moirai Ring (70%) 
(22778, 15813, 1, 1, 2, 231.007872), -- Recipe - Sealed Moirai Earring (70%) 
(22778, 15814, 1, 1, 2, 173.129808), -- Recipe - Sealed Moirai Necklace (70%) 
-- Sel Mahum Escort Guard
(22779, 15654, 1, 1, -1, 9273), -- Sealed Moirai Gauntlet Piece
(22779, 15655, 1, 1, -1, 9273), -- Sealed Moirai Leather Gloves Piece
(22779, 15656, 1, 1, -1, 9273), -- Sealed Moirai Gloves Piece
(22779, 15657, 1, 1, -1, 9273), -- Sealed Moirai Boots Piece
(22779, 15658, 1, 1, -1, 9273), -- Sealed Moirai Leather Boots Piece
(22779, 15659, 1, 1, -1, 9273), -- Sealed Moirai Shoes Piece
(22779, 15784, 1, 1, -1, 1234), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22779, 15785, 1, 1, -1, 1234), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22779, 15786, 1, 1, -1, 1234), -- Recipe - Sealed Moirai Gloves (60%) 
(22779, 15787, 1, 1, -1, 1234), -- Recipe - Sealed Moirai Boots (60%) 
(22779, 15788, 1, 1, -1, 1234), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22779, 15789, 1, 1, -1, 1234), -- Recipe - Sealed Moirai Shoes (60%) 
(22779, 57, 1008, 2061, 0, 700000), -- Adena
(22779, 15703, 1, 1, 1, 4.051814), -- Sealed Moirai Gauntlet 
(22779, 15704, 1, 1, 1, 4.051814), -- Sealed Moirai Leather Gloves 
(22779, 15705, 1, 1, 1, 4.051814), -- Sealed Moirai Gloves 
(22779, 15706, 1, 1, 1, 4.051814), -- Sealed Moirai Boots 
(22779, 15707, 1, 1, 1, 4.051814), -- Sealed Moirai Leather Boots 
(22779, 15708, 1, 1, 1, 4.051814), -- Sealed Moirai Shoes 
(22779, 15654, 1, 1, 1, 1523.775408), -- Sealed Moirai Gauntlet Piece
(22779, 15655, 1, 1, 1, 1523.775408), -- Sealed Moirai Leather Gloves Piece
(22779, 15656, 1, 1, 1, 1523.775408), -- Sealed Moirai Gloves Piece
(22779, 15657, 1, 1, 1, 1523.775408), -- Sealed Moirai Boots Piece
(22779, 15658, 1, 1, 1, 1523.775408), -- Sealed Moirai Leather Boots Piece
(22779, 15659, 1, 1, 1, 1523.812076), -- Sealed Moirai Shoes Piece
(22779, 1895, 1, 1, 2, 41764.983636), -- Metallic Fiber
(22779, 4040, 1, 1, 2, 2923.525335), -- Mold Lubricant
(22779, 9628, 1, 1, 2, 1146.478602), -- Leonard
(22779, 9630, 1, 1, 2, 769.333299), -- Orichalcum
(22779, 10483, 1, 1, 2, 1015.112283), -- Life Stone - Level 82
(22779, 10484, 1, 1, 2, 253.765821), -- Mid-Grade Life Stone - Level 82
(22779, 10485, 1, 1, 2, 25.381482), -- High-Grade Life Stone - Level 82
(22779, 960, 1, 1, 2, 58.455807), -- Scroll: Enchant Armor (S-Grade)
(22779, 15784, 1, 1, 2, 173.652456), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22779, 15785, 1, 1, 2, 173.652456), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22779, 15786, 1, 1, 2, 173.652456), -- Recipe - Sealed Moirai Gloves (60%) 
(22779, 15787, 1, 1, 2, 173.652456), -- Recipe - Sealed Moirai Boots (60%) 
(22779, 15788, 1, 1, 2, 173.652456), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22779, 15789, 1, 1, 2, 173.701455), -- Recipe - Sealed Moirai Shoes (60%) 
-- Sel Mahum Recruit
(22780, 15645, 1, 1, -1, 2290), -- Sealed Moirai Helmet Piece
(22780, 15646, 1, 1, -1, 2290), -- Sealed Moirai Leather Helmet Piece
(22780, 15647, 1, 1, -1, 2290), -- Sealed Moirai Circlet Piece
(22780, 15693, 1, 1, -1, 4106), -- Sealed Moirai Shield Piece
(22780, 15692, 1, 1, -1, 4106), -- Sealed Moirai Sigil Piece
(22780, 960, 1, 1, -1, 154), -- Scroll: Enchant Armor (S-Grade)
(22780, 15775, 1, 1, -1, 306), -- Recipe - Sealed Moirai Helmet (60%) 
(22780, 15776, 1, 1, -1, 306), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22780, 15777, 1, 1, -1, 306), -- Recipe - Sealed Moirai Circlet (60%) 
(22780, 15791, 1, 1, -1, 437), -- Recipe - Sealed Moirai Shield (60%) 
(22780, 15790, 1, 1, -1, 437), -- Recipe - Sealed Moirai Sigil (60%) 
(22780, 57, 346, 699, 0, 700000), -- Adena
(22780, 15694, 1, 1, 1, 1.104132), -- Sealed Moirai Helmet 
(22780, 15695, 1, 1, 1, 1.104132), -- Sealed Moirai Leather Helmet 
(22780, 15696, 1, 1, 1, 1.104132), -- Sealed Moirai Circlet 
(22780, 15710, 1, 1, 1, 1.579674), -- Sealed Moirai Shield 
(22780, 15709, 1, 1, 1, 1.579674), -- Sealed Moirai Sigil 
(22780, 15645, 1, 1, 1, 414.044034), -- Sealed Moirai Helmet Piece
(22780, 15646, 1, 1, 1, 414.044034), -- Sealed Moirai Leather Helmet Piece
(22780, 15647, 1, 1, 1, 414.044034), -- Sealed Moirai Circlet Piece
(22780, 15693, 1, 1, 1, 742.198077), -- Sealed Moirai Shield Piece
(22780, 15692, 1, 1, 1, 742.198077), -- Sealed Moirai Sigil Piece
(22780, 1894, 1, 1, 2, 2038.2912), -- Crafted Leather
(22780, 4039, 1, 1, 2, 1936.3752), -- Mold Glue
(22780, 4041, 1, 1, 2, 505.1448), -- Mold Hardener
(22780, 4044, 1, 1, 2, 1936.3752), -- Thons
(22780, 10483, 1, 1, 2, 403.4088), -- Life Stone - Level 82
(22780, 10484, 1, 1, 2, 100.8504), -- Mid-Grade Life Stone - Level 82
(22780, 10485, 1, 1, 2, 10.0872), -- High-Grade Life Stone - Level 82
(22780, 15775, 1, 1, 2, 46.008), -- Recipe - Sealed Moirai Helmet (60%) 
(22780, 15776, 1, 1, 2, 46.008), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22780, 15777, 1, 1, 2, 46.008), -- Recipe - Sealed Moirai Circlet (60%) 
(22780, 15791, 1, 1, 2, 65.7216), -- Recipe - Sealed Moirai Shield (60%) 
(22780, 15790, 1, 1, 2, 65.7216), -- Recipe - Sealed Moirai Sigil (60%) 
-- Sel Mahum Soldier
(22781, 10397, 1, 1, -1, 346), -- Icarus Sawsword Piece
(22781, 10399, 1, 1, -1, 346), -- Icarus Spirit Piece
(22781, 10400, 1, 1, -1, 345), -- Icarus Heavy Arms Piece
(22781, 9630, 1, 1, -1, 4244), -- Orichalcum
(22781, 10373, 1, 1, -1, 52), -- Recipe - Icarus Sawsword (60%)
(22781, 10375, 1, 1, -1, 52), -- Recipe - Icarus Spirit (60%)
(22781, 10376, 1, 1, -1, 52), -- Recipe - Icarus Heavy Arms (60%)
(22781, 57, 457, 933, 0, 700000), -- Adena
(22781, 10215, 1, 1, 1, 0.199), -- Icarus Sawsword
(22781, 10217, 1, 1, 1, 0.199), -- Icarus Spirit
(22781, 10218, 1, 1, 1, 0.199), -- Icarus Heavy Arms
(22781, 10397, 1, 1, 1, 66.205111), -- Icarus Sawsword Piece
(22781, 10399, 1, 1, 1, 66.205111), -- Icarus Spirit Piece
(22781, 10400, 1, 1, 1, 65.992778), -- Icarus Heavy Arms Piece
(22781, 1879, 1, 1, 2, 19307.540719), -- Cokes
(22781, 1885, 1, 1, 2, 9653.754355), -- High-Grade Suede
(22781, 9628, 1, 1, 2, 908.575465), -- Leonard
(22781, 9630, 1, 1, 2, 609.707432), -- Orichalcum
(22781, 9629, 1, 1, 2, 503.661615), -- Adamantine
(22781, 10483, 1, 1, 2, 804.482197), -- Life Stone - Level 82
(22781, 10484, 1, 1, 2, 201.112547), -- Mid-Grade Life Stone - Level 82
(22781, 10485, 1, 1, 2, 20.16567), -- High-Grade Life Stone - Level 82
-- Sel Mahum Recruit
(22782, 10404, 1, 1, -1, 363), -- Icarus Hall Piece
(22782, 10402, 1, 1, -1, 363), -- Icarus Hammer Piece
(22782, 9630, 1, 1, -1, 4469), -- Orichalcum
(22782, 10380, 1, 1, -1, 55), -- Recipe - Icarus Hall (60%)
(22782, 10378, 1, 1, -1, 55), -- Recipe - Icarus Hammer (60%)
(22782, 57, 346, 699, 0, 700000), -- Adena
(22782, 10222, 1, 1, 1, 0.224096), -- Icarus Hall
(22782, 10220, 1, 1, 1, 0.224096), -- Icarus Hammer
(22782, 10404, 1, 1, 1, 74.275904), -- Icarus Hall Piece
(22782, 10402, 1, 1, 1, 74.275904), -- Icarus Hammer Piece
(22782, 1894, 1, 1, 2, 3493.94364), -- Crafted Leather
(22782, 4039, 1, 1, 2, 3319.24824), -- Mold Glue
(22782, 4041, 1, 1, 2, 865.88568), -- Mold Hardener
(22782, 4044, 1, 1, 2, 3319.24824), -- Thons
(22782, 10483, 1, 1, 2, 691.51104), -- Life Stone - Level 82
(22782, 10484, 1, 1, 2, 172.87776), -- Mid-Grade Life Stone - Level 82
(22782, 10485, 1, 1, 2, 17.2854), -- High-Grade Life Stone - Level 82
-- Sel Mahum Soldier
(22783, 10403, 1, 1, -1, 440), -- Icarus Hand Piece
(22783, 959, 1, 1, -1, 41), -- Scroll: Enchant Weapon (S-Grade)
(22783, 1894, 1, 1, -1, 36096), -- Crafted Leather
(22783, 10379, 1, 1, -1, 66), -- Recipe - Icarus Hand (60%)
(22783, 57, 333, 680, 0, 700000), -- Adena
(22783, 10221, 1, 1, 1, 0.436015), -- Icarus Hand
(22783, 10403, 1, 1, 1, 144.563985), -- Icarus Hand Piece
(22783, 1879, 1, 1, 2, 14077.271558), -- Cokes
(22783, 1885, 1, 1, 2, 7038.62411), -- High-Grade Suede
(22783, 9628, 1, 1, 2, 662.44913), -- Leonard
(22783, 9630, 1, 1, 2, 444.542224), -- Orichalcum
(22783, 9629, 1, 1, 2, 367.22343), -- Adamantine
(22783, 10483, 1, 1, 2, 586.553954), -- Life Stone - Level 82
(22783, 10484, 1, 1, 2, 146.632654), -- Mid-Grade Life Stone - Level 82
(22783, 10485, 1, 1, 2, 14.70294), -- High-Grade Life Stone - Level 82
-- Sel Mahum Recruit
(22784, 10405, 1, 1, -1, 454), -- Icarus Spitter Piece
(22784, 1894, 1, 1, -1, 37238), -- Crafted Leather
(22784, 960, 1, 1, -1, 425), -- Scroll: Enchant Armor (S-Grade)
(22784, 10381, 1, 1, -1, 68), -- Recipe - Icarus Spitter (60%)
(22784, 57, 346, 699, 0, 700000), -- Adena
(22784, 10223, 1, 1, 1, 0.448043), -- Icarus Spitter
(22784, 10405, 1, 1, 1, 148.551957), -- Icarus Spitter Piece
(22784, 1894, 1, 1, 2, 3493.94364), -- Crafted Leather
(22784, 4039, 1, 1, 2, 3319.24824), -- Mold Glue
(22784, 4041, 1, 1, 2, 865.88568), -- Mold Hardener
(22784, 4044, 1, 1, 2, 3319.24824), -- Thons
(22784, 10483, 1, 1, 2, 691.51104), -- Life Stone - Level 82
(22784, 10484, 1, 1, 2, 172.87776), -- Mid-Grade Life Stone - Level 82
(22784, 10485, 1, 1, 2, 17.2854), -- High-Grade Life Stone - Level 82
-- Sel Mahum Soldier
(22785, 10398, 1, 1, -1, 282), -- Icarus Disperser Piece
(22785, 1894, 1, 1, -1, 23092), -- Crafted Leather
(22785, 10374, 1, 1, -1, 42), -- Recipe - Icarus Disperser (60%)
(22785, 57, 160, 326, 0, 700000), -- Adena
(22785, 10216, 1, 1, 1, 0.20986), -- Icarus Disperser
(22785, 10398, 1, 1, 1, 69.79014), -- Icarus Disperser Piece
(22785, 1894, 1, 1, 2, 1624.919075), -- Crafted Leather
(22785, 4039, 1, 1, 2, 1543.67395), -- Mold Glue
(22785, 4041, 1, 1, 2, 402.69515), -- Mold Hardener
(22785, 4044, 1, 1, 2, 1543.67395), -- Thons
(22785, 10483, 1, 1, 2, 321.5992), -- Life Stone - Level 82
(22785, 10484, 1, 1, 2, 80.3998), -- Mid-Grade Life Stone - Level 82
(22785, 10485, 1, 1, 2, 8.038875), -- High-Grade Life Stone - Level 82
-- Sel Mahum Squad Leader
(22786, 10401, 1, 1, -1, 1455), -- Icarus Trident Piece
(22786, 1894, 1, 1, -1, 119474), -- Crafted Leather
(22786, 10377, 1, 1, -1, 219), -- Recipe - Icarus Trident (60%)
(22786, 57, 826, 1689, 0, 700000), -- Adena
(22786, 10219, 1, 1, 1, 1.08252), -- Icarus Trident
(22786, 10401, 1, 1, 1, 358.91748), -- Icarus Trident Piece
(22786, 1895, 1, 1, 2, 68463.37751), -- Metallic Fiber
(22786, 4040, 1, 1, 2, 4792.424648), -- Mold Lubricant
(22786, 9628, 1, 1, 2, 1879.406848), -- Leonard
(22786, 9630, 1, 1, 2, 1261.156116), -- Orichalcum
(22786, 10483, 1, 1, 2, 1664.031974), -- Life Stone - Level 82
(22786, 10484, 1, 1, 2, 415.988364), -- Mid-Grade Life Stone - Level 82
(22786, 10485, 1, 1, 2, 41.61454), -- High-Grade Life Stone - Level 82
-- Sel Mahum Squad Leader
(22787, 15654, 1, 1, -1, 7016), -- Sealed Moirai Gauntlet Piece
(22787, 15655, 1, 1, -1, 7016), -- Sealed Moirai Leather Gloves Piece
(22787, 15656, 1, 1, -1, 7016), -- Sealed Moirai Gloves Piece
(22787, 15657, 1, 1, -1, 7016), -- Sealed Moirai Boots Piece
(22787, 15658, 1, 1, -1, 7016), -- Sealed Moirai Leather Boots Piece
(22787, 15659, 1, 1, -1, 7016), -- Sealed Moirai Shoes Piece
(22787, 960, 1, 1, -1, 314), -- Scroll: Enchant Armor (S-Grade)
(22787, 15784, 1, 1, -1, 933), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22787, 15785, 1, 1, -1, 933), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22787, 15786, 1, 1, -1, 933), -- Recipe - Sealed Moirai Gloves (60%) 
(22787, 15787, 1, 1, -1, 933), -- Recipe - Sealed Moirai Boots (60%) 
(22787, 15788, 1, 1, -1, 933), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22787, 15789, 1, 1, -1, 933), -- Recipe - Sealed Moirai Shoes (60%) 
(22787, 57, 826, 1689, 0, 700000), -- Adena
(22787, 15703, 1, 1, 1, 3.320746), -- Sealed Moirai Gauntlet 
(22787, 15704, 1, 1, 1, 3.320746), -- Sealed Moirai Leather Gloves 
(22787, 15705, 1, 1, 1, 3.320746), -- Sealed Moirai Gloves 
(22787, 15706, 1, 1, 1, 3.320746), -- Sealed Moirai Boots 
(22787, 15707, 1, 1, 1, 3.320746), -- Sealed Moirai Leather Boots 
(22787, 15708, 1, 1, 1, 3.320746), -- Sealed Moirai Shoes 
(22787, 15654, 1, 1, 1, 1248.840912), -- Sealed Moirai Gauntlet Piece
(22787, 15655, 1, 1, 1, 1248.840912), -- Sealed Moirai Leather Gloves Piece
(22787, 15656, 1, 1, 1, 1248.840912), -- Sealed Moirai Gloves Piece
(22787, 15657, 1, 1, 1, 1248.840912), -- Sealed Moirai Boots Piece
(22787, 15658, 1, 1, 1, 1248.840912), -- Sealed Moirai Leather Boots Piece
(22787, 15659, 1, 1, 1, 1248.870964), -- Sealed Moirai Shoes Piece
(22787, 1895, 1, 1, 2, 36864.395636), -- Metallic Fiber
(22787, 4040, 1, 1, 2, 2580.518926), -- Mold Lubricant
(22787, 9628, 1, 1, 2, 1011.956348), -- Leonard
(22787, 9630, 1, 1, 2, 679.07256), -- Orichalcum
(22787, 10483, 1, 1, 2, 896.012916), -- Life Stone - Level 82
(22787, 10484, 1, 1, 2, 223.98163), -- Mid-Grade Life Stone - Level 82
(22787, 10485, 1, 1, 2, 22.419762), -- High-Grade Life Stone - Level 82
(22787, 15784, 1, 1, 2, 153.266504), -- Recipe - Sealed Moirai Gauntlet (60%) 
(22787, 15785, 1, 1, 2, 153.266504), -- Recipe - Sealed Moirai Leather Gloves (60%) 
(22787, 15786, 1, 1, 2, 153.266504), -- Recipe - Sealed Moirai Gloves (60%) 
(22787, 15787, 1, 1, 2, 153.266504), -- Recipe - Sealed Moirai Boots (60%) 
(22787, 15788, 1, 1, 2, 153.266504), -- Recipe - Sealed Moirai Leather Boots (60%) 
(22787, 15789, 1, 1, 2, 153.309702), -- Recipe - Sealed Moirai Shoes (60%) 
-- Sel Mahum Squad Leader
(22788, 15645, 1, 1, -1, 5511), -- Sealed Moirai Helmet Piece
(22788, 15646, 1, 1, -1, 5511), -- Sealed Moirai Leather Helmet Piece
(22788, 15647, 1, 1, -1, 5511), -- Sealed Moirai Circlet Piece
(22788, 15693, 1, 1, -1, 9879), -- Sealed Moirai Shield Piece
(22788, 15692, 1, 1, -1, 9879), -- Sealed Moirai Sigil Piece
(22788, 1894, 1, 1, -1, 32584), -- Crafted Leather
(22788, 15775, 1, 1, -1, 735), -- Recipe - Sealed Moirai Helmet (60%) 
(22788, 15776, 1, 1, -1, 735), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22788, 15777, 1, 1, -1, 735), -- Recipe - Sealed Moirai Circlet (60%) 
(22788, 15791, 1, 1, -1, 1051), -- Recipe - Sealed Moirai Shield (60%) 
(22788, 15790, 1, 1, -1, 1051), -- Recipe - Sealed Moirai Sigil (60%) 
(22788, 57, 826, 1689, 0, 700000), -- Adena
(22788, 15694, 1, 1, 1, 2.656704), -- Sealed Moirai Helmet 
(22788, 15695, 1, 1, 1, 2.656704), -- Sealed Moirai Leather Helmet 
(22788, 15696, 1, 1, 1, 2.656704), -- Sealed Moirai Circlet 
(22788, 15710, 1, 1, 1, 3.800928), -- Sealed Moirai Shield 
(22788, 15709, 1, 1, 1, 3.800928), -- Sealed Moirai Sigil 
(22788, 15645, 1, 1, 1, 996.250848), -- Sealed Moirai Helmet Piece
(22788, 15646, 1, 1, 1, 996.250848), -- Sealed Moirai Leather Helmet Piece
(22788, 15647, 1, 1, 1, 996.250848), -- Sealed Moirai Circlet Piece
(22788, 15693, 1, 1, 1, 1785.837744), -- Sealed Moirai Shield Piece
(22788, 15692, 1, 1, 1, 1785.837744), -- Sealed Moirai Sigil Piece
(22788, 1895, 1, 1, 2, 39936.5023), -- Metallic Fiber
(22788, 4040, 1, 1, 2, 2795.5468), -- Mold Lubricant
(22788, 9628, 1, 1, 2, 1096.3129), -- Leonard
(22788, 9630, 1, 1, 2, 735.6751), -- Orichalcum
(22788, 10483, 1, 1, 2, 970.66565), -- Life Stone - Level 82
(22788, 10484, 1, 1, 2, 242.6548), -- Mid-Grade Life Stone - Level 82
(22788, 10485, 1, 1, 2, 24.2469), -- High-Grade Life Stone - Level 82
(22788, 15775, 1, 1, 2, 110.69035), -- Recipe - Sealed Moirai Helmet (60%) 
(22788, 15776, 1, 1, 2, 110.69035), -- Recipe - Sealed Moirai Leather Helmet(60%) 
(22788, 15777, 1, 1, 2, 110.69035), -- Recipe - Sealed Moirai Circlet (60%) 
(22788, 15791, 1, 1, 2, 158.1158), -- Recipe - Sealed Moirai Shield (60%) 
(22788, 15790, 1, 1, 2, 158.2087), -- Recipe - Sealed Moirai Sigil (60%) 
-- Guide Solina
(22789, 15634, 1, 1, -1, 987), -- Vesper Cutter Piece
(22789, 15635, 1, 1, -1, 986), -- Vesper Slasher Piece
(22789, 15636, 1, 1, -1, 987), -- Vesper Buster Piece
(22789, 1894, 1, 1, -1, 58327), -- Crafted Leather
(22789, 15815, 1, 1, -1, 116), -- Recipe - Sealed Vesper Cutter (60%)
(22789, 15816, 1, 1, -1, 116), -- Recipe - Sealed Vesper Slasher (60%)
(22789, 15817, 1, 1, -1, 116), -- Recipe - Vesper Buster (60%)
(22789, 57, 949, 1916, 0, 700000), -- Adena
(22789, 13457, 1, 1, 1, 0.444176), -- Vesper Cutter
(22789, 13458, 1, 1, 1, 0.444176), -- Vesper Slasher
(22789, 13459, 1, 1, 1, 0.444176), -- Vesper Buster
(22789, 15634, 1, 1, 1, 189.001432), -- Vesper Cutter Piece
(22789, 15635, 1, 1, 1, 188.665176), -- Vesper Slasher Piece
(22789, 15636, 1, 1, 1, 189.000864), -- Vesper Buster Piece
(22789, 1895, 1, 1, 2, 68239.497935), -- Metallic Fiber
(22789, 4040, 1, 1, 2, 4776.785825), -- Mold Lubricant
(22789, 9628, 1, 1, 2, 1873.202135), -- Leonard
(22789, 9630, 1, 1, 2, 1257.008025), -- Orichalcum
(22789, 14166, 1, 1, 2, 1153.79124), -- Life Stone - Level 84
(22789, 14167, 1, 1, 2, 288.13715), -- Mid-Grade Life Stone - Level 84
(22789, 14168, 1, 1, 2, 28.813715), -- High-Grade Life Stone - Level 84
(22789, 9557, 1, 1, 2, 47.763975), -- Holy Crystal
(22789, 15690, 1, 1, 3, 1000), -- Secret Key
(22789, 15540, 1, 1, 3, 1000), -- Unlit Torchlight
-- Seeker Solina
(22790, 15640, 1, 1, -1, 945), -- Vesper Avenger Piece
(22790, 15641, 1, 1, -1, 956), -- Vesper Retributer Piece
(22790, 15642, 1, 1, -1, 945), -- Vesper Caster Piece
(22790, 15643, 1, 1, -1, 947), -- Vesper Singer Piece
(22790, 15821, 1, 1, -1, 112), -- Recipe - Vesper Avenger (60%)
(22790, 15822, 1, 1, -1, 112), -- Recipe - Vesper Retributer (60%)
(22790, 15823, 1, 1, -1, 112), -- Recipe - Vesper Caster (60%)
(22790, 15824, 1, 1, -1, 112), -- Recipe - Vesper Singer (60%)
(22790, 57, 1047, 2114, 0, 700000), -- Adena
(22790, 13463, 1, 1, 1, 0.367536), -- Vesper Avenger
(22790, 13464, 1, 1, 1, 0.367536), -- Vesper Retributer
(22790, 13465, 1, 1, 1, 0.367536), -- Vesper Caster
(22790, 13466, 1, 1, 1, 0.367536), -- Vesper Singer
(22790, 15640, 1, 1, 1, 155.078976), -- Vesper Avenger Piece
(22790, 15641, 1, 1, 1, 156.881088), -- Vesper Retributer Piece
(22790, 15642, 1, 1, 1, 155.078976), -- Vesper Caster Piece
(22790, 15643, 1, 1, 1, 155.490816), -- Vesper Singer Piece
(22790, 1895, 1, 1, 2, 75269.488574), -- Metallic Fiber
(22790, 4040, 1, 1, 2, 5268.88733), -- Mold Lubricant
(22790, 9628, 1, 1, 2, 2066.178254), -- Leonard
(22790, 9630, 1, 1, 2, 1386.50421), -- Orichalcum
(22790, 14166, 1, 1, 2, 1272.654096), -- Life Stone - Level 84
(22790, 14167, 1, 1, 2, 317.82086), -- Mid-Grade Life Stone - Level 84
(22790, 14168, 1, 1, 2, 31.782086), -- High-Grade Life Stone - Level 84
(22790, 9557, 1, 1, 2, 52.68459), -- Holy Crystal
(22790, 15690, 1, 1, 3, 1000), -- Secret Key
(22790, 15540, 1, 1, 3, 1000), -- Unlit Torchlight
-- Savior Solina
(22791, 15638, 1, 1, -1, 1843), -- Vesper Fighter Piece
(22791, 959, 1, 1, -1, 125), -- Scroll: Enchant Weapon (S-Grade)
(22791, 960, 1, 1, -1, 1252), -- Scroll: Enchant Armor (S-Grade)
(22791, 15819, 1, 1, -1, 218), -- Recipe - Vesper Fighter (60%)
(22791, 57, 1021, 2062, 0, 700000), -- Adena
(22791, 13461, 1, 1, 1, 1.434341), -- Vesper Fighter
(22791, 15638, 1, 1, 1, 605.565659), -- Vesper Fighter Piece
(22791, 1895, 1, 1, 2, 73427.48858), -- Metallic Fiber
(22791, 4040, 1, 1, 2, 5139.91862), -- Mold Lubricant
(22791, 4042, 1, 1, 2, 4283.29652), -- Enria
(22791, 4043, 1, 1, 2, 8566.50003), -- Asofe
(22791, 14166, 1, 1, 2, 1241.49748), -- Life Stone - Level 84
(22791, 14167, 1, 1, 2, 310.00233), -- Mid-Grade Life Stone - Level 84
(22791, 14168, 1, 1, 2, 30.97233), -- High-Grade Life Stone - Level 84
(22791, 959, 1, 1, 2, 10.32411), -- Scroll: Enchant Weapon (S-Grade)
(22791, 15690, 1, 1, 3, 1000), -- Secret Key
(22791, 15540, 1, 1, 3, 1000), -- Unlit Torchlight
-- Disciple Solina
(22792, 15644, 1, 1, -1, 2519), -- Vesper Thrower Piece
(22792, 9628, 1, 1, -1, 33117), -- Leonard
(22792, 15825, 1, 1, -1, 295), -- Recipe - Vesper Thrower (60%)
(22792, 57, 1033, 2086, 0, 700000), -- Adena
(22792, 13467, 1, 1, 1, 1.451126), -- Vesper Thrower
(22792, 15644, 1, 1, 1, 620.548874), -- Vesper Thrower Piece
(22792, 1895, 1, 1, 2, 74287.208342), -- Metallic Fiber
(22792, 4040, 1, 1, 2, 5200.098938), -- Mold Lubricant
(22792, 4042, 1, 1, 2, 4333.447148), -- Enria
(22792, 4043, 1, 1, 2, 8666.800197), -- Asofe
(22792, 14166, 1, 1, 2, 1256.033452), -- Life Stone - Level 84
(22792, 14167, 1, 1, 2, 313.631967), -- Mid-Grade Life Stone - Level 84
(22792, 14168, 1, 1, 2, 31.334967), -- High-Grade Life Stone - Level 84
(22792, 959, 1, 1, 2, 10.444989), -- Scroll: Enchant Weapon (S-Grade)
(22792, 15690, 1, 1, 3, 1000), -- Secret Key
(22792, 15540, 1, 1, 3, 1000), -- Unlit Torchlight
-- Ascetic Solina
(22793, 15637, 1, 1, -1, 2612), -- Vesper Shaper Piece
(22793, 959, 1, 1, -1, 176), -- Scroll: Enchant Weapon (S-Grade)
(22793, 15818, 1, 1, -1, 307), -- Recipe - Vesper Shaper (60%)
(22793, 57, 1076, 2172, 0, 700000), -- Adena
(22793, 13460, 1, 1, 1, 1.511235), -- Vesper Shaper
(22793, 15637, 1, 1, 1, 643.488765), -- Vesper Shaper Piece
(22793, 1895, 1, 1, 2, 77357.009504), -- Metallic Fiber
(22793, 4040, 1, 1, 2, 5414.996832), -- Mold Lubricant
(22793, 9628, 1, 1, 2, 2123.55408), -- Leonard
(22793, 9630, 1, 1, 2, 1424.9528), -- Orichalcum
(22793, 14166, 1, 1, 2, 1307.961312), -- Life Stone - Level 84
(22793, 14167, 1, 1, 2, 326.571872), -- Mid-Grade Life Stone - Level 84
(22793, 14168, 1, 1, 2, 32.683616), -- High-Grade Life Stone - Level 84
(22793, 960, 1, 1, 2, 108.269984), -- Scroll: Enchant Armor (S-Grade)
(22793, 15690, 1, 1, 3, 1000), -- Secret Key
(22793, 15540, 1, 1, 3, 1000), -- Unlit Torchlight
-- Divinity Judge
(22794, 15639, 1, 1, -1, 13732), -- Vesper Stormer Piece
(22794, 959, 1, 1, -1, 922), -- Scroll: Enchant Weapon (S-Grade)
(22794, 15820, 1, 1, -1, 1608), -- Recipe - Vesper Stormer (60%)
(22794, 57, 5594, 11432, 0, 700000), -- Adena
(22794, 13462, 1, 1, 1, 7.91904), -- Vesper Stormer
(22794, 15639, 1, 1, 1, 3382.08096), -- Vesper Stormer Piece
(22794, 1895, 1, 1, 2, 405501.727705), -- Metallic Fiber
(22794, 4040, 1, 1, 2, 28385.153265), -- Mold Lubricant
(22794, 9628, 1, 1, 2, 11131.568475), -- Leonard
(22794, 9630, 1, 1, 2, 7469.534125), -- Orichalcum
(22794, 14166, 1, 1, 2, 6856.270365), -- Life Stone - Level 84
(22794, 14167, 1, 1, 2, 1711.874065), -- Mid-Grade Life Stone - Level 84
(22794, 14168, 1, 1, 2, 171.325945), -- High-Grade Life Stone - Level 84
(22794, 960, 1, 1, 2, 567.546055), -- Scroll: Enchant Armor (S-Grade)
(22794, 15690, 1, 1, 3, 10500), -- Secret Key
(22794, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22794, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Divinity Manager
(22795, 15663, 1, 1, -1, 26096), -- Sealed Vesper Breastplate Piece
(22795, 15666, 1, 1, -1, 42035), -- Sealed Vesper Gaiter Piece
(22795, 9628, 1, 1, -1, 113082), -- Leonard
(22795, 15795, 1, 1, -1, 3089), -- Recipe - Sealed Vesper Breastplate (60%) 
(22795, 15798, 1, 1, -1, 4943), -- Recipe - Sealed Vesper Gaiter (60%) 
(22795, 57, 5832, 11919, 0, 700000), -- Adena
(22795, 14105, 1, 1, 1, 12.68267), -- Sealed Vesper Breastplate
(22795, 15663, 1, 1, 1, 5355.09975), -- Sealed Vesper Breastplate Piece
(22795, 14108, 1, 1, 1, 20.292272), -- Sealed Vesper Gaiters
(22795, 15666, 1, 1, 1, 8625.925308), -- Sealed Vesper Gaiter Piece
(22795, 1879, 1, 1, 2, 179354.438224), -- Cokes
(22795, 1885, 1, 1, 2, 89677.219112), -- High-Grade Suede
(22795, 9628, 1, 1, 2, 8440.188016), -- Leonard
(22795, 9630, 1, 1, 2, 5663.895848), -- Orichalcum
(22795, 9629, 1, 1, 2, 4678.921832), -- Adamantine
(22795, 14166, 1, 1, 2, 5198.572392), -- Life Stone - Level 84
(22795, 14167, 1, 1, 2, 1298.240632), -- Mid-Grade Life Stone - Level 84
(22795, 14168, 1, 1, 2, 129.91264), -- High-Grade Life Stone - Level 84
(22795, 15795, 1, 1, 2, 230.594936), -- Recipe - Sealed Vesper Breastplate (60%) 
(22795, 15798, 1, 1, 2, 369.07), -- Recipe - Sealed Vesper Gaiter (60%) 
(22795, 9557, 1, 1, 2, 214.946368), -- Holy Crystal
(22795, 15690, 1, 1, 3, 10500), -- Secret Key
(22795, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22795, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Divinity Supervisor
(22796, 15664, 1, 1, -1, 37946), -- Sealed Vesper Leather Breastplate Piece
(22796, 15670, 1, 1, -1, 58481), -- Sealed Vesper Leather Legging Piece
(22796, 9630, 1, 1, -1, 84181), -- Orichalcum
(22796, 15796, 1, 1, -1, 4570), -- Recipe - Sealed Vesper Leather Breastplate (60%) 
(22796, 15799, 1, 1, -1, 7311), -- Recipe - Sealed Vesper Leather Legging (60%) 
(22796, 57, 6469, 13222, 0, 700000), -- Adena
(22796, 14106, 1, 1, 1, 18.75918), -- Sealed Vesper Leather Breastplate
(22796, 14112, 1, 1, 1, 30.00279), -- Sealed Vesper Leather Leggings
(22796, 15664, 1, 1, 1, 7784.42514), -- Sealed Vesper Leather Breastplate Piece
(22796, 15670, 1, 1, 1, 11996.81289), -- Sealed Vesper Leather Legging Piece
(22796, 1879, 1, 1, 2, 198965.627766), -- Cokes
(22796, 1885, 1, 1, 2, 99482.977764), -- High-Grade Suede
(22796, 9628, 1, 1, 2, 9363.177054), -- Leonard
(22796, 9630, 1, 1, 2, 6283.19754), -- Orichalcum
(22796, 9629, 1, 1, 2, 5190.439032), -- Adamantine
(22796, 14166, 1, 1, 2, 5766.97239), -- Life Stone - Level 84
(22796, 14167, 1, 1, 2, 1440.186228), -- Mid-Grade Life Stone - Level 84
(22796, 14168, 1, 1, 2, 143.887518), -- High-Grade Life Stone - Level 84
(22796, 15796, 1, 1, 2, 341.200242), -- Recipe - Sealed Vesper Leather Breastplate (60%) 
(22796, 15799, 1, 1, 2, 545.72373), -- Recipe - Sealed Vesper Leather Legging (60%) 
(22796, 9557, 1, 1, 2, 238.610736), -- Holy Crystal
(22796, 15690, 1, 1, 3, 10500), -- Secret Key
(22796, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22796, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Divinity Worshipper
(22797, 15665, 1, 1, -1, 35390), -- Sealed Vesper Tunic Piece
(22797, 15673, 1, 1, -1, 54541), -- Sealed Vesper Stockings Piece
(22797, 9628, 1, 1, -1, 116995), -- Leonard
(22797, 15797, 1, 1, -1, 4262), -- Recipe - Sealed Vesper Tunic (60%) 
(22797, 15800, 1, 1, -1, 6819), -- Recipe - Sealed Vesper Stockings (60%) 
(22797, 57, 6033, 12331, 0, 700000), -- Adena
(22797, 14107, 1, 1, 1, 17.495324), -- Sealed Vesper Tunic
(22797, 14115, 1, 1, 1, 27.981422), -- Sealed Vesper Stockings
(22797, 15665, 1, 1, 1, 7259.967652), -- Sealed Vesper Tunic Piece
(22797, 15673, 1, 1, 1, 11188.555602), -- Sealed Vesper Stockings Piece
(22797, 1895, 1, 1, 2, 388793.340716), -- Metallic Fiber
(22797, 4040, 1, 1, 2, 27215.454068), -- Mold Lubricant
(22797, 9628, 1, 1, 2, 10672.631486), -- Leonard
(22797, 9630, 1, 1, 2, 7161.774972), -- Orichalcum
(22797, 14166, 1, 1, 2, 6573.603454), -- Life Stone - Level 84
(22797, 14167, 1, 1, 2, 1641.295502), -- Mid-Grade Life Stone - Level 84
(22797, 14168, 1, 1, 2, 163.99658), -- High-Grade Life Stone - Level 84
(22797, 15797, 1, 1, 2, 388.716218), -- Recipe - Sealed Vesper Tunic (60%) 
(22797, 15800, 1, 1, 2, 623.187004), -- Recipe - Sealed Vesper Stockings (60%) 
(22797, 15690, 1, 1, 3, 10500), -- Secret Key
(22797, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22797, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Divinity Protector
(22798, 15770, 1, 1, -1, 142869), -- Sealed Vesper Earring Gem
(22798, 15771, 1, 1, -1, 102788), -- Sealed Vesper Necklace Gem
(22798, 15769, 1, 1, -1, 237865), -- Sealed Vesper Ring Gem
(22798, 15810, 1, 1, -1, 19937), -- Recipe - Sealed Vesper Earring (70%) 
(22798, 15811, 1, 1, -1, 14953), -- Recipe - Sealed Vesper Necklace (70%) 
(22798, 15809, 1, 1, -1, 29905), -- Recipe - Sealed Vesper Ring (70%) 
(22798, 57, 11026, 22534, 0, 700000), -- Adena
(22798, 14160, 1, 1, 1, 65.473944), -- Sealed Vesper Earring
(22798, 14161, 1, 1, 1, 49.145284), -- Sealed Vesper Necklace
(22798, 14162, 1, 1, 1, 98.290568), -- Sealed Vesper Ring
(22798, 15770, 1, 1, 1, 23472.24962), -- Sealed Vesper Earring Gem
(22798, 15771, 1, 1, 1, 16887.339128), -- Sealed Vesper Necklace Gem
(22798, 15769, 1, 1, 1, 39079.501456), -- Sealed Vesper Ring Gem
(22798, 1879, 1, 3, 2, 155419.66176), -- Cokes
(22798, 1885, 1, 1, 2, 155419.66176), -- High-Grade Suede
(22798, 9628, 1, 1, 2, 14627.563192), -- Leonard
(22798, 9630, 1, 1, 2, 9816.130456), -- Orichalcum
(22798, 9629, 1, 1, 2, 8108.836241), -- Adamantine
(22798, 14166, 1, 1, 2, 9009.898172), -- Life Stone - Level 84
(22798, 14167, 1, 1, 2, 2249.589991), -- Mid-Grade Life Stone - Level 84
(22798, 14168, 1, 1, 2, 224.995056), -- High-Grade Life Stone - Level 84
(22798, 15809, 1, 1, 2, 2455.114321), -- Recipe - Sealed Vesper Ring (70%) 
(22798, 15810, 1, 1, 2, 1636.98326), -- Recipe - Sealed Vesper Earring (70%) 
(22798, 15811, 1, 1, 2, 1227.737445), -- Recipe - Sealed Vesper Necklace (70%) 
(22798, 9557, 1, 1, 2, 372.828346), -- Holy Crystal
(22798, 15690, 1, 1, 3, 10500), -- Secret Key
(22798, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22798, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Divinity Fighter
(22799, 15667, 1, 1, -1, 81546), -- Sealed Vesper Gauntlet Piece
(22799, 15671, 1, 1, -1, 81546), -- Sealed Vesper Leather Gloves Piece
(22799, 15674, 1, 1, -1, 81546), -- Sealed Vesper Gloves Piece
(22799, 15668, 1, 1, -1, 81546), -- Sealed Vesper Boots Piece
(22799, 15672, 1, 1, -1, 81546), -- Sealed Vesper Leather Boots Piece
(22799, 15675, 1, 1, -1, 81546), -- Sealed Vesper Shoes Piece
(22799, 9630, 1, 1, -1, 56009), -- Orichalcum
(22799, 15801, 1, 1, -1, 9121), -- Recipe - Sealed Vesper Gauntlet (60%) 
(22799, 15802, 1, 1, -1, 9121), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(22799, 15803, 1, 1, -1, 9121), -- Recipe - Sealed Vesper Gloves (60%) 
(22799, 15804, 1, 1, -1, 9121), -- Recipe - Sealed Vesper Boots (60%) 
(22799, 15805, 1, 1, -1, 9121), -- Recipe - Sealed Vesper Leather Boots (60%) 
(22799, 15806, 1, 1, -1, 9121), -- Recipe - Sealed Vesper Shoes (60%) 
(22799, 57, 11191, 22872, 0, 700000), -- Adena
(22799, 14109, 1, 1, 1, 32.451048), -- Sealed Vesper Gauntlet
(22799, 14113, 1, 1, 1, 32.451048), -- Sealed Vesper Leather Gloves
(22799, 14116, 1, 1, 1, 32.451048), -- Sealed Vesper Gloves
(22799, 14110, 1, 1, 1, 32.451048), -- Sealed Vesper Boots
(22799, 14114, 1, 1, 1, 32.451048), -- Sealed Vesper Leather Boots
(22799, 14117, 1, 1, 1, 32.451048), -- Sealed Vesper Shoes
(22799, 15667, 1, 1, 1, 14506.57803), -- Sealed Vesper Gauntlet Piece
(22799, 15671, 1, 1, 1, 14506.57803), -- Sealed Vesper Leather Gloves Piece
(22799, 15674, 1, 1, 1, 14506.57803), -- Sealed Vesper Gloves Piece
(22799, 15668, 1, 1, 1, 14506.57803), -- Sealed Vesper Boots Piece
(22799, 15672, 1, 1, 1, 14506.57803), -- Sealed Vesper Leather Boots Piece
(22799, 15675, 1, 1, 1, 14506.403562), -- Sealed Vesper Shoes Piece
(22799, 1879, 1, 1, 2, 270432.400482), -- Cokes
(22799, 1885, 1, 1, 2, 135216.426394), -- High-Grade Suede
(22799, 9628, 1, 1, 2, 12726.081616), -- Leonard
(22799, 9630, 1, 1, 2, 8539.989586), -- Orichalcum
(22799, 9629, 1, 1, 2, 7054.616682), -- Adamantine
(22799, 14166, 1, 1, 2, 7838.46298), -- Life Stone - Level 84
(22799, 14167, 1, 1, 2, 1957.128062), -- Mid-Grade Life Stone - Level 84
(22799, 14168, 1, 1, 2, 195.848498), -- High-Grade Life Stone - Level 84
(22799, 15801, 1, 1, 2, 1390.84095), -- Recipe - Sealed Vesper Gauntlet (60%) 
(22799, 15802, 1, 1, 2, 1390.84095), -- Recipe - Sealed Vesper Leather Gloves (60%) 
(22799, 15803, 1, 1, 2, 1390.84095), -- Recipe - Sealed Vesper Gloves (60%) 
(22799, 15804, 1, 1, 2, 1390.84095), -- Recipe - Sealed Vesper Boots (60%) 
(22799, 15805, 1, 1, 2, 1390.84095), -- Recipe - Sealed Vesper Leather Boots (60%) 
(22799, 15806, 1, 1, 2, 1390.84095), -- Recipe - Sealed Vesper Shoes (60%) 
(22799, 15690, 1, 1, 3, 10500), -- Secret Key
(22799, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22799, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Divinity Magus
(22800, 15660, 1, 1, -1, 67556), -- Sealed Vesper Helmet Piece
(22800, 15661, 1, 1, -1, 67556), -- Sealed Vesper Leather Helmet Piece
(22800, 15662, 1, 1, -1, 67556), -- Sealed Vesper Circlet Piece
(22800, 15669, 1, 1, -1, 99846), -- Sealed Vesper Verteidiger Piece
(22800, 15691, 1, 1, -1, 99846), -- Sealed Vesper Sigil Piece
(22800, 15792, 1, 1, -1, 8416), -- Recipe - Sealed Vesper Helmet (60%) 
(22800, 15793, 1, 1, -1, 8416), -- Recipe - Sealed Vesper Leather Helmet (60%) 
(22800, 15794, 1, 1, -1, 8416), -- Recipe - Sealed Vesper Circlet (60%) 
(22800, 15808, 1, 1, -1, 12022), -- Recipe - Sealed Vesper Shield (60%) 
(22800, 15807, 1, 1, -1, 12022), -- Recipe - Sealed Vesper Sigil (60%) 
(22800, 57, 11913, 24348, 0, 700000), -- Adena
(22800, 13143, 1, 1, 1, 27.637509), -- Sealed Vesper Helmet
(22800, 13144, 1, 1, 1, 27.637509), -- Sealed Vesper Leather Helmet
(22800, 13145, 1, 1, 1, 27.637509), -- Sealed Vesper Circlet
(22800, 14111, 1, 1, 1, 39.501092), -- Sealed Vesper Shield
(22800, 13887, 1, 1, 1, 39.501092), -- Sealed Vesper Sigil
(22800, 15660, 1, 1, 1, 11100.668453), -- Sealed Vesper Helmet Piece
(22800, 15661, 1, 1, 1, 11100.668453), -- Sealed Vesper Leather Helmet Piece
(22800, 15662, 1, 1, 1, 11100.668453), -- Sealed Vesper Circlet Piece
(22800, 15669, 1, 1, 1, 16406.473688), -- Sealed Vesper Verteidiger Piece
(22800, 15691, 1, 1, 1, 16406.606242), -- Sealed Vesper Sigil Piece
(22800, 1879, 1, 3, 2, 155017.000272), -- Cokes
(22800, 1885, 1, 1, 2, 155017.000272), -- High-Grade Suede
(22800, 9628, 1, 1, 2, 14589.932781), -- Leonard
(22800, 9630, 1, 1, 2, 9790.494306), -- Orichalcum
(22800, 9629, 1, 1, 2, 8087.909265), -- Adamantine
(22800, 14166, 1, 1, 2, 8986.56585), -- Life Stone - Level 84
(22800, 14167, 1, 1, 2, 2243.94009), -- Mid-Grade Life Stone - Level 84
(22800, 14168, 1, 1, 2, 224.394009), -- High-Grade Life Stone - Level 84
(22800, 15792, 1, 1, 2, 1062.900033), -- Recipe - Sealed Vesper Helmet (60%) 
(22800, 15793, 1, 1, 2, 1062.900033), -- Recipe - Sealed Vesper Leather Helmet (60%) 
(22800, 15794, 1, 1, 2, 1062.900033), -- Recipe - Sealed Vesper Circlet (60%) 
(22800, 15808, 1, 1, 2, 1518.531528), -- Recipe - Sealed Vesper Shield (60%) 
(22800, 15807, 1, 1, 2, 1518.531528), -- Recipe - Sealed Vesper Sigil (60%) 
(22800, 15690, 1, 1, 3, 10500), -- Secret Key
(22800, 15540, 1, 1, 3, 10500), -- Unlit Torchlight
(22800, 8056, 1, 1, 3, 49000), -- Key of Splendor Room
-- Cruel Pincer Golem
(22801, 5162, 1, 1, -1, 858), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22801, 6701, 1, 1, -1, 10276), -- Sealed Imperial Crusader Breastplate Part
(22801, 6702, 1, 1, -1, 13228), -- Sealed Imperial Crusader Gaiters Pattern
(22801, 9630, 1, 1, -1, 10158), -- Orichalcum
(22801, 57, 1294, 2643, 0, 700000), -- Adena
(22801, 6364, 1, 1, 1, 2), -- Forgotten Blade
(22801, 6372, 1, 1, 1, 2), -- Heaven's Divider
(22801, 1895, 1, 1, 2, 67871.4985), -- Metallic Fiber
(22801, 4040, 1, 1, 2, 4751.0125), -- Mold Lubricant
(22801, 4042, 1, 1, 2, 3959.163), -- Enria
(22801, 4043, 1, 1, 2, 7918.326), -- Asofe
-- Cruel Pincer Golem
(22802, 6688, 1, 1, -1, 3844), -- Forgotten Blade Edge
(22802, 6696, 1, 1, -1, 3905), -- Heavens Divider Edge
(22802, 6711, 1, 1, -1, 8811), -- Sealed Major Arcana Robe Part
(22802, 57, 894, 1826, 0, 700000), -- Adena
(22802, 6366, 1, 1, 1, 0.75), -- Imperial Staff
(22802, 6369, 1, 1, 1, 0.75), -- Dragon Hunter Axe
(22802, 6365, 1, 1, 1, 0.75), -- Basalt Battlehammer
(22802, 6579, 1, 1, 1, 0.75), -- Arcana Mace
(22802, 1894, 1, 1, 2, 5759.85608), -- Crafted Leather
(22802, 4039, 1, 1, 2, 5471.863276), -- Mold Glue
(22802, 4041, 1, 1, 2, 1427.435499), -- Mold Hardener
(22802, 4044, 1, 1, 2, 5471.845145), -- Thons
-- Cruel Pincer Golem
(22803, 6694, 1, 1, -1, 3866), -- Saint Spear Blade
(22803, 5272, 1, 1, -1, 781), -- Recipe: Greater Soulshot (S) Compressed Package(100%)
(22803, 6691, 1, 1, -1, 3798), -- Angel Slayer Blade
(22803, 959, 1, 1, -1, 70), -- Scroll: Enchant Weapon (S-Grade)
(22803, 57, 1178, 2406, 0, 700000), -- Adena
(22803, 6371, 1, 1, 1, 4), -- Demon Splinter
(22803, 1894, 1, 1, 2, 7587.46912), -- Crafted Leather
(22803, 4039, 1, 1, 2, 7208.095664), -- Mold Glue
(22803, 4041, 1, 1, 2, 1880.363436), -- Mold Hardener
(22803, 4044, 1, 1, 2, 7208.07178), -- Thons
-- Horrifying Jackhammer Golem
(22804, 5277, 1, 1, -1, 1179), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22804, 6689, 1, 1, -1, 5626), -- Basalt Battlehammer Head
(22804, 6690, 1, 1, -1, 5745), -- Imperial Staff Head
(22804, 57, 1336, 2721, 0, 700000), -- Adena
(22804, 7575, 1, 1, 1, 5), -- Draconic Bow
(22804, 1895, 1, 1, 2, 55976.066854), -- Metallic Fiber
(22804, 4040, 1, 1, 2, 3918.351862), -- Mold Lubricant
(22804, 4042, 1, 1, 2, 3265.281602), -- Enria
(22804, 4043, 1, 1, 2, 6530.563204), -- Asofe
(22804, 959, 1, 1, 2, 7.736478), -- Scroll: Enchant Weapon (S-Grade)
-- Horrifying Jackhammer Golem
(22805, 6695, 1, 1, -1, 3888), -- Demon Splinter Blade
(22805, 7579, 1, 1, -1, 4009), -- Draconic Bow Shaft
(22805, 5282, 1, 1, -1, 815), -- Recipe: Greater Blessed Spiritshot (S) Compressed Package(100%)
(22805, 57, 924, 1880, 0, 700000), -- Adena
(22805, 6367, 1, 1, 1, 3), -- Angel Slayer
(22805, 1894, 1, 1, 2, 4750.13727), -- Crafted Leather
(22805, 4039, 1, 1, 2, 4512.619188), -- Mold Glue
(22805, 4041, 1, 1, 2, 1177.209558), -- Mold Hardener
(22805, 4044, 1, 1, 2, 4512.619188), -- Thons
(22805, 959, 1, 1, 2, 5.414796), -- Scroll: Enchant Weapon (S-Grade)
-- Horrifying Jackhammer Golem
(22806, 5529, 1, 1, -1, 4969), -- Dragon Slayer Edge
(22806, 1808, 1, 1, -1, 805), -- Recipe: Soulshot (S-Grade)
(22806, 5533, 1, 1, -1, 4968), -- Elysian Head
(22806, 959, 1, 1, -1, 72), -- Scroll: Enchant Weapon (S-Grade)
(22806, 57, 1217, 2477, 0, 700000), -- Adena
(22806, 6370, 1, 1, 1, 4), -- Saint Spear
(22806, 1894, 1, 1, 2, 6257.618325), -- Crafted Leather
(22806, 4039, 1, 1, 2, 5944.72263), -- Mold Glue
(22806, 4041, 1, 1, 2, 1550.803205), -- Mold Hardener
(22806, 4044, 1, 1, 2, 5944.72263), -- Thons
(22806, 959, 1, 1, 2, 7.13321), -- Scroll: Enchant Weapon (S-Grade)
-- Scout-type Golem No. 28
(22807, 6703, 1, 1, -1, 35837), -- Sealed Imperial Crusader Gauntlets Design
(22807, 6704, 1, 1, -1, 35837), -- Sealed Imperial Crusader Boots Design
(22807, 5277, 1, 1, -1, 1119), -- Recipe: Greater Spiritshot (S) Compressed Package(100%)
(22807, 57, 1266, 2585, 0, 700000), -- Adena
(22807, 6674, 1, 1, 1, 7.307628), -- Sealed Imperial Crusader Breastplate
(22807, 6675, 1, 1, 1, 11.692372), -- Sealed Imperial Crusader Gaiters
(22807, 1895, 1, 1, 2, 66383.144811), -- Metallic Fiber
(22807, 4040, 1, 1, 2, 4646.827575), -- Mold Lubricant
(22807, 4042, 1, 1, 2, 3872.342538), -- Enria
(22807, 4043, 1, 1, 2, 7744.685076), -- Asofe
-- Scout-type Golem No. 2
(22808, 3036, 1, 1, -1, 632), -- Recipe: Spiritshot S
(22808, 959, 1, 1, -1, 57), -- Scroll: Enchant Weapon (S-Grade)
(22808, 3957, 1, 1, -1, 632), -- Recipe: Blessed Spiritshot S
(22808, 57, 716, 1461, 0, 700000), -- Adena
(22808, 6680, 1, 1, 1, 7), -- Sealed Draconic Leather Armor
(22808, 1894, 1, 1, 2, 4607.9484), -- Crafted Leather
(22808, 4039, 1, 1, 2, 4377.55098), -- Mold Glue
(22808, 4041, 1, 1, 2, 1141.964145), -- Mold Hardener
(22808, 4044, 1, 1, 2, 4377.536475), -- Thons
-- Guard Golem
(22809, 6688, 1, 1, -1, 11477), -- Forgotten Blade Edge
(22809, 960, 1, 1, -1, 2124), -- Scroll: Enchant Armor (S-Grade)
(22809, 1894, 1, 1, -1, 186300), -- Crafted Leather
(22809, 57, 2675, 5446, 0, 700000), -- Adena
(22809, 6684, 1, 1, 1, 25), -- Sealed Major Arcana Robe
(22809, 1895, 1, 1, 2, 112025.516031), -- Metallic Fiber
(22809, 4040, 1, 1, 2, 7841.837439), -- Mold Lubricant
(22809, 9628, 1, 1, 2, 3075.25491), -- Leonard
(22809, 9630, 1, 1, 2, 2063.687544), -- Orichalcum
(22809, 960, 1, 1, 2, 156.704076), -- Scroll: Enchant Armor (S-Grade)
-- Micro Scout Golem
(22810, 6708, 1, 1, -1, 61449), -- Sealed Draconic Leather Gloves Fabric
(22810, 6709, 1, 1, -1, 61449), -- Sealed Draconic Leather Boots Design
(22810, 5157, 1, 1, -1, 1918), -- Recipe: Soulshot (S) Compressed Package (100%)
(22810, 57, 2171, 4432, 0, 700000), -- Adena
(22810, 6724, 1, 1, 1, 32.617154), -- Sealed Tateossian Earring
(22810, 6725, 1, 1, 1, 48.925678), -- Sealed Tateossian Ring
(22810, 6726, 1, 1, 1, 24.457168), -- Sealed Tateossian Necklace
(22810, 1895, 1, 1, 2, 113824.86624), -- Metallic Fiber
(22810, 4040, 1, 1, 2, 7967.715234), -- Mold Lubricant
(22810, 9628, 1, 1, 2, 3124.5444), -- Leonard
(22810, 9630, 1, 1, 2, 2096.874126), -- Orichalcum
-- Great Chaos Golem
(22811, 6712, 1, 1, -1, 107447), -- Sealed Major Arcana Gloves fabric
(22811, 5162, 1, 1, -1, 3354), -- Recipe: Spiritshot (S) Compressed Package (100%)
(22811, 6713, 1, 1, -1, 107447), -- Sealed Major Arcana Boots Design
(22811, 57, 3802, 7740, 0, 700000), -- Adena
(22811, 6676, 1, 1, 1, 29.000058), -- Sealed Imperial Crusader Gauntlet
(22811, 6681, 1, 1, 1, 29.000058), -- Sealed Draconic Leather Glove
(22811, 6685, 1, 1, 1, 29.000058), -- Sealed Major Arcana Glove
(22811, 6677, 1, 1, 1, 29.000058), -- Sealed Imperial Crusader Boots
(22811, 6682, 1, 1, 1, 29.000058), -- Sealed Draconic Leather Boots
(22811, 6686, 1, 1, 1, 28.99971), -- Sealed Major Arcana Boots
(22811, 1895, 1, 1, 2, 159224.234127), -- Metallic Fiber
(22811, 4040, 1, 1, 2, 11145.742034), -- Mold Lubricant
(22811, 4042, 1, 1, 2, 9287.986057), -- Enria
(22811, 4043, 1, 1, 2, 18576.170571), -- Asofe
(22811, 960, 1, 1, 2, 222.867211), -- Scroll: Enchant Armor (S-Grade)
-- Boom Golem
(22812, 6706, 1, 1, -1, 104685), -- Sealed Imperial Crusader Helmet Pattern
(22812, 6710, 1, 1, -1, 104685), -- Sealed Draconic Leather Helmet Pattern
(22812, 57, 2164, 4418, 0, 700000), -- Adena
(22812, 6679, 1, 1, 1, 13.194498), -- Sealed Imperial Crusader Helmet
(22812, 6683, 1, 1, 1, 13.194498), -- Sealed Draconic Leather Helmet
(22812, 6687, 1, 1, 1, 13.194498), -- Sealed Major Arcana Circlet
(22812, 6678, 1, 1, 1, 18.849861), -- Sealed Imperial Crusader Shield
(22812, 13885, 1, 1, 1, 12.566645), -- Sealed Arcana Sigil
(22812, 1895, 1, 1, 2, 113464.278019), -- Metallic Fiber
(22812, 4040, 1, 1, 2, 7942.512175), -- Mold Lubricant
(22812, 4042, 1, 1, 2, 6618.736602), -- Enria
(22812, 4043, 1, 1, 2, 13237.473204), -- Asofe
-- Greyclaw Kutus
(25001, 348, 1, 1, 0, 272693.767227), -- Scale Mail
(25001, 377, 4, 12, 0, 54506.950827), -- Scale Gaiters
(25001, 1935, 53, 157, 0, 74357.519607), -- Scale Mail Fragment
(25001, 1937, 24, 72, 0, 250134.762339), -- Scale Gaiters Fragment
(25001, 69, 1, 1, 1, 67691.868545), -- Bastard Sword
(25001, 125, 1, 1, 1, 67691.868545), -- Spinebone Sword
(25001, 126, 1, 1, 1, 67691.868545), -- Artisan's Sword
(25001, 128, 1, 1, 1, 67691.868545), -- Knight's Sword
(25001, 2021, 3, 9, 1, 352919.52582), -- Spinebone Sword Blade
(25001, 6575, 1, 1, 2, 40258.77498), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25001, 6576, 1, 1, 2, 362331.59166), -- Blessed Scroll: Enchant Armor (D-Grade)
(25001, 956, 12, 36, 2, 251619.63336), -- Scroll: Enchant Armor (D-Grade)
-- Turek Mercenary Captain
(25004, 352, 1, 1, 0, 143869.013464), -- Brigandine Tunic
(25004, 2377, 6, 16, 0, 20921.22954), -- Mithril Scale Gaiters
(25004, 2378, 1, 1, 0, 230130.51772), -- Brigandine Gaiters
(25004, 1941, 140, 420, 0, 23468.946324), -- Brigandine Temper
(25004, 2918, 40, 120, 0, 122540.606336), -- Mithril Scale Gaiters Material
(25004, 2919, 81, 243, 0, 60513.686616), -- Brigandine Gaiters Material
(25004, 224, 1, 1, 1, 69231.989442), -- Maingauche
(25004, 1660, 1, 1, 1, 69231.989442), -- Cursed Maingauche
(25004, 2038, 24, 72, 1, 81835.535628), -- Maingauche Edge
(25004, 2044, 8, 22, 1, 261874.485488), -- Cursed Maingauche Edge
(25004, 6387, 60, 180, 2, 321287), -- Blessed Scroll of Resurrection for Pets
-- Retreat Spider Cletu
(25007, 398, 1, 1, 0, 115012.39948), -- Plated Leather
(25007, 418, 7, 19, 0, 14146.910844), -- Plated Leather Gaiters
(25007, 399, 1, 1, 0, 106046.117958), -- Rind Leather Armor
(25007, 419, 1, 1, 0, 169820.072048), -- Rind Leather Gaiters
(25007, 1966, 192, 576, 0, 18753.26387), -- Plated Leather Fragment
(25007, 1967, 116, 346, 0, 46570.6648), -- Plated Leather Gaiters Material
(25007, 1975, 23, 67, 0, 143972.63881), -- Rind Leather Armor Design
(25007, 1976, 60, 180, 0, 99951.93219), -- Rind Leather Gaiters Material
(25007, 282, 1, 1, 1, 53558.3565), -- Elemental Bow
(25007, 285, 1, 1, 1, 53558.3565), -- Noble Elven Bow
(25007, 2085, 24, 72, 1, 85281.5799), -- Crossbow Shaft
(25007, 2086, 8, 22, 1, 272901.7071), -- Noble Elven Bow Shaft
(25007, 952, 12, 36, 2, 852299), -- Scroll: Enchant Armor (C-Grade)
(25007, 9816, 1, 5, 2, 730000), -- Earth Egg
(25007, 8176, 1, 2, 2, 730000), -- Destruction Tombstone
-- Furious Thieles
(25010, 2397, 1, 1, 0, 64704.244), -- Tunic of Zubei
(25010, 2402, 1, 1, 0, 103502.7048), -- Stockings of Zubei
(25010, 2406, 1, 1, 0, 39800.42176), -- Avadon Robe
(25010, 4069, 81, 243, 0, 56358.92768), -- Tunic of Zubei Fabric
(25010, 4070, 40, 120, 0, 173284.88144), -- Stockings of Zubei Fabric
(25010, 4071, 14, 42, 0, 250508.82032), -- Avadon Robe Fabric
(25010, 300, 1, 1, 1, 52171.151061), -- Great Axe
(25010, 4113, 12, 36, 1, 373635.848939), -- Great Axe Head
(25010, 4622, 1, 3, 2, 389480.76973), -- Greater Dye of MEN (Men+4 Wit-4)
(25010, 4623, 2, 4, 2, 259654.177978), -- Greater Dye of WIT (Wit+4 Int-4)
(25010, 4624, 2, 6, 2, 194739.887628), -- Greater Dye of WIT (Wit+4 Men-4)
(25010, 6572, 1, 1, 2, 150599.164664), -- Blessed Scroll: Enchant Armor (B-Grade)
(25010, 9818, 2, 7, 2, 720000), -- Angelic Essence
(25010, 8176, 1, 3, 2, 800000), -- Destruction Tombstone
-- Ghost of Peasant Leader
(25013, 2384, 1, 1, 0, 54316.17395), -- Zubei's Leather Shirt
(25013, 2388, 1, 1, 0, 86885.65959), -- Zubei's Leather Gaiters
(25013, 2390, 1, 1, 0, 33410.584808), -- Avadon Leather Armor
(25013, 4066, 81, 243, 0, 47310.672844), -- Zubei's Leather Shirt Fabric
(25013, 4067, 40, 120, 0, 145464.519502), -- Zubei's Leather Gaiter Texture
(25013, 4068, 14, 42, 0, 210290.389306), -- Avadon Leather Armor Lining
(25013, 300, 1, 1, 1, 43795.233735), -- Great Axe
(25013, 4113, 12, 36, 1, 313649.766265), -- Great Axe Head
(25013, 4604, 2, 6, 2, 263376.522948), -- Greater Dye of CON (Con+3 Dex-3)
(25013, 4605, 3, 7, 2, 210701.058326), -- Greater Dye of DEX (Dex+3 Str-3)
(25013, 4606, 3, 9, 2, 175584.348632), -- Greater Dye of DEX (Dex+3 Con-3)
(25013, 952, 21, 63, 2, 150500.070094), -- Scroll: Enchant Armor (C-Grade)
(25013, 9814, 2, 5, 2, 770000), -- Memento Mori
(25013, 8176, 1, 3, 2, 670000), -- Destruction Tombstone
-- The 3rd Underwater Guardian
(25016, 601, 1, 1, 0, 96753.109299), -- Sealed Doom Boots
(25016, 2439, 1, 1, 0, 96753.109299), -- Sealed Blue Wolf Boots
(25016, 2475, 1, 1, 0, 96753.109299), -- Sealed Doom Gloves
(25016, 2487, 1, 1, 0, 96753.109299), -- Sealed Blue Wolf Gloves
(25016, 4099, 60, 180, 0, 111992.294568), -- Sealed Doom Boots Part
(25016, 4090, 116, 346, 0, 58177.479822), -- Sealed Blue Wolf Boots Design
(25016, 4091, 192, 576, 0, 34997.284476), -- Sealed Doom Gloves Part
(25016, 4096, 293, 877, 0, 22973.503938), -- Sealed Blue Wolf Gloves Fabric
(25016, 268, 1, 1, 1, 35597.18129), -- Bellion Cestus
(25016, 4120, 12, 36, 1, 327028.81871), -- Bellion Cestus Edge
(25016, 4619, 5, 15, 2, 80286.58396), -- Greater Dye of INT (Int+4 Men-4)
(25016, 4620, 2, 4, 2, 267621.425564), -- Greater Dye of INT (Int+4 Wit-4)
(25016, 4621, 2, 6, 2, 200715.678446), -- Greater Dye of MEN (Men+4 Int-4)
(25016, 947, 1, 1, 2, 232830.31203), -- Scroll: Enchant Weapon (B-Grade)
(25016, 9817, 2, 7, 2, 740000), -- Nonliving Nucleus
(25016, 8176, 1, 3, 2, 830000), -- Destruction Tombstone
-- Pan Dryad
(25019, 393, 1, 1, 0, 167391.624988), -- Mithril Banded Mail
(25019, 394, 1, 1, 0, 167391.624988), -- Reinforced Leather Shirt
(25019, 415, 4, 12, 0, 33443.901498), -- Mithril Banded Gaiters
(25019, 416, 5, 13, 0, 29727.699162), -- Reinforced Leather Gaiters
(25019, 1938, 53, 157, 0, 62696.198054), -- Mithril Banded Mail Material
(25019, 1939, 24, 72, 0, 179190.95131), -- Mithril Banded Gaiters Material
(25019, 316, 1, 1, 1, 79024.176192), -- Sage's Blood
(25019, 317, 1, 1, 1, 79024.176192), -- Tome of Blood
(25019, 2030, 3, 9, 1, 572655.647616), -- Tome of Blood Page
(25019, 956, 12, 36, 2, 793367), -- Scroll: Enchant Armor (D-Grade)
-- Breka Warlock Pastu
(25020, 396, 1, 1, 0, 210544.158658), -- Salamander Skin Mail
(25020, 1952, 12, 36, 0, 515064.841342), -- Salamander Skin Mail Texture
(25020, 159, 1, 1, 1, 16694.76785), -- Bonebreaker
(25020, 187, 1, 1, 1, 16694.76785), -- Atuba Hammer
(25020, 188, 1, 1, 1, 16694.76785), -- Ghost Staff
(25020, 189, 1, 1, 1, 16694.76785), -- Staff of Life
(25020, 190, 1, 1, 1, 16694.76785), -- Atuba Mace
(25020, 2048, 2, 6, 1, 239325.056795), -- Bonebreaker Head
(25020, 2049, 3, 7, 1, 191460.67632), -- Atuba Hammer Head
(25020, 2050, 7, 21, 1, 72503.555095), -- Ghost Staff Head
(25020, 2051, 12, 36, 1, 42293.674755), -- Staff of Life Shaft
(25020, 2058, 3, 9, 1, 159548.197785), -- Atuba Mace Head
(25020, 6574, 1, 1, 2, 428808), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Stakato Queen Zyrnna
(25023, 353, 1, 1, 0, 189124.908196), -- Half Plate Armor
(25023, 380, 4, 12, 0, 37825.104442), -- Plate Gaiters
(25023, 1950, 53, 157, 0, 87925.576772), -- Half Plate Temper
(25023, 1951, 24, 72, 0, 299138.41059), -- Plate Gaiters Part
(25023, 262, 1, 1, 1, 123046.939911), -- Scallop Jamadhr
(25023, 2053, 12, 36, 1, 293992.060089), -- Scallop Jamadhr Edge
(25023, 951, 3, 9, 2, 335203), -- Scroll: Enchant Weapon (C-Grade)
-- Ketra Commander Atis
(25026, 119, 1, 1, 0, 96888.312381), -- Necklace of Seal
(25026, 855, 1, 1, 0, 129184.198869), -- Nassen's Earring
(25026, 886, 1, 1, 0, 193776.624762), -- Ring of Seal
(25026, 1920, 140, 420, 0, 25717.094796), -- Necklace of Seal Chain
(25026, 1918, 81, 243, 0, 56259.246222), -- Nassen's Earring Gemstone
(25026, 2917, 40, 120, 0, 151091.52297), -- Ring of Seal Gemstone
(25026, 286, 1, 1, 1, 40181.852172), -- Eminence Bow
(25026, 2121, 3, 9, 1, 725814.147828), -- Eminence Bow Shaft
(25026, 4607, 1, 3, 2, 340992.819254), -- Greater Dye of INT (Int+3 Men-3)
(25026, 4608, 2, 4, 2, 227328.293077), -- Greater Dye of INT (Int+3 Wit-3)
(25026, 4609, 2, 6, 2, 170496.409627), -- Greater Dye of MEN (Men+3 Int-3)
(25026, 6573, 1, 1, 2, 20459.478042), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25026, 9814, 1, 3, 2, 870000), -- Memento Mori
(25026, 8176, 1, 1, 2, 870000), -- Destruction Tombstone
-- Atraiban
(25029, 503, 1, 1, 0, 95783.348416), -- Zubei's Helmet
(25029, 633, 1, 1, 0, 136840.172308), -- Zubei's Shield
(25029, 673, 1, 1, 0, 136840.172308), -- Avadon Shield
(25029, 2415, 1, 1, 0, 95783.348416), -- Avadon Circlet
(25029, 4102, 192, 576, 0, 33531.140872), -- Zubei's Helmet Design
(25029, 4101, 116, 346, 0, 71944.317684), -- Zubei's Shield Fragment
(25029, 4439, 60, 180, 0, 164759.054952), -- Avadon Shield Fragment
(25029, 4072, 293, 877, 0, 22010.445044), -- Avadon Circlet Pattern
(25029, 284, 1, 1, 1, 51495.46105), -- Dark Elven Long Bow
(25029, 4112, 12, 36, 1, 405774.53895), -- Dark Elven Longbow Shaft
(25029, 4613, 5, 15, 2, 76887.22558), -- Greater Dye of STR (Str+4 Con-4)
(25029, 4614, 2, 4, 2, 256290.253022), -- Greater Dye of STR (Str+4 Dex-4)
(25029, 4615, 2, 6, 2, 192217.315583), -- Greater Dye of CON (Con+4 Str-4)
(25029, 947, 1, 1, 2, 222972.205815), -- Scroll: Enchant Weapon (B-Grade)
(25029, 9817, 2, 6, 2, 790000), -- Nonliving Nucleus
(25029, 8176, 1, 3, 2, 790000), -- Destruction Tombstone
-- Eva's Guardian Millenu
(25032, 5297, 1, 1, 0, 37700.777166), -- Sealed Dark Crystal Leather Armor
(25032, 5298, 1, 1, 0, 60298.931086), -- Sealed Dark Crystal Leggings
(25032, 5301, 1, 1, 0, 23197.18086), -- Sealed Tallum Leather Armor
(25032, 5478, 9, 27, 0, 235216.99583), -- Sealed Dark Crystal Leather Armor Pattern
(25032, 5482, 28, 84, 0, 118669.984644), -- Sealed Dark Crystal Leggings Design
(25032, 5479, 20, 60, 0, 74482.130414), -- Sealed Tallum Leather Armor Pattern
(25032, 288, 1, 1, 1, 32142.454791), -- Carnage Bow
(25032, 5535, 12, 36, 1, 322118.545209), -- Carnage Bow Stave
(25032, 6570, 1, 1, 2, 163169.5), -- Blessed Scroll: Enchant Armor (A-Grade)
(25032, 729, 1, 1, 2, 163169.5), -- Scroll: Enchant Weapon (A-Grade)
(25032, 9814, 2, 6, 2, 820000), -- Memento Mori
(25032, 8176, 1, 3, 2, 820000), -- Destruction Tombstone
-- Shilen's Messenger Cabrio
(25035, 5313, 1, 1, 0, 54307.97645), -- Sealed Gauntlets of Nightmare
(25035, 5314, 1, 1, 0, 54307.97645), -- Sealed Boots of Nightmare
(25035, 5318, 1, 1, 0, 54307.97645), -- Sealed Majestic Gauntlets
(25035, 5319, 1, 1, 0, 54307.97645), -- Sealed Majestic Boots
(25035, 5514, 60, 180, 0, 51784.493033), -- Sealed Gauntlets of Nightmare Design
(25035, 5502, 116, 346, 0, 26900.823222), -- Sealed Boots of Nightmare Lining
(25035, 5515, 16, 48, 0, 194191.377723), -- Sealed Majestic Gauntlets Design
(25035, 5503, 23, 67, 0, 138092.400222), -- Sealed Majestic Boots Lining
(25035, 305, 1, 1, 1, 21287.467624), -- Tallum Glaive
(25035, 5541, 12, 36, 1, 252256.532376), -- Tallum Glaive Edge
(25035, 959, 1, 1, 2, 38156.405712), -- Scroll: Enchant Weapon (S-Grade)
(25035, 960, 1, 1, 2, 381564.909282), -- Scroll: Enchant Armor (S-Grade)
(25035, 6577, 1, 1, 2, 6359.685006), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25035, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25035, 9814, 3, 8, 2, 740000), -- Memento Mori
(25035, 8176, 2, 3, 2, 820000), -- Destruction Tombstone
-- Tirak
(25038, 849, 4, 10, 0, 93125.53428), -- Tiger's Eye Earring
(25038, 880, 3, 7, 0, 195168.125643), -- Black Pearl Ring
(25038, 912, 4, 12, 0, 61082.77308), -- Near Forest Necklace
(25038, 1901, 72, 216, 0, 154440.566997), -- Tiger's Eye Earring Stone
(25038, 83, 1, 1, 1, 58465.561752), -- Sword of Magic
(25038, 144, 1, 1, 1, 58465.561752), -- Sword of Occult
(25038, 124, 1, 1, 1, 43312.931172), -- Two-Handed Sword
(25038, 127, 1, 1, 1, 43312.931172), -- Crimson Sword
(25038, 130, 1, 1, 1, 43312.931172), -- Elven Sword
(25038, 2026, 3, 9, 1, 322992.08298), -- Two-Handed Sword Edge
(25038, 955, 3, 9, 2, 417444), -- Scroll: Enchant Weapon (D-Grade)
-- Remmel
(25041, 61, 9, 25, 0, 10511.075844), -- Mithril Plate Gloves
(25041, 607, 9, 27, 0, 9927.127186), -- Ogre Power Gauntlets
(25041, 1125, 10, 28, 0, 9405.017595), -- Assault Boots
(25041, 2427, 10, 30, 0, 8934.571022), -- Salamander Skin Boots
(25041, 2428, 1, 1, 0, 178694.551532), -- Plate Boots
(25041, 2451, 1, 1, 0, 178694.551532), -- Sage's Worn Gloves
(25041, 1949, 112, 336, 0, 33476.852891), -- Mithril Gloves Design
(25041, 1963, 203, 607, 0, 18515.712542), -- Ogre Power Gauntlets Part
(25041, 1957, 320, 960, 0, 11716.546264), -- Assault Boots Part
(25041, 2931, 28, 82, 0, 136341.835594), -- Salamander Skin Boot Lining
(25041, 2932, 36, 108, 0, 104149.513196), -- Plate Boots Design
(25041, 2933, 46, 136, 0, 82405.644802), -- Sage's Worn Gloves Lining
(25041, 262, 1, 1, 1, 87192.585431), -- Scallop Jamadhr
(25041, 2053, 12, 36, 1, 208326.414569), -- Scallop Jamadhr Edge
(25041, 6574, 1, 1, 2, 447912), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Barion
(25044, 2436, 1, 1, 0, 79199.868012), -- Theca Leather Boots
(25044, 2460, 1, 1, 0, 79199.868012), -- Theca Leather Gloves
(25044, 2437, 1, 1, 0, 60918.565), -- Drake Leather Boots
(25044, 2438, 1, 1, 0, 60918.565), -- Full Plate Boots
(25044, 2461, 1, 1, 0, 60918.565), -- Drake Leather Gloves
(25044, 2462, 1, 1, 0, 60918.565), -- Full Plate Gauntlets
(25044, 2463, 1, 1, 0, 60918.565), -- Divine Gloves
(25044, 2954, 144, 432, 0, 18414.607166), -- Theca Leather Boots Texture
(25044, 2955, 255, 765, 0, 10399.15739), -- Theca Leather Gloves Texture
(25044, 2960, 396, 1188, 0, 5760.746182), -- Drake Leather Boots Design
(25044, 2961, 30, 90, 0, 76045.003034), -- Full Plate Boots Part
(25044, 2962, 39, 117, 0, 58496.15618), -- Drake Leather Gloves Design
(25044, 2963, 49, 147, 0, 46558.267507), -- Full Plate Gauntlets Part
(25044, 2964, 60, 180, 0, 38022.501517), -- Divine Gloves Pattern
(25044, 228, 1, 1, 1, 37332.361506), -- Crystal Dagger
(25044, 2119, 3, 9, 1, 668196.638494), -- Crystal Dagger Blade
(25044, 4604, 2, 6, 2, 158405.691654), -- Greater Dye of CON (Con+3 Dex-3)
(25044, 4605, 3, 7, 2, 126724.457073), -- Greater Dye of DEX (Dex+3 Str-3)
(25044, 4606, 3, 9, 2, 105603.794436), -- Greater Dye of DEX (Dex+3 Con-3)
(25044, 952, 21, 63, 2, 90517.056837), -- Scroll: Enchant Armor (C-Grade)
(25044, 9814, 1, 3, 2, 810000), -- Memento Mori
(25044, 8176, 1, 1, 2, 810000), -- Destruction Tombstone
-- Karte
(25047, 2436, 1, 1, 0, 85244.876628), -- Theca Leather Boots
(25047, 2460, 1, 1, 0, 85244.876628), -- Theca Leather Gloves
(25047, 2437, 1, 1, 0, 65568.235), -- Drake Leather Boots
(25047, 2438, 1, 1, 0, 65568.235), -- Full Plate Boots
(25047, 2461, 1, 1, 0, 65568.235), -- Drake Leather Gloves
(25047, 2462, 1, 1, 0, 65568.235), -- Full Plate Gauntlets
(25047, 2463, 1, 1, 0, 65568.235), -- Divine Gloves
(25047, 2954, 144, 432, 0, 19820.120354), -- Theca Leather Boots Texture
(25047, 2955, 255, 765, 0, 11192.88341), -- Theca Leather Gloves Texture
(25047, 2960, 396, 1188, 0, 6200.440858), -- Drake Leather Boots Design
(25047, 2961, 30, 90, 0, 81849.213446), -- Full Plate Boots Part
(25047, 2962, 39, 117, 0, 62960.93342), -- Drake Leather Gloves Design
(25047, 2963, 49, 147, 0, 50111.873533), -- Full Plate Gauntlets Part
(25047, 2964, 60, 180, 0, 40924.606723), -- Divine Gloves Pattern
(25047, 228, 1, 1, 1, 40181.83332), -- Crystal Dagger
(25047, 2119, 3, 9, 1, 719198.16668), -- Crystal Dagger Blade
(25047, 4610, 1, 3, 2, 340992.83337), -- Greater Dye of MEN (Men+3 Wit-3)
(25047, 4611, 2, 4, 2, 227328.55558), -- Greater Dye of WIT (Wit+3 Int-3)
(25047, 4612, 2, 6, 2, 170496.416685), -- Greater Dye of WIT (Wit+3 Men-3)
(25047, 6574, 1, 1, 2, 175367.194365), -- Blessed Scroll: Enchant Armor (C-Grade)
(25047, 9814, 1, 3, 2, 870000), -- Memento Mori
(25047, 8176, 1, 1, 2, 870000), -- Destruction Tombstone
-- Verfa
(25050, 2384, 1, 1, 0, 34355.623846), -- Zubei's Leather Shirt
(25050, 2388, 1, 1, 0, 54955.572082), -- Zubei's Leather Gaiters
(25050, 2390, 1, 1, 0, 21132.152876), -- Avadon Leather Armor
(25050, 4066, 9, 27, 0, 269318.529404), -- Zubei's Leather Shirt Fabric
(25050, 4067, 40, 120, 0, 92006.691474), -- Zubei's Leather Gaiter Texture
(25050, 4068, 14, 42, 0, 133009.430318), -- Avadon Leather Armor Lining
(25050, 300, 1, 1, 1, 27700.980024), -- Great Axe
(25050, 4113, 12, 36, 1, 198387.019976), -- Great Axe Head
(25050, 4610, 1, 3, 2, 333178.068468), -- Greater Dye of MEN (Men+3 Wit-3)
(25050, 4611, 2, 4, 2, 222118.712312), -- Greater Dye of WIT (Wit+3 Int-3)
(25050, 4612, 2, 6, 2, 166589.034234), -- Greater Dye of WIT (Wit+3 Men-3)
(25050, 6574, 1, 1, 2, 171348.184986), -- Blessed Scroll: Enchant Armor (C-Grade)
(25050, 9814, 1, 3, 2, 850000), -- Memento Mori
(25050, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Rahha
(25051, 5287, 1, 1, 0, 26966.603944), -- Sealed Dark Crystal breastplate
(25051, 5288, 1, 1, 0, 43150.78033), -- Sealed Dark Crystal Gaiters
(25051, 5293, 1, 1, 0, 16595.433484), -- Sealed Tallum Plate Armor
(25051, 5520, 9, 27, 0, 172056.85952), -- Sealed Dark Crystal Breastplate Pattern
(25051, 5524, 28, 84, 0, 84528.550932), -- Sealed Dark Crystal Gaiters Pattern
(25051, 5521, 3, 7, 0, 437075.77179), -- Sealed Tallum Plate Armor Pattern
(25051, 235, 1, 1, 1, 30660.25589), -- Bloody Orchid
(25051, 5536, 12, 36, 1, 306376.74411), -- Bloody Orchid Head
(25051, 729, 1, 1, 2, 103763.205969), -- Scroll: Enchant Weapon (A-Grade)
(25051, 730, 1, 1, 2, 778226.28087), -- Scroll: Enchant Armor (A-Grade)
(25051, 6569, 1, 1, 2, 12451.513161), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25051, 9814, 3, 7, 2, 800000), -- Memento Mori
(25051, 8176, 2, 3, 2, 800000), -- Destruction Tombstone
-- Kernon
(25054, 6676, 1, 1, 0, 15738.553335), -- Sealed Imperial Crusader Gauntlet
(25054, 6677, 1, 1, 0, 15738.553335), -- Sealed Imperial Crusader Boots
(25054, 6681, 1, 1, 0, 15738.553335), -- Sealed Draconic Leather Glove
(25054, 6682, 1, 1, 0, 15738.553335), -- Sealed Draconic Leather Boots
(25054, 6685, 1, 1, 0, 15738.553335), -- Sealed Major Arcana Glove
(25054, 6686, 1, 1, 0, 15738.553335), -- Sealed Major Arcana Boots
(25054, 6703, 8, 24, 0, 223738.829795), -- Sealed Imperial Crusader Gauntlets Design
(25054, 6704, 14, 40, 0, 132585.767464), -- Sealed Imperial Crusader Boots Design
(25054, 6708, 20, 60, 0, 89495.531918), -- Sealed Draconic Leather Gloves Fabric
(25054, 6709, 28, 82, 0, 65087.407068), -- Sealed Draconic Leather Boots Design
(25054, 6712, 36, 108, 0, 49719.662799), -- Sealed Major Arcana Gloves fabric
(25054, 6713, 46, 136, 0, 39340.480946), -- Sealed Major Arcana Boots Design
(25054, 6371, 1, 1, 1, 10583.905527), -- Demon Splinter
(25054, 6695, 12, 36, 1, 199953.094473), -- Demon Splinter Blade
(25054, 959, 1, 1, 2, 39110.313616), -- Scroll: Enchant Weapon (S-Grade)
(25054, 960, 1, 1, 2, 391104.009626), -- Scroll: Enchant Armor (S-Grade)
(25054, 6577, 1, 1, 2, 6518.676758), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Beacon of Blue Sky
(25057, 64, 1, 1, 0, 286396.192443), -- Composite Boots
(25057, 608, 1, 1, 0, 286396.192443), -- Mithril Gauntlets
(25057, 2956, 192, 576, 0, 41415.03621), -- Composite Boots Part
(25057, 1981, 53, 157, 0, 151461.578904), -- Mithril Gauntlets Design
(25057, 231, 1, 1, 1, 24546.01275), -- Grace Dagger
(25057, 233, 1, 1, 1, 24546.01275), -- Dark Screamer
(25057, 2106, 4, 12, 1, 276249.704325), -- Grace Dagger Edge
(25057, 2107, 8, 22, 1, 147333.270175), -- Dark Screamer Edge
(25057, 4604, 2, 6, 2, 146026.690173), -- Greater Dye of CON (Con+3 Dex-3)
(25057, 4605, 3, 7, 2, 116821.163277), -- Greater Dye of DEX (Dex+3 Str-3)
(25057, 4606, 3, 9, 2, 97351.441551), -- Greater Dye of DEX (Dex+3 Con-3)
(25057, 952, 3, 9, 2, 584107.704999), -- Scroll: Enchant Armor (C-Grade)
(25057, 9816, 1, 3, 2, 750000), -- Earth Egg
(25057, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Unrequited Kael
(25060, 605, 4, 12, 0, 278795.254564), -- Leather Gauntlets
(25060, 1123, 8, 22, 0, 148690.745436), -- Blue Buckskin Boots
(25060, 275, 1, 1, 1, 115231.555273), -- Long Bow
(25060, 276, 1, 1, 1, 115231.555273), -- Elven Bow
(25060, 2024, 12, 36, 1, 169447.889454), -- Elven Bow Shaft
(25060, 6387, 24, 72, 2, 154197.698152), -- Blessed Scroll of Resurrection for Pets
(25060, 955, 4, 10, 2, 105735.545272), -- Scroll: Enchant Weapon (D-Grade)
(25060, 956, 8, 22, 2, 411194.756576), -- Scroll: Enchant Armor (D-Grade)
-- Chertuba of Great Soul
(25063, 630, 6, 16, 0, 30926.025583), -- Square Shield
(25063, 2412, 1, 1, 0, 238250.687982), -- Plate Helmet
(25063, 2494, 6, 18, 0, 28348.805033), -- Plate Shield
(25063, 1956, 40, 120, 0, 190654.703068), -- Square Shield Fragment
(25063, 2930, 140, 420, 0, 38686.254015), -- Plate Helmet Design
(25063, 2934, 81, 243, 0, 94150.524319), -- Plate Shield Fragment
(25063, 297, 1, 1, 1, 87192.585431), -- Glaive
(25063, 2055, 12, 36, 1, 208326.414569), -- Glaive Edge
(25063, 951, 1, 3, 2, 712587), -- Scroll: Enchant Weapon (C-Grade)
-- Wizard of Storm Teruk
(25064, 852, 1, 1, 0, 258666.745276), -- Moonstone Earring
(25064, 883, 6, 16, 0, 35287.519992), -- Aquastone Ring
(25064, 915, 1, 1, 0, 194081.359956), -- Aquastone Necklace
(25064, 1908, 81, 243, 0, 90193.115364), -- Moonstone Earring Wire
(25064, 1909, 480, 1440, 0, 21704.640664), -- Aquastone Ring Wire
(25064, 1910, 140, 420, 0, 41494.618748), -- Aquastone Necklace Chain
(25064, 89, 1, 1, 1, 9846.369026), -- Big Hammer
(25064, 160, 1, 1, 1, 9846.369026), -- Battle Axe
(25064, 161, 1, 1, 1, 9846.369026), -- Silver Axe
(25064, 173, 1, 1, 1, 9846.369026), -- Skull Graver
(25064, 191, 1, 1, 1, 9846.369026), -- Heavy Doom Hammer
(25064, 192, 1, 1, 1, 9846.369026), -- Crystal Staff
(25064, 193, 1, 1, 1, 9846.369026), -- Stick of Faith
(25064, 194, 1, 1, 1, 9846.369026), -- Heavy Doom Axe
(25064, 2061, 2, 6, 1, 167705.311661), -- Big Hammer Head
(25064, 2063, 3, 7, 1, 134164.091205), -- Battle Axe Head
(25064, 2064, 3, 9, 1, 111803.014028), -- Silver Axe Head
(25064, 2065, 4, 10, 1, 95831.719609), -- Skull Graver Head
(25064, 2066, 10, 30, 1, 34034.566712), -- Heavy Doom Hammer Head
(25064, 2067, 4, 12, 1, 78186.684767), -- Crystal Staff Head
(25064, 2068, 5, 13, 1, 69499.363195), -- Stick of Faith Shaft
(25064, 2069, 17, 49, 1, 20623.296615), -- Heavy Doom Axe Blade
(25064, 4591, 1, 3, 2, 375021.86218), -- Greater Dye of CON (Con+2 Str-2)
(25064, 4592, 2, 4, 2, 250014.87291), -- Greater Dye of CON (Con+2 Dex-2)
(25064, 4593, 2, 6, 2, 187510.93109), -- Greater Dye of DEX (Dex+2 Str-2)
(25064, 951, 3, 7, 2, 81822.33382), -- Scroll: Enchant Weapon (C-Grade)
(25064, 9818, 1, 3, 2, 640000), -- Angelic Essence
(25064, 8176, 1, 1, 2, 640000), -- Destruction Tombstone
-- Captain of Red Flag Shaka
(25067, 2397, 1, 1, 0, 63240.932925), -- Tunic of Zubei
(25067, 2402, 1, 1, 0, 101161.951785), -- Stockings of Zubei
(25067, 2406, 1, 1, 0, 38900.320092), -- Avadon Robe
(25067, 4069, 81, 243, 0, 55084.349106), -- Tunic of Zubei Fabric
(25067, 4070, 40, 120, 0, 169365.977973), -- Stockings of Zubei Fabric
(25067, 4071, 14, 42, 0, 244843.468119), -- Avadon Robe Fabric
(25067, 78, 1, 1, 1, 16997.10012), -- Great Sword
(25067, 142, 1, 1, 1, 16997.10012), -- Keshanberk
(25067, 148, 1, 1, 1, 16997.10012), -- Sword of Valhalla
(25067, 4104, 5, 15, 1, 324888.22938), -- Great Sword Blade
(25067, 4107, 9, 27, 1, 177696.89509), -- Keshanberk Blade
(25067, 4108, 14, 42, 1, 114233.57517), -- Sword of Valhalla Blade
(25067, 4604, 2, 6, 2, 306652.703406), -- Greater Dye of CON (Con+3 Dex-3)
(25067, 4605, 3, 7, 2, 245321.976397), -- Greater Dye of DEX (Dex+3 Str-3)
(25067, 4606, 3, 9, 2, 204435.135604), -- Greater Dye of DEX (Dex+3 Con-3)
(25067, 952, 21, 63, 2, 175229.184593), -- Scroll: Enchant Armor (C-Grade)
(25067, 9816, 2, 6, 2, 790000), -- Earth Egg
(25067, 8176, 1, 3, 2, 790000), -- Destruction Tombstone
-- Enchanted Forest Watcher Ruell
(25070, 856, 1, 1, 0, 96655.207475), -- Adamantite Earring
(25070, 887, 1, 1, 0, 144982.514915), -- Adamantite Ring
(25070, 918, 1, 1, 0, 72491.553755), -- Adamantite Necklace
(25070, 4049, 81, 243, 0, 72901.0369), -- Adamantite Earring Gemstone
(25070, 4050, 40, 120, 0, 174378.782485), -- Adamantite Ring Wire
(25070, 4051, 140, 420, 0, 31185.90447), -- Adamantite Necklace Chain
(25070, 78, 1, 1, 1, 10111.137876), -- Great Sword
(25070, 142, 1, 1, 1, 10111.137876), -- Keshanberk
(25070, 148, 1, 1, 1, 10111.137876), -- Sword of Valhalla
(25070, 4104, 5, 15, 1, 193267.654974), -- Great Sword Blade
(25070, 4107, 9, 27, 1, 105707.314407), -- Keshanberk Blade
(25070, 4108, 14, 42, 1, 67954.616991), -- Sword of Valhalla Blade
(25070, 947, 1, 1, 2, 175123.055518), -- Scroll: Enchant Weapon (B-Grade)
(25070, 948, 1, 3, 2, 547259.364771), -- Scroll: Enchant Armor (B-Grade)
(25070, 6571, 1, 1, 2, 12508.579711), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25070, 9818, 1, 4, 2, 750000), -- Angelic Essence
(25070, 8176, 1, 1, 2, 900000), -- Destruction Tombstone
-- Bloody Priest Rudelto
(25073, 5326, 1, 1, 0, 22189.788936), -- Sealed Robe of Nightmare
(25073, 5329, 1, 1, 0, 22189.788936), -- Sealed Majestic Robe
(25073, 5487, 4, 12, 0, 412371.296883), -- Sealed Robe of Nightmare Fabric
(25073, 5488, 8, 22, 0, 219932.125245), -- Sealed Majestic Robe Fabric
(25073, 289, 1, 1, 1, 21192.664057), -- Soul Bow
(25073, 5534, 12, 36, 1, 251406.335943), -- Soul Bow Stave
(25073, 959, 1, 1, 2, 37986.436016), -- Scroll: Enchant Weapon (S-Grade)
(25073, 960, 1, 1, 2, 379865.208526), -- Scroll: Enchant Armor (S-Grade)
(25073, 6577, 1, 1, 2, 6331.355458), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25073, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25073, 9814, 2, 8, 2, 760000), -- Memento Mori
(25073, 8176, 1, 4, 2, 810000), -- Destruction Tombstone
-- Princess Molrang
(25076, 58, 1, 1, 0, 118972.338728), -- Mithril Breastplate
(25076, 349, 1, 1, 0, 118972.338728), -- Compound Scale Mail
(25076, 350, 1, 1, 0, 118972.338728), -- Dwarven Scale Mail
(25076, 59, 1, 3, 0, 85998.886515), -- Mithril Gaiters
(25076, 351, 1, 1, 0, 107470.733261), -- Blast Plate
(25076, 378, 2, 4, 0, 57332.59101), -- Compound Scale Gaiters
(25076, 379, 1, 1, 0, 171997.77303), -- Dwarven Scale Gaiters
(25076, 293, 1, 1, 1, 118536.5), -- War Hammer
(25076, 296, 1, 1, 1, 118536.5), -- Dwarven Pike
(25076, 6575, 1, 1, 2, 126939), -- Blessed Scroll: Enchant Weapon (D-Grade)
-- Cat's Eye Bandit
(25079, 437, 1, 1, 0, 288198.293442), -- Mithril Tunic
(25079, 470, 4, 12, 0, 57532.815102), -- Mithril Stockings
(25079, 1944, 53, 157, 0, 120402.180791), -- Mithril Tunic Fabric
(25079, 1945, 216, 648, 0, 45569.710665), -- Mithril Stocking Design
(25079, 318, 1, 1, 1, 138463.887114), -- Crucifix of Blood
(25079, 2042, 12, 36, 1, 286294.112886), -- Crucifix of Blood Piece
(25079, 955, 3, 9, 2, 642575), -- Scroll: Enchant Weapon (D-Grade)
-- Leader of Cat Gang
(25082, 439, 1, 1, 0, 154890.037149), -- Karmian Tunic
(25082, 471, 1, 1, 0, 247517.619074), -- Karmian Stockings
(25082, 1962, 53, 157, 0, 68682.4241), -- Karmian Tunic Pattern
(25082, 1954, 24, 72, 0, 249606.919677), -- Karmian Stocking Design
(25082, 71, 1, 1, 1, 38351.285115), -- Flamberge
(25082, 72, 1, 1, 1, 38351.285115), -- Stormbringer
(25082, 2059, 8, 22, 1, 167402.649479), -- Flamberge Blade
(25082, 2060, 4, 12, 1, 335525.780291), -- Stormbringer Blade
(25082, 4589, 1, 3, 2, 486899.60431), -- Greater Dye of STR (Str+2 Con-2)
(25082, 4590, 2, 4, 2, 324600.388498), -- Greater Dye of STR (Str+2 Dex-2)
(25082, 6574, 1, 1, 2, 166937.007192), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Timak Orc Chief Ranger
(25085, 854, 7, 19, 0, 45880.262463), -- Earring of Seal
(25085, 885, 6, 16, 0, 81314.899652), -- Ring of Ages
(25085, 917, 7, 21, 0, 31955.933884), -- Necklace of Mermaid
(25085, 1914, 81, 243, 0, 234348.179541), -- Earring of Seal Gemstone
(25085, 1915, 280, 840, 0, 106319.583923), -- Ring of Ages Gemstone
(25085, 1916, 240, 720, 0, 59908.140537), -- Necklace of Mermaid Teardrop
(25085, 4601, 6, 18, 1, 72999.88056), -- Greater Dye of STR (Str+3 Con-3)
(25085, 4602, 2, 4, 1, 291999.52224), -- Greater Dye of STR (Str+3 Dex-3)
(25085, 4603, 2, 6, 1, 218999.64168), -- Greater Dye of CON (Con+3 Str-3)
(25085, 951, 3, 7, 1, 143344.95552), -- Scroll: Enchant Weapon (C-Grade)
(25085, 9816, 2, 4, 2, 750000), -- Earth Egg
(25085, 8176, 1, 2, 2, 750000), -- Destruction Tombstone
-- Crazy Mechanic Golem
(25088, 355, 1, 1, 0, 161489.971319), -- Dwarven Chain Mail Shirt
(25088, 382, 1, 1, 0, 258373.806492), -- Dwarven Chain Gaiters
(25088, 1968, 53, 157, 0, 91816.643985), -- Dwarven Chain Mail Shirt Material
(25088, 1969, 192, 576, 0, 39820.578204), -- Dwarven Chain Gaiters Material
(25088, 227, 1, 1, 1, 54318.404395), -- Stiletto
(25088, 242, 1, 1, 1, 54318.404395), -- Soulfire Dirk
(25088, 2083, 24, 72, 1, 83075.152892), -- Stiletto Edge
(25088, 2084, 8, 22, 1, 265841.038318), -- Soulfire Dirk Blade
(25088, 6573, 1, 1, 2, 103727), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25088, 9817, 2, 4, 2, 740000), -- Nonliving Nucleus
(25088, 8176, 1, 2, 2, 740000), -- Destruction Tombstone
-- Soulless Wild Boar
(25089, 864, 1, 1, 0, 71285.845609), -- Earring of Black Ore
(25089, 895, 1, 1, 0, 106929.071327), -- Ring of Black Ore
(25089, 926, 1, 1, 0, 53464.838577), -- Necklace of Black Ore
(25089, 4052, 81, 243, 0, 55384.70434), -- Earring of Black Ore Piece
(25089, 4053, 28, 84, 0, 193973.083033), -- Ring of Black Ore Gemstone
(25089, 4054, 20, 60, 0, 124789.457114), -- Necklace of Black Ore Beads
(25089, 171, 1, 1, 1, 7533.77405), -- Deadman's Glory
(25089, 175, 1, 1, 1, 7533.77405), -- Art of Battle Axe
(25089, 210, 1, 1, 1, 7533.77405), -- Staff of Evil Spirits
(25089, 4116, 5, 15, 1, 166115.33378), -- Deadman's Glory Stone
(25089, 4117, 9, 27, 1, 92286.371485), -- Art of Battle Axe Blade
(25089, 4118, 2, 6, 1, 393461.972585), -- Evil Spirit Head
(25089, 4616, 1, 3, 2, 254877.86626), -- Greater Dye of CON (Con+4 Dex-4)
(25089, 4617, 2, 4, 2, 169918.794436), -- Greater Dye of DEX (Dex+4 Str-4)
(25089, 4618, 2, 6, 2, 127438.607736), -- Greater Dye of DEX (Dex+4 Con-4)
(25089, 6572, 1, 1, 2, 98552.731568), -- Blessed Scroll: Enchant Armor (B-Grade)
(25089, 9816, 1, 4, 2, 830000), -- Earth Egg
(25089, 8176, 1, 2, 2, 700000), -- Destruction Tombstone
-- Korim
(25092, 5312, 1, 1, 0, 48285.636708), -- Sealed Helm of Nightmare
(25092, 5315, 1, 1, 0, 68999.445144), -- Sealed Shield of Nightmare
(25092, 5317, 1, 1, 0, 48285.636708), -- Sealed Majestic Circlet
(25092, 5527, 9, 27, 0, 325857.974808), -- Sealed Helm of Nightmare Design
(25092, 5495, 40, 120, 0, 93118.839672), -- Sealed Shield of Nightmare Fragment
(25092, 5528, 14, 42, 0, 209480.46696), -- Sealed Majestic Circlet Design
(25092, 305, 1, 1, 1, 21287.467624), -- Tallum Glaive
(25092, 5541, 12, 36, 1, 252256.532376), -- Tallum Glaive Edge
(25092, 6578, 1, 1, 2, 63593.940624), -- Blessed Scroll: Enchant Armor (S-Grade)
(25092, 730, 1, 3, 2, 596190.059376), -- Scroll: Enchant Armor (A-Grade)
(25092, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25092, 9814, 3, 7, 2, 810000), -- Memento Mori
(25092, 8176, 1, 4, 2, 810000), -- Destruction Tombstone
-- Elf Renoa
(25095, 395, 1, 1, 0, 193209.438088), -- Manticore Skin Shirt
(25095, 417, 4, 12, 0, 38570.335964), -- Manticore Skin Gaiters
(25095, 1942, 53, 157, 0, 80718.254608), -- Manticore Skin Shirt Texture
(25095, 1943, 24, 72, 0, 274953.97134), -- Manticore Skin Gaiters Pattern
(25095, 279, 1, 1, 1, 92826.959365), -- Reinforced Long Bow
(25095, 2040, 12, 36, 1, 240310.040635), -- Reinforced Long Bow Shaft
(25095, 6576, 1, 3, 2, 646178), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Sejarr's Servitor
(25098, 396, 1, 1, 0, 219923.93547), -- Salamander Skin Mail
(25098, 1952, 12, 36, 0, 538011.06453), -- Salamander Skin Mail Texture
(25098, 70, 1, 1, 1, 43596.351546), -- Claymore
(25098, 2499, 1, 1, 1, 43596.351546), -- Elven Long Sword
(25098, 2047, 4, 12, 1, 332241.088641), -- Claymore Blade
(25098, 2967, 8, 22, 1, 174797.208267), -- Elven Long Sword Blade
(25098, 4589, 2, 6, 2, 217735.018788), -- Greater Dye of STR (Str+2 Con-2)
(25098, 4590, 3, 7, 2, 174187.236992), -- Greater Dye of STR (Str+2 Dex-2)
(25098, 952, 3, 9, 2, 580625.74422), -- Scroll: Enchant Armor (C-Grade)
-- Rotting Tree Repiro
(25099, 64, 1, 1, 0, 275300.088188), -- Composite Boots
(25099, 608, 1, 1, 0, 275300.088188); -- Mithril Gauntlets

INSERT INTO `droplist` VALUES
(25099, 2956, 192, 576, 0, 39810.45636), -- Composite Boots Part
(25099, 1981, 53, 157, 0, 145593.367264), -- Mithril Gauntlets Design
(25099, 75, 1, 1, 1, 7865.000948), -- Caliburs
(25099, 76, 1, 1, 1, 7865.000948), -- Sword of Delusion
(25099, 77, 1, 1, 1, 7865.000948), -- Tsurugi
(25099, 84, 1, 1, 1, 7865.000948), -- Homunkulus's Sword
(25099, 134, 1, 1, 1, 7865.000948), -- Sword of Nightmare
(25099, 145, 1, 1, 1, 7865.000948), -- Sword of Whispering Death
(25099, 2089, 8, 24, 1, 44258.493416), -- Caliburs Edge
(25099, 2090, 14, 40, 1, 26227.59526), -- Delusional Blade
(25099, 2091, 2, 6, 1, 177035.284716), -- Tsurugi Blade
(25099, 2092, 3, 7, 1, 141627.703352), -- Homunkulus's Sword Blade
(25099, 2095, 3, 9, 1, 118023.523144), -- Sword of Nightmare Blade
(25099, 2096, 4, 10, 1, 101163.394424), -- Sword of Whispering Death Blade
(25099, 4604, 2, 6, 2, 140369.067719), -- Greater Dye of CON (Con+3 Dex-3)
(25099, 4605, 3, 7, 2, 112295.072631), -- Greater Dye of DEX (Dex+3 Str-3)
(25099, 4606, 3, 9, 2, 93579.681053), -- Greater Dye of DEX (Dex+3 Con-3)
(25099, 952, 3, 9, 2, 561477.178597), -- Scroll: Enchant Armor (C-Grade)
(25099, 9816, 1, 3, 2, 720000), -- Earth Egg
(25099, 8176, 1, 1, 2, 720000), -- Destruction Tombstone
-- Shacram
(25102, 854, 1, 1, 0, 159080.840568), -- Earring of Seal
(25102, 885, 1, 1, 0, 238568.488704), -- Ring of Ages
(25102, 917, 1, 1, 0, 119323.423674), -- Necklace of Mermaid
(25102, 1914, 81, 243, 0, 62504.611416), -- Earring of Seal Gemstone
(25102, 1915, 280, 840, 0, 28357.03377), -- Ring of Ages Gemstone
(25102, 1916, 20, 60, 0, 191743.601868), -- Necklace of Mermaid Teardrop
(25102, 326, 1, 1, 1, 49092.126514), -- Heathen's Book
(25102, 2110, 12, 36, 1, 190500.873486), -- Heathen's Book Page
(25102, 4607, 1, 3, 2, 292053.27611), -- Greater Dye of INT (Int+3 Men-3)
(25102, 4608, 2, 4, 2, 194701.967305), -- Greater Dye of INT (Int+3 Wit-3)
(25102, 4609, 2, 6, 2, 146026.638055), -- Greater Dye of MEN (Men+3 Int-3)
(25102, 6573, 1, 1, 2, 17523.11853), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25102, 9816, 1, 3, 2, 750000), -- Earth Egg
(25102, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Sorcerer Isirr
(25103, 554, 1, 1, 0, 84624.773742), -- Sealed Zubei's Boots
(25103, 600, 1, 1, 0, 84624.773742), -- Sealed Avadon Boots
(25103, 612, 1, 1, 0, 84624.773742), -- Sealed Zubei's Gauntlets
(25103, 2464, 1, 1, 0, 84624.773742), -- Sealed Avadon Gloves
(25103, 4097, 60, 180, 0, 73236.021642), -- Sealed Zubei's Boots Design
(25103, 4098, 116, 346, 0, 38045.111634), -- Sealed Avadon Boots Design
(25103, 4100, 192, 576, 0, 22886.382006), -- Sealed Zubei's Gauntlets Part
(25103, 4073, 23, 67, 0, 195295.38975), -- Sealed Avadon Gloves Part
(25103, 91, 1, 1, 1, 15166.72486), -- Heavy War Axe
(25103, 92, 1, 1, 1, 15166.72486), -- Sprite's Staff
(25103, 4105, 4, 12, 1, 362385.23678), -- Heavy War Axe Head
(25103, 4106, 8, 22, 1, 190101.3135), -- Sprite's Staff Head
(25103, 6572, 1, 1, 2, 175123.165536), -- Blessed Scroll: Enchant Armor (B-Grade)
(25103, 948, 1, 3, 2, 820890.834464), -- Scroll: Enchant Armor (B-Grade)
(25103, 9816, 2, 3, 2, 750000), -- Earth Egg
(25103, 8176, 1, 1, 2, 900000), -- Destruction Tombstone
-- Ghost of the Well Lidia
(25106, 5290, 1, 1, 0, 48676.114035), -- Sealed Dark Crystal Gloves
(25106, 5291, 1, 1, 0, 48676.114035), -- Sealed Dark Crystal Boots
(25106, 5295, 1, 1, 0, 48676.114035), -- Sealed Tallum Gloves
(25106, 5296, 1, 1, 0, 48676.114035), -- Sealed Tallum Boots
(25106, 5508, 60, 180, 0, 42322.846665), -- Sealed Dark Crystal Gloves Design
(25106, 5496, 11, 31, 0, 241845.159705), -- Sealed Dark Crystal Boots Lining
(25106, 5509, 16, 48, 0, 158710.862605), -- Sealed Tallum Gloves Design
(25106, 5497, 23, 67, 0, 112861.674885), -- Sealed Tallum Boots Lining
(25106, 212, 1, 1, 1, 9218.703769), -- Dasparion's Staff
(25106, 2504, 1, 1, 1, 9218.703769), -- Meteor Shower
(25106, 5543, 4, 12, 1, 276498.046781), -- Dasparion's Staff Head
(25106, 5532, 8, 22, 1, 146087.545681), -- Meteor Shower Head
(25106, 6570, 1, 1, 2, 93596.41712), -- Blessed Scroll: Enchant Armor (A-Grade)
(25106, 6571, 1, 1, 2, 24067.58288), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25106, 9814, 1, 4, 2, 840000), -- Memento Mori
(25106, 8176, 1, 2, 2, 720000), -- Destruction Tombstone
-- Antharas Priest Cloe
(25109, 5311, 1, 1, 0, 17049.26124), -- Sealed Armor of Nightmare
(25109, 5316, 1, 1, 0, 17049.26124), -- Sealed Majestic Plate Armor
(25109, 5522, 4, 12, 0, 319487.89734), -- Sealed Armor of Nightmare Pattern
(25109, 5523, 8, 22, 0, 170393.58018), -- Sealed Majestic Plate Armor Pattern
(25109, 305, 1, 1, 1, 21710.891685), -- Tallum Glaive
(25109, 5541, 12, 36, 1, 257274.108315), -- Tallum Glaive Edge
(25109, 6578, 1, 1, 2, 64858.792284), -- Blessed Scroll: Enchant Armor (S-Grade)
(25109, 6570, 1, 1, 2, 162147.207716), -- Blessed Scroll: Enchant Armor (A-Grade)
(25109, 8619, 1, 1, 2, 560000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25109, 9814, 3, 7, 2, 820000), -- Memento Mori
(25109, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Beleth's Agent, Meana
(25112, 850, 6, 18, 0, 26510.23429), -- Elven Earring
(25112, 881, 5, 15, 0, 47751.962331), -- Elven Ring
(25112, 913, 1, 1, 0, 238758.496337), -- Elven Necklace
(25112, 1902, 81, 243, 0, 71525.677522), -- Elven Earring Beads
(25112, 1903, 40, 120, 0, 238459.261492), -- Elven Ring Piece
(25112, 1904, 154, 462, 0, 34653.368028), -- Elven Necklace Beads
(25112, 93, 1, 1, 1, 47918.363584), -- Winged Spear
(25112, 294, 1, 1, 1, 47918.363584), -- War Pick
(25112, 2033, 4, 12, 1, 358807.610798), -- Winged Spear Blade
(25112, 2041, 8, 22, 1, 191364.662034), -- War Pick Head
(25112, 956, 12, 36, 2, 926570), -- Scroll: Enchant Armor (D-Grade)
-- Icarus Sample 1
(25115, 62, 11, 33, 0, 7592.95865), -- Reinforced Mithril Boots
(25115, 2429, 12, 34, 0, 7262.6955), -- Chain Boots
(25115, 2430, 12, 36, 0, 6960.27655), -- Karmian Boots
(25115, 2431, 13, 37, 0, 6681.83455), -- Plated Leather Boots
(25115, 2432, 13, 39, 0, 6424.2757), -- Dwarven Chain Boots
(25115, 2433, 14, 40, 0, 6186.82655), -- Boots of Seal
(25115, 2452, 14, 42, 0, 5965.61985), -- Reinforced Mithril Gloves
(25115, 2453, 15, 43, 0, 5759.88215), -- Chain Gloves
(25115, 2454, 1, 1, 0, 167038.12925), -- Karmian Gloves
(25115, 1958, 220, 660, 0, 16567.299), -- Reinforced Mithril Boots Design
(25115, 2937, 378, 1134, 0, 9642.60115), -- Chain Boots Part
(25115, 2938, 26, 78, 0, 140184.7187), -- Karmian Boots Fabric
(25115, 2939, 35, 105, 0, 104137.308), -- Plate Leather Boots Lining
(25115, 2940, 45, 135, 0, 80995.684), -- Dwarven Chain Boots Part
(25115, 2941, 56, 168, 0, 65085.8175), -- Boots of Seal Pattern
(25115, 2942, 68, 204, 0, 53600.085), -- Reinforced Mithril Gloves Design
(25115, 2943, 81, 243, 0, 44997.7741), -- Chain Gloves Design
(25115, 2944, 95, 285, 0, 38366.2138), -- Karmian Gloves Fabric
(25115, 263, 1, 1, 1, 124210.65636), -- Chakram
(25115, 2073, 12, 36, 1, 352609.34364), -- Chakram Edge
(25115, 4594, 2, 6, 2, 295678.607409), -- Greater Dye of DEX (Dex+2 Con-2)
(25115, 4595, 3, 7, 2, 236542.212344), -- Greater Dye of INT (Int+2 Men-2)
(25115, 4596, 3, 9, 2, 197119.071606), -- Greater Dye of INT (Int+2 Wit-2)
(25115, 952, 21, 63, 2, 112639.108641), -- Scroll: Enchant Armor (C-Grade)
(25115, 9817, 1, 4, 2, 810000), -- Nonliving Nucleus
(25115, 8176, 1, 2, 2, 680000), -- Destruction Tombstone
-- Guillotine, Warden of the Execution Grounds
(25118, 353, 1, 1, 0, 134016.19392), -- Half Plate Armor
(25118, 380, 1, 1, 0, 214426.15936), -- Plate Gaiters
(25118, 1950, 53, 157, 0, 62305.00416), -- Half Plate Temper
(25118, 1951, 24, 72, 0, 211972.64256), -- Plate Gaiters Part
(25118, 159, 1, 1, 1, 17438.52864), -- Bonebreaker
(25118, 187, 1, 1, 1, 17438.52864), -- Atuba Hammer
(25118, 188, 1, 1, 1, 17438.52864), -- Ghost Staff
(25118, 189, 1, 1, 1, 17438.52864), -- Staff of Life
(25118, 190, 1, 1, 1, 17438.52864), -- Atuba Mace
(25118, 2048, 18, 54, 1, 27776.526336), -- Bonebreaker Head
(25118, 2049, 3, 7, 1, 199993.275456), -- Atuba Hammer Head
(25118, 2050, 7, 21, 1, 75734.585472), -- Ghost Staff Head
(25118, 2051, 12, 36, 1, 44178.608448), -- Staff of Life Shaft
(25118, 2058, 3, 9, 1, 166660.361088), -- Atuba Mace Head
(25118, 4591, 1, 3, 2, 326602.419916), -- Greater Dye of CON (Con+2 Str-2)
(25118, 4592, 2, 4, 2, 217735.186845), -- Greater Dye of CON (Con+2 Dex-2)
(25118, 4593, 2, 6, 2, 163301.209958), -- Greater Dye of DEX (Dex+2 Str-2)
(25118, 6573, 1, 1, 2, 13064.183281), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Messenger of Fairy Queen Berun
(25119, 357, 1, 1, 0, 30552.824718), -- Zubei's Breastplate
(25119, 383, 1, 1, 0, 48875.5131), -- Zubei's Gaiters
(25119, 2376, 1, 1, 0, 30552.824718), -- Avadon Breastplate
(25119, 2379, 1, 1, 0, 48875.5131), -- Avadon Gaiters
(25119, 4056, 16, 48, 0, 137903.48307), -- Zubei's Breastplate Part
(25119, 4057, 60, 180, 0, 56833.021182), -- Zubei's Gaiter Material
(25119, 4064, 23, 67, 0, 98064.699072), -- Avadon Breastplate Part
(25119, 4065, 11, 31, 0, 324760.12104), -- Avadon Gaiters Material
(25119, 78, 1, 1, 1, 14598.401832), -- Great Sword
(25119, 142, 1, 1, 1, 14598.401832), -- Keshanberk
(25119, 148, 1, 1, 1, 14598.401832), -- Sword of Valhalla
(25119, 4104, 5, 15, 1, 279038.711868), -- Great Sword Blade
(25119, 4107, 9, 27, 1, 152619.603374), -- Keshanberk Blade
(25119, 4108, 14, 42, 1, 98112.479262), -- Sword of Valhalla Blade
(25119, 4607, 5, 15, 2, 105350.670687), -- Greater Dye of INT (Int+3 Men-3)
(25119, 4608, 2, 4, 2, 351168.90229), -- Greater Dye of INT (Int+3 Wit-3)
(25119, 4609, 2, 6, 2, 263376.300967), -- Greater Dye of MEN (Men+3 Int-3)
(25119, 6573, 1, 1, 2, 31605.126056), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25119, 9818, 2, 5, 2, 770000), -- Angelic Essence
(25119, 8176, 1, 2, 2, 900000), -- Destruction Tombstone
-- Refugee Applicant Leo
(25122, 2391, 1, 1, 0, 23096.919312), -- Blue Wolf Leather Armor
(25122, 2392, 1, 1, 0, 23096.919312), -- Leather Armor of Doom
(25122, 4082, 24, 72, 0, 82018.851696), -- Blue Wolf Leather Armor Texture
(25122, 4083, 8, 22, 0, 262459.30968), -- Leather Armor of Doom Design
(25122, 268, 1, 1, 1, 20715.68432), -- Bellion Cestus
(25122, 4120, 3, 9, 1, 761244.31568), -- Bellion Cestus Edge
(25122, 4616, 2, 4, 2, 155741.908966), -- Greater Dye of CON (Con+4 Dex-4)
(25122, 4617, 2, 6, 2, 116806.23437), -- Greater Dye of DEX (Dex+4 Str-4)
(25122, 4618, 3, 7, 2, 93444.987496), -- Greater Dye of DEX (Dex+4 Con-4)
(25122, 948, 1, 3, 2, 423424.869168), -- Scroll: Enchant Armor (B-Grade)
(25122, 9816, 1, 4, 2, 770000), -- Earth Egg
(25122, 8176, 1, 2, 2, 650000), -- Destruction Tombstone
-- Fierce Tiger King Angel
(25125, 5304, 1, 1, 0, 35962.222023), -- Sealed Tallum Tunic
(25125, 5305, 1, 1, 0, 57518.271783), -- Sealed Tallum Stockings
(25125, 5308, 1, 1, 0, 22127.45283), -- Sealed Dark Crystal Robe
(25125, 5485, 9, 27, 0, 224370.065115), -- Sealed Tallum Tunic Texture
(25125, 5489, 28, 84, 0, 113197.569282), -- Sealed Tallum Stockings Fabric
(25125, 5486, 20, 60, 0, 71047.418967), -- Sealed Dark Crystal Robe Fabric
(25125, 212, 1, 1, 1, 15330.113879), -- Dasparion's Staff
(25125, 2504, 1, 1, 1, 15330.113879), -- Meteor Shower
(25125, 5543, 4, 12, 1, 459798.541171), -- Dasparion's Staff Head
(25125, 5532, 8, 22, 1, 242934.231071), -- Meteor Shower Head
(25125, 6570, 1, 1, 2, 155644.617954), -- Blessed Scroll: Enchant Armor (A-Grade)
(25125, 6569, 1, 1, 2, 18677.382046), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25125, 9816, 3, 7, 2, 800000), -- Earth Egg
(25125, 8176, 1, 4, 2, 800000), -- Destruction Tombstone
-- Longhorn Golkonda
(25126, 6678, 1, 1, 0, 30142.910967), -- Sealed Imperial Crusader Shield
(25126, 6679, 1, 1, 0, 21099.48837), -- Sealed Imperial Crusader Helmet
(25126, 6683, 1, 1, 0, 21099.48837), -- Sealed Draconic Leather Helmet
(25126, 6687, 1, 1, 0, 21099.48837), -- Sealed Major Arcana Circlet
(25126, 6705, 23, 67, 0, 156706.272432), -- Sealed Imperial Crusader Shield Part
(25126, 6706, 60, 180, 0, 68354.529954), -- Sealed Imperial Crusader Helmet Pattern
(25126, 6710, 116, 346, 0, 35509.029039), -- Sealed Draconic Leather Helmet Pattern
(25126, 6714, 16, 48, 0, 256329.792498), -- Sealed Major Arcana Circlet Pattern
(25126, 6365, 1, 1, 1, 3547.62376), -- Basalt Battlehammer
(25126, 6366, 1, 1, 1, 3547.62376), -- Imperial Staff
(25126, 6369, 1, 1, 1, 3547.62376), -- Dragon Hunter Axe
(25126, 6579, 1, 1, 1, 3547.62376), -- Arcana Mace
(25126, 6689, 16, 48, 1, 50263.5348), -- Basalt Battlehammer Head
(25126, 6690, 11, 31, 1, 78211.8584), -- Imperial Staff Head
(25126, 6693, 6, 18, 1, 139086.28216), -- Dragon Hunter Axe Blade
(25126, 6697, 3, 7, 1, 321687.8296), -- Arcana Mace Head
(25126, 6578, 1, 1, 2, 87395.846057), -- Blessed Scroll: Enchant Armor (S-Grade)
(25126, 3936, 1, 3, 2, 491603.153943), -- Blessed Scroll of Resurrection
-- Langk Matriarch Rashkos
(25127, 46, 2, 4, 0, 495635.644724), -- Bronze Helmet
(25127, 627, 4, 12, 0, 265321.355276), -- Aspis
(25127, 222, 1, 1, 1, 345695), -- Poniard Dagger
(25127, 6575, 1, 1, 2, 41119.434216), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25127, 6576, 1, 1, 2, 370071.782892), -- Blessed Scroll: Enchant Armor (D-Grade)
(25127, 955, 1, 3, 2, 370071.782892), -- Scroll: Enchant Weapon (D-Grade)
-- Vuku Grand Priest Gharmash
(25128, 851, 6, 18, 0, 22045.716132), -- Omen Beast's Eye Earring
(25128, 882, 5, 15, 0, 39682.403871), -- Mithril Ring
(25128, 914, 1, 1, 0, 198411.445188), -- Necklace of Darkness
(25128, 1905, 81, 243, 0, 74105.438022), -- Omen Beast's Eye Earring Gemstone
(25128, 1906, 40, 120, 0, 212047.911438), -- Mithril Ring Wire
(25128, 1907, 154, 462, 0, 27874.085349), -- Necklace of Darkness Gem
(25128, 159, 1, 1, 1, 16015.97297), -- Bonebreaker
(25128, 187, 1, 1, 1, 16015.97297), -- Atuba Hammer
(25128, 188, 1, 1, 1, 16015.97297), -- Ghost Staff
(25128, 189, 1, 1, 1, 16015.97297), -- Staff of Life
(25128, 190, 1, 1, 1, 16015.97297), -- Atuba Mace
(25128, 2048, 2, 6, 1, 229594.306139), -- Bonebreaker Head
(25128, 2049, 3, 7, 1, 183676.050144), -- Atuba Hammer Head
(25128, 2050, 7, 21, 1, 69555.622999), -- Ghost Staff Head
(25128, 2051, 12, 36, 1, 40574.050371), -- Staff of Life Shaft
(25128, 2058, 3, 9, 1, 153061.105497), -- Atuba Mace Head
(25128, 951, 1, 1, 2, 436304.797848), -- Scroll: Enchant Weapon (C-Grade)
(25128, 952, 3, 9, 2, 533260.543536), -- Scroll: Enchant Armor (C-Grade)
(25128, 6573, 1, 1, 2, 15997.658616), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Carnage Lord Gato
(25131, 2397, 1, 1, 0, 34264.448611), -- Tunic of Zubei
(25131, 2402, 1, 1, 0, 54809.727337), -- Stockings of Zubei
(25131, 2406, 1, 1, 0, 21076.070966), -- Avadon Robe
(25131, 4069, 9, 27, 0, 268603.794014), -- Tunic of Zubei Fabric
(25131, 4070, 40, 120, 0, 91762.518009), -- Stockings of Zubei Fabric
(25131, 4071, 14, 42, 0, 132656.441063), -- Avadon Robe Fabric
(25131, 91, 1, 1, 1, 13813.737044), -- Heavy War Axe
(25131, 92, 1, 1, 1, 13813.737044), -- Sprite's Staff
(25131, 4105, 4, 12, 1, 330057.703012), -- Heavy War Axe Head
(25131, 4106, 8, 22, 1, 173142.8229), -- Sprite's Staff Head
(25131, 4610, 1, 3, 2, 332293.680726), -- Greater Dye of MEN (Men+3 Wit-3)
(25131, 4611, 2, 4, 2, 221529.120484), -- Greater Dye of WIT (Wit+3 Int-3)
(25131, 4612, 2, 6, 2, 166146.840363), -- Greater Dye of WIT (Wit+3 Men-3)
(25131, 6574, 1, 1, 2, 170893.358427), -- Blessed Scroll: Enchant Armor (C-Grade)
(25131, 9814, 1, 3, 2, 850000), -- Memento Mori
(25131, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Leto Chief Talkin
(25134, 631, 6, 16, 0, 27503.529111), -- Eldarake
(25134, 2413, 1, 1, 0, 211798.631457), -- Chain Hood
(25134, 2495, 6, 18, 0, 25211.523537), -- Chain Shield
(25134, 1964, 40, 120, 0, 155853.690147), -- Eldarake Temper
(25134, 2936, 140, 420, 0, 40444.594839), -- Chain Hood Pattern
(25134, 2945, 81, 243, 0, 76965.030909), -- Chain Shield Fragment
(25134, 281, 1, 1, 1, 78770.879994), -- Crystallized Ice Bow
(25134, 2074, 12, 36, 1, 204903.120006), -- Crystallized Ice Bow Shaft
(25134, 4597, 1, 3, 2, 375022.035428), -- Greater Dye of MEN (Men+2 Int-2)
(25134, 4598, 2, 4, 2, 250014.966135), -- Greater Dye of MEN (Men+2 Wit-2)
(25134, 4599, 2, 6, 2, 187511.017714), -- Greater Dye of WIT (Wit+2 Int-2)
(25134, 6573, 1, 1, 2, 15000.980723), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25134, 9816, 1, 2, 2, 850000), -- Earth Egg
(25134, 8176, 1, 1, 2, 650000), -- Destruction Tombstone
-- Beleth's Seer, Sephia
(25137, 503, 1, 1, 0, 56421.181217), -- Zubei's Helmet
(25137, 633, 1, 1, 0, 80606.157826), -- Zubei's Shield
(25137, 673, 1, 1, 0, 80606.157826), -- Avadon Shield
(25137, 2415, 1, 1, 0, 56421.181217), -- Avadon Circlet
(25137, 4102, 192, 576, 0, 19751.054201), -- Zubei's Helmet Design
(25137, 4101, 116, 346, 0, 42378.621582), -- Zubei's Shield Fragment
(25137, 4439, 60, 180, 0, 97051.027213), -- Avadon Shield Fragment
(25137, 4072, 23, 67, 0, 168545.618918), -- Avadon Circlet Pattern
(25137, 267, 1, 1, 1, 30333.380207), -- Arthro Nail
(25137, 4111, 12, 36, 1, 241585.619793), -- Arthro Nail Blade
(25137, 4613, 1, 3, 2, 226452.18376), -- Greater Dye of STR (Str+4 Con-4)
(25137, 4614, 2, 4, 2, 150968.402409), -- Greater Dye of STR (Str+4 Dex-4)
(25137, 4615, 1, 1, 2, 452904.36752), -- Greater Dye of CON (Con+4 Str-4)
(25137, 6571, 1, 1, 2, 9382.046311), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25137, 9814, 1, 4, 2, 750000), -- Memento Mori
(25137, 8176, 1, 4, 2, 750000), -- Destruction Tombstone
-- Hekaton Prime
(25140, 6323, 1, 1, 0, 71682.871665), -- Sealed Phoenix Necklace
(25140, 6324, 1, 1, 0, 95577.60153), -- Sealed Phoenix Earring
(25140, 6325, 1, 1, 0, 143365.74333), -- Sealed Phoenix Ring
(25140, 6343, 140, 420, 0, 36674.697075), -- Sealed Phoenix Necklace Beads
(25140, 6341, 81, 243, 0, 81998.96874), -- Sealed Phoenix Earring Gemstone
(25140, 6345, 40, 120, 0, 229665.11766), -- Sealed Phoenix Ring Gemstone
(25140, 98, 1, 1, 1, 30660.191175), -- Halberd
(25140, 5542, 12, 36, 1, 303674.808825), -- Halberd Edge
(25140, 729, 1, 1, 2, 103763.205969), -- Scroll: Enchant Weapon (A-Grade)
(25140, 730, 1, 1, 2, 778226.28087), -- Scroll: Enchant Armor (A-Grade)
(25140, 6569, 1, 1, 2, 12451.513161), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25140, 9817, 3, 7, 2, 800000), -- Nonliving Nucleus
(25140, 8176, 1, 4, 2, 800000), -- Destruction Tombstone
-- Fire of Wrath Shuriel
(25143, 6680, 1, 1, 0, 26700.84925), -- Sealed Draconic Leather Armor
(25143, 6707, 12, 36, 0, 429334.15075), -- Sealed Draconic Leather Armor Part
(25143, 6371, 1, 1, 1, 14590.453956), -- Demon Splinter
(25143, 6695, 12, 36, 1, 275645.546044), -- Demon Splinter Blade
(25143, 959, 1, 1, 2, 53915.408464), -- Scroll: Enchant Weapon (S-Grade)
(25143, 960, 1, 1, 2, 539155.288754), -- Scroll: Enchant Armor (S-Grade)
(25143, 6577, 1, 1, 2, 8986.302782), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Serpent Demon Bifrons
(25146, 848, 3, 9, 0, 133492.95575), -- Enchanted Earring
(25146, 879, 3, 7, 0, 241022.0045), -- Enchanted Ring
(25146, 911, 4, 10, 0, 85882.46825), -- Enchanted Necklace
(25146, 1900, 96, 288, 0, 74852.5715), -- Enchanted Necklace Chain
(25146, 275, 1, 1, 1, 106040.081716), -- Long Bow
(25146, 276, 1, 1, 1, 106040.081716), -- Elven Bow
(25146, 2024, 12, 36, 1, 155931.836568), -- Elven Bow Shaft
(25146, 6575, 1, 1, 2, 56759.2), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25146, 6576, 1, 1, 2, 510832.8), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Zombie Lord Crowl
(25149, 436, 2, 4, 0, 167391.631989), -- Tunic of Knowledge
(25149, 469, 1, 3, 0, 401327.368011), -- Stockings of Knowledge
(25149, 83, 1, 1, 1, 53335.55656), -- Sword of Magic
(25149, 144, 1, 1, 1, 53335.55656), -- Sword of Occult
(25149, 124, 1, 1, 1, 39512.47916), -- Two-Handed Sword
(25149, 127, 1, 1, 1, 39512.47916), -- Crimson Sword
(25149, 130, 1, 1, 1, 39512.47916), -- Elven Sword
(25149, 2026, 3, 9, 1, 294651.4494), -- Two-Handed Sword Edge
(25149, 6576, 1, 3, 2, 571224), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Flame Lord Shadar
(25152, 438, 1, 1, 0, 219923.93547), -- Sage's Rag
(25152, 1953, 12, 36, 0, 538011.06453), -- Sage's Rag Lining
(25152, 262, 1, 1, 1, 87192.585431), -- Scallop Jamadhr
(25152, 2053, 12, 36, 1, 208326.414569), -- Scallop Jamadhr Edge
(25152, 4594, 1, 3, 2, 326602.621394), -- Greater Dye of DEX (Dex+2 Con-2)
(25152, 4595, 2, 4, 2, 217735.354135), -- Greater Dye of INT (Int+2 Men-2)
(25152, 4596, 2, 6, 2, 163301.310697), -- Greater Dye of INT (Int+2 Wit-2)
(25152, 6574, 1, 1, 2, 111977.713774), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Shaman King Selu
(25155, 397, 1, 1, 0, 250826.039528), -- Mithril Shirt
(25155, 2387, 5, 13, 0, 44536.42216), -- Reinforced Mithril Gaiters
(25155, 1961, 53, 157, 0, 111223.577616), -- Mithril Shirt Fabric
(25155, 2935, 192, 576, 0, 50525.960696), -- Reinforced Mithril Gaiters Fragment
(25155, 226, 1, 1, 1, 62105.317868), -- Cursed Dagger
(25155, 232, 1, 1, 1, 62105.317868), -- Dark Elven Dagger
(25155, 2070, 24, 72, 1, 90556.779588), -- Cursed Dagger Blade
(25155, 2072, 8, 22, 1, 289780.584676), -- Dark Elven Dagger Edge
(25155, 4600, 3, 9, 2, 394238.23092), -- Greater Dye of WIT (Wit+2 Men-2)
(25155, 6574, 1, 1, 2, 405501.76908), -- Blessed Scroll: Enchant Armor (C-Grade)
(25155, 9814, 1, 4, 2, 810000), -- Memento Mori
(25155, 8176, 1, 2, 2, 680000), -- Destruction Tombstone
-- King Tarlk
(25158, 400, 1, 1, 0, 88525.085433), -- Theca Leather Armor
(25158, 420, 1, 1, 0, 141702.871516), -- Theca Leather Gaiters
(25158, 401, 1, 1, 0, 41919.125848), -- Drake Leather Armor
(25158, 1984, 81, 243, 0, 37191.608814), -- Theca Leather Armor Pattern
(25158, 1985, 28, 84, 0, 173070.872729), -- Theca Leather Gaiters Pattern
(25158, 1987, 20, 60, 0, 107203.43566), -- Drake Leather Armor Texture
(25158, 135, 1, 1, 1, 26833.6432), -- Samurai Longsword
(25158, 5286, 1, 1, 1, 26833.6432), -- Berserker Blade
(25158, 2115, 8, 22, 1, 193153.47584), -- Samurai Longsword Blade
(25158, 5530, 4, 12, 1, 362619.23776), -- Berserker Blade Edge
(25158, 4610, 5, 15, 2, 91086.631521), -- Greater Dye of MEN (Men+3 Wit-3)
(25158, 4611, 2, 4, 2, 303622.10507), -- Greater Dye of WIT (Wit+3 Int-3)
(25158, 4612, 2, 6, 2, 227717.007127), -- Greater Dye of WIT (Wit+3 Men-3)
(25158, 6574, 1, 1, 2, 234223.256282), -- Blessed Scroll: Enchant Armor (C-Grade)
(25158, 9817, 2, 4, 2, 760000), -- Nonliving Nucleus
(25158, 8176, 1, 2, 2, 770000), -- Destruction Tombstone
-- Paniel the Unicorn
(25159, 357, 1, 1, 0, 20511.275889), -- Zubei's Breastplate
(25159, 383, 1, 1, 0, 32811.99505), -- Zubei's Gaiters
(25159, 2376, 1, 1, 0, 20511.275889), -- Avadon Breastplate
(25159, 2379, 1, 1, 0, 32811.99505), -- Avadon Gaiters
(25159, 4056, 16, 48, 0, 92579.864985), -- Zubei's Breastplate Part
(25159, 4057, 60, 180, 0, 38154.173561), -- Zubei's Gaiter Material
(25159, 4064, 23, 67, 0, 65834.570656), -- Avadon Breastplate Part
(25159, 4065, 11, 31, 0, 218023.84892), -- Avadon Gaiters Material
(25159, 284, 1, 1, 1, 29401.411585), -- Dark Elven Long Bow
(25159, 4112, 12, 36, 1, 231677.588415), -- Dark Elven Longbow Shaft
(25159, 4619, 1, 3, 2, 219494.17008), -- Greater Dye of INT (Int+4 Men-4)
(25159, 4620, 2, 4, 2, 146329.718022), -- Greater Dye of INT (Int+4 Wit-4)
(25159, 4621, 1, 1, 2, 438988.34016), -- Greater Dye of MEN (Men+4 Int-4)
(25159, 6571, 1, 1, 2, 9093.771738), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25159, 9818, 1, 3, 2, 900000), -- Angelic Essence
(25159, 8176, 1, 1, 2, 900000), -- Destruction Tombstone
-- Giant Marpanak
(25162, 110, 1, 1, 0, 122849.753904), -- Doom Shield
(25162, 2416, 1, 1, 0, 85994.028216), -- Blue Wolf Helmet
(25162, 2417, 1, 1, 0, 85994.028216), -- Doom Helmet
(25162, 4077, 40, 120, 0, 224437.69104), -- Doom Shield Fragment
(25162, 4088, 81, 243, 0, 93115.057848), -- Blue Wolf Helmet Design
(25162, 4089, 140, 420, 0, 53873.440776), -- Doom Helmet Pattern
(25162, 287, 1, 1, 1, 35597.131464), -- Bow of Peril
(25162, 4121, 12, 36, 1, 325930.868536), -- Bow of Peril Shaft
(25162, 4622, 2, 4, 2, 267621.893865), -- Greater Dye of MEN (Men+4 Wit-4)
(25162, 4623, 2, 6, 2, 200716.607943), -- Greater Dye of WIT (Wit+4 Int-4)
(25162, 4624, 3, 7, 2, 160573.136319), -- Greater Dye of WIT (Wit+4 Men-4)
(25162, 948, 6, 18, 2, 121265.361873), -- Scroll: Enchant Armor (B-Grade)
(25162, 9817, 2, 6, 2, 830000), -- Nonliving Nucleus
(25162, 8176, 1, 3, 2, 830000), -- Destruction Tombstone
-- Roaring Skylancer
(25163, 5320, 1, 1, 0, 22289.045658), -- Sealed Leather Armor of Nightmare
(25163, 5323, 1, 1, 0, 22289.045658), -- Sealed Majestic Leather Armor
(25163, 5480, 4, 12, 0, 412748.06108), -- Sealed Leather Armor of Nightmare Fabric
(25163, 5481, 8, 22, 0, 220131.847604), -- Sealed Majestic Leather Armor Fabric
(25163, 81, 1, 1, 1, 7095.82683), -- Dragon Slayer
(25163, 151, 1, 1, 1, 7095.82683), -- Sword of Miracles
(25163, 2500, 1, 1, 1, 7095.82683), -- Dark Legion's Edge
(25163, 5529, 9, 27, 1, 112159.87101), -- Dragon Slayer Edge
(25163, 5546, 5, 15, 1, 221754.630105), -- Sword of Miracles Edge
(25163, 5545, 14, 42, 1, 72103.018395), -- Dark Legion's Edge Blade
(25163, 959, 1, 1, 2, 38156.405712), -- Scroll: Enchant Weapon (S-Grade)
(25163, 960, 1, 1, 2, 381564.909282), -- Scroll: Enchant Armor (S-Grade)
(25163, 6577, 1, 1, 2, 6359.685006), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25163, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25163, 9815, 3, 7, 2, 810000), -- Dragon Heart
(25163, 8176, 1, 4, 2, 810000), -- Destruction Tombstone
-- Ikuntai
(25166, 849, 4, 10, 0, 132966.5024), -- Tiger's Eye Earring
(25166, 880, 3, 7, 0, 278664.95744), -- Black Pearl Ring
(25166, 912, 4, 12, 0, 87215.2064), -- Near Forest Necklace
(25166, 1901, 72, 216, 0, 220513.33376), -- Tiger's Eye Earring Stone
(25166, 157, 1, 1, 1, 123684.743895), -- Spiked Club
(25166, 186, 1, 1, 1, 123684.743895), -- Staff of Magic
(25166, 2027, 12, 36, 1, 250975.51221), -- Spiked Club Head
(25166, 6387, 60, 180, 2, 298017), -- Blessed Scroll of Resurrection for Pets
-- Ragraman
(25169, 606, 10, 30, 0, 10794.866538), -- Rip Gauntlets
(25169, 1124, 11, 31, 0, 10281.029178), -- Boots of Power
(25169, 2424, 11, 33, 0, 9813.579913), -- Manticore Skin Boots
(25169, 2425, 12, 34, 0, 9386.809439), -- Brigandine Boots
(25169, 2426, 12, 36, 0, 8995.722115), -- Elven Mithril Boots
(25169, 2448, 13, 37, 0, 8636.035963), -- Manticore Skin Gloves
(25169, 2449, 13, 39, 0, 8303.469005), -- Brigandine Gauntlets
(25169, 2450, 14, 40, 0, 7996.593915), -- Mithril Gloves
(25169, 1946, 180, 540, 0, 23259.704496), -- Rip Gauntlets Pattern
(25169, 1948, 314, 940, 0, 13354.775719), -- Boots of Power Pattern
(25169, 2923, 24, 72, 0, 174445.642731), -- Manticore Skin Boot Lining
(25169, 2924, 33, 97, 0, 128821.167141), -- Brigandine Boots Design
(25169, 2925, 42, 126, 0, 99683.020514), -- Elven Mithril Boots Design
(25169, 2926, 53, 157, 0, 79746.130946), -- Manticore Skin Gloves Lining
(25169, 2927, 64, 192, 0, 65417.205232), -- Brigandine Gauntlets Pattern
(25169, 2928, 77, 229, 0, 54727.247155), -- Mithril Gloves Design
(25169, 129, 1, 1, 1, 138463.796885), -- Sword of Revolution
(25169, 2034, 12, 36, 1, 327341.203115), -- Sword of Revolution Blade
(25169, 4553, 5, 15, 2, 96386.234882), -- Greater Dye of STR (Str+1 Con-1)
(25169, 4554, 2, 4, 2, 321288.399192), -- Greater Dye of STR (Str+1 Dex-1)
(25169, 4555, 2, 6, 2, 240966.299394), -- Greater Dye of CON (Con+1 Str-1)
(25169, 6575, 1, 1, 2, 53548.066532), -- Blessed Scroll: Enchant Weapon (D-Grade)
-- Lizardmen Leader Hellion
(25170, 631, 6, 16, 0, 25658.26035), -- Eldarake
(25170, 2413, 1, 1, 0, 197590.35285), -- Chain Hood
(25170, 2495, 1, 1, 0, 282244.665975), -- Chain Shield
(25170, 1964, 40, 120, 0, 145398.582975), -- Eldarake Temper
(25170, 2936, 140, 420, 0, 37731.528075), -- Chain Hood Pattern
(25170, 2945, 81, 243, 0, 71801.609775), -- Chain Shield Fragment
(25170, 226, 1, 1, 1, 36743.029232), -- Cursed Dagger
(25170, 232, 1, 1, 1, 36743.029232), -- Dark Elven Dagger
(25170, 2070, 4, 12, 1, 321455.203888), -- Cursed Dagger Blade
(25170, 2072, 8, 22, 1, 171442.737648), -- Dark Elven Dagger Edge
(25170, 951, 1, 3, 2, 763333), -- Scroll: Enchant Weapon (C-Grade)
-- Tiger King Karuta
(25173, 64, 1, 1, 0, 286396.192443), -- Composite Boots
(25173, 608, 1, 1, 0, 286396.192443), -- Mithril Gauntlets
(25173, 2956, 192, 576, 0, 41415.03621), -- Composite Boots Part
(25173, 1981, 53, 157, 0, 151461.578904), -- Mithril Gauntlets Design
(25173, 326, 1, 1, 1, 49092.126514), -- Heathen's Book
(25173, 2110, 12, 36, 1, 190500.873486), -- Heathen's Book Page
(25173, 4610, 1, 3, 2, 292053.478962), -- Greater Dye of MEN (Men+3 Wit-3)
(25173, 4611, 2, 4, 2, 194702.319308), -- Greater Dye of WIT (Wit+3 Int-3)
(25173, 4612, 2, 6, 2, 146026.739481), -- Greater Dye of WIT (Wit+3 Men-3)
(25173, 6574, 1, 1, 2, 150198.462249), -- Blessed Scroll: Enchant Armor (C-Grade)
(25173, 9816, 1, 3, 2, 750000), -- Earth Egg
(25173, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Black Lily
(25176, 2384, 1, 1, 0, 37620.43575), -- Zubei's Leather Shirt
(25176, 2388, 1, 1, 0, 60177.99525), -- Zubei's Leather Gaiters
(25176, 2390, 1, 1, 0, 23140.3395), -- Avadon Leather Armor
(25176, 4066, 9, 27, 0, 294911.8455), -- Zubei's Leather Shirt Fabric
(25176, 4067, 40, 120, 0, 100750.07925), -- Zubei's Leather Gaiter Texture
(25176, 4068, 14, 42, 0, 145649.30475), -- Avadon Leather Armor Lining
(25176, 284, 1, 1, 1, 30333.413325), -- Dark Elven Long Bow
(25176, 4112, 12, 36, 1, 239021.586675), -- Dark Elven Longbow Shaft
(25176, 4616, 1, 3, 2, 226452.326235), -- Greater Dye of CON (Con+4 Dex-4)
(25176, 4617, 2, 4, 2, 150968.21749), -- Greater Dye of DEX (Dex+4 Str-4)
(25176, 4618, 1, 1, 2, 452903.734585), -- Greater Dye of DEX (Dex+4 Con-4)
(25176, 6572, 1, 1, 2, 87560.72169), -- Blessed Scroll: Enchant Armor (B-Grade)
(25176, 9814, 1, 4, 2, 750000), -- Memento Mori
(25176, 8176, 1, 1, 2, 900000), -- Destruction Tombstone
-- Guardian of the Statue of Giant Karum
(25179, 2391, 1, 1, 0, 25854.381873), -- Blue Wolf Leather Armor
(25179, 2392, 1, 1, 0, 25854.381873), -- Leather Armor of Doom
(25179, 4082, 24, 72, 0, 91810.803159), -- Blue Wolf Leather Armor Texture
(25179, 4083, 8, 22, 0, 293793.433095), -- Leather Armor of Doom Design
(25179, 234, 1, 1, 1, 23188.821312), -- Demon's Dagger
(25179, 4119, 12, 36, 1, 213393.178688), -- Demon's Dagger Edge
(25179, 947, 1, 1, 2, 202229.21472), -- Scroll: Enchant Weapon (B-Grade)
(25179, 948, 1, 3, 2, 631966.08384), -- Scroll: Enchant Armor (B-Grade)
(25179, 6571, 1, 1, 2, 14444.70144), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25179, 9817, 1, 4, 2, 850000), -- Nonliving Nucleus
(25179, 8176, 1, 1, 2, 950000), -- Destruction Tombstone
-- Demon Kuri
(25182, 5290, 1, 1, 0, 52614.08262), -- Sealed Dark Crystal Gloves
(25182, 5291, 1, 1, 0, 52614.08262), -- Sealed Dark Crystal Boots
(25182, 5295, 1, 1, 0, 52614.08262), -- Sealed Tallum Gloves
(25182, 5296, 1, 1, 0, 52614.08262), -- Sealed Tallum Boots
(25182, 5508, 60, 180, 0, 45746.837958), -- Sealed Dark Crystal Gloves Design
(25182, 5496, 116, 346, 0, 23764.658181), -- Sealed Dark Crystal Boots Lining
(25182, 5509, 16, 48, 0, 171551.502612), -- Sealed Tallum Gloves Design
(25182, 5497, 23, 67, 0, 121993.670769), -- Sealed Tallum Boots Lining
(25182, 80, 1, 1, 1, 9964.51008), -- Tallum Blade
(25182, 150, 1, 1, 1, 9964.51008), -- Elemental Sword
(25182, 5548, 4, 12, 1, 298715.91876), -- Tallum Blade Edge
(25182, 5547, 8, 22, 1, 159315.06108), -- Elemental Sword Edge
(25182, 6570, 1, 1, 2, 101168.5), -- Blessed Scroll: Enchant Armor (A-Grade)
(25182, 729, 1, 1, 2, 101168.5), -- Scroll: Enchant Weapon (A-Grade)
(25182, 9814, 1, 4, 2, 830000), -- Memento Mori
(25182, 8176, 1, 2, 2, 700000), -- Destruction Tombstone
-- Tasaba Patriarch Hellena
(25185, 851, 6, 18, 0, 24003.83534), -- Omen Beast's Eye Earring
(25185, 882, 5, 15, 0, 43207.028645), -- Mithril Ring
(25185, 914, 1, 1, 0, 216034.51806), -- Necklace of Darkness
(25185, 1905, 81, 243, 0, 80687.54589), -- Omen Beast's Eye Earring Gemstone
(25185, 1906, 40, 120, 0, 230882.18681), -- Mithril Ring Wire
(25185, 1907, 154, 462, 0, 30349.885255), -- Necklace of Darkness Gem
(25185, 280, 1, 1, 1, 87192.636294), -- Light Crossbow
(25185, 2054, 12, 36, 1, 214425.363706), -- Light Crossbow Shaft
(25185, 4597, 1, 3, 2, 326602.416658), -- Greater Dye of MEN (Men+2 Int-2)
(25185, 4598, 2, 4, 2, 217735.204071), -- Greater Dye of MEN (Men+2 Wit-2)
(25185, 4599, 2, 6, 2, 163301.208329), -- Greater Dye of WIT (Wit+2 Int-2)
(25185, 951, 3, 7, 2, 71258.170942), -- Scroll: Enchant Weapon (C-Grade)
-- Apepi
(25188, 629, 5, 15, 0, 37932.06702), -- Kite Shield
(25188, 2411, 1, 1, 0, 265656.44013), -- Brigandine Helmet
(25188, 2493, 6, 16, 0, 34483.38018), -- Brigandine Shield
(25188, 1947, 336, 1008, 0, 24504.7455), -- Kite Shield Fragment
(25188, 2922, 27, 81, 0, 81566.211), -- Brigandine Helmet Design
(25188, 2929, 60, 180, 0, 137227.15617), -- Brigandine Shield Fragment
(25188, 88, 1, 1, 1, 19167.343272), -- Morning Star
(25188, 90, 1, 1, 1, 19167.343272), -- Goat Head Staff
(25188, 158, 1, 1, 1, 19167.343272), -- Tarbar
(25188, 169, 1, 1, 1, 19167.343272), -- Skull Breaker
(25188, 172, 1, 1, 1, 19167.343272), -- Heavy Bone Club
(25188, 2031, 7, 21, 1, 74424.466732), -- Morning Star Head
(25188, 2032, 3, 9, 1, 158524.644432), -- Goat Head Staff Head
(25188, 2035, 12, 36, 1, 43414.526232), -- Tarbar Head
(25188, 2036, 18, 54, 1, 28943.017488), -- Skull Breaker Head
(25188, 2037, 3, 7, 1, 208388.628756), -- Heavy Bone Club Head
(25188, 4556, 5, 15, 2, 66713.037066), -- Greater Dye of CON (Con+1 Dex-1)
(25188, 4557, 2, 4, 2, 222376.79022), -- Greater Dye of DEX (Dex+1 Str-1)
(25188, 4558, 2, 6, 2, 166782.987384), -- Greater Dye of DEX (Dex+1 Con-1)
(25188, 6576, 1, 1, 2, 333565.18533), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Cronos' Servitor Mumu
(25189, 438, 1, 1, 0, 210544.158658), -- Sage's Rag
(25189, 1953, 12, 36, 0, 515064.841342), -- Sage's Rag Lining
(25189, 280, 1, 1, 1, 83473.872582), -- Light Crossbow
(25189, 2054, 12, 36, 1, 205280.127418), -- Light Crossbow Shaft
(25189, 952, 12, 36, 2, 416897), -- Scroll: Enchant Armor (C-Grade)
-- Earth Protector Panathen
(25192, 440, 1, 1, 0, 165585.995067), -- Robe of Seal
(25192, 1970, 12, 36, 0, 465225.004933), -- Robe of Seal Fabric
(25192, 325, 1, 1, 1, 67880.705832), -- Horn of Glory
(25192, 2088, 12, 36, 1, 220235.294168), -- Horn of Glory Fragment
(25192, 6574, 1, 1, 2, 555541), -- Blessed Scroll: Enchant Armor (C-Grade)
(25192, 9816, 1, 2, 2, 890000), -- Earth Egg
(25192, 8176, 1, 1, 2, 700000), -- Destruction Tombstone
-- Fafurion's Herald Lokness
(25198, 5311, 1, 1, 0, 16716.708375), -- Sealed Armor of Nightmare
(25198, 5316, 1, 1, 0, 16716.708375), -- Sealed Majestic Plate Armor
(25198, 164, 1, 1, 0, 7095.791625), -- Elysian
(25198, 213, 1, 1, 0, 7095.791625), -- Branch of the Mother Tree
(25198, 5522, 6, 18, 1, 313254.995702), -- Sealed Armor of Nightmare Pattern
(25198, 5523, 11, 31, 1, 179002.574363), -- Sealed Majestic Plate Armor Pattern
(25198, 5533, 16, 48, 1, 94615.936117), -- Elysian Head
(25198, 5544, 23, 67, 1, 67215.493818), -- Branch of the Mother Tree Head
(25198, 6578, 1, 1, 2, 63593.865232), -- Blessed Scroll: Enchant Armor (S-Grade)
(25198, 6569, 1, 1, 2, 19078.134768), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25198, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25198, 9815, 3, 7, 2, 820000), -- Dragon Heart
(25198, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Water Dragon Priest Sheshark
(25199, 6326, 1, 1, 0, 74440.128384), -- Sealed Majestic Necklace
(25199, 6327, 1, 1, 0, 99286.592238), -- Sealed Majestic Earring
(25199, 6328, 1, 1, 0, 148880.256768), -- Sealed Majestic Ring
(25199, 270, 1, 1, 0, 7171.02261), -- Dragon Grinder
(25199, 6344, 240, 720, 1, 34067.708416), -- Sealed Majestic Necklace Beads
(25199, 6342, 90, 270, 1, 140381.366208), -- Sealed Majestic Earring Gemstone
(25199, 6346, 308, 924, 1, 58956.813824), -- Sealed Majestic Ring Gemstone
(25199, 5538, 5, 13, 1, 339970.111552), -- Dragon Grinder Edge
(25199, 6578, 1, 1, 2, 64266.507162), -- Blessed Scroll: Enchant Armor (S-Grade)
(25199, 6570, 1, 1, 2, 160666.492838), -- Blessed Scroll: Enchant Armor (A-Grade)
(25199, 8619, 1, 1, 2, 540000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25199, 9816, 3, 7, 2, 820000), -- Earth Egg
(25199, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Krokian Padisha Sobekk
(25202, 5326, 1, 1, 0, 18185.72348), -- Sealed Robe of Nightmare
(25202, 5329, 1, 1, 0, 18185.72348), -- Sealed Majestic Robe
(25202, 81, 1, 1, 0, 5789.51768), -- Dragon Slayer
(25202, 151, 1, 1, 0, 5789.51768), -- Sword of Miracles
(25202, 2500, 1, 1, 0, 5789.51768), -- Dark Legion's Edge
(25202, 5487, 7, 21, 1, 289680.2741), -- Sealed Robe of Nightmare Fabric
(25202, 5488, 12, 36, 1, 168979.7977), -- Sealed Majestic Robe Fabric
(25202, 5529, 25, 75, 1, 49416.1892), -- Dragon Slayer Edge
(25202, 5546, 18, 54, 1, 75387.1944), -- Sword of Miracles Edge
(25202, 5545, 33, 99, 1, 37436.5446), -- Dark Legion's Edge Blade
(25202, 959, 1, 1, 2, 38915.26936), -- Scroll: Enchant Weapon (S-Grade)
(25202, 960, 1, 1, 2, 389153.56271), -- Scroll: Enchant Armor (S-Grade)
(25202, 6577, 1, 1, 2, 6486.16793), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25202, 8619, 1, 1, 2, 560000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25202, 9816, 3, 7, 2, 820000), -- Earth Egg
(25202, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Ocean Flame Ashakiel
(25205, 6678, 1, 1, 0, 48238.15168), -- Sealed Imperial Crusader Shield
(25205, 6679, 1, 1, 0, 33765.6636), -- Sealed Imperial Crusader Helmet
(25205, 6683, 1, 1, 0, 33765.6636), -- Sealed Draconic Leather Helmet
(25205, 6687, 1, 1, 0, 33765.6636), -- Sealed Major Arcana Circlet
(25205, 6371, 1, 1, 0, 3784.85752), -- Demon Splinter
(25205, 6705, 315, 945, 1, 26869.153452), -- Sealed Imperial Crusader Shield Part
(25205, 6706, 66, 198, 1, 149168.43174), -- Sealed Imperial Crusader Helmet Pattern
(25205, 6710, 126, 378, 1, 78135.898428), -- Sealed Draconic Leather Helmet Pattern
(25205, 6714, 208, 624, 1, 47332.47894), -- Sealed Major Arcana Circlet Pattern
(25205, 6695, 5, 15, 1, 257418.03744), -- Demon Splinter Blade
(25205, 6578, 1, 1, 2, 87412.902616), -- Blessed Scroll: Enchant Armor (S-Grade)
(25205, 3936, 1, 3, 2, 491699.097384), -- Blessed Scroll of Resurrection
-- Water Couatl Ateka
(25208, 354, 1, 1, 0, 119115.84225), -- Chain Mail Shirt
(25208, 381, 1, 1, 0, 190565.822994), -- Chain Gaiters
(25208, 1959, 12, 36, 0, 259755.358224), -- Chain Mail Shirt Material
(25208, 1960, 105, 315, 0, 60388.976532), -- Chain Gaiters Part
(25208, 439, 1, 1, 1, 238600.199718), -- Karmian Tunic
(25208, 471, 1, 1, 1, 381288.174858), -- Karmian Stockings
(25208, 1962, 53, 157, 1, 105802.348206), -- Karmian Tunic Pattern
(25208, 1954, 192, 576, 1, 48063.277218), -- Karmian Stocking Design
(25208, 951, 1, 1, 2, 545486.341412), -- Scroll: Enchant Weapon (C-Grade)
(25208, 952, 12, 36, 2, 166676.402436), -- Scroll: Enchant Armor (C-Grade)
(25208, 6573, 1, 1, 2, 20001.256152), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25208, 9816, 1, 2, 2, 850000), -- Earth Egg
(25208, 8176, 1, 1, 2, 650000), -- Destruction Tombstone
-- Sebek
(25211, 851, 6, 18, 0, 25076.81156), -- Omen Beast's Eye Earring
(25211, 882, 5, 15, 0, 45138.39143), -- Mithril Ring
(25211, 914, 1, 1, 0, 225691.30404), -- Necklace of Darkness
(25211, 1905, 81, 243, 0, 84294.29526), -- Omen Beast's Eye Earring Gemstone
(25211, 1906, 40, 120, 0, 241202.66654), -- Mithril Ring Wire
(25211, 1907, 154, 462, 0, 31706.53117), -- Necklace of Darkness Gem
(25211, 262, 1, 1, 1, 91090.182721), -- Scallop Jamadhr
(25211, 2053, 12, 36, 1, 217638.817279), -- Scallop Jamadhr Edge
(25211, 6573, 1, 1, 2, 54592), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Fafurion's Page Sika
(25214, 439, 1, 1, 0, 159066.734127), -- Karmian Tunic
(25214, 471, 1, 1, 0, 254192.070902), -- Karmian Stockings
(25214, 1962, 53, 157, 0, 70534.4843), -- Karmian Tunic Pattern
(25214, 1954, 24, 72, 0, 256337.710671), -- Karmian Stocking Design
(25214, 96, 1, 1, 1, 26256.97572), -- Scythe
(25214, 298, 1, 1, 1, 26256.97572), -- Orcish Glaive
(25214, 302, 1, 1, 1, 26256.97572), -- Body Slasher
(25214, 2062, 5, 15, 1, 181524.560193), -- Scythe Edge
(25214, 2075, 9, 27, 1, 100846.977885), -- Orcish Glaive Blade
(25214, 2076, 14, 42, 1, 64830.534762), -- Body Slasher Blade
(25214, 6574, 1, 1, 2, 514316), -- Blessed Scroll: Enchant Armor (C-Grade)
(25214, 9817, 1, 2, 2, 850000), -- Nonliving Nucleus
(25214, 8176, 1, 1, 2, 640000), -- Destruction Tombstone
-- Cursed Clara
(25217, 856, 1, 1, 0, 88032.920976), -- Adamantite Earring
(25217, 887, 1, 1, 0, 132048.586096), -- Adamantite Ring
(25217, 918, 1, 1, 0, 66024.293048), -- Adamantite Necklace
(25217, 4049, 81, 243, 0, 66398.116008), -- Adamantite Earring Gemstone
(25217, 4050, 40, 120, 0, 158823.05908), -- Adamantite Ring Wire
(25217, 4051, 14, 42, 0, 284041.024792), -- Adamantite Necklace Chain
(25217, 267, 1, 1, 1, 27627.439086), -- Arthro Nail
(25217, 4111, 12, 36, 1, 220034.560914), -- Arthro Nail Blade
(25217, 4601, 1, 3, 2, 332293.916812), -- Greater Dye of STR (Str+3 Con-3)
(25217, 4602, 2, 4, 2, 221529.554115), -- Greater Dye of STR (Str+3 Dex-3)
(25217, 4603, 2, 6, 2, 166146.958406), -- Greater Dye of CON (Con+3 Str-3)
(25217, 951, 3, 7, 2, 108750.570667), -- Scroll: Enchant Weapon (C-Grade)
(25217, 9816, 1, 3, 2, 850000), -- Earth Egg
(25217, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Death Lord Hallate
(25220, 5320, 1, 1, 0, 22627.33374), -- Sealed Leather Armor of Nightmare
(25220, 5323, 1, 1, 0, 22627.33374), -- Sealed Majestic Leather Armor
(25220, 5480, 4, 12, 0, 419012.4724), -- Sealed Leather Armor of Nightmare Fabric
(25220, 5481, 8, 22, 0, 223472.86012), -- Sealed Majestic Leather Armor Fabric
(25220, 289, 1, 1, 1, 21610.532682), -- Soul Bow
(25220, 5534, 12, 36, 1, 256363.467318), -- Soul Bow Stave
(25220, 959, 1, 1, 2, 38735.448944), -- Scroll: Enchant Weapon (S-Grade)
(25220, 960, 1, 1, 2, 387355.354534), -- Scroll: Enchant Armor (S-Grade)
(25220, 6577, 1, 1, 2, 6456.196522), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25220, 8619, 1, 1, 2, 560000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25220, 9814, 3, 7, 2, 820000), -- Memento Mori
(25220, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Soul Collector Acheron
(25223, 61, 9, 25, 0, 10511.075844), -- Mithril Plate Gloves
(25223, 607, 9, 27, 0, 9927.127186), -- Ogre Power Gauntlets
(25223, 1125, 10, 28, 0, 9405.017595), -- Assault Boots
(25223, 2427, 10, 30, 0, 8934.571022), -- Salamander Skin Boots
(25223, 2428, 1, 1, 0, 178694.551532), -- Plate Boots
(25223, 2451, 1, 1, 0, 178694.551532), -- Sage's Worn Gloves
(25223, 1949, 112, 336, 0, 33476.852891), -- Mithril Gloves Design
(25223, 1963, 203, 607, 0, 18515.712542), -- Ogre Power Gauntlets Part
(25223, 1957, 320, 960, 0, 11716.546264), -- Assault Boots Part
(25223, 2931, 28, 82, 0, 136341.835594), -- Salamander Skin Boot Lining
(25223, 2932, 36, 108, 0, 104149.513196), -- Plate Boots Design
(25223, 2933, 46, 136, 0, 82405.644802), -- Sage's Worn Gloves Lining
(25223, 225, 1, 1, 1, 87192.549621), -- Mithril Dagger
(25223, 2052, 12, 36, 1, 218498.450379), -- Mithril Dagger Blade
(25223, 4600, 2, 6, 2, 326602.21746), -- Greater Dye of WIT (Wit+2 Men-2)
(25223, 952, 15, 45, 2, 174187.78254), -- Scroll: Enchant Armor (C-Grade)
-- Roaring Lord Kastor
(25226, 6323, 1, 1, 0, 70713.08905), -- Sealed Phoenix Necklace
(25226, 6324, 1, 1, 0, 94284.5521), -- Sealed Phoenix Earring
(25226, 6325, 1, 1, 0, 141426.1781), -- Sealed Phoenix Ring
(25226, 6343, 140, 420, 0, 36178.53275), -- Sealed Phoenix Necklace Beads
(25226, 6341, 81, 243, 0, 80889.6218), -- Sealed Phoenix Earring Gemstone
(25226, 6345, 40, 120, 0, 226558.0262), -- Sealed Phoenix Ring Gemstone
(25226, 80, 1, 1, 1, 15122.701392), -- Tallum Blade
(25226, 150, 1, 1, 1, 15122.701392), -- Elemental Sword
(25226, 5548, 4, 12, 1, 453348.092799), -- Tallum Blade Edge
(25226, 5547, 8, 22, 1, 241785.504417), -- Elemental Sword Edge
(25226, 729, 1, 1, 2, 102359.265051), -- Scroll: Enchant Weapon (A-Grade)
(25226, 730, 1, 1, 2, 767696.69373), -- Scroll: Enchant Armor (A-Grade)
(25226, 6569, 1, 1, 2, 12283.041219), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25226, 9816, 3, 7, 2, 790000), -- Earth Egg
(25226, 8176, 1, 4, 2, 790000), -- Destruction Tombstone
-- Storm Winged Naga
(25229, 6678, 1, 1, 0, 22481.994318), -- Sealed Imperial Crusader Shield
(25229, 6679, 1, 1, 0, 15737.107995), -- Sealed Imperial Crusader Helmet
(25229, 6683, 1, 1, 0, 15737.107995), -- Sealed Draconic Leather Helmet
(25229, 6687, 1, 1, 0, 15737.107995), -- Sealed Major Arcana Circlet
(25229, 6705, 23, 67, 0, 116879.439873), -- Sealed Imperial Crusader Shield Part
(25229, 6706, 60, 180, 0, 50982.325338), -- Sealed Imperial Crusader Helmet Pattern
(25229, 6710, 11, 31, 0, 291329.116365), -- Sealed Draconic Leather Helmet Pattern
(25229, 6714, 16, 48, 0, 191184.800121), -- Sealed Major Arcana Circlet Pattern
(25229, 7575, 1, 1, 1, 10583.939322), -- Draconic Bow
(25229, 7579, 12, 36, 1, 206149.060678), -- Draconic Bow Shaft
(25229, 6578, 1, 1, 2, 65183.868867), -- Blessed Scroll: Enchant Armor (S-Grade)
(25229, 3936, 1, 1, 2, 733315.131133), -- Blessed Scroll of Resurrection
-- Timak Priest Ragoth
(25230, 358, 1, 1, 0, 19345.786092), -- Blue Wolf Breastplate
(25230, 2380, 1, 1, 0, 30948.981633), -- Blue Wolf Gaiters
(25230, 2381, 1, 1, 0, 11904.943977), -- Doom Plate Armor
(25230, 4078, 9, 27, 0, 194278.794165), -- Blue Wolf Breastplate Part
(25230, 4080, 28, 84, 0, 87937.885116), -- Blue Wolf Gaiters Material
(25230, 4081, 20, 60, 0, 58990.609017), -- Doom Plate Armor Temper
(25230, 97, 1, 1, 1, 21351.244636), -- Lance
(25230, 4115, 12, 36, 1, 195822.755364), -- Lance Blade
(25230, 6572, 1, 1, 2, 186202.97338), -- Blessed Scroll: Enchant Armor (B-Grade)
(25230, 948, 3, 9, 2, 290942.02662), -- Scroll: Enchant Armor (B-Grade)
(25230, 9816, 1, 4, 2, 800000), -- Earth Egg
(25230, 8176, 1, 2, 2, 670000), -- Destruction Tombstone
-- Spirit of Andras, the Betrayer
(25233, 6326, 1, 1, 0, 29742.130182), -- Sealed Majestic Necklace
(25233, 6327, 1, 1, 0, 39669.509447), -- Sealed Majestic Earring
(25233, 6328, 1, 1, 0, 59485.044827), -- Sealed Majestic Ring
(25233, 6344, 20, 60, 0, 108893.662419), -- Sealed Majestic Necklace Beads
(25233, 6342, 9, 27, 0, 373928.409284), -- Sealed Majestic Earring Gemstone
(25233, 6346, 28, 84, 0, 172744.243841), -- Sealed Majestic Ring Gemstone
(25233, 236, 1, 1, 1, 12892.903739), -- Soul Separator
(25233, 5537, 3, 9, 1, 611370.096261), -- Soul Separator Head
(25233, 6578, 1, 1, 2, 38516.165401), -- Blessed Scroll: Enchant Armor (S-Grade)
(25233, 6569, 1, 1, 2, 11554.834599), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25233, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25233, 9814, 2, 4, 2, 820000), -- Memento Mori
(25233, 8176, 1, 2, 2, 820000), -- Destruction Tombstone
-- Ancient Drake
(25234, 5289, 1, 1, 0, 46285.81449), -- Sealed Dark Crystal Helmet
(25234, 5292, 1, 1, 0, 66137.0802), -- Sealed Dark Crystal Shield
(25234, 5294, 1, 1, 0, 46285.81449), -- Sealed Tallum Helmet
(25234, 5525, 9, 27, 0, 265532.06085), -- Sealed Dark Crystal Helmet Design
(25234, 5494, 40, 120, 0, 81169.70994), -- Sealed Dark Crystal Shield Fragment
(25234, 5526, 14, 42, 0, 170699.52003), -- Sealed Tallum Helm Design
(25234, 212, 1, 1, 1, 9869.14242), -- Dasparion's Staff
(25234, 2504, 1, 1, 1, 9869.14242), -- Meteor Shower
(25234, 5543, 4, 12, 1, 296006.75658), -- Dasparion's Staff Head
(25234, 5532, 8, 22, 1, 156394.95858), -- Meteor Shower Head
(25234, 729, 1, 1, 2, 66800.186371), -- Scroll: Enchant Weapon (A-Grade)
(25234, 730, 1, 1, 2, 501002.83733), -- Scroll: Enchant Armor (A-Grade)
(25234, 6569, 1, 1, 2, 8015.976299), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25234, 9815, 1, 4, 2, 850000), -- Dragon Heart
(25234, 8176, 1, 2, 2, 720000), -- Destruction Tombstone
-- Vanor Chief Kandra
(25235, 5313, 1, 1, 0, 54882.4367), -- Sealed Gauntlets of Nightmare
(25235, 5314, 1, 1, 0, 54882.4367), -- Sealed Boots of Nightmare
(25235, 5318, 1, 1, 0, 54882.4367), -- Sealed Majestic Gauntlets
(25235, 5319, 1, 1, 0, 54882.4367), -- Sealed Majestic Boots
(25235, 5514, 60, 180, 0, 52332.260318), -- Sealed Gauntlets of Nightmare Design
(25235, 5502, 116, 346, 0, 27185.375412), -- Sealed Boots of Nightmare Lining
(25235, 5515, 16, 48, 0, 196245.500058), -- Sealed Majestic Gauntlets Design
(25235, 5503, 23, 67, 0, 139553.117412), -- Sealed Majestic Boots Lining
(25235, 289, 1, 1, 1, 21512.654245), -- Soul Bow
(25235, 5534, 12, 36, 1, 255202.345755), -- Soul Bow Stave
(25235, 959, 1, 1, 2, 38560.016576), -- Scroll: Enchant Weapon (S-Grade)
(25235, 960, 1, 1, 2, 385601.026936), -- Scroll: Enchant Armor (S-Grade)
(25235, 6577, 1, 1, 2, 6426.956488), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25235, 8619, 1, 1, 2, 540000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25235, 9814, 3, 7, 2, 820000), -- Memento Mori
(25235, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Abyss Brukunt
(25238, 5289, 1, 1, 0, 49901.955788), -- Sealed Dark Crystal Helmet
(25238, 5292, 1, 1, 0, 71304.12824), -- Sealed Dark Crystal Shield
(25238, 5294, 1, 1, 0, 49901.955788), -- Sealed Tallum Helmet
(25238, 5525, 9, 27, 0, 286277.10902), -- Sealed Dark Crystal Helmet Design
(25238, 5494, 40, 120, 0, 87511.202328), -- Sealed Dark Crystal Shield Fragment
(25238, 5526, 14, 42, 0, 184035.648836), -- Sealed Tallum Helm Design
(25238, 80, 1, 1, 1, 10640.172912), -- Tallum Blade
(25238, 150, 1, 1, 1, 10640.172912), -- Elemental Sword
(25238, 5548, 4, 12, 1, 318970.927989), -- Tallum Blade Edge
(25238, 5547, 8, 22, 1, 170117.726187), -- Elemental Sword Edge
(25238, 729, 1, 1, 2, 72018.967245), -- Scroll: Enchant Weapon (A-Grade)
(25238, 730, 1, 1, 2, 540143.80635), -- Scroll: Enchant Armor (A-Grade)
(25238, 6569, 1, 1, 2, 8642.226405), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25238, 9815, 1, 4, 2, 840000), -- Dragon Heart
(25238, 8176, 1, 2, 2, 700000), -- Destruction Tombstone
-- Harit Hero Tamash
(25241, 357, 1, 1, 0, 36396.161184), -- Zubei's Breastplate
(25241, 383, 1, 1, 0, 58222.049892), -- Zubei's Gaiters
(25241, 2376, 1, 1, 0, 36396.161184), -- Avadon Breastplate
(25241, 2379, 1, 1, 0, 58222.049892), -- Avadon Gaiters
(25241, 4056, 16, 48, 0, 164276.827176), -- Zubei's Breastplate Part
(25241, 4057, 60, 180, 0, 67701.697644), -- Zubei's Gaiter Material
(25241, 4064, 23, 67, 0, 116818.9752), -- Avadon Breastplate Part
(25241, 4065, 116, 346, 0, 35170.077828), -- Avadon Gaiters Material
(25241, 229, 1, 1, 1, 26085.602722), -- Kris
(25241, 243, 1, 1, 1, 26085.602722), -- Hell Knife
(25241, 4109, 24, 72, 1, 102267.277444), -- Kris Edge
(25241, 4110, 8, 22, 1, 327254.517112), -- Hell Knife Edge
(25241, 4619, 5, 15, 2, 77896.13238), -- Greater Dye of INT (Int+4 Men-4)
(25241, 4620, 2, 4, 2, 259653.269142), -- Greater Dye of INT (Int+4 Wit-4)
(25241, 4621, 2, 6, 2, 194739.572763), -- Greater Dye of MEN (Men+4 Int-4)
(25241, 947, 1, 1, 2, 225898.025715), -- Scroll: Enchant Weapon (B-Grade)
(25241, 9815, 2, 6, 2, 810000), -- Dragon Heart
(25241, 8176, 1, 3, 2, 810000), -- Destruction Tombstone
-- Last Lesser Giant Olkuth
(25244, 6680, 1, 1, 0, 19368.8084), -- Sealed Draconic Leather Armor
(25244, 6707, 12, 36, 0, 311439.1916), -- Sealed Draconic Leather Armor Part
(25244, 6367, 1, 1, 1, 10583.908125), -- Angel Slayer
(25244, 6691, 12, 36, 1, 203791.091875), -- Angel Slayer Blade
(25244, 959, 1, 1, 2, 39110.313616), -- Scroll: Enchant Weapon (S-Grade)
(25244, 960, 1, 1, 2, 391104.009626), -- Scroll: Enchant Armor (S-Grade)
(25244, 6577, 1, 1, 2, 6518.676758), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Last Lesser Giant Glaki
(25245, 6680, 1, 1, 0, 25960.9529), -- Sealed Draconic Leather Armor
(25245, 6707, 12, 36, 0, 417437.0471), -- Sealed Draconic Leather Armor Part
(25245, 7575, 1, 1, 1, 14186.130498), -- Draconic Bow
(25245, 7579, 12, 36, 1, 276310.869502), -- Draconic Bow Shaft
(25245, 959, 1, 1, 2, 52421.412448), -- Scroll: Enchant Weapon (S-Grade)
(25245, 960, 1, 1, 2, 524215.295228), -- Scroll: Enchant Armor (S-Grade)
(25245, 6577, 1, 1, 2, 8737.292324), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Doom Blade Thanatos
(25248, 5312, 1, 1, 0, 48796.385672), -- Sealed Helm of Nightmare
(25248, 5315, 1, 1, 0, 69728.564108), -- Sealed Shield of Nightmare
(25248, 5317, 1, 1, 0, 48796.385672), -- Sealed Majestic Circlet
(25248, 5527, 81, 243, 0, 36589.38878), -- Sealed Helm of Nightmare Design
(25248, 5495, 40, 120, 0, 94102.800668), -- Sealed Shield of Nightmare Fragment
(25248, 5528, 14, 42, 0, 211694.4751), -- Sealed Majestic Circlet Design
(25248, 236, 1, 1, 1, 21512.677472), -- Soul Separator
(25248, 5537, 12, 36, 1, 255028.322528), -- Soul Separator Head
(25248, 6578, 1, 1, 2, 64266.618518), -- Blessed Scroll: Enchant Armor (S-Grade)
(25248, 730, 1, 3, 2, 602496.381482), -- Scroll: Enchant Armor (A-Grade)
(25248, 8619, 1, 1, 2, 540000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25248, 9814, 3, 7, 2, 820000), -- Memento Mori
(25248, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Menacing Palatanos
(25249, 6674, 1, 1, 0, 29507.499871), -- Sealed Imperial Crusader Breastplate
(25249, 6675, 1, 1, 0, 47212.971263), -- Sealed Imperial Crusader Gaiters
(25249, 6701, 53, 157, 0, 95615.109387), -- Sealed Imperial Crusader Breastplate Part
(25249, 6702, 24, 72, 0, 269241.419479), -- Sealed Imperial Crusader Gaiters Pattern
(25249, 6578, 1, 1, 1, 65183.868867), -- Blessed Scroll: Enchant Armor (S-Grade)
(25249, 3936, 1, 1, 1, 733315.131133), -- Blessed Scroll of Resurrection
-- Palibati Queen Themis
(25252, 5326, 1, 1, 0, 22289.05032), -- Sealed Robe of Nightmare
(25252, 5329, 1, 1, 0, 22289.05032), -- Sealed Majestic Robe
(25252, 5487, 4, 12, 0, 414215.95371), -- Sealed Robe of Nightmare Fabric
(25252, 5488, 8, 22, 0, 220915.94565), -- Sealed Majestic Robe Fabric
(25252, 270, 1, 1, 1, 21287.488182), -- Dragon Grinder
(25252, 5538, 12, 36, 1, 252309.511818), -- Dragon Grinder Edge
(25252, 959, 1, 1, 2, 38156.405712), -- Scroll: Enchant Weapon (S-Grade)
(25252, 960, 1, 1, 2, 381564.909282), -- Scroll: Enchant Armor (S-Grade)
(25252, 6577, 1, 1, 2, 6359.685006), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25252, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25252, 9816, 3, 7, 2, 820000), -- Earth Egg
(25252, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Gargoyle Lord Tiphon
(25255, 5297, 1, 1, 0, 35962.222023), -- Sealed Dark Crystal Leather Armor
(25255, 5298, 1, 1, 0, 57518.271783), -- Sealed Dark Crystal Leggings
(25255, 5301, 1, 1, 0, 22127.45283), -- Sealed Tallum Leather Armor
(25255, 5478, 9, 27, 0, 224370.065115), -- Sealed Dark Crystal Leather Armor Pattern
(25255, 5482, 28, 84, 0, 113197.569282), -- Sealed Dark Crystal Leggings Design
(25255, 5479, 20, 60, 0, 71047.418967), -- Sealed Tallum Leather Armor Pattern
(25255, 269, 1, 1, 1, 30660.191175), -- Blood Tornado
(25255, 5539, 12, 36, 1, 303674.808825), -- Blood Tornado Edge
(25255, 6570, 1, 1, 2, 155644.617954), -- Blessed Scroll: Enchant Armor (A-Grade)
(25255, 6569, 1, 1, 2, 18677.382046), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25255, 9817, 3, 7, 2, 800000), -- Nonliving Nucleus
(25255, 8176, 1, 4, 2, 800000), -- Destruction Tombstone
-- Taik High Prefect Arak
(25256, 358, 1, 1, 0, 21010.818412), -- Blue Wolf Breastplate
(25256, 2380, 1, 1, 0, 33612.665313), -- Blue Wolf Gaiters
(25256, 2381, 1, 1, 0, 12929.565897), -- Doom Plate Armor
(25256, 4078, 9, 27, 0, 210999.772565), -- Blue Wolf Breastplate Part
(25256, 4080, 28, 84, 0, 95506.428476), -- Blue Wolf Gaiters Material
(25256, 4081, 20, 60, 0, 64067.749337), -- Doom Plate Armor Temper
(25256, 6323, 1, 1, 1, 58210.997501), -- Sealed Phoenix Necklace
(25256, 6324, 1, 1, 1, 77615.020082), -- Sealed Phoenix Earring
(25256, 6325, 1, 1, 1, 116421.995002), -- Sealed Phoenix Ring
(25256, 6343, 140, 420, 1, 29782.159255), -- Sealed Phoenix Necklace Beads
(25256, 6341, 81, 243, 1, 66588.316756), -- Sealed Phoenix Earring Gemstone
(25256, 6345, 40, 120, 1, 186502.511404), -- Sealed Phoenix Ring Gemstone
(25256, 6572, 1, 1, 2, 202229.591722), -- Blessed Scroll: Enchant Armor (B-Grade)
(25256, 6571, 1, 1, 2, 21667.408278), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25256, 9814, 1, 4, 2, 850000), -- Memento Mori
(25256, 8176, 1, 2, 2, 720000), -- Destruction Tombstone
-- Zaken's Butcher Krantz
(25259, 2397, 1, 1, 0, 64704.244), -- Tunic of Zubei
(25259, 2402, 1, 1, 0, 103502.7048), -- Stockings of Zubei
(25259, 2406, 1, 1, 0, 39800.42176), -- Avadon Robe
(25259, 4069, 81, 243, 0, 56358.92768), -- Tunic of Zubei Fabric
(25259, 4070, 40, 120, 0, 173284.88144), -- Stockings of Zubei Fabric
(25259, 4071, 14, 42, 0, 250508.82032), -- Avadon Robe Fabric
(25259, 97, 1, 1, 1, 34537.314944), -- Lance
(25259, 4115, 12, 36, 1, 316758.685056), -- Lance Blade
(25259, 4622, 2, 4, 2, 259653.637545), -- Greater Dye of MEN (Men+4 Wit-4)
(25259, 4623, 2, 6, 2, 194740.410119), -- Greater Dye of WIT (Wit+4 Int-4)
(25259, 4624, 3, 7, 2, 155792.182527), -- Greater Dye of WIT (Wit+4 Men-4)
(25259, 948, 6, 18, 2, 117654.769809), -- Scroll: Enchant Armor (B-Grade)
(25259, 9817, 2, 6, 2, 800000), -- Nonliving Nucleus
(25259, 8176, 1, 3, 2, 800000), -- Destruction Tombstone
-- Iron Giant Totem
(25260, 103, 7, 19, 0, 15941.353662), -- Tower Shield
(25260, 107, 7, 21, 0, 14802.278985), -- Composite Shield
(25260, 517, 1, 1, 0, 145108.580058), -- Composite Helmet
(25260, 1149, 1, 1, 0, 145108.580058), -- Shining Circlet
(25260, 1978, 60, 180, 0, 109761.691221), -- Tower Shield Fragment
(25260, 4055, 116, 346, 0, 57019.189734), -- Composite Shield Fragment
(25260, 2957, 192, 576, 0, 23468.780322), -- Composite Helmet Design
(25260, 1983, 23, 67, 0, 200266.54596), -- Shining Circlet Pattern
(25260, 75, 1, 1, 1, 12436.884812), -- Caliburs
(25260, 76, 1, 1, 1, 12436.884812), -- Sword of Delusion
(25260, 77, 1, 1, 1, 12436.884812), -- Tsurugi
(25260, 84, 1, 1, 1, 12436.884812), -- Homunkulus's Sword
(25260, 134, 1, 1, 1, 12436.884812), -- Sword of Nightmare
(25260, 145, 1, 1, 1, 12436.884812), -- Sword of Whispering Death
(25260, 2089, 8, 24, 1, 69984.251952), -- Caliburs Edge
(25260, 2090, 14, 40, 1, 41472.236484), -- Delusional Blade
(25260, 2091, 20, 60, 1, 27994.171548), -- Tsurugi Blade
(25260, 2092, 3, 7, 1, 223950.233936), -- Homunkulus's Sword Blade
(25260, 2095, 3, 9, 1, 186625.456484), -- Sword of Nightmare Blade
(25260, 2096, 4, 10, 1, 159964.340724), -- Sword of Whispering Death Blade
(25260, 4601, 6, 18, 2, 73988.27508), -- Greater Dye of STR (Str+3 Con-3)
(25260, 4602, 2, 4, 2, 295953.10032), -- Greater Dye of STR (Str+3 Dex-3)
(25260, 4603, 2, 6, 2, 221964.82524), -- Greater Dye of CON (Con+3 Str-3)
(25260, 951, 3, 7, 2, 145285.79936), -- Scroll: Enchant Weapon (C-Grade)
(25260, 9817, 2, 4, 2, 760000), -- Nonliving Nucleus
(25260, 8176, 1, 2, 2, 760000), -- Destruction Tombstone
-- Kernon's Faithful Servant Kelone
(25263, 5297, 1, 1, 0, 36251.924046), -- Sealed Dark Crystal Leather Armor
(25263, 5298, 1, 1, 0, 57981.623566), -- Sealed Dark Crystal Leggings
(25263, 5301, 1, 1, 0, 22305.70566), -- Sealed Tallum Leather Armor
(25263, 5478, 9, 27, 0, 226177.53023), -- Sealed Dark Crystal Leather Armor Pattern
(25263, 5482, 28, 84, 0, 114109.458564), -- Sealed Dark Crystal Leggings Design
(25263, 5479, 20, 60, 0, 71619.757934), -- Sealed Tallum Leather Armor Pattern
(25263, 212, 1, 1, 1, 15453.608803), -- Dasparion's Staff
(25263, 2504, 1, 1, 1, 15453.608803), -- Meteor Shower
(25263, 5543, 4, 12, 1, 463502.544047), -- Dasparion's Staff Head
(25263, 5532, 8, 22, 1, 244891.238347), -- Meteor Shower Head
(25263, 6570, 1, 1, 2, 156898.5), -- Blessed Scroll: Enchant Armor (A-Grade)
(25263, 729, 1, 1, 2, 156898.5), -- Scroll: Enchant Weapon (A-Grade)
(25263, 8619, 1, 1, 2, 500000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25263, 9816, 3, 7, 2, 810000), -- Earth Egg
(25263, 8176, 1, 4, 2, 810000), -- Destruction Tombstone
-- Bloody Empress Decarbia
(25266, 6684, 1, 1, 0, 19368.8084), -- Sealed Major Arcana Robe
(25266, 6711, 12, 36, 0, 311439.1916), -- Sealed Major Arcana Robe Part
(25266, 6370, 1, 1, 1, 10583.93038), -- Saint Spear
(25266, 6694, 12, 36, 1, 207484.06962), -- Saint Spear Blade
(25266, 959, 1, 1, 2, 39110.313616), -- Scroll: Enchant Weapon (S-Grade)
(25266, 960, 1, 1, 2, 391104.009626), -- Scroll: Enchant Armor (S-Grade)
(25266, 6577, 1, 1, 2, 6518.676758), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Beast Lord Behemoth
(25269, 6326, 1, 1, 0, 49107.30075), -- Sealed Majestic Necklace
(25269, 6327, 1, 1, 0, 65498.047325), -- Sealed Majestic Earring
(25269, 6328, 1, 1, 0, 98214.6015), -- Sealed Majestic Ring
(25269, 6344, 20, 60, 0, 179792.136175), -- Sealed Majestic Necklace Beads
(25269, 6342, 81, 243, 0, 68598.696775), -- Sealed Majestic Earring Gemstone
(25269, 6346, 28, 84, 0, 285214.217475), -- Sealed Majestic Ring Gemstone
(25269, 289, 1, 1, 1, 21287.510517), -- Soul Bow
(25269, 5534, 12, 36, 1, 252531.489483), -- Soul Bow Stave
(25269, 6578, 1, 1, 2, 63593.940624), -- Blessed Scroll: Enchant Armor (S-Grade)
(25269, 730, 1, 3, 2, 596190.059376), -- Scroll: Enchant Armor (A-Grade)
(25269, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25269, 9817, 3, 7, 2, 810000), -- Nonliving Nucleus
(25269, 8176, 1, 4, 2, 810000), -- Destruction Tombstone
-- Partisan Leader Talakin
(25272, 63, 3, 9, 0, 78438.24912), -- Gauntlets
(25272, 553, 4, 10, 0, 67232.719092), -- Iron Boots
(25272, 2422, 4, 12, 0, 58828.68684), -- Reinforced Leather Boots
(25272, 2423, 5, 13, 0, 52292.012388), -- Boots of Knowledge
(25272, 2446, 5, 15, 0, 47062.949472), -- Reinforced Leather Gloves
(25272, 2447, 6, 16, 0, 42784.164192), -- Gloves of Knowledge
(25272, 1940, 60, 180, 0, 114437.218896), -- Iron Boots Design
(25272, 157, 1, 1, 1, 86624.863775), -- Spiked Club
(25272, 186, 1, 1, 1, 86624.863775), -- Staff of Magic
(25272, 2027, 12, 36, 1, 175775.27245), -- Spiked Club Head
(25272, 956, 12, 36, 2, 869675), -- Scroll: Enchant Armor (D-Grade)
-- Carnamakos
(25273, 358, 1, 1, 0, 33257.00644), -- Blue Wolf Breastplate
(25273, 2380, 1, 1, 0, 53203.85931), -- Blue Wolf Gaiters
(25273, 2381, 1, 1, 0, 20465.58339), -- Doom Plate Armor
(25273, 4078, 9, 27, 0, 333981.31655), -- Blue Wolf Breastplate Part
(25273, 4080, 28, 84, 0, 151172.49812), -- Blue Wolf Gaiters Material
(25273, 4081, 20, 60, 0, 101409.73619), -- Doom Plate Armor Temper
(25273, 287, 1, 1, 1, 36704.544825), -- Bow of Peril
(25273, 4121, 12, 36, 1, 336070.455175), -- Bow of Peril Shaft
(25273, 4619, 1, 3, 2, 413920.536904), -- Greater Dye of INT (Int+4 Men-4)
(25273, 4620, 2, 4, 2, 275946.719944), -- Greater Dye of INT (Int+4 Wit-4)
(25273, 4621, 2, 6, 2, 206960.72544), -- Greater Dye of MEN (Men+4 Int-4)
(25273, 6571, 1, 1, 2, 17148.017712), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25273, 9817, 2, 5, 2, 770000), -- Nonliving Nucleus
(25273, 8176, 1, 3, 2, 680000), -- Destruction Tombstone
-- Death Lord Ipos
(25276, 6724, 1, 1, 0, 30755.19612), -- Sealed Tateossian Earring
(25276, 6725, 1, 1, 0, 46133.05064), -- Sealed Tateossian Ring
(25276, 6726, 1, 1, 0, 23061.39612), -- Sealed Tateossian Necklace
(25276, 6698, 81, 243, 0, 60970.28748), -- Sealed Tateossian Earring Part
(25276, 6699, 40, 120, 0, 137000.932), -- Sealed Tateossian Ring Gem
(25276, 6700, 14, 42, 0, 214999.13764), -- Sealed Tateossian Necklace Chain
(25276, 6364, 1, 1, 1, 5291.96717), -- Forgotten Blade
(25276, 6372, 1, 1, 1, 5291.96717), -- Heaven's Divider
(25276, 6688, 8, 22, 1, 163036.164046), -- Forgotten Blade Edge
(25276, 6696, 4, 12, 1, 310548.901614), -- Heavens Divider Edge
(25276, 6578, 1, 1, 2, 65183.868867), -- Blessed Scroll: Enchant Armor (S-Grade)
(25276, 3936, 1, 1, 2, 733315.131133), -- Blessed Scroll of Resurrection
-- Lilith's Witch Marilion
(25277, 554, 1, 1, 0, 122180.657684), -- Sealed Zubei's Boots
(25277, 600, 1, 1, 0, 122180.657684), -- Sealed Avadon Boots
(25277, 612, 1, 1, 0, 122180.657684), -- Sealed Zubei's Gauntlets
(25277, 2464, 1, 1, 0, 122180.657684), -- Sealed Avadon Gloves
(25277, 4097, 60, 180, 0, 105738.00074), -- Sealed Zubei's Boots Design
(25277, 4098, 116, 346, 0, 54929.261342), -- Sealed Avadon Boots Design
(25277, 4100, 192, 576, 0, 33043.037216), -- Sealed Zubei's Gauntlets Part
(25277, 4073, 293, 877, 0, 21689.069966), -- Sealed Avadon Gloves Part
(25277, 284, 1, 1, 1, 43795.185195), -- Dark Elven Long Bow
(25277, 4112, 12, 36, 1, 345097.814805), -- Dark Elven Longbow Shaft
(25277, 4604, 2, 6, 2, 263376.522948), -- Greater Dye of CON (Con+3 Dex-3)
(25277, 4605, 3, 7, 2, 210701.058326), -- Greater Dye of DEX (Dex+3 Str-3)
(25277, 4606, 3, 9, 2, 175584.348632), -- Greater Dye of DEX (Dex+3 Con-3)
(25277, 952, 21, 63, 2, 150500.070094), -- Scroll: Enchant Armor (C-Grade)
(25277, 9814, 2, 5, 2, 770000), -- Memento Mori
(25277, 8176, 1, 3, 2, 670000), -- Destruction Tombstone
-- Pagan Watcher Cerberon
(25280, 856, 1, 1, 0, 166239.567024), -- Adamantite Earring
(25280, 887, 1, 1, 0, 249359.350536), -- Adamantite Ring
(25280, 918, 1, 1, 0, 124679.675268), -- Adamantite Necklace
(25280, 4049, 81, 243, 0, 125385.181083), -- Adamantite Earring Gemstone
(25280, 4050, 440, 1320, 0, 27265.373407), -- Adamantite Ring Wire
(25280, 4051, 140, 420, 0, 53637.852682), -- Adamantite Necklace Chain
(25280, 300, 1, 1, 1, 52171.151061), -- Great Axe
(25280, 4113, 12, 36, 1, 373635.848939), -- Great Axe Head
(25280, 947, 1, 1, 2, 301198.167179), -- Scroll: Enchant Weapon (B-Grade)
(25280, 948, 3, 9, 2, 313748.541638), -- Scroll: Enchant Armor (B-Grade)
(25280, 6571, 1, 1, 2, 21514.291183), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25280, 9818, 2, 6, 2, 800000), -- Angelic Essence
(25280, 8176, 1, 3, 2, 800000), -- Destruction Tombstone
-- Anakim's Nemesis Zakaron
(25281, 5313, 1, 1, 0, 54307.97645), -- Sealed Gauntlets of Nightmare
(25281, 5314, 1, 1, 0, 54307.97645), -- Sealed Boots of Nightmare
(25281, 5318, 1, 1, 0, 54307.97645), -- Sealed Majestic Gauntlets
(25281, 5319, 1, 1, 0, 54307.97645), -- Sealed Majestic Boots
(25281, 5514, 60, 180, 0, 51784.493033), -- Sealed Gauntlets of Nightmare Design
(25281, 5502, 116, 346, 0, 26900.823222), -- Sealed Boots of Nightmare Lining
(25281, 5515, 16, 48, 0, 194191.377723), -- Sealed Majestic Gauntlets Design
(25281, 5503, 23, 67, 0, 138092.400222), -- Sealed Majestic Boots Lining
(25281, 236, 1, 1, 1, 21287.469632), -- Soul Separator
(25281, 5537, 12, 36, 1, 252358.530368), -- Soul Separator Head
(25281, 959, 1, 1, 2, 38156.405712), -- Scroll: Enchant Weapon (S-Grade)
(25281, 960, 1, 1, 2, 381564.909282), -- Scroll: Enchant Armor (S-Grade)
(25281, 6577, 1, 1, 2, 6359.685006), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25281, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25281, 9814, 3, 7, 2, 820000), -- Memento Mori
(25281, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Death Lord Shax
(25282, 6676, 1, 1, 0, 15738.553335), -- Sealed Imperial Crusader Gauntlet
(25282, 6677, 1, 1, 0, 15738.553335), -- Sealed Imperial Crusader Boots
(25282, 6681, 1, 1, 0, 15738.553335), -- Sealed Draconic Leather Glove
(25282, 6682, 1, 1, 0, 15738.553335), -- Sealed Draconic Leather Boots
(25282, 6685, 1, 1, 0, 15738.553335), -- Sealed Major Arcana Glove
(25282, 6686, 1, 1, 0, 15738.553335), -- Sealed Major Arcana Boots
(25282, 6703, 8, 24, 0, 223738.829795), -- Sealed Imperial Crusader Gauntlets Design
(25282, 6704, 14, 40, 0, 132585.767464), -- Sealed Imperial Crusader Boots Design
(25282, 6708, 20, 60, 0, 89495.531918), -- Sealed Draconic Leather Gloves Fabric
(25282, 6709, 28, 82, 0, 65087.407068), -- Sealed Draconic Leather Boots Design
(25282, 6712, 36, 108, 0, 49719.662799), -- Sealed Major Arcana Gloves fabric
(25282, 6713, 46, 136, 0, 39340.480946), -- Sealed Major Arcana Boots Design
(25282, 6365, 1, 1, 1, 2645.980338), -- Basalt Battlehammer
(25282, 6366, 1, 1, 1, 2645.980338), -- Imperial Staff
(25282, 6369, 1, 1, 1, 2645.980338), -- Dragon Hunter Axe
(25282, 6579, 1, 1, 1, 2645.980338), -- Arcana Mace
(25282, 6689, 2, 6, 1, 299966.374806), -- Basalt Battlehammer Head
(25282, 6690, 11, 31, 1, 58344.828498), -- Imperial Staff Head
(25282, 6693, 6, 18, 1, 103756.207722), -- Dragon Hunter Axe Blade
(25282, 6697, 3, 7, 1, 239974.667622), -- Arcana Mace Head
(25282, 959, 1, 1, 2, 39110.313616), -- Scroll: Enchant Weapon (S-Grade)
(25282, 960, 1, 1, 2, 391104.009626), -- Scroll: Enchant Armor (S-Grade)
(25282, 6577, 1, 1, 2, 6518.676758), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Lilith
(25283, 6364, 1, 1, 0, 6284.68442), -- Forgotten Blade
(25283, 6372, 1, 1, 0, 6284.68442), -- Heaven's Divider
(25283, 6688, 8, 22, 0, 193620.029596), -- Forgotten Blade Edge
(25283, 6696, 4, 12, 0, 368804.601564), -- Heavens Divider Edge
(25283, 7575, 1, 1, 1, 18854.07489), -- Draconic Bow
(25283, 7579, 12, 36, 1, 367230.92511), -- Draconic Bow Shaft
(25283, 6578, 1, 1, 2, 116117.732926), -- Blessed Scroll: Enchant Armor (S-Grade)
(25283, 3936, 1, 3, 2, 653164.267074), -- Blessed Scroll of Resurrection
-- Anakim
(25286, 6365, 1, 1, 0, 3142.343137), -- Basalt Battlehammer
(25286, 6366, 1, 1, 0, 3142.343137), -- Imperial Staff
(25286, 6369, 1, 1, 0, 3142.343137), -- Dragon Hunter Axe
(25286, 6579, 1, 1, 0, 3142.343137), -- Arcana Mace
(25286, 6689, 16, 48, 0, 44521.427385), -- Basalt Battlehammer Head
(25286, 6690, 11, 31, 0, 69276.93383), -- Imperial Staff Head
(25286, 6693, 6, 18, 0, 123197.061967), -- Dragon Hunter Axe Blade
(25286, 6697, 3, 7, 0, 284938.20427), -- Arcana Mace Head
(25286, 6367, 1, 1, 1, 18854.044335), -- Angel Slayer
(25286, 6691, 12, 36, 1, 363030.955665), -- Angel Slayer Blade
(25286, 959, 1, 1, 2, 69670.56048), -- Scroll: Enchant Weapon (S-Grade)
(25286, 960, 1, 1, 2, 696707.16078), -- Scroll: Enchant Armor (S-Grade)
(25286, 6577, 1, 1, 2, 11612.27874), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Daimon the White-Eyed
(25290, 6674, 1, 1, 0, 15820.11648), -- Sealed Imperial Crusader Breastplate
(25290, 6675, 1, 1, 0, 25312.51296), -- Sealed Imperial Crusader Gaiters
(25290, 6701, 8, 22, 0, 358837.5168), -- Sealed Imperial Crusader Breastplate Part
(25290, 6702, 24, 72, 0, 144349.85376), -- Sealed Imperial Crusader Gaiters Pattern
(25290, 6367, 1, 1, 1, 14186.164398), -- Angel Slayer
(25290, 6691, 12, 36, 1, 273151.835602), -- Angel Slayer Blade
(25290, 6578, 1, 1, 2, 87369.129146), -- Blessed Scroll: Enchant Armor (S-Grade)
(25290, 3936, 1, 3, 2, 491452.870854), -- Blessed Scroll of Resurrection
-- Hesti Guardian Deity of the Hot Springs
(25293, 6684, 1, 1, 0, 25960.9529), -- Sealed Major Arcana Robe
(25293, 6711, 12, 36, 0, 417437.0471), -- Sealed Major Arcana Robe Part
(25293, 6674, 1, 1, 1, 23730.18376), -- Sealed Imperial Crusader Breastplate
(25293, 6675, 1, 1, 1, 37969.07528), -- Sealed Imperial Crusader Gaiters
(25293, 6701, 53, 157, 1, 76894.48872), -- Sealed Imperial Crusader Breastplate Part
(25293, 6702, 24, 72, 1, 216526.25224), -- Sealed Imperial Crusader Gaiters Pattern
(25293, 959, 1, 1, 2, 52421.412448), -- Scroll: Enchant Weapon (S-Grade)
(25293, 960, 1, 1, 2, 524215.295228), -- Scroll: Enchant Armor (S-Grade)
(25293, 6577, 1, 1, 2, 8737.292324), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Icicle Emperor Bumbalump
(25296, 6326, 1, 1, 0, 50083.9533), -- Sealed Majestic Necklace
(25296, 6327, 1, 1, 0, 66800.68123), -- Sealed Majestic Earring
(25296, 6328, 1, 1, 0, 100167.9066), -- Sealed Majestic Ring
(25296, 6344, 20, 60, 0, 183367.86617), -- Sealed Majestic Necklace Beads
(25296, 6342, 81, 243, 0, 69962.99681), -- Sealed Majestic Earring Gemstone
(25296, 6346, 28, 84, 0, 290886.59589), -- Sealed Majestic Ring Gemstone
(25296, 164, 1, 1, 1, 10855.42226), -- Elysian
(25296, 213, 1, 1, 1, 10855.42226), -- Branch of the Mother Tree
(25296, 5533, 4, 12, 1, 385996.80785), -- Elysian Head
(25296, 5544, 8, 22, 1, 205662.34763), -- Branch of the Mother Tree Head
(25296, 6578, 1, 1, 2, 64858.717716), -- Blessed Scroll: Enchant Armor (S-Grade)
(25296, 730, 1, 3, 2, 608047.282284), -- Scroll: Enchant Armor (A-Grade)
(25296, 8619, 1, 1, 2, 560000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25296, 9817, 3, 7, 2, 830000), -- Nonliving Nucleus
(25296, 8176, 1, 4, 2, 830000), -- Destruction Tombstone
-- Ketra's Hero Hekaton
(25299, 6680, 1, 1, 0, 13446.4759), -- Sealed Draconic Leather Armor
(25299, 6707, 12, 36, 0, 216211.5241), -- Sealed Draconic Leather Armor Part
(25299, 6367, 1, 1, 1, 7347.704126), -- Angel Slayer
(25299, 6691, 3, 9, 1, 565930.295874), -- Angel Slayer Blade
(25299, 6578, 1, 1, 2, 45252.763752), -- Blessed Scroll: Enchant Armor (S-Grade)
(25299, 3936, 1, 1, 2, 509091.236248), -- Blessed Scroll of Resurrection
-- Ketra's Commander Tayr
(25302, 6684, 1, 1, 0, 14896.6423), -- Sealed Major Arcana Robe
(25302, 6711, 12, 36, 0, 239529.3577), -- Sealed Major Arcana Robe Part
(25302, 6370, 1, 1, 1, 8140.136176), -- Saint Spear
(25302, 6694, 3, 9, 1, 638312.863824), -- Saint Spear Blade
(25302, 6578, 1, 1, 2, 50133.192657), -- Blessed Scroll: Enchant Armor (S-Grade)
(25302, 3936, 1, 1, 2, 563995.807343), -- Blessed Scroll of Resurrection
-- Ketra's Chief Brakki
(25305, 6724, 1, 1, 0, 25380.89169), -- Sealed Tateossian Earring
(25305, 6725, 1, 1, 0, 38071.54918), -- Sealed Tateossian Ring
(25305, 6726, 1, 1, 0, 19031.54169), -- Sealed Tateossian Necklace
(25305, 6698, 81, 243, 0, 50316.05901), -- Sealed Tateossian Earring Part
(25305, 6699, 40, 120, 0, 113060.759), -- Sealed Tateossian Ring Gem
(25305, 6700, 14, 42, 0, 177429.19943), -- Sealed Tateossian Necklace Chain
(25305, 6370, 1, 1, 1, 8734.453392), -- Saint Spear
(25305, 6694, 3, 9, 1, 684916.546608), -- Saint Spear Blade
(25305, 959, 1, 1, 2, 32276.063184), -- Scroll: Enchant Weapon (S-Grade)
(25305, 960, 1, 1, 2, 322761.352674), -- Scroll: Enchant Armor (S-Grade)
(25305, 6577, 1, 1, 2, 5379.584142), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Soul of Fire Nastron
(25306, 6676, 1, 1, 0, 9091.85326), -- Sealed Imperial Crusader Gauntlet
(25306, 6677, 1, 1, 0, 9091.85326), -- Sealed Imperial Crusader Boots
(25306, 6681, 1, 1, 0, 9091.85326), -- Sealed Draconic Leather Glove
(25306, 6682, 1, 1, 0, 9091.85326), -- Sealed Draconic Leather Boots
(25306, 6685, 1, 1, 0, 9091.85326), -- Sealed Major Arcana Glove
(25306, 6686, 1, 1, 0, 9091.85326), -- Sealed Major Arcana Boots
(25306, 6703, 8, 24, 0, 129244.74038), -- Sealed Imperial Crusader Gauntlets Design
(25306, 6704, 14, 40, 0, 76589.7503), -- Sealed Imperial Crusader Boots Design
(25306, 6708, 20, 60, 0, 51698.16568), -- Sealed Draconic Leather Gloves Fabric
(25306, 6709, 28, 82, 0, 37598.48218), -- Sealed Draconic Leather Boots Design
(25306, 6712, 36, 108, 0, 28720.90368), -- Sealed Major Arcana Gloves fabric
(25306, 6713, 4, 10, 0, 295416.83822), -- Sealed Major Arcana Boots Design
(25306, 6364, 1, 1, 1, 3057.059708), -- Forgotten Blade
(25306, 6372, 1, 1, 1, 3057.059708), -- Heaven's Divider
(25306, 6688, 2, 4, 1, 470926.36116), -- Forgotten Blade Edge
(25306, 6696, 4, 12, 1, 179403.519424), -- Heavens Divider Edge
(25306, 6578, 1, 1, 2, 37655.425341), -- Blessed Scroll: Enchant Armor (S-Grade)
(25306, 3936, 1, 1, 2, 423621.574659), -- Blessed Scroll of Resurrection
-- Varka's Hero Shadith
(25309, 6674, 1, 1, 0, 8194.02108), -- Sealed Imperial Crusader Breastplate
(25309, 6675, 1, 1, 0, 13111.089512), -- Sealed Imperial Crusader Gaiters
(25309, 6701, 8, 22, 0, 185866.891768), -- Sealed Imperial Crusader Breastplate Part
(25309, 6702, 4, 12, 0, 448611.99764), -- Sealed Imperial Crusader Gaiters Pattern
(25309, 6367, 1, 1, 1, 7347.704126), -- Angel Slayer
(25309, 6691, 3, 9, 1, 565930.295874), -- Angel Slayer Blade
(25309, 959, 1, 1, 2, 27151.629088), -- Scroll: Enchant Weapon (S-Grade)
(25309, 960, 1, 1, 2, 271516.897268), -- Scroll: Enchant Armor (S-Grade)
(25309, 6577, 1, 1, 2, 4525.473644), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Varka's Commander Mos
(25312, 6724, 1, 1, 0, 23653.900622), -- Sealed Tateossian Earring
(25312, 6725, 1, 1, 0, 35480.850933), -- Sealed Tateossian Ring
(25312, 6726, 1, 1, 0, 17736.192485), -- Sealed Tateossian Necklace
(25312, 6698, 9, 27, 0, 422035.182247), -- Sealed Tateossian Earring Part
(25312, 6699, 40, 120, 0, 105368.145131), -- Sealed Tateossian Ring Gem
(25312, 6700, 14, 42, 0, 165358.728582), -- Sealed Tateossian Necklace Chain
(25312, 6364, 1, 1, 1, 4070.06968), -- Forgotten Blade
(25312, 6372, 1, 1, 1, 4070.06968), -- Heaven's Divider
(25312, 6688, 8, 22, 1, 125391.659984), -- Forgotten Blade Edge
(25312, 6696, 4, 12, 1, 238844.200656), -- Heavens Divider Edge
(25312, 959, 1, 1, 2, 30079.889936), -- Scroll: Enchant Weapon (S-Grade)
(25312, 960, 1, 1, 2, 300799.571146), -- Scroll: Enchant Armor (S-Grade)
(25312, 6577, 1, 1, 2, 5013.538918), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Varka's Chief Horus
(25315, 6678, 1, 1, 0, 18553.423724), -- Sealed Imperial Crusader Shield
(25315, 6679, 1, 1, 0, 12987.15891), -- Sealed Imperial Crusader Helmet
(25315, 6683, 1, 1, 0, 12987.15891), -- Sealed Draconic Leather Helmet
(25315, 6687, 1, 1, 0, 12987.15891), -- Sealed Major Arcana Circlet
(25315, 6705, 23, 67, 0, 96455.578714), -- Sealed Imperial Crusader Shield Part
(25315, 6706, 60, 180, 0, 42073.522084), -- Sealed Imperial Crusader Helmet Pattern
(25315, 6710, 11, 31, 0, 240421.39957), -- Sealed Draconic Leather Helmet Pattern
(25315, 6714, 16, 48, 0, 157776.599178), -- Sealed Major Arcana Circlet Pattern
(25315, 6365, 1, 1, 1, 2183.6153), -- Basalt Battlehammer
(25315, 6366, 1, 1, 1, 2183.6153), -- Imperial Staff
(25315, 6369, 1, 1, 1, 2183.6153), -- Dragon Hunter Axe
(25315, 6579, 1, 1, 1, 2183.6153), -- Arcana Mace
(25315, 6689, 2, 6, 1, 247549.5211), -- Basalt Battlehammer Head
(25315, 6690, 11, 31, 1, 48149.5113), -- Imperial Staff Head
(25315, 6693, 6, 18, 1, 85625.5957), -- Dragon Hunter Axe Blade
(25315, 6697, 3, 7, 1, 198040.9107), -- Arcana Mace Head
(25315, 959, 1, 1, 2, 32276.063184), -- Scroll: Enchant Weapon (S-Grade)
(25315, 960, 1, 1, 2, 322761.352674), -- Scroll: Enchant Armor (S-Grade)
(25315, 6577, 1, 1, 2, 5379.584142), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Soul of Water Ashutar
(25316, 6680, 1, 1, 0, 11188.97668), -- Sealed Draconic Leather Armor
(25316, 6707, 3, 9, 0, 719639.02332), -- Sealed Draconic Leather Armor Part
(25316, 6371, 1, 1, 1, 6114.11736), -- Demon Splinter
(25316, 6695, 3, 9, 1, 462041.88264), -- Demon Splinter Blade
(25316, 6578, 1, 1, 2, 37655.425341), -- Blessed Scroll: Enchant Armor (S-Grade)
(25316, 3936, 1, 1, 2, 423621.574659), -- Blessed Scroll of Resurrection
-- Ember
(25319, 6676, 1, 1, 0, 23965.066238), -- Sealed Imperial Crusader Gauntlet
(25319, 6677, 1, 1, 0, 23965.066238), -- Sealed Imperial Crusader Boots
(25319, 6681, 1, 1, 0, 23965.066238), -- Sealed Draconic Leather Glove
(25319, 6682, 1, 1, 0, 23965.066238), -- Sealed Draconic Leather Boots
(25319, 6685, 1, 1, 0, 23965.066238), -- Sealed Major Arcana Glove
(25319, 6686, 1, 1, 0, 23965.066238), -- Sealed Major Arcana Boots
(25319, 6703, 112, 336, 0, 24334.07876), -- Sealed Imperial Crusader Gauntlets Design
(25319, 6704, 14, 40, 0, 201883.194039), -- Sealed Imperial Crusader Boots Design
(25319, 6708, 20, 60, 0, 136270.841056), -- Sealed Draconic Leather Gloves Fabric
(25319, 6709, 28, 82, 0, 99105.796772), -- Sealed Draconic Leather Boots Design
(25319, 6712, 36, 108, 0, 75706.105141), -- Sealed Major Arcana Gloves fabric
(25319, 6713, 46, 136, 0, 59898.586804), -- Sealed Major Arcana Boots Design
(25319, 6365, 1, 1, 1, 4029.025675), -- Basalt Battlehammer
(25319, 6366, 1, 1, 1, 4029.025675), -- Imperial Staff
(25319, 6369, 1, 1, 1, 4029.025675), -- Dragon Hunter Axe
(25319, 6579, 1, 1, 1, 4029.025675), -- Arcana Mace
(25319, 6689, 16, 48, 1, 57084.145875), -- Basalt Battlehammer Head
(25319, 6690, 11, 31, 1, 88824.97325), -- Imperial Staff Head
(25319, 6693, 6, 18, 1, 157959.873925), -- Dragon Hunter Axe Blade
(25319, 6697, 3, 7, 1, 365339.90425), -- Arcana Mace Head
(25319, 6578, 1, 1, 2, 99255.286624), -- Blessed Scroll: Enchant Armor (S-Grade)
(25319, 3936, 1, 3, 2, 558312.713376), -- Blessed Scroll of Resurrection
-- Demon's Agent Falston
(25322, 6323, 1, 1, 0, 71974.078402), -- Sealed Phoenix Necklace
(25322, 6324, 1, 1, 0, 95965.878964), -- Sealed Phoenix Earring
(25322, 6325, 1, 1, 0, 143948.156804), -- Sealed Phoenix Ring
(25322, 6343, 140, 420, 0, 36823.68551), -- Sealed Phoenix Necklace Beads
(25322, 6341, 81, 243, 0, 82332.083912), -- Sealed Phoenix Earring Gemstone
(25322, 6345, 40, 120, 0, 230598.116408), -- Sealed Phoenix Ring Gemstone
(25322, 212, 1, 1, 1, 15392.383916), -- Dasparion's Staff
(25322, 2504, 1, 1, 1, 15392.383916), -- Meteor Shower
(25322, 5543, 4, 12, 1, 461666.216284), -- Dasparion's Staff Head
(25322, 5532, 8, 22, 1, 243921.015884), -- Meteor Shower Head
(25322, 729, 1, 1, 2, 104184.666666), -- Scroll: Enchant Weapon (A-Grade)
(25322, 730, 1, 1, 2, 781387.24518), -- Scroll: Enchant Armor (A-Grade)
(25322, 6569, 1, 1, 2, 12502.088154), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25322, 8619, 1, 1, 2, 500000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25322, 9814, 3, 7, 2, 800000), -- Memento Mori
(25322, 8176, 1, 4, 2, 800000), -- Destruction Tombstone
-- Flame of Splendor Barakiel
(25325, 5312, 1, 1, 0, 48285.636708), -- Sealed Helm of Nightmare
(25325, 5315, 1, 1, 0, 68999.445144), -- Sealed Shield of Nightmare
(25325, 5317, 1, 1, 0, 48285.636708), -- Sealed Majestic Circlet
(25325, 5527, 9, 27, 0, 325857.974808), -- Sealed Helm of Nightmare Design
(25325, 5495, 40, 120, 0, 93118.839672), -- Sealed Shield of Nightmare Fragment
(25325, 5528, 14, 42, 0, 209480.46696), -- Sealed Majestic Circlet Design
(25325, 5311, 1, 1, 1, 25075.181934), -- Sealed Armor of Nightmare
(25325, 5316, 1, 1, 1, 25075.181934), -- Sealed Majestic Plate Armor
(25325, 5522, 4, 12, 1, 469886.468319), -- Sealed Armor of Nightmare Pattern
(25325, 5523, 8, 22, 1, 250606.167813), -- Sealed Majestic Plate Armor Pattern
(25325, 6578, 1, 1, 2, 63593.936406), -- Blessed Scroll: Enchant Armor (S-Grade)
(25325, 6570, 1, 1, 2, 158985.063594), -- Blessed Scroll: Enchant Armor (A-Grade)
(25325, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25325, 9818, 3, 7, 2, 810000), -- Angelic Essence
(25325, 8176, 1, 4, 2, 810000), -- Destruction Tombstone
-- Eilhalder von Hellmann
(25328, 5311, 1, 1, 0, 16821.98331), -- Sealed Armor of Nightmare
(25328, 5316, 1, 1, 0, 16821.98331), -- Sealed Majestic Plate Armor
(25328, 5522, 4, 12, 0, 315228.912335), -- Sealed Armor of Nightmare Pattern
(25328, 5523, 8, 22, 0, 168122.121045), -- Sealed Majestic Plate Armor Pattern
(25328, 81, 1, 1, 1, 7140.480364), -- Dragon Slayer
(25328, 151, 1, 1, 1, 7140.480364), -- Sword of Miracles
(25328, 2500, 1, 1, 1, 7140.480364), -- Dark Legion's Edge
(25328, 5529, 9, 27, 1, 112865.685108), -- Dragon Slayer Edge
(25328, 5546, 5, 15, 1, 223150.116234), -- Sword of Miracles Edge
(25328, 5545, 14, 42, 1, 72556.757566), -- Dark Legion's Edge Blade
(25328, 6578, 1, 1, 2, 63994.135296), -- Blessed Scroll: Enchant Armor (S-Grade)
(25328, 730, 1, 3, 2, 599941.864704), -- Scroll: Enchant Armor (A-Grade)
(25328, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25328, 9814, 3, 7, 2, 820000), -- Memento Mori
(25328, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Anakazel
(25333, 47, 2, 4, 0, 256450.033852), -- Helmet
(25333, 628, 4, 12, 0, 137450.966148), -- Hoplon
(25333, 260, 1, 1, 1, 181912), -- Triple-Edged Jamadhr
(25333, 6575, 1, 1, 2, 97404), -- Blessed Scroll: Enchant Weapon (D-Grade)
-- Anakazel
(25334, 397, 1, 1, 0, 103876.333566), -- Mithril Shirt
(25334, 2387, 1, 1, 0, 165996.406404), -- Reinforced Mithril Gaiters
(25334, 1961, 8, 22, 0, 322431.963138), -- Mithril Shirt Fabric
(25334, 2935, 24, 72, 0, 167397.296892), -- Reinforced Mithril Gaiters Fragment
(25334, 439, 1, 1, 1, 155814.395166), -- Karmian Tunic
(25334, 471, 1, 1, 1, 248994.763116), -- Karmian Stockings
(25334, 1962, 53, 157, 1, 69092.3094), -- Karmian Tunic Pattern
(25334, 1954, 24, 72, 1, 251096.532318), -- Karmian Stocking Design
(25334, 952, 12, 36, 2, 326537), -- Scroll: Enchant Armor (C-Grade)
-- Anakazel
(25335, 356, 1, 1, 0, 47647.602), -- Full Plate Armor
(25335, 1986, 3, 9, 0, 750202.398), -- Full Plate Armor Temper
(25335, 203, 1, 1, 1, 6949.502294), -- Pa'agrian Axe
(25335, 204, 1, 1, 1, 5422.31011), -- Deadman's Staff
(25335, 205, 1, 1, 1, 5422.31011), -- Ghoul's Staff
(25335, 206, 1, 1, 1, 5422.31011), -- Demon's Staff
(25335, 2503, 1, 1, 1, 5422.31011), -- Yaksa Mace
(25335, 2112, 7, 21, 1, 44202.360874), -- Pa'agrian Axe Blade
(25335, 2116, 2, 6, 1, 150308.510534), -- Deadman's Staff Head
(25335, 2117, 3, 7, 1, 120246.289856), -- Ghoul's Staff Head
(25335, 2118, 3, 9, 1, 100205.457618), -- Demon's Staff Head
(25335, 2969, 2, 4, 1, 204612.638384), -- Yaksa Mace Head
(25335, 4601, 1, 3, 2, 230076.344624), -- Greater Dye of STR (Str+3 Con-3)
(25335, 4602, 2, 4, 2, 153384.521412), -- Greater Dye of STR (Str+3 Dex-3)
(25335, 4603, 2, 6, 2, 115038.172312), -- Greater Dye of CON (Con+3 Str-3)
(25335, 951, 1, 1, 2, 376488.961652), -- Scroll: Enchant Weapon (C-Grade)
(25335, 9814, 1, 2, 2, 790000), -- Memento Mori
(25335, 8176, 1, 1, 2, 590000), -- Destruction Tombstone
-- Anakazel
(25336, 2398, 1, 1, 0, 13929.66454), -- Blue Wolf Tunic
(25336, 2399, 1, 1, 0, 13929.66454), -- Tunic of Doom
(25336, 2403, 1, 1, 0, 22294.19029), -- Blue Wolf Stockings
(25336, 2404, 1, 1, 0, 22294.19029), -- Stockings of Doom
(25336, 4084, 16, 48, 0, 70243.72351), -- Blue Wolf Tunic Fabric
(25336, 4085, 23, 67, 0, 49951.1185), -- Tunic of Doom Pattern
(25336, 4086, 6, 18, 0, 252920.83526), -- Blue Wolf Stockings Pattern
(25336, 4087, 11, 31, 0, 144526.61307), -- Stockings of Doom Pattern
(25336, 79, 1, 1, 1, 15379.882272), -- Sword of Damascus
(25336, 4114, 3, 9, 1, 566134.117728), -- Sword of Damascus Blade
(25336, 4613, 1, 3, 2, 173440.50284), -- Greater Dye of STR (Str+4 Con-4)
(25336, 4614, 1, 1, 2, 346881.88007), -- Greater Dye of STR (Str+4 Dex-4)
(25336, 4615, 1, 1, 2, 346881.88007), -- Greater Dye of CON (Con+4 Str-4)
(25336, 9814, 1, 3, 2, 710000), -- Memento Mori
(25336, 8176, 1, 1, 2, 710000), -- Destruction Tombstone
(25336, 6571, 1, 1, 2, 7185.73702), -- Blessed Scroll: Enchant Weapon (B-Grade)
-- Anakazel
(25337, 5311, 1, 1, 0, 6954.356784), -- Sealed Armor of Nightmare
(25337, 5316, 1, 1, 0, 6954.356784), -- Sealed Majestic Plate Armor
(25337, 5522, 4, 12, 0, 130320.672776), -- Sealed Armor of Nightmare Pattern
(25337, 5523, 2, 4, 0, 347522.613656), -- Sealed Majestic Plate Armor Pattern
(25337, 270, 1, 1, 1, 8855.821156), -- Dragon Grinder
(25337, 5538, 3, 9, 1, 419852.178844), -- Dragon Grinder Edge
(25337, 6577, 1, 1, 2, 3968.35444), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25337, 6578, 1, 1, 2, 26455.64556), -- Blessed Scroll: Enchant Armor (S-Grade)
(25337, 8619, 1, 1, 2, 500000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25337, 9814, 1, 3, 2, 850000), -- Memento Mori
(25337, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Anakazel
(25338, 6724, 1, 1, 0, 14460.562138), -- Sealed Tateossian Earring
(25338, 6725, 1, 1, 0, 21690.843207), -- Sealed Tateossian Ring
(25338, 6726, 1, 1, 0, 10842.833815), -- Sealed Tateossian Necklace
(25338, 6698, 9, 27, 0, 258006.748013), -- Sealed Tateossian Earring Part
(25338, 6699, 40, 120, 0, 64415.701849), -- Sealed Tateossian Ring Gem
(25338, 6700, 14, 42, 0, 101090.310978), -- Sealed Tateossian Necklace Chain
(25338, 6370, 1, 1, 1, 4976.383584), -- Saint Spear
(25338, 6694, 3, 9, 1, 390225.616416), -- Saint Spear Blade
(25338, 6578, 1, 1, 2, 30648.375153), -- Blessed Scroll: Enchant Armor (S-Grade)
(25338, 3936, 1, 1, 2, 344792.624847), -- Blessed Scroll of Resurrection
-- Shadow of Halisha
(25339, 6678, 1, 1, 0, 11219.98706), -- Sealed Imperial Crusader Shield
(25339, 6679, 1, 1, 0, 7853.990942), -- Sealed Imperial Crusader Helmet
(25339, 6683, 1, 1, 0, 7853.990942), -- Sealed Draconic Leather Helmet
(25339, 6687, 1, 1, 0, 7853.990942), -- Sealed Major Arcana Circlet
(25339, 6705, 23, 67, 0, 58330.988836), -- Sealed Imperial Crusader Shield Part
(25339, 6706, 6, 18, 0, 254437.770532), -- Sealed Imperial Crusader Helmet Pattern
(25339, 6710, 11, 31, 0, 145393.263886), -- Sealed Draconic Leather Helmet Pattern
(25339, 6714, 16, 48, 0, 95414.01686), -- Sealed Major Arcana Circlet Pattern
(25339, 6371, 1, 1, 1, 5282.06476), -- Demon Splinter
(25339, 6695, 3, 9, 1, 399163.93524), -- Demon Splinter Blade
(25339, 959, 1, 1, 2, 19518.574816), -- Scroll: Enchant Weapon (S-Grade)
(25339, 960, 1, 1, 2, 195186.184076), -- Scroll: Enchant Armor (S-Grade)
(25339, 6577, 1, 1, 2, 3253.241108), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Shadow of Halisha
(25342, 6680, 1, 1, 0, 9666.30532), -- Sealed Draconic Leather Armor
(25342, 6707, 3, 9, 0, 621705.69468), -- Sealed Draconic Leather Armor Part
(25342, 7575, 1, 1, 1, 5282.068381), -- Draconic Bow
(25342, 7579, 3, 9, 1, 411514.931619), -- Draconic Bow Shaft
(25342, 6578, 1, 1, 2, 32530.995399), -- Blessed Scroll: Enchant Armor (S-Grade)
(25342, 3936, 1, 1, 2, 365972.004601), -- Blessed Scroll of Resurrection
-- Shadow of Halisha
(25346, 6674, 1, 1, 0, 5890.46787), -- Sealed Imperial Crusader Breastplate
(25346, 6675, 1, 1, 0, 9425.220018), -- Sealed Imperial Crusader Gaiters
(25346, 6701, 8, 22, 0, 133614.856902), -- Sealed Imperial Crusader Breastplate Part
(25346, 6702, 4, 12, 0, 322495.45521), -- Sealed Imperial Crusader Gaiters Pattern
(25346, 6367, 1, 1, 1, 5282.065138), -- Angel Slayer
(25346, 6691, 3, 9, 1, 406831.934862), -- Angel Slayer Blade
(25346, 959, 1, 1, 2, 19518.574816), -- Scroll: Enchant Weapon (S-Grade)
(25346, 960, 1, 1, 2, 195186.184076), -- Scroll: Enchant Armor (S-Grade)
(25346, 6577, 1, 1, 2, 3253.241108), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Shadow of Halisha
(25349, 6684, 1, 1, 0, 9666.30532), -- Sealed Major Arcana Robe
(25349, 6711, 3, 9, 0, 621705.69468), -- Sealed Major Arcana Robe Part
(25349, 6678, 1, 1, 1, 16829.969324), -- Sealed Imperial Crusader Shield
(25349, 6679, 1, 1, 1, 11780.76291), -- Sealed Imperial Crusader Helmet
(25349, 6683, 1, 1, 1, 11780.76291), -- Sealed Draconic Leather Helmet
(25349, 6687, 1, 1, 1, 11780.76291), -- Sealed Major Arcana Circlet
(25349, 6705, 23, 67, 1, 87495.680314), -- Sealed Imperial Crusader Shield Part
(25349, 6706, 60, 180, 1, 38165.251684), -- Sealed Imperial Crusader Helmet Pattern
(25349, 6710, 11, 31, 1, 218088.30757), -- Sealed Draconic Leather Helmet Pattern
(25349, 6714, 16, 48, 1, 143120.502378), -- Sealed Major Arcana Circlet Pattern
(25349, 6578, 1, 1, 2, 32530.995399), -- Blessed Scroll: Enchant Armor (S-Grade)
(25349, 3936, 1, 1, 2, 365972.004601), -- Blessed Scroll of Resurrection
-- Giant Wasteland Basilisk
(25352, 395, 1, 1, 0, 199474.211), -- Manticore Skin Shirt
(25352, 417, 4, 12, 0, 39820.9705), -- Manticore Skin Gaiters
(25352, 1942, 53, 157, 0, 83335.526), -- Manticore Skin Shirt Texture
(25352, 1943, 24, 72, 0, 283869.2925), -- Manticore Skin Gaiters Pattern
(25352, 261, 1, 1, 1, 95836.829793), -- Bich'Hwa
(25352, 2039, 12, 36, 1, 217072.170207), -- Bich'Hwa Edge
(25352, 4559, 3, 7, 2, 133426.146758), -- Greater Dye of INT (Int+1 Men-1)
(25352, 4560, 3, 9, 2, 111188.867559), -- Greater Dye of INT (Int+1 Wit-1)
(25352, 4561, 4, 10, 2, 95304.743622), -- Greater Dye of MEN (Men+1 Int-1)
(25352, 6387, 12, 36, 2, 277971.242061), -- Blessed Scroll of Resurrection for Pets
-- Gargoyle Lord Sirocco
(25354, 630, 6, 16, 0, 30926.025583), -- Square Shield
(25354, 2412, 1, 1, 0, 238250.687982), -- Plate Helmet
(25354, 2494, 6, 18, 0, 28348.805033), -- Plate Shield
(25354, 1956, 40, 120, 0, 190654.703068), -- Square Shield Fragment
(25354, 2930, 140, 420, 0, 38686.254015), -- Plate Helmet Design
(25354, 2934, 81, 243, 0, 94150.524319), -- Plate Shield Fragment
(25354, 397, 1, 1, 1, 207794.336418), -- Mithril Shirt
(25354, 2387, 1, 1, 1, 332059.752558), -- Reinforced Mithril Gaiters
(25354, 1961, 53, 157, 1, 92142.122106), -- Mithril Shirt Fabric
(25354, 2935, 192, 576, 1, 41857.788918), -- Reinforced Mithril Gaiters Fragment
(25354, 951, 1, 1, 2, 475058.371922), -- Scroll: Enchant Weapon (C-Grade)
(25354, 952, 12, 36, 2, 145156.742466), -- Scroll: Enchant Armor (C-Grade)
(25354, 6573, 1, 1, 2, 17418.885612), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Sukar Wererat Chief
(25357, 605, 4, 12, 0, 256556.773338), -- Leather Gauntlets
(25357, 1123, 8, 22, 0, 136830.226662), -- Blue Buckskin Boots
(25357, 222, 1, 1, 1, 318120), -- Poniard Dagger
(25357, 6387, 24, 72, 2, 141898.009605), -- Blessed Scroll of Resurrection for Pets
(25357, 955, 4, 10, 2, 97301.474655), -- Scroll: Enchant Weapon (D-Grade)
(25357, 956, 8, 22, 2, 378395.51574), -- Scroll: Enchant Armor (D-Grade)
-- Tiger Hornet
(25360, 58, 1, 1, 0, 122830.011408), -- Mithril Breastplate
(25360, 349, 1, 1, 0, 122830.011408), -- Compound Scale Mail
(25360, 350, 1, 1, 0, 122830.011408), -- Dwarven Scale Mail
(25360, 59, 1, 3, 0, 88787.59904), -- Mithril Gaiters
(25360, 351, 1, 1, 0, 110956.282402), -- Blast Plate
(25360, 378, 2, 4, 0, 59191.956633), -- Compound Scale Gaiters
(25360, 379, 2, 6, 0, 44393.127701), -- Dwarven Scale Gaiters
(25360, 316, 1, 1, 1, 81586.526756), -- Sage's Blood
(25360, 317, 1, 1, 1, 81586.526756), -- Tome of Blood
(25360, 2030, 3, 9, 1, 591223.946488), -- Tome of Blood Page
(25360, 6576, 1, 3, 2, 589746), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Tracker Leader Sharuk
(25362, 433, 6, 16, 0, 16521.512524), -- Elven Tunic
(25362, 434, 1, 1, 0, 181735.934182), -- White Tunic
(25362, 435, 1, 1, 0, 181735.934182), -- Mystic's Tunic
(25362, 466, 4, 12, 0, 36394.186114), -- Elven Stockings
(25362, 467, 5, 13, 0, 32350.70036), -- Dark Stockings
(25362, 468, 5, 15, 0, 29115.630324), -- Mystic's Stockings
(25362, 1936, 53, 157, 0, 54460.061128), -- White Tunic Pattern
(25362, 1933, 24, 72, 0, 171268.041186), -- Dark Stockings Fabric
(25362, 86, 1, 1, 1, 33845.948), -- Tomahawk
(25362, 179, 1, 1, 1, 33845.948), -- Mace of Prayer
(25362, 180, 1, 1, 1, 33845.948), -- Mace of Judgment
(25362, 181, 1, 1, 1, 33845.948), -- Mace of Miracle
(25362, 182, 1, 1, 1, 33845.948), -- Doom Hammer
(25362, 183, 1, 1, 1, 33845.948), -- Mystic Staff
(25362, 184, 1, 1, 1, 33845.948), -- Conjuror's Staff
(25362, 185, 1, 1, 1, 33845.948), -- Staff of Mana
(25362, 2022, 4, 12, 1, 163267.484), -- Mace of Judgment Head
(25362, 2023, 2, 4, 1, 346364.932), -- Conjuror's Staff Head
(25362, 6387, 24, 72, 2, 150970.503238), -- Blessed Scroll of Resurrection for Pets
(25362, 955, 4, 10, 2, 103522.612018), -- Scroll: Enchant Weapon (D-Grade)
(25362, 956, 8, 22, 2, 402588.884744), -- Scroll: Enchant Armor (D-Grade)
-- Patriarch Kuroboros
(25365, 436, 2, 4, 0, 172819.38996), -- Tunic of Knowledge
(25365, 469, 1, 3, 0, 414340.61004), -- Stockings of Knowledge
(25365, 293, 1, 1, 1, 122380), -- War Hammer
(25365, 296, 1, 1, 1, 122380), -- Dwarven Pike
(25365, 6387, 12, 36, 2, 982910), -- Blessed Scroll of Resurrection for Pets
-- Kuroboros' Priest
(25366, 848, 3, 9, 0, 142028.025216), -- Enchanted Earring
(25366, 879, 3, 7, 0, 256432.102656), -- Enchanted Ring
(25366, 911, 4, 10, 0, 91373.490816), -- Enchanted Necklace
(25366, 1900, 96, 288, 0, 79638.381312), -- Enchanted Necklace Chain
(25366, 259, 1, 1, 1, 338459), -- Single-Edged Jamadhr
(25366, 6575, 1, 1, 2, 60388.2), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25366, 6576, 1, 1, 2, 543493.8), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Soul Scavenger
(25369, 63, 3, 9, 0, 71555.8744), -- Gauntlets
(25369, 553, 4, 10, 0, 61333.54654), -- Iron Boots
(25369, 2422, 4, 12, 0, 53666.9058), -- Reinforced Leather Boots
(25369, 2423, 5, 13, 0, 47703.77606), -- Boots of Knowledge
(25369, 2446, 5, 15, 0, 42933.52464), -- Reinforced Leather Gloves
(25369, 2447, 6, 16, 0, 39030.17104), -- Gloves of Knowledge
(25369, 1940, 60, 180, 0, 104396.20152), -- Iron Boots Design
(25369, 260, 1, 1, 1, 237073), -- Triple-Edged Jamadhr
(25369, 955, 3, 9, 2, 380816), -- Scroll: Enchant Weapon (D-Grade)
-- Discarded Guardian
(25372, 391, 2, 4, 0, 374352.540555), -- Puma Skin Shirt
(25372, 413, 4, 12, 0, 224798.459445), -- Puma Skin Gaiters
(25372, 123, 1, 1, 1, 128884.061844), -- Saber
(25372, 5285, 1, 1, 1, 128884.061844), -- Heavy Sword
(25372, 2017, 8, 22, 1, 179838.237657), -- Saber Blade
(25372, 5531, 24, 72, 1, 71004.638655), -- Heavy Sword Edge
(25372, 6387, 24, 72, 2, 146188.069653), -- Blessed Scroll of Resurrection for Pets
(25372, 955, 4, 10, 2, 100243.229583), -- Scroll: Enchant Weapon (D-Grade)
(25372, 956, 8, 22, 2, 389835.700764), -- Scroll: Enchant Armor (D-Grade)
-- Malex Herald of Dagoniel 
(25373, 46, 2, 4, 0, 456101.094988), -- Bronze Helmet
(25373, 627, 4, 12, 0, 244157.905012), -- Aspis
(25373, 315, 1, 1, 1, 318120), -- Divine Tome
(25373, 6575, 1, 1, 2, 37839.466027), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25373, 6576, 1, 1, 2, 340554.532054), -- Blessed Scroll: Enchant Armor (D-Grade)
(25373, 6387, 12, 36, 2, 283795.001919), -- Blessed Scroll of Resurrection for Pets
-- Zombie Lord Ferkel
(25375, 347, 2, 4, 0, 281012.070567), -- Ring Mail Breastplate
(25375, 376, 4, 12, 0, 168738.929433), -- Iron Plate Gaiters
(25375, 156, 1, 1, 1, 171845.494821), -- Hand Axe
(25375, 167, 1, 1, 1, 171845.494821), -- Scalpel
(25375, 178, 1, 1, 1, 171846.010358), -- Bone Staff
(25375, 6575, 1, 1, 2, 38983.46976), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25375, 6576, 1, 1, 2, 350848.26512), -- Blessed Scroll: Enchant Armor (D-Grade)
(25375, 955, 1, 3, 2, 350848.26512), -- Scroll: Enchant Weapon (D-Grade)
-- Madness Beast
(25378, 432, 2, 4, 0, 374352.540555), -- Cursed Tunic
(25378, 465, 4, 12, 0, 224798.459445), -- Cursed Stockings
(25378, 258, 1, 1, 1, 515537), -- Bagh-Nakh
(25378, 6387, 24, 72, 2, 146188.069653), -- Blessed Scroll of Resurrection for Pets
(25378, 955, 4, 10, 2, 100243.229583), -- Scroll: Enchant Weapon (D-Grade)
(25378, 956, 8, 22, 2, 389835.700764), -- Scroll: Enchant Armor (D-Grade)
-- Kaysha Herald of Icarus
(25380, 392, 2, 4, 0, 227753.944752), -- Lion Skin Shirt
(25380, 414, 1, 3, 0, 547320.055248), -- Lion Skin Gaiters
(25380, 292, 1, 1, 1, 318120), -- Pike
(25380, 6387, 24, 72, 2, 141898.009605), -- Blessed Scroll of Resurrection for Pets
(25380, 955, 4, 10, 2, 97301.474655), -- Scroll: Enchant Weapon (D-Grade)
(25380, 956, 8, 22, 2, 378395.51574), -- Scroll: Enchant Armor (D-Grade)
-- Revenant of Sir Calibus
(25383, 851, 6, 18, 0, 22980.082792), -- Omen Beast's Eye Earring
(25383, 882, 5, 15, 0, 41364.268726), -- Mithril Ring
(25383, 914, 1, 1, 0, 206820.745128), -- Necklace of Darkness
(25383, 1905, 81, 243, 0, 77246.259132), -- Omen Beast's Eye Earring Gemstone
(25383, 1906, 40, 120, 0, 221035.167628), -- Mithril Ring Wire
(25383, 1907, 154, 462, 0, 29055.476594), -- Necklace of Darkness Gem
(25383, 225, 1, 1, 1, 83473.707843), -- Mithril Dagger
(25383, 2052, 12, 36, 1, 209179.292157), -- Mithril Dagger Blade
(25383, 6573, 1, 1, 2, 50028), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Evil Spirit Tempest
(25385, 61, 9, 25, 0, 10980.90205), -- Mithril Plate Gloves
(25385, 607, 9, 27, 0, 10371.0297), -- Ogre Power Gauntlets
(25385, 1125, 10, 28, 0, 9825.15235), -- Assault Boots
(25385, 2427, 10, 30, 0, 9333.67075), -- Salamander Skin Boots
(25385, 2428, 11, 31, 0, 8889.54545), -- Plate Boots
(25385, 2451, 1, 1, 0, 186676.61475), -- Sage's Worn Gloves
(25385, 1949, 112, 336, 0, 34971.9876), -- Mithril Gloves Design
(25385, 1963, 203, 607, 0, 19342.48875), -- Ogre Power Gauntlets Part
(25385, 1957, 320, 960, 0, 12240.32365), -- Assault Boots Part
(25385, 2931, 28, 82, 0, 142431.75165), -- Salamander Skin Boot Lining
(25385, 2932, 36, 108, 0, 108801.7392), -- Plate Boots Design
(25385, 2933, 46, 136, 0, 86084.7941), -- Sage's Worn Gloves Lining
(25385, 280, 1, 1, 1, 91090.0533), -- Light Crossbow
(25385, 2054, 12, 36, 1, 224009.9467), -- Light Crossbow Shaft
(25385, 6574, 1, 1, 2, 467933), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Red Eye Captain Trakia
(25388, 396, 1, 1, 0, 219923.93547), -- Salamander Skin Mail
(25388, 1952, 12, 36, 0, 538011.06453), -- Salamander Skin Mail Texture
(25388, 297, 1, 1, 1, 87192.585431), -- Glaive
(25388, 2055, 12, 36, 1, 208326.414569), -- Glaive Edge
(25388, 6574, 1, 1, 2, 447912), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Nurka's Messenger
(25391, 61, 9, 25, 0, 9653.617476), -- Mithril Plate Gloves
(25391, 607, 9, 27, 0, 9117.305394), -- Ogre Power Gauntlets
(25391, 1125, 10, 28, 0, 8637.787755), -- Assault Boots
(25391, 2427, 10, 30, 0, 8205.718638), -- Salamander Skin Boots
(25391, 2428, 1, 1, 0, 164117.248428), -- Plate Boots
(25391, 2451, 1, 1, 0, 164117.248428), -- Sage's Worn Gloves
(25391, 1949, 112, 336, 0, 30745.923339), -- Mithril Gloves Design
(25391, 1963, 203, 607, 0, 17005.262718), -- Ogre Power Gauntlets Part
(25391, 1957, 320, 960, 0, 10760.749656), -- Assault Boots Part
(25391, 2931, 28, 82, 0, 125219.525226), -- Salamander Skin Boot Lining
(25391, 2932, 36, 108, 0, 95653.344684), -- Plate Boots Design
(25391, 2933, 46, 136, 0, 75683.268258), -- Sage's Worn Gloves Lining
(25391, 297, 1, 1, 1, 80079.839188), -- Glaive
(25391, 2055, 12, 36, 1, 191332.160812), -- Glaive Edge
(25391, 6574, 1, 1, 2, 411373), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Captain of Queen's Royal Guards
(25392, 352, 1, 1, 0, 102759.8052), -- Brigandine Tunic
(25392, 2377, 1, 1, 0, 164372.6254), -- Mithril Scale Gaiters
(25392, 2378, 1, 1, 0, 164372.6254), -- Brigandine Gaiters
(25392, 1941, 14, 42, 0, 167627.16032), -- Brigandine Temper
(25392, 2918, 40, 120, 0, 87525.74984), -- Mithril Scale Gaiters Material
(25392, 2919, 81, 243, 0, 43222.03384), -- Brigandine Gaiters Material
(25392, 279, 1, 1, 1, 98899.191205), -- Reinforced Long Bow
(25392, 2040, 12, 36, 1, 256029.808795), -- Reinforced Long Bow Shaft
(25392, 4562, 1, 3, 2, 344224.3311), -- Greater Dye of MEN (Men+1 Wit-1)
(25392, 4563, 2, 4, 2, 229482.8874), -- Greater Dye of WIT (Wit+1 Int-1)
(25392, 4564, 2, 6, 2, 172112.16555), -- Greater Dye of WIT (Wit+1 Men-1)
(25392, 955, 3, 7, 2, 137690.61595), -- Scroll: Enchant Weapon (D-Grade)
-- Premo Prime
(25394, 354, 1, 1, 0, 111124.17625), -- Chain Mail Shirt
(25394, 381, 1, 1, 0, 177780.46733), -- Chain Gaiters
(25394, 1959, 12, 36, 0, 242327.96968), -- Chain Mail Shirt Material
(25394, 1960, 105, 315, 0, 56337.38674), -- Chain Gaiters Part
(25394, 96, 1, 1, 1, 24495.364663), -- Scythe
(25394, 298, 1, 1, 1, 24495.364663), -- Orcish Glaive
(25394, 302, 1, 1, 1, 24495.364663), -- Body Slasher
(25394, 2062, 5, 15, 1, 169345.619534), -- Scythe Edge
(25394, 2075, 9, 27, 1, 94081.237642), -- Orcish Glaive Blade
(25394, 2076, 2, 6, 1, 423364.048835), -- Body Slasher Blade
(25394, 6573, 1, 1, 2, 55978), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Archon Susceptor
(25395, 103, 1, 1, 0, 136337.893362), -- Tower Shield
(25395, 107, 1, 1, 0, 136337.893362), -- Composite Shield
(25395, 517, 1, 1, 0, 95465.56239), -- Composite Helmet
(25395, 1149, 1, 1, 0, 95465.56239), -- Shining Circlet
(25395, 1978, 60, 180, 0, 72210.71484), -- Tower Shield Fragment
(25395, 4055, 116, 346, 0, 37511.816364), -- Composite Shield Fragment
(25395, 2957, 192, 576, 0, 15440.065938), -- Composite Helmet Design
(25395, 1983, 23, 67, 0, 131752.491354), -- Shining Circlet Pattern
(25395, 162, 1, 1, 1, 6136.503432), -- War Axe
(25395, 174, 1, 1, 1, 6136.503432), -- Nirvana Axe
(25395, 196, 1, 1, 1, 6136.503432), -- Stick of Eternity
(25395, 197, 1, 1, 1, 6136.503432), -- Paradia Staff
(25395, 199, 1, 1, 1, 6136.503432), -- Pa'agrian Hammer
(25395, 200, 1, 1, 1, 6136.503432), -- Sage's Staff
(25395, 201, 1, 1, 1, 6136.503432), -- Club of Nature
(25395, 202, 1, 1, 1, 6136.503432), -- Mace of Underworld
(25395, 2097, 4, 10, 1, 77575.046086), -- War Axe Blade
(25395, 2098, 4, 12, 1, 67878.408992), -- Nirvana Axe Blade
(25395, 2099, 10, 30, 1, 28574.637328), -- Stick of Eternity Shaft
(25395, 2100, 17, 49, 1, 17317.883256), -- Paradia Staff Head
(25395, 2102, 3, 9, 1, 91832.474962), -- Pa'agrian Hammer Head
(25395, 2103, 2, 6, 1, 142873.18664), -- Sage's Staff Head
(25395, 2104, 3, 7, 1, 114298.549312), -- Club of Nature Head
(25395, 2105, 5, 13, 1, 60335.785968), -- Mace of Underworld Head
(25395, 4604, 2, 6, 2, 146026.690173), -- Greater Dye of CON (Con+3 Dex-3)
(25395, 4605, 3, 7, 2, 116821.163277), -- Greater Dye of DEX (Dex+3 Str-3)
(25395, 4606, 3, 9, 2, 97351.441551), -- Greater Dye of DEX (Dex+3 Con-3)
(25395, 952, 3, 9, 2, 584107.704999), -- Scroll: Enchant Armor (C-Grade)
(25395, 9817, 1, 3, 2, 750000), -- Nonliving Nucleus
(25395, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Beleth's Eye
(25398, 353, 1, 1, 0, 134016.19392), -- Half Plate Armor
(25398, 380, 1, 1, 0, 214426.15936), -- Plate Gaiters
(25398, 1950, 53, 157, 0, 62305.00416), -- Half Plate Temper
(25398, 1951, 24, 72, 0, 211972.64256), -- Plate Gaiters Part
(25398, 70, 1, 1, 1, 43596.351546), -- Claymore
(25398, 2499, 1, 1, 1, 43596.351546), -- Elven Long Sword
(25398, 2047, 4, 12, 1, 332241.088641), -- Claymore Blade
(25398, 2967, 8, 22, 1, 174797.208267), -- Elven Long Sword Blade
(25398, 951, 1, 3, 2, 712587), -- Scroll: Enchant Weapon (C-Grade)
-- Skyla
(25401, 437, 1, 1, 0, 205848.17672), -- Mithril Tunic
(25401, 470, 4, 12, 0, 41093.40316), -- Mithril Stockings
(25401, 1944, 53, 157, 0, 85998.41552), -- Mithril Tunic Fabric
(25401, 1945, 24, 72, 0, 292940.0046), -- Mithril Stocking Design
(25401, 224, 1, 1, 1, 49449.630505), -- Maingauche
(25401, 1660, 1, 1, 1, 49449.630505), -- Cursed Maingauche
(25401, 2038, 4, 12, 1, 350710.31992), -- Maingauche Edge
(25401, 2044, 8, 22, 1, 187045.41907), -- Cursed Maingauche Edge
(25401, 956, 12, 36, 2, 956178), -- Scroll: Enchant Armor (D-Grade)
-- Corsair Captain Kylon
(25404, 630, 6, 16, 0, 28403.208243), -- Square Shield
(25404, 2412, 1, 1, 0, 218815.181622), -- Plate Helmet
(25404, 2494, 6, 18, 0, 26036.226693), -- Plate Shield
(25404, 1956, 40, 120, 0, 175101.880428), -- Square Shield Fragment
(25404, 2930, 140, 420, 0, 35530.389315), -- Plate Helmet Design
(25404, 2934, 81, 243, 0, 86470.113699), -- Plate Shield Fragment
(25404, 70, 1, 1, 1, 40039.934696), -- Claymore
(25404, 2499, 1, 1, 1, 40039.934696), -- Elven Long Sword
(25404, 2047, 4, 12, 1, 305138.182916), -- Claymore Blade
(25404, 2967, 8, 22, 1, 160537.947692), -- Elven Long Sword Blade
(25404, 6573, 1, 1, 2, 47994), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Lord Ishka 
(25407, 2398, 1, 1, 0, 21002.349345), -- Blue Wolf Tunic
(25407, 2399, 1, 1, 0, 21002.349345), -- Tunic of Doom
(25407, 2403, 1, 1, 0, 33613.267965), -- Blue Wolf Stockings
(25407, 2404, 1, 1, 0, 33613.267965), -- Stockings of Doom
(25407, 4084, 16, 48, 0, 105909.091515), -- Blue Wolf Tunic Fabric
(25407, 4085, 23, 67, 0, 75313.022445), -- Tunic of Doom Pattern
(25407, 4086, 60, 180, 0, 38133.874605), -- Blue Wolf Stockings Pattern
(25407, 4087, 11, 31, 0, 217907.776815), -- Stockings of Doom Pattern
(25407, 97, 1, 1, 1, 23188.83161), -- Lance
(25407, 4115, 12, 36, 1, 212676.16839), -- Lance Blade
(25407, 4613, 1, 3, 2, 261503.392436), -- Greater Dye of STR (Str+4 Con-4)
(25407, 4614, 2, 4, 2, 174335.116116), -- Greater Dye of STR (Str+4 Dex-4)
(25407, 4615, 2, 6, 2, 130751.696218), -- Greater Dye of CON (Con+4 Str-4)
(25407, 947, 1, 1, 2, 151671.79523), -- Scroll: Enchant Weapon (B-Grade)
(25407, 9814, 1, 4, 2, 850000), -- Memento Mori
(25407, 8176, 1, 2, 2, 730000), -- Destruction Tombstone
-- Road Scavenger Leader
(25410, 852, 1, 1, 0, 258666.745276), -- Moonstone Earring
(25410, 883, 6, 16, 0, 35287.519992), -- Aquastone Ring
(25410, 915, 1, 1, 0, 194081.359956), -- Aquastone Necklace
(25410, 1908, 81, 243, 0, 90193.115364), -- Moonstone Earring Wire
(25410, 1909, 480, 1440, 0, 21704.640664), -- Aquastone Ring Wire
(25410, 1910, 140, 420, 0, 41494.618748), -- Aquastone Necklace Chain
(25410, 71, 1, 1, 1, 39385.444065), -- Flamberge
(25410, 72, 1, 1, 1, 39385.444065), -- Stormbringer
(25410, 2059, 8, 22, 1, 171916.734149), -- Flamberge Blade
(25410, 2060, 4, 12, 1, 344573.377721), -- Stormbringer Blade
(25410, 6573, 1, 1, 2, 60004), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25410, 9814, 1, 2, 2, 850000), -- Memento Mori
(25410, 8176, 1, 1, 2, 640000), -- Destruction Tombstone
-- Necrosentinel Royal Guard
(25412, 2414, 1, 1, 0, 142160.53287), -- Full Plate Helmet
(25412, 2497, 1, 1, 0, 203100.77997), -- Full Plate Shield
(25412, 2959, 53, 157, 0, 96614.08249), -- Full Plate Helmet Design
(25412, 2966, 24, 72, 0, 334334.60467), -- Full Plate Shield Fragment
(25412, 301, 1, 1, 1, 15948.92637), -- Scorpion
(25412, 303, 1, 1, 1, 15948.92637), -- Widow Maker
(25412, 299, 1, 1, 1, 12444.182046), -- Orcish Poleaxe
(25412, 2113, 5, 15, 1, 142023.134592), -- Scorpion Blade
(25412, 2114, 9, 27, 1, 78901.74144), -- Widowmaker Head
(25412, 2122, 2, 6, 1, 334655.089182), -- Orcish Poleaxe Blade
(25412, 4607, 1, 3, 2, 316811.371166), -- Greater Dye of INT (Int+3 Men-3)
(25412, 4608, 2, 4, 2, 211207.345633), -- Greater Dye of INT (Int+3 Wit-3)
(25412, 4609, 2, 6, 2, 158405.685583), -- Greater Dye of MEN (Men+3 Int-3)
(25412, 6573, 1, 1, 2, 19008.597618), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25412, 9814, 1, 3, 2, 810000), -- Memento Mori
(25412, 8176, 1, 1, 2, 810000), -- Destruction Tombstone
-- Nakondas
(25415, 438, 1, 1, 0, 195393.059666), -- Sage's Rag
(25415, 1953, 12, 36, 0, 477999.940334), -- Sage's Rag Lining
(25415, 159, 1, 1, 1, 15493.39152), -- Bonebreaker
(25415, 187, 1, 1, 1, 15493.39152), -- Atuba Hammer
(25415, 188, 1, 1, 1, 15493.39152), -- Ghost Staff
(25415, 189, 1, 1, 1, 15493.39152), -- Staff of Life
(25415, 190, 1, 1, 1, 15493.39152), -- Atuba Mace
(25415, 2048, 2, 6, 1, 222102.927024), -- Bonebreaker Head
(25415, 2049, 3, 7, 1, 177682.927104), -- Atuba Hammer Head
(25415, 2050, 7, 21, 1, 67286.108784), -- Ghost Staff Head
(25415, 2051, 12, 36, 1, 39250.169136), -- Staff of Life Shaft
(25415, 2058, 3, 9, 1, 148066.910352), -- Atuba Mace Head
(25415, 952, 12, 36, 2, 386897), -- Scroll: Enchant Armor (C-Grade)
(25415, 9815, 1, 2, 2, 850000), -- Dragon Heart
(25415, 8176, 1, 1, 2, 640000), -- Destruction Tombstone
-- Dread Avenger Kraven
(25418, 103, 1, 1, 0, 131055.599926), -- Tower Shield
(25418, 107, 1, 1, 0, 131055.599926), -- Composite Shield
(25418, 517, 1, 1, 0, 91766.83197), -- Composite Helmet
(25418, 1149, 1, 1, 0, 91766.83197), -- Shining Circlet
(25418, 1978, 60, 180, 0, 69412.97332), -- Tower Shield Fragment
(25418, 4055, 116, 346, 0, 36058.453572), -- Composite Shield Fragment
(25418, 2957, 192, 576, 0, 14841.853974), -- Composite Helmet Design
(25418, 1983, 23, 67, 0, 126647.855342), -- Shining Circlet Pattern
(25418, 162, 1, 1, 1, 5898.755452), -- War Axe
(25418, 174, 1, 1, 1, 5898.755452), -- Nirvana Axe
(25418, 196, 1, 1, 1, 5898.755452), -- Stick of Eternity
(25418, 197, 1, 1, 1, 5898.755452), -- Paradia Staff
(25418, 199, 1, 1, 1, 5898.755452), -- Pa'agrian Hammer
(25418, 200, 1, 1, 1, 5898.755452), -- Sage's Staff
(25418, 201, 1, 1, 1, 5898.755452), -- Club of Nature
(25418, 202, 1, 1, 1, 5898.755452), -- Mace of Underworld
(25418, 2097, 4, 10, 1, 74566.217504), -- War Axe Blade
(25418, 2098, 4, 12, 1, 65245.440316), -- Nirvana Axe Blade
(25418, 2099, 10, 30, 1, 27466.351992), -- Stick of Eternity Shaft
(25418, 2100, 2, 4, 1, 183108.222244), -- Paradia Staff Head
(25418, 2102, 3, 9, 1, 88270.125168), -- Pa'agrian Hammer Head
(25418, 2103, 2, 6, 1, 137331.75996), -- Sage's Staff Head
(25418, 2104, 3, 7, 1, 109865.407968), -- Club of Nature Head
(25418, 2105, 5, 13, 1, 57992.431232), -- Mace of Underworld Head
(25418, 4607, 1, 3, 2, 280738.15122), -- Greater Dye of INT (Int+3 Men-3)
(25418, 4608, 2, 4, 2, 187158.55911), -- Greater Dye of INT (Int+3 Wit-3)
(25418, 4609, 2, 6, 2, 140369.07561), -- Greater Dye of MEN (Men+3 Int-3)
(25418, 6573, 1, 1, 2, 16844.21406), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25418, 9814, 1, 3, 2, 720000), -- Memento Mori
(25418, 8176, 1, 1, 2, 720000), -- Destruction Tombstone
-- Orfen's Handmaiden
(25420, 442, 1, 1, 0, 73760.97344), -- Divine Tunic
(25420, 473, 1, 1, 0, 117977.386048), -- Divine Stockings
(25420, 1988, 8, 22, 0, 389745.011168), -- Divine Tunic Fabric
(25420, 1989, 24, 72, 0, 191044.629344), -- Divine Stocking Pattern
(25420, 266, 1, 1, 1, 38730.97732), -- Great Pata
(25420, 2120, 3, 9, 1, 730779.02268), -- Great Pata Blade
(25420, 4604, 2, 6, 2, 164340.338274), -- Greater Dye of CON (Con+3 Dex-3)
(25420, 4605, 3, 7, 2, 131472.170763), -- Greater Dye of DEX (Dex+3 Str-3)
(25420, 4606, 3, 9, 2, 109560.225516), -- Greater Dye of DEX (Dex+3 Con-3)
(25420, 952, 21, 63, 2, 93908.265447), -- Scroll: Enchant Armor (C-Grade)
(25420, 9816, 1, 3, 2, 840000), -- Earth Egg
(25420, 8176, 1, 1, 2, 840000), -- Destruction Tombstone
-- Fairy Queen Timiniel
(25423, 2398, 1, 1, 0, 16782.80373), -- Blue Wolf Tunic
(25423, 2399, 1, 1, 0, 16782.80373), -- Tunic of Doom
(25423, 2403, 1, 1, 0, 26860.590855), -- Blue Wolf Stockings
(25423, 2404, 1, 1, 0, 26860.590855), -- Stockings of Doom
(25423, 4084, 16, 48, 0, 84631.372245), -- Blue Wolf Tunic Fabric
(25423, 4085, 23, 67, 0, 60182.34075), -- Tunic of Doom Pattern
(25423, 4086, 6, 18, 0, 304725.26637), -- Blue Wolf Stockings Pattern
(25423, 4087, 11, 31, 0, 174129.231465), -- Stockings of Doom Pattern
(25423, 234, 1, 1, 1, 18530.050656), -- Demon's Dagger
(25423, 4119, 3, 9, 1, 682091.949344), -- Demon's Dagger Edge
(25423, 4622, 1, 3, 2, 208965.203844), -- Greater Dye of MEN (Men+4 Wit-4)
(25423, 4623, 2, 4, 2, 139310.135896), -- Greater Dye of WIT (Wit+4 Int-4)
(25423, 4624, 1, 1, 2, 417929.560684), -- Greater Dye of WIT (Wit+4 Men-4)
(25423, 6572, 1, 1, 2, 80799.099576), -- Blessed Scroll: Enchant Armor (B-Grade)
(25423, 9818, 1, 4, 2, 830000), -- Angelic Essence
(25423, 8176, 1, 2, 2, 690000), -- Destruction Tombstone
-- Betrayer of Urutu Freki
(25426, 47, 2, 4, 0, 334212.335784), -- Helmet
(25426, 628, 4, 12, 0, 179129.664216), -- Hoplon
(25426, 278, 1, 1, 1, 118536.37999), -- Gastraphetes
(25426, 2029, 12, 36, 1, 219010.62001), -- Gastraphetes Shaft
(25426, 956, 12, 36, 2, 793367), -- Scroll: Enchant Armor (D-Grade)
-- Mammon Collector Talos
(25429, 393, 1, 1, 0, 125543.801799), -- Mithril Banded Mail
(25429, 394, 1, 1, 0, 125543.801799), -- Reinforced Leather Shirt
(25429, 415, 1, 1, 0, 200664.255381), -- Mithril Banded Gaiters
(25429, 416, 1, 1, 0, 200664.255381), -- Reinforced Leather Gaiters
(25429, 223, 1, 1, 0, 19756.22141), -- Kukuri
(25429, 238, 1, 1, 0, 19756.22141), -- Dagger of Mana
(25429, 239, 1, 1, 0, 19756.22141), -- Mystic Knife
(25429, 241, 1, 1, 0, 19756.22141), -- Shilen Knife
(25429, 1938, 60, 180, 1, 164578.510346), -- Mithril Banded Mail Material
(25429, 1939, 28, 84, 1, 460776.635407), -- Mithril Banded Gaiters Material
(25429, 2028, 27, 81, 1, 64637.854247), -- Shilen Knife Edge
(25429, 6575, 1, 1, 2, 126939), -- Blessed Scroll: Enchant Weapon (D-Grade)
-- Flamestone Golem
(25431, 60, 1, 1, 0, 84721.889494), -- Composite Armor
(25431, 265, 1, 1, 0, 31460.110506), -- Fisted Blade
(25431, 1977, 15, 45, 1, 384443.070102), -- Composite Armor Temper
(25431, 2108, 12, 36, 1, 173997.929898), -- Fisted Blade Piece
(25431, 4610, 1, 3, 2, 280738.09029), -- Greater Dye of MEN (Men+3 Wit-3)
(25431, 4611, 2, 4, 2, 187158.72686), -- Greater Dye of WIT (Wit+3 Int-3)
(25431, 4612, 2, 6, 2, 140369.045145), -- Greater Dye of WIT (Wit+3 Men-3)
(25431, 6574, 1, 1, 2, 144379.137705), -- Blessed Scroll: Enchant Armor (C-Grade)
(25431, 9817, 1, 3, 2, 720000), -- Nonliving Nucleus
(25431, 8176, 1, 1, 2, 720000), -- Destruction Tombstone
-- Bandit Leader Barda
(25434, 554, 1, 1, 0, 84624.773742), -- Sealed Zubei's Boots
(25434, 600, 1, 1, 0, 84624.773742), -- Sealed Avadon Boots
(25434, 612, 1, 1, 0, 84624.773742), -- Sealed Zubei's Gauntlets
(25434, 2464, 1, 1, 0, 84624.773742), -- Sealed Avadon Gloves
(25434, 4097, 60, 180, 0, 73236.021642), -- Sealed Zubei's Boots Design
(25434, 4098, 116, 346, 0, 38045.111634), -- Sealed Avadon Boots Design
(25434, 4100, 192, 576, 0, 22886.382006), -- Sealed Zubei's Gauntlets Part
(25434, 4073, 23, 67, 0, 195295.38975), -- Sealed Avadon Gloves Part
(25434, 78, 1, 1, 1, 10111.137876), -- Great Sword
(25434, 142, 1, 1, 1, 10111.137876), -- Keshanberk
(25434, 148, 1, 1, 1, 10111.137876), -- Sword of Valhalla
(25434, 4104, 5, 15, 1, 193267.654974), -- Great Sword Blade
(25434, 4107, 9, 27, 1, 105707.314407), -- Keshanberk Blade
(25434, 4108, 14, 42, 1, 67954.616991), -- Sword of Valhalla Blade
(25434, 6572, 1, 1, 2, 116748.786948), -- Blessed Scroll: Enchant Armor (B-Grade)
(25434, 948, 1, 3, 2, 547258.426104), -- Scroll: Enchant Armor (B-Grade)
(25434, 9814, 1, 4, 2, 750000), -- Memento Mori
(25434, 8176, 1, 2, 2, 620000), -- Destruction Tombstone
-- Timak Orc Gosmos
(25437, 60, 1, 1, 0, 88136.203356), -- Composite Armor
(25437, 1977, 12, 36, 0, 333281.796644), -- Composite Armor Temper
(25437, 265, 1, 1, 1, 49092.07058), -- Fisted Blade
(25437, 2108, 3, 9, 1, 724047.92942), -- Fisted Blade Piece
(25437, 4607, 1, 3, 2, 292053.27611), -- Greater Dye of INT (Int+3 Men-3)
(25437, 4608, 2, 4, 2, 194701.967305), -- Greater Dye of INT (Int+3 Wit-3)
(25437, 4609, 2, 6, 2, 146026.638055), -- Greater Dye of MEN (Men+3 Int-3)
(25437, 6573, 1, 1, 2, 17523.11853), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25437, 9814, 1, 3, 2, 750000), -- Memento Mori
(25437, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Thief Kelbar
(25438, 60, 1, 1, 0, 84721.541922), -- Composite Armor
(25438, 1977, 12, 36, 0, 320369.458078), -- Composite Armor Temper
(25438, 283, 1, 1, 1, 47190.02827), -- Akat Long Bow
(25438, 2109, 3, 9, 1, 728578.97173), -- Akat Longbow Shaft
(25438, 4601, 1, 3, 2, 280738.139968), -- Greater Dye of STR (Str+3 Con-3)
(25438, 4602, 2, 4, 2, 187158.99336), -- Greater Dye of STR (Str+3 Dex-3)
(25438, 4603, 2, 6, 2, 140369.069984), -- Greater Dye of CON (Con+3 Str-3)
(25438, 951, 3, 7, 2, 91877.796688), -- Scroll: Enchant Weapon (C-Grade)
(25438, 9814, 1, 3, 2, 720000), -- Memento Mori
(25438, 8176, 1, 1, 2, 720000), -- Destruction Tombstone
-- Evil Spirit Cyrion
(25441, 854, 1, 1, 0, 159080.840568), -- Earring of Seal
(25441, 885, 1, 1, 0, 238568.488704), -- Ring of Ages
(25441, 917, 1, 1, 0, 119323.423674), -- Necklace of Mermaid
(25441, 1914, 81, 243, 0, 62504.611416), -- Earring of Seal Gemstone
(25441, 1915, 280, 840, 0, 28357.03377), -- Ring of Ages Gemstone
(25441, 1916, 20, 60, 0, 191743.601868), -- Necklace of Mermaid Teardrop
(25441, 283, 1, 1, 1, 49091.98929), -- Akat Long Bow
(25441, 2109, 12, 36, 1, 189485.01071), -- Akat Longbow Shaft
(25441, 4610, 1, 3, 2, 292053.478962), -- Greater Dye of MEN (Men+3 Wit-3)
(25441, 4611, 2, 4, 2, 194702.319308), -- Greater Dye of WIT (Wit+3 Int-3)
(25441, 4612, 2, 6, 2, 146026.739481), -- Greater Dye of WIT (Wit+3 Men-3)
(25441, 6574, 1, 1, 2, 150198.462249), -- Blessed Scroll: Enchant Armor (C-Grade)
(25441, 9815, 1, 3, 2, 750000), -- Dragon Heart
(25441, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Enmity Ghost Ramdal
(25444, 5287, 1, 1, 0, 15381.06416), -- Sealed Dark Crystal breastplate
(25444, 5288, 1, 1, 0, 24612.34646), -- Sealed Dark Crystal Gaiters
(25444, 5293, 1, 1, 0, 9465.55271), -- Sealed Tallum Plate Armor
(25444, 5520, 9, 27, 0, 98138.00448), -- Sealed Dark Crystal Breastplate Pattern
(25444, 5524, 4, 12, 0, 337493.33084), -- Sealed Dark Crystal Gaiters Pattern
(25444, 5521, 3, 7, 0, 249299.70135), -- Sealed Tallum Plate Armor Pattern
(25444, 288, 1, 1, 1, 17487.790551), -- Carnage Bow
(25444, 5535, 3, 9, 1, 701021.209449), -- Carnage Bow Stave
(25444, 729, 1, 1, 2, 59183.847494), -- Scroll: Enchant Weapon (A-Grade)
(25444, 730, 1, 1, 2, 443880.13162), -- Scroll: Enchant Armor (A-Grade)
(25444, 6569, 1, 1, 2, 7102.020886), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25444, 9814, 1, 4, 2, 890000), -- Memento Mori
(25444, 8176, 1, 2, 2, 760000), -- Destruction Tombstone
-- Immortal Savior Mardil
(25447, 5326, 1, 1, 0, 14002.479128), -- Sealed Robe of Nightmare
(25447, 5329, 1, 1, 0, 14002.479128), -- Sealed Majestic Robe
(25447, 5487, 4, 12, 0, 260219.711609), -- Sealed Robe of Nightmare Fabric
(25447, 5488, 8, 22, 0, 138784.330135), -- Sealed Majestic Robe Fabric
(25447, 164, 1, 1, 1, 6686.640662), -- Elysian
(25447, 213, 1, 1, 1, 6686.640662), -- Branch of the Mother Tree
(25447, 5533, 4, 12, 1, 237763.385795), -- Elysian Head
(25447, 5544, 8, 22, 1, 126682.332881), -- Branch of the Mother Tree Head
(25447, 959, 1, 1, 2, 23970.652496), -- Scroll: Enchant Weapon (S-Grade)
(25447, 960, 1, 1, 2, 239707.060306), -- Scroll: Enchant Armor (S-Grade)
(25447, 6577, 1, 1, 2, 3995.287198), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25447, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25447, 9814, 2, 4, 2, 840000), -- Memento Mori
(25447, 8176, 1, 2, 2, 850000), -- Destruction Tombstone
-- Cherub Galaxia
(25450, 6676, 1, 1, 0, 20516.891566), -- Sealed Imperial Crusader Gauntlet
(25450, 6677, 1, 1, 0, 20516.891566), -- Sealed Imperial Crusader Boots
(25450, 6681, 1, 1, 0, 20516.891566), -- Sealed Draconic Leather Glove
(25450, 6682, 1, 1, 0, 20516.891566), -- Sealed Draconic Leather Boots
(25450, 6685, 1, 1, 0, 20516.891566), -- Sealed Major Arcana Glove
(25450, 6686, 1, 1, 0, 20516.891566), -- Sealed Major Arcana Boots
(25450, 6703, 112, 336, 0, 20832.80932), -- Sealed Imperial Crusader Gauntlets Design
(25450, 6704, 14, 40, 0, 172835.558223), -- Sealed Imperial Crusader Boots Design
(25450, 6708, 20, 60, 0, 116663.732192), -- Sealed Draconic Leather Gloves Fabric
(25450, 6709, 28, 82, 0, 84846.120004), -- Sealed Draconic Leather Boots Design
(25450, 6712, 36, 108, 0, 64813.255037), -- Sealed Major Arcana Gloves fabric
(25450, 6713, 46, 136, 0, 51280.175828), -- Sealed Major Arcana Boots Design
(25450, 6364, 1, 1, 1, 6898.64438), -- Forgotten Blade
(25450, 6372, 1, 1, 1, 6898.64438), -- Heaven's Divider
(25450, 6688, 8, 22, 1, 212535.051844), -- Forgotten Blade Edge
(25450, 6696, 4, 12, 1, 404833.659396), -- Heavens Divider Edge
(25450, 959, 1, 1, 2, 50984.550608), -- Scroll: Enchant Weapon (S-Grade)
(25450, 960, 1, 1, 2, 509846.644738), -- Scroll: Enchant Armor (S-Grade)
(25450, 6577, 1, 1, 2, 8497.804654), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Meanas Anor
(25453, 5320, 1, 1, 0, 22289.045658), -- Sealed Leather Armor of Nightmare
(25453, 5323, 1, 1, 0, 22289.045658), -- Sealed Majestic Leather Armor
(25453, 5480, 4, 12, 0, 412748.06108), -- Sealed Leather Armor of Nightmare Fabric
(25453, 5481, 8, 22, 0, 220131.847604), -- Sealed Majestic Leather Armor Fabric
(25453, 305, 1, 1, 1, 21287.467624), -- Tallum Glaive
(25453, 5541, 12, 36, 1, 252256.532376), -- Tallum Glaive Edge
(25453, 959, 1, 1, 2, 38156.405712), -- Scroll: Enchant Weapon (S-Grade)
(25453, 960, 1, 1, 2, 381564.909282), -- Scroll: Enchant Armor (S-Grade)
(25453, 6577, 1, 1, 2, 6359.685006), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25453, 8619, 1, 1, 2, 520000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25453, 9815, 3, 7, 2, 810000), -- Dragon Heart
(25453, 8176, 1, 4, 2, 820000), -- Destruction Tombstone
-- Mirror of Oblivion
(25456, 2414, 1, 1, 0, 153011.090448), -- Full Plate Helmet
(25456, 2497, 1, 1, 0, 218602.592112), -- Full Plate Shield
(25456, 2959, 53, 157, 0, 103988.736336), -- Full Plate Helmet Design
(25456, 2966, 192, 576, 0, 44981.581104), -- Full Plate Shield Fragment
(25456, 266, 1, 1, 1, 40181.847552), -- Great Pata
(25456, 2120, 3, 9, 1, 758154.152448), -- Great Pata Blade
(25456, 4601, 1, 3, 2, 340993.004352), -- Greater Dye of STR (Str+3 Con-3)
(25456, 4602, 2, 4, 2, 227328.95304), -- Greater Dye of STR (Str+3 Dex-3)
(25456, 4603, 2, 6, 2, 170496.502176), -- Greater Dye of CON (Con+3 Str-3)
(25456, 951, 3, 7, 2, 111597.540432), -- Scroll: Enchant Weapon (C-Grade)
(25456, 9818, 1, 4, 2, 700000), -- Angelic Essence
(25456, 8176, 1, 2, 2, 580000), -- Destruction Tombstone
-- Deadman Ereve
(25460, 357, 1, 1, 0, 19325.039994), -- Zubei's Breastplate
(25460, 383, 1, 1, 0, 30914.3673), -- Zubei's Gaiters
(25460, 2376, 1, 1, 0, 19325.039994), -- Avadon Breastplate
(25460, 2379, 1, 1, 0, 30914.3673), -- Avadon Gaiters
(25460, 4056, 16, 48, 0, 87225.66081), -- Zubei's Breastplate Part
(25460, 4057, 60, 180, 0, 35947.589706), -- Zubei's Gaiter Material
(25460, 4064, 23, 67, 0, 62027.136576), -- Avadon Breastplate Part
(25460, 4065, 11, 31, 0, 205414.79832), -- Avadon Gaiters Material
(25460, 300, 1, 1, 1, 27700.980024), -- Great Axe
(25460, 4113, 12, 36, 1, 198387.019976), -- Great Axe Head
(25460, 4601, 1, 3, 2, 333178.060072), -- Greater Dye of STR (Str+3 Con-3)
(25460, 4602, 2, 4, 2, 222118.98369), -- Greater Dye of STR (Str+3 Dex-3)
(25460, 4603, 2, 6, 2, 166589.030036), -- Greater Dye of CON (Con+3 Str-3)
(25460, 951, 3, 7, 2, 109039.926202), -- Scroll: Enchant Weapon (C-Grade)
(25460, 9814, 1, 3, 2, 850000), -- Memento Mori
(25460, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Harit Guardian Garangky
(25463, 2391, 1, 1, 0, 23096.919312), -- Blue Wolf Leather Armor
(25463, 2392, 1, 1, 0, 23096.919312), -- Leather Armor of Doom
(25463, 4082, 24, 72, 0, 82018.851696), -- Blue Wolf Leather Armor Texture
(25463, 4083, 8, 22, 0, 262459.30968), -- Leather Armor of Doom Design
(25463, 234, 1, 1, 1, 20715.686928), -- Demon's Dagger
(25463, 4119, 3, 9, 1, 762545.313072), -- Demon's Dagger Edge
(25463, 947, 1, 1, 2, 180660.624442), -- Scroll: Enchant Weapon (B-Grade)
(25463, 948, 1, 3, 2, 564564.261849), -- Scroll: Enchant Armor (B-Grade)
(25463, 6571, 1, 1, 2, 12904.113709), -- Blessed Scroll: Enchant Weapon (B-Grade)
(25463, 9816, 1, 4, 2, 770000), -- Earth Egg
(25463, 8176, 1, 2, 2, 650000), -- Destruction Tombstone
-- Gorgolos
(25467, 5289, 1, 1, 0, 40082.470664), -- Sealed Dark Crystal Helmet
(25467, 5292, 1, 1, 0, 57273.21872), -- Sealed Dark Crystal Shield
(25467, 5294, 1, 1, 0, 40082.470664), -- Sealed Tallum Helmet
(25467, 5525, 9, 27, 0, 229944.77156), -- Sealed Dark Crystal Helmet Design
(25467, 5494, 40, 120, 0, 70291.136784), -- Sealed Dark Crystal Shield Fragment
(25467, 5526, 14, 42, 0, 147821.931608), -- Sealed Tallum Helm Design
(25467, 269, 1, 1, 1, 17092.90278), -- Blood Tornado
(25467, 5539, 3, 9, 1, 677176.09722), -- Blood Tornado Edge
(25467, 729, 1, 1, 2, 57847.423814), -- Scroll: Enchant Weapon (A-Grade)
(25467, 730, 1, 1, 2, 433856.92522), -- Scroll: Enchant Armor (A-Grade)
(25467, 6569, 1, 1, 2, 6941.650966), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25467, 9817, 1, 5, 2, 740000), -- Nonliving Nucleus
(25467, 8176, 1, 2, 2, 740000), -- Destruction Tombstone
-- Last Titan Utenus
(25470, 5290, 1, 1, 0, 47168.892504), -- Sealed Dark Crystal Gloves
(25470, 5291, 1, 1, 0, 47168.892504), -- Sealed Dark Crystal Boots
(25470, 5295, 1, 1, 0, 47168.892504), -- Sealed Tallum Gloves
(25470, 5296, 1, 1, 0, 47168.892504), -- Sealed Tallum Boots
(25470, 5508, 60, 180, 0, 41012.349576), -- Sealed Dark Crystal Gloves Design
(25470, 5496, 11, 31, 0, 234356.594952), -- Sealed Dark Crystal Boots Lining
(25470, 5509, 16, 48, 0, 153796.492712), -- Sealed Tallum Gloves Design
(25470, 5497, 23, 67, 0, 109366.992744), -- Sealed Tallum Boots Lining
(25470, 98, 1, 1, 1, 17866.4878), -- Halberd
(25470, 5542, 3, 9, 1, 707823.5122), -- Halberd Edge
(25470, 6570, 1, 1, 2, 90698.199774), -- Blessed Scroll: Enchant Armor (A-Grade)
(25470, 6569, 1, 1, 2, 10883.800226), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25470, 8619, 1, 1, 2, 500000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25470, 9817, 1, 5, 2, 770000), -- Nonliving Nucleus
(25470, 8176, 1, 2, 2, 770000), -- Destruction Tombstone
-- Grave Robber Kim
(25473, 856, 1, 1, 0, 87763.188942), -- Adamantite Earring
(25473, 887, 1, 1, 0, 131643.990482), -- Adamantite Ring
(25473, 918, 1, 1, 0, 65821.995241), -- Adamantite Necklace
(25473, 4049, 81, 243, 0, 66194.672811), -- Adamantite Earring Gemstone
(25473, 4050, 40, 120, 0, 158336.426735), -- Adamantite Ring Wire
(25473, 4051, 14, 42, 0, 283170.725789), -- Adamantite Necklace Chain
(25473, 91, 1, 1, 1, 13771.423646), -- Heavy War Axe
(25473, 92, 1, 1, 1, 13771.423646), -- Sprite's Staff
(25473, 4105, 4, 12, 1, 329046.690358), -- Heavy War Axe Head
(25473, 4106, 8, 22, 1, 172612.46235), -- Sprite's Staff Head
(25473, 4607, 1, 3, 2, 331275.59928), -- Greater Dye of INT (Int+3 Men-3)
(25473, 4608, 2, 4, 2, 220850.15364), -- Greater Dye of INT (Int+3 Wit-3)
(25473, 4609, 2, 6, 2, 165637.79964), -- Greater Dye of MEN (Men+3 Int-3)
(25473, 6573, 1, 1, 2, 19876.44744), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25473, 9816, 1, 3, 2, 850000), -- Earth Egg
(25473, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Ghost Knight Kabed
(25475, 357, 1, 1, 0, 21161.511813), -- Zubei's Breastplate
(25475, 383, 1, 1, 0, 33852.18085), -- Zubei's Gaiters
(25475, 2376, 1, 1, 0, 21161.511813), -- Avadon Breastplate
(25475, 2379, 1, 1, 0, 33852.18085), -- Avadon Gaiters
(25475, 4056, 16, 48, 0, 95514.775245), -- Zubei's Breastplate Part
(25475, 4057, 60, 180, 0, 39363.713837), -- Zubei's Gaiter Material
(25475, 4064, 23, 67, 0, 67921.617952), -- Avadon Breastplate Part
(25475, 4065, 11, 31, 0, 224935.50764), -- Avadon Gaiters Material
(25475, 78, 1, 1, 1, 10111.137876), -- Great Sword
(25475, 142, 1, 1, 1, 10111.137876), -- Keshanberk
(25475, 148, 1, 1, 1, 10111.137876), -- Sword of Valhalla
(25475, 4104, 5, 15, 1, 193267.654974), -- Great Sword Blade
(25475, 4107, 9, 27, 1, 105707.314407), -- Keshanberk Blade
(25475, 4108, 14, 42, 1, 67954.616991), -- Sword of Valhalla Blade
(25475, 947, 1, 1, 2, 175123.048356), -- Scroll: Enchant Weapon (B-Grade)
(25475, 948, 1, 3, 2, 547260.218868), -- Scroll: Enchant Armor (B-Grade)
(25475, 4617, 2, 4, 2, 201290.732776), -- Greater Dye of DEX (Dex+4 Str-4)
(25475, 9814, 1, 4, 2, 750000), -- Memento Mori
(25475, 8176, 1, 1, 2, 920000), -- Destruction Tombstone
-- Shilen's Priest Hisilrome
(25478, 5304, 1, 1, 0, 20511.927436), -- Sealed Tallum Tunic
(25478, 5305, 1, 1, 0, 32806.614995), -- Sealed Tallum Stockings
(25478, 5308, 1, 1, 0, 12620.976599), -- Sealed Dark Crystal Robe
(25478, 5485, 9, 27, 0, 127973.474783), -- Sealed Tallum Tunic Texture
(25478, 5489, 28, 84, 0, 64563.861131), -- Sealed Tallum Stockings Fabric
(25478, 5486, 3, 7, 0, 324182.145056), -- Sealed Dark Crystal Robe Fabric
(25478, 235, 1, 1, 1, 17487.795024), -- Bloody Orchid
(25478, 5536, 3, 9, 1, 698990.204976), -- Bloody Orchid Head
(25478, 6570, 1, 1, 2, 88776), -- Blessed Scroll: Enchant Armor (A-Grade)
(25478, 729, 1, 1, 2, 88776), -- Scroll: Enchant Weapon (A-Grade)
(25478, 9816, 1, 5, 2, 760000), -- Earth Egg
(25478, 8176, 1, 2, 2, 760000), -- Destruction Tombstone
-- Magus Kenishee
(25481, 2384, 1, 1, 0, 35287.656295), -- Zubei's Leather Shirt
(25481, 2388, 1, 1, 0, 56446.459765), -- Zubei's Leather Gaiters
(25481, 2390, 1, 1, 0, 21705.44627), -- Avadon Leather Armor
(25481, 4066, 9, 27, 0, 276624.86183), -- Zubei's Leather Shirt Fabric
(25481, 4067, 40, 120, 0, 94502.737605), -- Zubei's Leather Gaiter Texture
(25481, 4068, 14, 42, 0, 136617.838235), -- Avadon Leather Armor Lining
(25481, 229, 1, 1, 1, 14226.249708), -- Kris
(25481, 243, 1, 1, 1, 14226.249708), -- Hell Knife
(25481, 4109, 4, 12, 1, 334648.857291), -- Kris Edge
(25481, 4110, 8, 22, 1, 178479.643293), -- Hell Knife Edge
(25481, 4616, 2, 4, 2, 141606.887277), -- Greater Dye of CON (Con+4 Dex-4)
(25481, 4617, 2, 6, 2, 106204.986015), -- Greater Dye of DEX (Dex+4 Str-4)
(25481, 4618, 3, 7, 2, 84963.988812), -- Greater Dye of DEX (Dex+4 Con-4)
(25481, 948, 1, 3, 2, 384995.137896), -- Scroll: Enchant Armor (B-Grade)
(25481, 9814, 1, 3, 2, 880000), -- Memento Mori
(25481, 8176, 1, 1, 2, 880000), -- Destruction Tombstone
-- Zaken's Chief Mate Tillion
(25484, 503, 1, 1, 0, 51388.117599), -- Zubei's Helmet
(25484, 633, 1, 1, 0, 73414.580478), -- Zubei's Shield
(25484, 673, 1, 1, 0, 73414.580478), -- Avadon Shield
(25484, 2415, 1, 1, 0, 51388.117599), -- Avadon Circlet
(25484, 4102, 16, 48, 0, 215871.570237), -- Zubei's Helmet Design
(25484, 4101, 116, 346, 0, 38598.341934), -- Zubei's Shield Fragment
(25484, 4439, 60, 180, 0, 88393.052661), -- Avadon Shield Fragment
(25484, 4072, 23, 67, 0, 153508.639014), -- Avadon Circlet Pattern
(25484, 229, 1, 1, 1, 13813.737036), -- Kris
(25484, 243, 1, 1, 1, 13813.737036), -- Hell Knife
(25484, 4109, 4, 12, 1, 324945.182947), -- Kris Edge
(25484, 4110, 8, 22, 1, 173304.342981), -- Hell Knife Edge
(25484, 4607, 1, 3, 2, 332293.713514), -- Greater Dye of INT (Int+3 Men-3)
(25484, 4608, 2, 4, 2, 221528.895707), -- Greater Dye of INT (Int+3 Wit-3)
(25484, 4609, 2, 6, 2, 166146.856757), -- Greater Dye of MEN (Men+3 Int-3)
(25484, 6573, 1, 1, 2, 19937.534022), -- Blessed Scroll: Enchant Weapon (C-Grade)
(25484, 9814, 1, 3, 2, 850000), -- Memento Mori
(25484, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Water Spirit Lian
(25487, 62, 11, 33, 0, 4815.238362), -- Reinforced Mithril Boots
(25487, 2429, 12, 34, 0, 4605.637619), -- Chain Boots
(25487, 2430, 12, 36, 0, 4413.570018), -- Karmian Boots
(25487, 2431, 13, 37, 0, 4237.441637), -- Plated Leather Boots
(25487, 2432, 13, 39, 0, 4074.064632), -- Dwarven Chain Boots
(25487, 2433, 1, 1, 0, 105934.447003), -- Boots of Seal
(25487, 2452, 1, 1, 0, 105934.447003), -- Reinforced Mithril Gloves
(25487, 2453, 1, 1, 0, 105934.447003), -- Chain Gloves
(25487, 2454, 1, 1, 0, 105934.447003), -- Karmian Gloves
(25487, 1958, 220, 660, 0, 10507.133824), -- Reinforced Mithril Boots Design
(25487, 2937, 378, 1134, 0, 6115.081753), -- Chain Boots Part
(25487, 2938, 26, 78, 0, 88904.187394), -- Karmian Boots Fabric
(25487, 2939, 35, 105, 0, 66043.361109), -- Plate Leather Boots Lining
(25487, 2940, 45, 135, 0, 51367.324294); -- Dwarven Chain Boots Part

INSERT INTO `droplist` VALUES
(25487, 2941, 56, 168, 0, 41277.001073), -- Boots of Seal Pattern
(25487, 2942, 68, 204, 0, 33992.777533), -- Reinforced Mithril Gloves Design
(25487, 2943, 81, 243, 0, 28537.579488), -- Chain Gloves Design
(25487, 2944, 95, 285, 0, 24332.813252), -- Karmian Gloves Fabric
(25487, 89, 1, 1, 1, 9846.369026), -- Big Hammer
(25487, 160, 1, 1, 1, 9846.369026), -- Battle Axe
(25487, 161, 1, 1, 1, 9846.369026), -- Silver Axe
(25487, 173, 1, 1, 1, 9846.369026), -- Skull Graver
(25487, 191, 1, 1, 1, 9846.369026), -- Heavy Doom Hammer
(25487, 192, 1, 1, 1, 9846.369026), -- Crystal Staff
(25487, 193, 1, 1, 1, 9846.369026), -- Stick of Faith
(25487, 194, 1, 1, 1, 9846.369026), -- Heavy Doom Axe
(25487, 2061, 2, 6, 1, 167705.311661), -- Big Hammer Head
(25487, 2063, 3, 7, 1, 134164.091205), -- Battle Axe Head
(25487, 2064, 3, 9, 1, 111803.014028), -- Silver Axe Head
(25487, 2065, 4, 10, 1, 95831.719609), -- Skull Graver Head
(25487, 2066, 10, 30, 1, 34034.566712), -- Heavy Doom Hammer Head
(25487, 2067, 4, 12, 1, 78186.684767), -- Crystal Staff Head
(25487, 2068, 5, 13, 1, 69499.363195), -- Stick of Faith Shaft
(25487, 2069, 17, 49, 1, 20623.296615), -- Heavy Doom Axe Blade
(25487, 6574, 1, 1, 2, 514316), -- Blessed Scroll: Enchant Armor (C-Grade)
(25487, 9818, 1, 2, 2, 850000), -- Angelic Essence
(25487, 8176, 1, 1, 2, 640000), -- Destruction Tombstone
-- Gwindorr
(25490, 631, 6, 16, 0, 27503.529111), -- Eldarake
(25490, 2413, 1, 1, 0, 211798.631457), -- Chain Hood
(25490, 2495, 6, 18, 0, 25211.523537), -- Chain Shield
(25490, 1964, 40, 120, 0, 155853.690147), -- Eldarake Temper
(25490, 2936, 140, 420, 0, 40444.594839), -- Chain Hood Pattern
(25490, 2945, 81, 243, 0, 76965.030909), -- Chain Shield Fragment
(25490, 263, 1, 1, 1, 78770.948228), -- Chakram
(25490, 2073, 12, 36, 1, 223615.051772), -- Chakram Edge
(25490, 951, 1, 3, 2, 818230), -- Scroll: Enchant Weapon (C-Grade)
(25490, 9816, 1, 2, 2, 850000), -- Earth Egg
(25490, 8176, 1, 1, 2, 650000), -- Destruction Tombstone
-- Eva's Spirit Niniel
(25493, 503, 1, 1, 0, 56421.181217), -- Zubei's Helmet
(25493, 633, 1, 1, 0, 80606.157826), -- Zubei's Shield
(25493, 673, 1, 1, 0, 80606.157826), -- Avadon Shield
(25493, 2415, 1, 1, 0, 56421.181217), -- Avadon Circlet
(25493, 4102, 192, 576, 0, 19751.054201), -- Zubei's Helmet Design
(25493, 4101, 116, 346, 0, 42378.621582), -- Zubei's Shield Fragment
(25493, 4439, 60, 180, 0, 97051.027213), -- Avadon Shield Fragment
(25493, 4072, 23, 67, 0, 168545.618918), -- Avadon Circlet Pattern
(25493, 91, 1, 1, 1, 15166.72486), -- Heavy War Axe
(25493, 92, 1, 1, 1, 15166.72486), -- Sprite's Staff
(25493, 4105, 4, 12, 1, 362385.23678), -- Heavy War Axe Head
(25493, 4106, 8, 22, 1, 190101.3135), -- Sprite's Staff Head
(25493, 4613, 1, 3, 2, 226452.383493), -- Greater Dye of STR (Str+4 Con-4)
(25493, 4614, 2, 4, 2, 150968.255662), -- Greater Dye of STR (Str+4 Dex-4)
(25493, 4615, 1, 1, 2, 452904.766986), -- Greater Dye of CON (Con+4 Str-4)
(25493, 947, 1, 1, 2, 131341.593859), -- Scroll: Enchant Weapon (B-Grade)
(25493, 9816, 1, 4, 2, 750000), -- Earth Egg
(25493, 8176, 1, 2, 2, 630000), -- Destruction Tombstone
-- Fafurion's Envoy Pingolpin
(25496, 554, 1, 1, 0, 76839.485101), -- Sealed Zubei's Boots
(25496, 600, 1, 1, 0, 76839.485101), -- Sealed Avadon Boots
(25496, 612, 1, 1, 0, 76839.485101), -- Sealed Zubei's Gauntlets
(25496, 2464, 1, 1, 0, 76839.485101), -- Sealed Avadon Gloves
(25496, 4097, 60, 180, 0, 66498.472551), -- Sealed Zubei's Boots Design
(25496, 4098, 116, 346, 0, 34545.047027), -- Sealed Avadon Boots Design
(25496, 4100, 192, 576, 0, 20780.886393), -- Sealed Zubei's Gauntlets Part
(25496, 4073, 23, 67, 0, 177328.653625), -- Sealed Avadon Gloves Part
(25496, 267, 1, 1, 1, 27542.881912), -- Arthro Nail
(25496, 4111, 12, 36, 1, 219361.118088), -- Arthro Nail Blade
(25496, 4610, 1, 3, 2, 331275.385266), -- Greater Dye of MEN (Men+3 Wit-3)
(25496, 4611, 2, 4, 2, 220850.256844), -- Greater Dye of WIT (Wit+3 Int-3)
(25496, 4612, 2, 6, 2, 165637.692633), -- Greater Dye of WIT (Wit+3 Men-3)
(25496, 6574, 1, 1, 2, 170369.665257), -- Blessed Scroll: Enchant Armor (C-Grade)
(25496, 9816, 1, 3, 2, 850000), -- Earth Egg
(25496, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Fafurion's Henchman Istary
(25498, 854, 1, 1, 0, 159080.840568), -- Earring of Seal
(25498, 885, 1, 1, 0, 238568.488704), -- Ring of Ages
(25498, 917, 1, 1, 0, 119323.423674), -- Necklace of Mermaid
(25498, 1914, 81, 243, 0, 62504.611416), -- Earring of Seal Gemstone
(25498, 1915, 280, 840, 0, 28357.03377), -- Ring of Ages Gemstone
(25498, 1916, 20, 60, 0, 191743.601868), -- Necklace of Mermaid Teardrop
(25498, 231, 1, 1, 1, 24546.01275), -- Grace Dagger
(25498, 233, 1, 1, 1, 24546.01275), -- Dark Screamer
(25498, 2106, 4, 12, 1, 276249.704325), -- Grace Dagger Edge
(25498, 2107, 8, 22, 1, 147333.270175), -- Dark Screamer Edge
(25498, 4601, 1, 3, 2, 292053.569808), -- Greater Dye of STR (Str+3 Con-3)
(25498, 4602, 2, 4, 2, 194702.62266), -- Greater Dye of STR (Str+3 Dex-3)
(25498, 4603, 2, 6, 2, 146026.784904), -- Greater Dye of CON (Con+3 Str-3)
(25498, 951, 3, 7, 2, 95581.022628), -- Scroll: Enchant Weapon (C-Grade)
(25498, 9816, 1, 3, 2, 750000), -- Earth Egg
(25498, 8176, 1, 1, 2, 750000), -- Destruction Tombstone
-- Boss Akata
(25501, 395, 1, 1, 0, 199474.211), -- Manticore Skin Shirt
(25501, 417, 4, 12, 0, 39820.9705), -- Manticore Skin Gaiters
(25501, 1942, 53, 157, 0, 83335.526), -- Manticore Skin Shirt Texture
(25501, 1943, 24, 72, 0, 283869.2925), -- Manticore Skin Gaiters Pattern
(25501, 224, 1, 1, 1, 47918.424411), -- Maingauche
(25501, 1660, 1, 1, 1, 47918.424411), -- Cursed Maingauche
(25501, 2038, 4, 12, 1, 339850.587024), -- Maingauche Edge
(25501, 2044, 8, 22, 1, 181253.564154), -- Cursed Maingauche Edge
(25501, 4553, 1, 3, 2, 333565.166912), -- Greater Dye of STR (Str+1 Con-1)
(25501, 4554, 2, 4, 2, 222377.031204), -- Greater Dye of STR (Str+1 Dex-1)
(25501, 4555, 2, 6, 2, 166782.583456), -- Greater Dye of CON (Con+1 Str-1)
(25501, 6575, 1, 1, 2, 37063.218428), -- Blessed Scroll: Enchant Weapon (D-Grade)
-- Nellis' Vengeful Spirit
(25504, 62, 11, 33, 0, 4688.80347), -- Reinforced Mithril Boots
(25504, 2429, 12, 34, 0, 4484.706265), -- Chain Boots
(25504, 2430, 12, 36, 0, 4297.68183), -- Karmian Boots
(25504, 2431, 13, 37, 0, 4126.178095), -- Plated Leather Boots
(25504, 2432, 13, 39, 0, 3967.09092), -- Dwarven Chain Boots
(25504, 2433, 1, 1, 0, 103152.900305), -- Boots of Seal
(25504, 2452, 1, 1, 0, 103152.900305), -- Reinforced Mithril Gloves
(25504, 2453, 1, 1, 0, 103152.900305), -- Chain Gloves
(25504, 2454, 1, 1, 0, 103152.900305), -- Karmian Gloves
(25504, 1958, 220, 660, 0, 10231.24544), -- Reinforced Mithril Boots Design
(25504, 2937, 378, 1134, 0, 5954.516555), -- Chain Boots Part
(25504, 2938, 26, 78, 0, 86569.80839), -- Karmian Boots Fabric
(25504, 2939, 35, 105, 0, 64309.244415), -- Plate Leather Boots Lining
(25504, 2940, 45, 135, 0, 50018.55989), -- Dwarven Chain Boots Part
(25504, 2941, 56, 168, 0, 40193.180755), -- Boots of Seal Pattern
(25504, 2942, 68, 204, 0, 33100.220855), -- Reinforced Mithril Gloves Design
(25504, 2943, 81, 243, 0, 27788.26128), -- Chain Gloves Design
(25504, 2944, 95, 285, 0, 23693.90062), -- Karmian Gloves Fabric
(25504, 96, 1, 1, 1, 25567.548545), -- Scythe
(25504, 298, 1, 1, 1, 25567.548545), -- Orcish Glaive
(25504, 302, 1, 1, 1, 25567.548545), -- Body Slasher
(25504, 2062, 5, 15, 1, 176758.02781), -- Scythe Edge
(25504, 2075, 9, 27, 1, 98199.25703), -- Orcish Glaive Blade
(25504, 2076, 2, 6, 1, 441895.069525), -- Body Slasher Blade
(25504, 951, 1, 1, 2, 531163.081987), -- Scroll: Enchant Weapon (C-Grade)
(25504, 952, 12, 36, 2, 162299.850411), -- Scroll: Enchant Armor (C-Grade)
(25504, 6573, 1, 1, 2, 19476.067602), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Rayito the Looter
(25506, 397, 1, 1, 0, 142372.411401), -- Mithril Shirt
(25506, 2387, 1, 1, 0, 227514.183226), -- Reinforced Mithril Gaiters
(25506, 1961, 53, 157, 0, 63131.7709), -- Mithril Shirt Fabric
(25506, 2935, 24, 72, 0, 229434.634473), -- Reinforced Mithril Gaiters Fragment
(25506, 281, 1, 1, 1, 70503.761262), -- Crystallized Ice Bow
(25506, 2074, 12, 36, 1, 183398.238738), -- Crystallized Ice Bow Shaft
(25506, 6574, 1, 1, 2, 460338), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Dark Shaman Varangka 
(25509, 2397, 1, 1, 0, 35287.656295), -- Tunic of Zubei
(25509, 2402, 1, 1, 0, 56446.459765), -- Stockings of Zubei
(25509, 2406, 1, 1, 0, 21705.44627), -- Avadon Robe
(25509, 4069, 9, 27, 0, 276624.86183), -- Tunic of Zubei Fabric
(25509, 4070, 40, 120, 0, 94502.737605), -- Stockings of Zubei Fabric
(25509, 4071, 14, 42, 0, 136617.838235), -- Avadon Robe Fabric
(25509, 91, 1, 1, 1, 7113.123261), -- Heavy War Axe
(25509, 92, 1, 1, 1, 7113.123261), -- Sprite's Staff
(25509, 7892, 1, 1, 1, 7113.123261), -- Spell Breaker
(25509, 7900, 1, 1, 1, 7113.123261), -- Ice Storm Hammer
(25509, 4105, 6, 18, 1, 113305.76271), -- Heavy War Axe Head
(25509, 4106, 2, 6, 1, 334339.569084), -- Sprite's Staff Head
(25509, 8339, 11, 31, 1, 64746.15012), -- Spell Breaker Head
(25509, 8347, 3, 7, 1, 244529.025042), -- Ice Storm Hammer Head
(25509, 4613, 1, 3, 2, 212410.299765), -- Greater Dye of STR (Str+4 Con-4)
(25509, 4614, 2, 4, 2, 141606.86651), -- Greater Dye of STR (Str+4 Dex-4)
(25509, 4615, 1, 1, 2, 424820.59953), -- Greater Dye of CON (Con+4 Str-4)
(25509, 947, 1, 1, 2, 123197.234195), -- Scroll: Enchant Weapon (B-Grade)
(25509, 9814, 1, 3, 2, 880000), -- Memento Mori
(25509, 8176, 1, 1, 2, 880000), -- Destruction Tombstone
-- Gigantic Chaos Golem
(25512, 357, 1, 1, 0, 19214.69979), -- Zubei's Breastplate
(25512, 383, 1, 1, 0, 30737.8555), -- Zubei's Gaiters
(25512, 2376, 1, 1, 0, 19214.69979), -- Avadon Breastplate
(25512, 2379, 1, 1, 0, 30737.8555), -- Avadon Gaiters
(25512, 4056, 16, 48, 0, 86727.62835), -- Zubei's Breastplate Part
(25512, 4057, 60, 180, 0, 35742.33971), -- Zubei's Gaiter Material
(25512, 4064, 23, 67, 0, 61672.98016), -- Avadon Breastplate Part
(25512, 4065, 11, 31, 0, 204241.9412), -- Avadon Gaiters Material
(25512, 78, 1, 1, 1, 9180.94552), -- Great Sword
(25512, 142, 1, 1, 1, 9180.94552), -- Keshanberk
(25512, 148, 1, 1, 1, 9180.94552), -- Sword of Valhalla
(25512, 4104, 5, 15, 1, 175495.674129), -- Great Sword Blade
(25512, 4107, 9, 27, 1, 95986.931605), -- Keshanberk Blade
(25512, 4108, 2, 6, 1, 431941.557706), -- Sword of Valhalla Blade
(25512, 4604, 2, 6, 2, 165637.863342), -- Greater Dye of CON (Con+3 Dex-3)
(25512, 4605, 3, 7, 2, 132510.190029), -- Greater Dye of DEX (Dex+3 Str-3)
(25512, 4606, 3, 9, 2, 110425.242228), -- Greater Dye of DEX (Dex+3 Con-3)
(25512, 952, 21, 63, 2, 94649.704401), -- Scroll: Enchant Armor (C-Grade)
(25512, 9817, 1, 3, 2, 850000), -- Nonliving Nucleus
(25512, 8176, 1, 1, 2, 850000), -- Destruction Tombstone
-- Queen Shyeed
(25514, 6678, 1, 1, 0, 15607.72169), -- Sealed Imperial Crusader Shield
(25514, 6679, 1, 1, 0, 10925.205225), -- Sealed Imperial Crusader Helmet
(25514, 6683, 1, 1, 0, 10925.205225), -- Sealed Draconic Leather Helmet
(25514, 6687, 1, 1, 0, 10925.205225), -- Sealed Major Arcana Circlet
(25514, 6705, 23, 67, 0, 81141.456715), -- Sealed Imperial Crusader Shield Part
(25514, 6706, 60, 180, 0, 35393.56579), -- Sealed Imperial Crusader Helmet Pattern
(25514, 6710, 11, 31, 0, 202250.018575), -- Sealed Draconic Leather Helmet Pattern
(25514, 6714, 16, 48, 0, 132726.621555), -- Sealed Major Arcana Circlet Pattern
(25514, 6367, 1, 1, 1, 7347.704126), -- Angel Slayer
(25514, 6691, 3, 9, 1, 565930.295874), -- Angel Slayer Blade
(25514, 6578, 1, 1, 2, 45252.763752), -- Blessed Scroll: Enchant Armor (S-Grade)
(25514, 3936, 1, 1, 2, 509091.236248), -- Blessed Scroll of Resurrection
-- Plague Golem
(25523, 6678, 1, 1, 0, 22266.500074), -- Sealed Imperial Crusader Shield
(25523, 6679, 1, 1, 0, 15586.264785), -- Sealed Imperial Crusader Helmet
(25523, 6683, 1, 1, 0, 15586.264785), -- Sealed Draconic Leather Helmet
(25523, 6687, 1, 1, 0, 15586.264785), -- Sealed Major Arcana Circlet
(25523, 6705, 23, 67, 0, 115759.127939), -- Sealed Imperial Crusader Shield Part
(25523, 6706, 60, 180, 0, 50493.649934), -- Sealed Imperial Crusader Helmet Pattern
(25523, 6710, 11, 31, 0, 288536.670695), -- Sealed Draconic Leather Helmet Pattern
(25523, 6714, 16, 48, 0, 189352.257003), -- Sealed Major Arcana Circlet Pattern
(25523, 6367, 1, 1, 1, 10482.500091), -- Angel Slayer
(25523, 6691, 12, 36, 1, 201838.499909), -- Angel Slayer Blade
(25523, 6578, 1, 1, 2, 64559.078298), -- Blessed Scroll: Enchant Armor (S-Grade)
(25523, 6570, 1, 1, 2, 161397.921702), -- Blessed Scroll: Enchant Armor (A-Grade)
(25523, 8619, 1, 1, 2, 560000), -- Ancient Book: Divine Inspiration (Original Language Version)
(25523, 9817, 3, 7, 2, 830000), -- Nonliving Nucleus
(25523, 8176, 1, 4, 2, 830000), -- Destruction Tombstone
-- Flamestone Giant
(25524, 5311, 1, 1, 0, 22978.01022), -- Sealed Armor of Nightmare
(25524, 5316, 1, 1, 0, 22978.01022), -- Sealed Majestic Plate Armor
(25524, 5522, 4, 12, 0, 430587.34727), -- Sealed Armor of Nightmare Pattern
(25524, 5523, 8, 22, 0, 229646.63229), -- Sealed Majestic Plate Armor Pattern
(25524, 81, 1, 1, 1, 9753.550706), -- Dragon Slayer
(25524, 151, 1, 1, 1, 9753.550706), -- Sword of Miracles
(25524, 2500, 1, 1, 1, 9753.550706), -- Dark Legion's Edge
(25524, 5529, 9, 27, 1, 154169.065182), -- Dragon Slayer Edge
(25524, 5546, 5, 15, 1, 304812.262311), -- Sword of Miracles Edge
(25524, 5545, 14, 42, 1, 99109.020389), -- Dark Legion's Edge Blade
(25524, 959, 1, 1, 2, 52447.740736), -- Scroll: Enchant Weapon (S-Grade)
(25524, 960, 1, 1, 2, 524478.578696), -- Scroll: Enchant Armor (S-Grade)
(25524, 6577, 1, 1, 2, 8741.680568), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Uruka
(25527, 6724, 1, 1, 0, 29654.492043), -- Sealed Tateossian Earring
(25527, 6725, 1, 1, 0, 44481.985346), -- Sealed Tateossian Ring
(25527, 6726, 1, 1, 0, 22236.047043), -- Sealed Tateossian Necklace
(25527, 6698, 81, 243, 0, 58788.209247), -- Sealed Tateossian Earring Part
(25527, 6699, 40, 120, 0, 132097.7773), -- Sealed Tateossian Ring Gem
(25527, 6700, 14, 42, 0, 207304.489021), -- Sealed Tateossian Necklace Chain
(25527, 6365, 1, 1, 1, 2551.287699), -- Basalt Battlehammer
(25527, 6366, 1, 1, 1, 2551.287699), -- Imperial Staff
(25527, 6369, 1, 1, 1, 2551.287699), -- Dragon Hunter Axe
(25527, 6579, 1, 1, 1, 2551.287699), -- Arcana Mace
(25527, 6689, 2, 6, 1, 289231.371513), -- Basalt Battlehammer Head
(25527, 6690, 11, 31, 1, 56256.821379), -- Imperial Staff Head
(25527, 6693, 6, 18, 1, 100043.047431), -- Dragon Hunter Axe Blade
(25527, 6697, 3, 7, 1, 231386.608881), -- Arcana Mace Head
-- Tiberias
(25528, 348, 1, 1, 0, 106747.320177), -- Scale Mail
(25528, 377, 1, 1, 0, 170695.294089), -- Scale Gaiters
(25528, 1935, 8, 22, 0, 203753.959694), -- Scale Mail Fragment
(25528, 1937, 24, 72, 0, 97916.42604), -- Scale Gaiters Fragment
(25528, 69, 1, 1, 1, 26498.344042), -- Bastard Sword
(25528, 125, 1, 1, 1, 26498.344042), -- Spinebone Sword
(25528, 126, 1, 1, 1, 26498.344042), -- Artisan's Sword
(25528, 128, 1, 1, 1, 26498.344042), -- Knight's Sword
(25528, 2021, 1, 3, 1, 414459.623832), -- Spinebone Sword Blade
(25528, 6575, 1, 1, 2, 15759.506461), -- Blessed Scroll: Enchant Weapon (D-Grade)
(25528, 6576, 1, 1, 2, 141837.764513), -- Blessed Scroll: Enchant Armor (D-Grade)
(25528, 956, 3, 9, 2, 393993.729026), -- Scroll: Enchant Armor (D-Grade)
(25528, 9712, 1, 1, 2, 1000000), -- Gate Key: Massive Cavern
-- Darnel
(25531, 6678, 1, 1, 0, 15916.66338), -- Sealed Imperial Crusader Shield
(25531, 6679, 1, 1, 0, 11141.46045), -- Sealed Imperial Crusader Helmet
(25531, 6683, 1, 1, 0, 11141.46045), -- Sealed Draconic Leather Helmet
(25531, 6687, 1, 1, 0, 11141.46045), -- Sealed Major Arcana Circlet
(25531, 6705, 23, 67, 0, 82747.58343), -- Sealed Imperial Crusader Shield Part
(25531, 6706, 60, 180, 0, 36094.15158), -- Sealed Imperial Crusader Helmet Pattern
(25531, 6710, 11, 31, 0, 206253.38715), -- Sealed Draconic Leather Helmet Pattern
(25531, 6714, 16, 48, 0, 135353.83311), -- Sealed Major Arcana Circlet Pattern
(25531, 7575, 1, 1, 1, 7493.152037), -- Draconic Bow
(25531, 7579, 3, 9, 1, 583775.847963), -- Draconic Bow Shaft
(25531, 9468, 1, 1, 2, 6670.944775), -- Dynasty Necklace - Sleep Resistance
(25531, 9474, 1, 1, 2, 6670.944775), -- Dynasty Necklace  - Hold Resistance
(25531, 9477, 1, 1, 2, 6670.944775), -- Dynasty Necklace - Fear Resistance
(25531, 6578, 1, 1, 2, 23074.165675), -- Blessed Scroll: Enchant Armor (S-Grade)
-- Kechi
(25532, 6676, 1, 1, 0, 8941.67617), -- Sealed Imperial Crusader Gauntlet
(25532, 6677, 1, 1, 0, 8941.67617), -- Sealed Imperial Crusader Boots
(25532, 6681, 1, 1, 0, 8941.67617), -- Sealed Draconic Leather Glove
(25532, 6682, 1, 1, 0, 8941.67617), -- Sealed Draconic Leather Boots
(25532, 6685, 1, 1, 0, 8941.67617), -- Sealed Major Arcana Glove
(25532, 6686, 1, 1, 0, 8941.67617), -- Sealed Major Arcana Boots
(25532, 6703, 8, 24, 0, 127109.90621), -- Sealed Imperial Crusader Gauntlets Design
(25532, 6704, 14, 40, 0, 75324.65885), -- Sealed Imperial Crusader Boots Design
(25532, 6708, 20, 60, 0, 50844.22756), -- Sealed Draconic Leather Gloves Fabric
(25532, 6709, 28, 82, 0, 36977.43931), -- Sealed Draconic Leather Boots Design
(25532, 6712, 36, 108, 0, 28246.49856), -- Sealed Major Arcana Gloves fabric
(25532, 6713, 4, 10, 0, 290537.21249), -- Sealed Major Arcana Boots Design
(25532, 6365, 1, 1, 1, 1503.28272), -- Basalt Battlehammer
(25532, 6366, 1, 1, 1, 1503.28272), -- Imperial Staff
(25532, 6369, 1, 1, 1, 1503.28272), -- Dragon Hunter Axe
(25532, 6579, 1, 1, 1, 1503.28272), -- Arcana Mace
(25532, 6689, 2, 6, 1, 170414.30256), -- Basalt Battlehammer Head
(25532, 6690, 2, 4, 1, 232024.141232), -- Imperial Staff Head
(25532, 6693, 6, 18, 1, 58944.98328), -- Dragon Hunter Axe Blade
(25532, 6697, 3, 7, 1, 136331.442048), -- Arcana Mace Head
(25532, 9459, 1, 1, 2, 4282.668192), -- Dynasty Necklace - Stun Resistance
(25532, 9462, 1, 1, 2, 4282.668192), -- Dynasty Necklace  - Poison Resistance
(25532, 9465, 1, 1, 2, 4282.668192), -- Dynasty Necklace  - Bleed Resistance
(25532, 9471, 1, 1, 2, 4282.668192), -- Dynasty Necklace - Paralysis Resistance
(25532, 6578, 1, 1, 2, 14813.327232), -- Blessed Scroll: Enchant Armor (S-Grade)
-- Tears
(25534, 6680, 1, 1, 0, 21951.62455), -- Sealed Draconic Leather Armor
(25534, 6707, 12, 36, 0, 352969.37545), -- Sealed Draconic Leather Armor Part
(25534, 7575, 1, 1, 1, 11995.241922), -- Draconic Bow
(25534, 7579, 12, 36, 1, 233637.758078), -- Draconic Bow Shaft
-- Hannibal
(25536, 6364, 1, 1, 0, 6618.69429), -- Forgotten Blade
(25536, 6372, 1, 1, 0, 6618.69429), -- Heaven's Divider
(25536, 6688, 8, 22, 0, 203910.283902), -- Forgotten Blade Edge
(25536, 6696, 4, 12, 0, 388405.327518), -- Heavens Divider Edge
(25536, 6678, 1, 1, 1, 63266.347365), -- Sealed Imperial Crusader Shield
(25536, 6679, 1, 1, 1, 44285.103785), -- Sealed Imperial Crusader Helmet
(25536, 6683, 1, 1, 1, 44285.103785), -- Sealed Draconic Leather Helmet
(25536, 6687, 1, 1, 1, 44285.103785), -- Sealed Major Arcana Circlet
(25536, 6705, 23, 67, 1, 328909.213685), -- Sealed Imperial Crusader Shield Part
(25536, 6706, 60, 180, 1, 143469.428635), -- Sealed Imperial Crusader Helmet Pattern
(25536, 6710, 116, 346, 1, 74529.665405), -- Sealed Draconic Leather Helmet Pattern
(25536, 6714, 192, 576, 1, 44835.033555), -- Sealed Major Arcana Circlet Pattern
-- Typhoon
(25539, 7575, 1, 1, 0, 13271.665014), -- Draconic Bow
(25539, 7579, 12, 36, 0, 258499.334986), -- Draconic Bow Shaft
(25539, 6676, 1, 1, 1, 44404.308277), -- Sealed Imperial Crusader Gauntlet
(25539, 6677, 1, 1, 1, 44404.308277), -- Sealed Imperial Crusader Boots
(25539, 6681, 1, 1, 1, 44404.308277), -- Sealed Draconic Leather Glove
(25539, 6682, 1, 1, 1, 44404.308277), -- Sealed Draconic Leather Boots
(25539, 6685, 1, 1, 1, 44404.308277), -- Sealed Major Arcana Glove
(25539, 6686, 1, 1, 1, 44404.308277), -- Sealed Major Arcana Boots
(25539, 6703, 112, 336, 1, 45088.323378), -- Sealed Imperial Crusader Gauntlets Design
(25539, 6704, 203, 607, 1, 24937.820978), -- Sealed Imperial Crusader Boots Design
(25539, 6708, 320, 960, 1, 15781.149321), -- Sealed Draconic Leather Gloves Fabric
(25539, 6709, 28, 82, 1, 183633.260055), -- Sealed Draconic Leather Boots Design
(25539, 6712, 36, 108, 1, 140275.046219), -- Sealed Major Arcana Gloves fabric
(25539, 6713, 46, 136, 1, 110987.550387), -- Sealed Major Arcana Boots Design
-- Demon Prince
(25540, 6680, 1, 1, 0, 14132.4477), -- Sealed Draconic Leather Armor
(25540, 6707, 12, 36, 0, 227241.5523), -- Sealed Draconic Leather Armor Part
(25540, 6365, 1, 1, 1, 1930.63644), -- Basalt Battlehammer
(25540, 6366, 1, 1, 1, 1930.63644), -- Imperial Staff
(25540, 6369, 1, 1, 1, 1930.63644), -- Dragon Hunter Axe
(25540, 6579, 1, 1, 1, 1930.63644), -- Arcana Mace
(25540, 6689, 2, 6, 1, 218859.73812), -- Basalt Battlehammer Head
(25540, 6690, 2, 4, 1, 297984.042564), -- Imperial Staff Head
(25540, 6693, 6, 18, 1, 75701.88306), -- Dragon Hunter Axe Blade
(25540, 6697, 3, 7, 1, 175087.790496), -- Arcana Mace Head
-- Ranku
(25542, 6364, 1, 1, 0, 2574.180035), -- Forgotten Blade
(25542, 6372, 1, 1, 0, 2574.180035), -- Heaven's Divider
(25542, 6688, 2, 4, 0, 396540.90945), -- Forgotten Blade Edge
(25542, 6696, 4, 12, 0, 151065.73048), -- Heavens Divider Edge
(25542, 7575, 1, 1, 1, 7722.54601), -- Draconic Bow
(25542, 7579, 3, 9, 1, 601647.45399), -- Draconic Bow Shaft
-- Tully
(25544, 7575, 1, 1, 0, 11182.49766), -- Draconic Bow
(25544, 7579, 12, 36, 0, 217807.50234), -- Draconic Bow Shaft
(25544, 6680, 1, 1, 1, 46044.4226), -- Sealed Draconic Leather Armor
(25544, 6707, 12, 36, 1, 740367.5774), -- Sealed Draconic Leather Armor Part
-- Rhianna the Traitor
(25546, 5297, 1, 1, 0, 9588.782896), -- Sealed Dark Crystal Leather Armor
(25546, 5478, 2, 4, 0, 358938.400359), -- Sealed Dark Crystal Leather Armor Pattern
(25546, 5298, 1, 1, 0, 15335.982277), -- Sealed Dark Crystal Leggings
(25546, 5482, 4, 12, 0, 211269.834468), -- Sealed Dark Crystal Leggings Design
(25546, 9626, 1, 1, 1, 39840.38535), -- Giant's Codex - Discipline
(25546, 6570, 1, 1, 1, 33200.321125), -- Blessed Scroll: Enchant Armor (A-Grade)
(25546, 729, 1, 1, 1, 33200.321125), -- Scroll: Enchant Weapon (A-Grade)
(25546, 6569, 1, 1, 1, 3983.9724), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25546, 9912, 190, 380, 2, 1000000), -- Knight's Epaulette
-- Tesla the Deceiver
(25549, 5287, 1, 1, 0, 7411.894303), -- Sealed Dark Crystal breastplate
(25549, 5288, 1, 1, 0, 11860.33473), -- Sealed Dark Crystal Gaiters
(25549, 5520, 2, 4, 0, 283750.708627), -- Sealed Dark Crystal Breastplate Pattern
(25549, 5524, 4, 12, 0, 162636.06234), -- Sealed Dark Crystal Gaiters Pattern
(25549, 9626, 1, 1, 1, 82137), -- Giant's Codex - Discipline
(25549, 6578, 1, 1, 1, 27379), -- Blessed Scroll: Enchant Armor (S-Grade)
(25549, 9912, 190, 380, 2, 1000000), -- Knight's Epaulette
-- Soul Hunter Chakundel
(25552, 6364, 1, 1, 0, 612.308907), -- Forgotten Blade
(25552, 6372, 1, 1, 0, 612.308907), -- Heaven's Divider
(25552, 6688, 1, 1, 0, 282998.199849), -- Forgotten Blade Edge
(25552, 6696, 1, 1, 0, 287494.182337), -- Heavens Divider Edge
(25552, 9626, 1, 1, 1, 40727.576025), -- Giant's Codex - Discipline
(25552, 959, 1, 1, 1, 12218.36139), -- Scroll: Enchant Weapon (S-Grade)
(25552, 960, 1, 1, 1, 122182.728075), -- Scroll: Enchant Armor (S-Grade)
(25552, 6577, 1, 1, 1, 2036.33451), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25552, 9912, 188, 377, 2, 1000000), -- Knight's Epaulette
-- Durango the Crusher
(25553, 6679, 1, 1, 0, 3705.775824), -- Sealed Imperial Crusader Helmet
(25553, 6683, 1, 1, 0, 3705.775824), -- Sealed Draconic Leather Helmet
(25553, 6687, 1, 1, 0, 3705.775824), -- Sealed Major Arcana Circlet
(25553, 6706, 5, 15, 0, 144069.775371), -- Sealed Imperial Crusader Helmet Pattern
(25553, 6710, 9, 27, 0, 80038.565628), -- Sealed Draconic Leather Helmet Pattern
(25553, 6714, 2, 6, 0, 360175.331529), -- Sealed Major Arcana Circlet Pattern
(25553, 9626, 1, 1, 1, 82888.5), -- Giant's Codex - Discipline
(25553, 6578, 1, 1, 1, 27629.5), -- Blessed Scroll: Enchant Armor (S-Grade)
(25553, 9912, 191, 389, 2, 1000000), -- Knight's Epaulette
-- Brutus the Obstinate
(25554, 6364, 1, 1, 0, 634.425057), -- Forgotten Blade
(25554, 6372, 1, 1, 0, 634.425057), -- Heaven's Divider
(25554, 6688, 1, 1, 0, 293219.887899), -- Forgotten Blade Edge
(25554, 6696, 1, 1, 0, 297878.261987), -- Heavens Divider Edge
(25554, 9626, 1, 1, 1, 168794), -- Giant's Codex - Discipline
(25554, 9912, 199, 391, 2, 1000000), -- Knight's Epaulette
-- Ranger Karankawa
(25557, 6694, 1, 1, 0, 607459.839129), -- Saint Spear Blade
(25557, 6370, 1, 1, 0, 1291.160871), -- Saint Spear
(25557, 9627, 1, 1, 1, 85878), -- Giant's Codex - Mastery
(25557, 9912, 200, 400, 2, 1000000), -- Knight's Epaulette
-- Sargon the Mad
(25560, 6684, 1, 1, 0, 3647.87), -- Sealed Major Arcana Robe
(25560, 6711, 1, 3, 0, 703852.13), -- Sealed Major Arcana Robe Part
(25560, 9627, 1, 1, 1, 88391), -- Giant's Codex - Mastery
(25560, 9912, 200, 400, 2, 1000000), -- Knight's Epaulette
-- Beautiful Atrielle
(25563, 9450, 1, 1, 0, 305.505623), -- Dynasty Bagh-Nakh
(25563, 9624, 1, 1, 0, 61625.494377), -- Dynasty Bagh-Nakh Piece
(25563, 9588, 1, 1, 1, 9014.204907), -- Striped Mithril Shirt
(25563, 9582, 1, 1, 1, 12720.053154), -- Mithril Shirt
(25563, 9592, 1, 1, 1, 6438.741939), -- Mithril Bracelet
(25563, 9627, 1, 1, 2, 89041), -- Giant's Codex - Mastery
(25563, 9912, 205, 415, 3, 1000000), -- Knight's Epaulette
-- Nagen the Tomboy
(25566, 9445, 1, 1, 0, 311.143885), -- Dynasty Bow
(25566, 9619, 1, 1, 0, 65261.856115), -- Dynasty Bow Piece
(25566, 9588, 1, 1, 1, 9180.583587), -- Striped Mithril Shirt
(25566, 9582, 1, 1, 1, 12954.832114), -- Mithril Shirt
(25566, 9592, 1, 1, 1, 6557.584299), -- Mithril Bracelet
(25566, 9627, 1, 1, 2, 90685), -- Giant's Codex - Mastery
(25566, 9912, 209, 421, 3, 1000000), -- Knight's Epaulette
-- Jax the Destroyer
(25569, 9442, 1, 1, 0, 106.587584), -- Dynasty Sword
(25569, 9443, 1, 1, 0, 106.587584), -- Dynasty Blade
(25569, 9444, 1, 1, 0, 106.587584), -- Dynasty Phantom
(25569, 9616, 1, 1, 0, 22210.723432), -- Dynasty Sword Piece
(25569, 9617, 1, 1, 0, 22210.723432), -- Dynasty Blade Piece
(25569, 9618, 1, 1, 0, 22210.790384), -- Dynasty Phantom Piece
(25569, 9588, 1, 1, 1, 9434.950992), -- Striped Mithril Shirt
(25569, 9582, 1, 1, 1, 13313.773024), -- Mithril Shirt
(25569, 9592, 1, 1, 1, 6739.275984), -- Mithril Bracelet
(25569, 9627, 1, 1, 2, 93197), -- Giant's Codex - Mastery
(25569, 9912, 209, 421, 3, 1000000), -- Knight's Epaulette
-- Hager the Outlaw
(25572, 6364, 1, 1, 0, 447.248529), -- Forgotten Blade
(25572, 6372, 1, 1, 0, 447.248529), -- Heaven's Divider
(25572, 6688, 1, 1, 0, 206710.252203), -- Forgotten Blade Edge
(25572, 6696, 1, 1, 0, 209994.250739), -- Heavens Divider Edge
(25572, 9625, 1, 1, 1, 178492), -- Giant's Codex - Oblivion
(25572, 9912, 180, 362, 2, 1000000), -- Knight's Epaulette
-- All-Seeing Rango
(25575, 5297, 1, 1, 0, 7319.246576), -- Sealed Dark Crystal Leather Armor
(25575, 5478, 2, 4, 0, 273982.494579), -- Sealed Dark Crystal Leather Armor Pattern
(25575, 5298, 1, 1, 0, 11706.160937), -- Sealed Dark Crystal Leggings
(25575, 5482, 4, 12, 0, 161265.097908), -- Sealed Dark Crystal Leggings Design
(25575, 9625, 1, 1, 1, 45616.256928), -- Giant's Codex - Oblivion
(25575, 6570, 1, 1, 1, 25342.342884), -- Blessed Scroll: Enchant Armor (A-Grade)
(25575, 729, 1, 1, 1, 25342.342884), -- Scroll: Enchant Weapon (A-Grade)
(25575, 6569, 1, 1, 1, 3041.057304), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25575, 9912, 184, 368, 2, 1000000), -- Knight's Epaulette
-- Jakard
(25578, 6684, 1, 1, 0, 2598.21152), -- Sealed Major Arcana Robe
(25578, 6711, 1, 3, 0, 501321.78848), -- Sealed Major Arcana Robe Part
(25578, 9625, 1, 1, 1, 94435.359516), -- Giant's Codex - Oblivion
(25578, 730, 1, 1, 1, 393481.640484), -- Scroll: Enchant Armor (A-Grade)
(25578, 9912, 184, 368, 2, 1000000), -- Knight's Epaulette
-- Helsing
(25579, 6703, 1, 3, 0, 245239.120812), -- Sealed Imperial Crusader Gauntlets Design
(25579, 6704, 2, 4, 0, 163492.217742), -- Sealed Imperial Crusader Boots Design
(25579, 6708, 2, 6, 0, 122619.560406), -- Sealed Draconic Leather Gloves Fabric
(25579, 6709, 3, 7, 0, 98095.489485), -- Sealed Draconic Leather Boots Design
(25579, 6712, 3, 9, 0, 81746.108871), -- Sealed Major Arcana Gloves fabric
(25579, 6713, 4, 10, 0, 70068.206775), -- Sealed Major Arcana Boots Design
(25579, 6676, 1, 1, 0, 2156.250285), -- Sealed Imperial Crusader Gauntlet
(25579, 6677, 1, 1, 0, 2156.250285), -- Sealed Imperial Crusader Boots
(25579, 6681, 1, 1, 0, 2156.250285), -- Sealed Draconic Leather Glove
(25579, 6682, 1, 1, 0, 2156.250285), -- Sealed Draconic Leather Boots
(25579, 6685, 1, 1, 0, 2156.250285), -- Sealed Major Arcana Glove
(25579, 6686, 1, 1, 0, 2157.044484), -- Sealed Major Arcana Boots
(25579, 9625, 1, 1, 1, 48228.09552), -- Giant's Codex - Oblivion
(25579, 6570, 1, 1, 1, 26793.36306), -- Blessed Scroll: Enchant Armor (A-Grade)
(25579, 729, 1, 1, 1, 26793.36306), -- Scroll: Enchant Weapon (A-Grade)
(25579, 6569, 1, 1, 1, 3215.17836), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25579, 9912, 186, 378, 2, 1000000), -- Knight's Epaulette
-- Gillien
(25582, 6724, 1, 1, 0, 8609.69782), -- Sealed Tateossian Earring
(25582, 6725, 1, 1, 0, 12914.53274), -- Sealed Tateossian Ring
(25582, 6726, 1, 1, 0, 6455.76944), -- Sealed Tateossian Necklace
(25582, 9625, 1, 1, 1, 98539.351308), -- Giant's Codex - Oblivion
(25582, 730, 1, 1, 1, 410581.648692), -- Scroll: Enchant Armor (A-Grade)
(25582, 9912, 190, 380, 2, 1000000), -- Knight's Epaulette
-- Medici
(25585, 6703, 8, 24, 0, 31137.28112), -- Sealed Imperial Crusader Gauntlets Design
(25585, 6704, 2, 4, 0, 166066.48054), -- Sealed Imperial Crusader Boots Design
(25585, 6708, 2, 6, 0, 124549.71322), -- Sealed Draconic Leather Gloves Fabric
(25585, 6709, 3, 7, 0, 99639.53508), -- Sealed Draconic Leather Boots Design
(25585, 6712, 3, 9, 0, 83032.9459), -- Sealed Major Arcana Gloves fabric
(25585, 6713, 4, 10, 0, 71171.01238), -- Sealed Major Arcana Boots Design
(25585, 6676, 1, 1, 0, 2190.1128), -- Sealed Imperial Crusader Gauntlet
(25585, 6677, 1, 1, 0, 2190.1128), -- Sealed Imperial Crusader Boots
(25585, 6681, 1, 1, 0, 2190.1128), -- Sealed Draconic Leather Glove
(25585, 6682, 1, 1, 0, 2190.1128), -- Sealed Draconic Leather Boots
(25585, 6685, 1, 1, 0, 2190.1128), -- Sealed Major Arcana Glove
(25585, 6686, 1, 1, 0, 2192.46776), -- Sealed Major Arcana Boots
(25585, 9625, 1, 1, 1, 48987.126672), -- Giant's Codex - Oblivion
(25585, 6570, 1, 1, 1, 27215.046666), -- Blessed Scroll: Enchant Armor (A-Grade)
(25585, 729, 1, 1, 1, 27215.046666), -- Scroll: Enchant Weapon (A-Grade)
(25585, 6569, 1, 1, 1, 3265.779996), -- Blessed Scroll: Enchant Weapon (A-Grade)
(25585, 9912, 188, 377, 2, 1000000), -- Knight's Epaulette
-- Immortal Muus
(25588, 6679, 1, 1, 0, 2980.542896), -- Sealed Imperial Crusader Helmet
(25588, 6683, 1, 1, 0, 2980.542896), -- Sealed Draconic Leather Helmet
(25588, 6687, 1, 1, 0, 2980.542896), -- Sealed Major Arcana Circlet
(25588, 6706, 5, 15, 0, 115874.830509), -- Sealed Imperial Crusader Helmet Pattern
(25588, 6710, 9, 27, 0, 64374.746212), -- Sealed Draconic Leather Helmet Pattern
(25588, 6714, 2, 6, 0, 289687.794591), -- Sealed Major Arcana Circlet Pattern
(25588, 9625, 1, 1, 1, 100000.058064), -- Giant's Codex - Oblivion
(25588, 730, 1, 1, 1, 416667.941936), -- Scroll: Enchant Armor (A-Grade)
(25588, 9912, 191, 389, 2, 1000000), -- Knight's Epaulette
-- Brand the Exile
(25589, 6364, 1, 1, 0, 511.831971), -- Forgotten Blade
(25589, 6372, 1, 1, 0, 511.831971), -- Heaven's Divider
(25589, 6688, 1, 1, 0, 236559.561297), -- Forgotten Blade Edge
(25589, 6696, 1, 1, 0, 240317.774761), -- Heavens Divider Edge
(25589, 9626, 1, 1, 1, 27235.556331), -- Giant's Codex - Discipline
(25589, 9587, 1, 1, 1, 46424.246469), -- Striped Scale Shirt
(25589, 9591, 1, 1, 1, 35710.986471), -- Steel Bracelet
(25589, 6577, 1, 1, 1, 1361.771826), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25589, 6578, 1, 1, 1, 9078.438903), -- Blessed Scroll: Enchant Armor (S-Grade)
(25589, 9912, 199, 391, 2, 1000000), -- Knight's Epaulette
-- Commander Koenig
(25592, 6680, 1, 1, 0, 2867.550648), -- Sealed Draconic Leather Armor
(25592, 6707, 1, 3, 0, 553290.449352), -- Sealed Draconic Leather Armor Part
(25592, 9626, 1, 1, 1, 23161.066872), -- Giant's Codex - Discipline
(25592, 9587, 1, 1, 1, 39479.106768), -- Striped Scale Shirt
(25592, 9591, 1, 1, 1, 30368.491176), -- Steel Bracelet
(25592, 959, 1, 1, 1, 6948.285942), -- Scroll: Enchant Weapon (S-Grade)
(25592, 960, 1, 1, 1, 69483.030018), -- Scroll: Enchant Armor (S-Grade)
(25592, 6577, 1, 1, 1, 1158.019224), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25592, 9912, 200, 400, 2, 1000000), -- Knight's Epaulette
-- Gerg the Hunter
(25593, 9445, 1, 1, 0, 608.81197), -- Dynasty Bow
(25593, 9619, 1, 1, 0, 127697.18803), -- Dynasty Bow Piece
(25593, 9626, 1, 1, 1, 35488.473428), -- Giant's Codex - Discipline
(25593, 9587, 1, 1, 1, 60491.877428), -- Striped Scale Shirt
(25593, 9591, 1, 1, 1, 46532.106554), -- Steel Bracelet
(25593, 6578, 1, 1, 1, 11829.54259), -- Blessed Scroll: Enchant Armor (S-Grade)
(25593, 9912, 202, 408, 2, 1000000), -- Knight's Epaulette
-- Temenir
(25600, 6364, 1, 1, 0, 1388.930517), -- Forgotten Blade
(25600, 6372, 1, 1, 0, 1388.930517), -- Heaven's Divider
(25600, 6688, 2, 4, 0, 213954.460785), -- Forgotten Blade Edge
(25600, 6696, 1, 3, 0, 326030.678181), -- Heavens Divider Edge
(25600, 6680, 1, 1, 1, 11437.99383), -- Sealed Draconic Leather Armor
(25600, 6707, 3, 9, 1, 735655.00617), -- Sealed Draconic Leather Armor Part
(25600, 6578, 1, 1, 2, 25662.313146), -- Blessed Scroll: Enchant Armor (S-Grade)
(25600, 3936, 1, 1, 2, 288699.686854), -- Blessed Scroll of Resurrection
-- Draksius
(25601, 6364, 1, 1, 0, 2271.521605), -- Forgotten Blade
(25601, 6372, 1, 1, 0, 2271.521605), -- Heaven's Divider
(25601, 6688, 2, 4, 0, 349917.73335), -- Forgotten Blade Edge
(25601, 6696, 4, 12, 0, 133304.22344), -- Heavens Divider Edge
(25601, 6674, 1, 1, 1, 11399.19144), -- Sealed Imperial Crusader Breastplate
(25601, 6675, 1, 1, 1, 18238.94163), -- Sealed Imperial Crusader Gaiters
(25601, 6701, 8, 22, 1, 258560.5204), -- Sealed Imperial Crusader Breastplate Part
(25601, 6702, 24, 72, 1, 104011.34653), -- Sealed Imperial Crusader Gaiters Pattern
-- Kiretcenah
(25602, 6724, 1, 1, 0, 11388.241242), -- Sealed Tateossian Earring
(25602, 6725, 1, 1, 0, 17082.361863), -- Sealed Tateossian Ring
(25602, 6726, 1, 1, 0, 8539.366824), -- Sealed Tateossian Necklace
(25602, 6698, 9, 27, 0, 203187.29643), -- Sealed Tateossian Earring Part
(25602, 6699, 5, 15, 0, 405834.714468), -- Sealed Tateossian Ring Gem
(25602, 6700, 14, 42, 0, 79611.019173), -- Sealed Tateossian Necklace Chain
(25602, 6370, 1, 1, 1, 3919.096304), -- Saint Spear
(25602, 6694, 3, 9, 1, 307317.903696), -- Saint Spear Blade
(25602, 959, 1, 1, 2, 14482.080784), -- Scroll: Enchant Weapon (S-Grade)
(25602, 960, 1, 1, 2, 144821.131274), -- Scroll: Enchant Armor (S-Grade)
(25602, 6577, 1, 1, 2, 2413.787942), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Darion
(25603, 6367, 1, 1, 0, 7555.839389), -- Angel Slayer
(25603, 6691, 3, 9, 0, 581961.160611), -- Angel Slayer Blade
(25603, 6680, 1, 1, 1, 31111.53785), -- Sealed Draconic Leather Armor
(25603, 6707, 12, 36, 1, 500255.46215), -- Sealed Draconic Leather Armor Part
-- Epidos
(25609, 7575, 1, 1, 0, 19749.69045), -- Draconic Bow
(25609, 7579, 12, 36, 0, 384675.30955), -- Draconic Bow Shaft
(25609, 6676, 1, 1, 1, 66078.607551), -- Sealed Imperial Crusader Gauntlet
(25609, 6677, 1, 1, 1, 66078.607551), -- Sealed Imperial Crusader Boots
(25609, 6681, 1, 1, 1, 66078.607551), -- Sealed Draconic Leather Glove
(25609, 6682, 1, 1, 1, 66078.607551), -- Sealed Draconic Leather Boots
(25609, 6685, 1, 1, 1, 66078.607551), -- Sealed Major Arcana Glove
(25609, 6686, 1, 1, 1, 66078.607551), -- Sealed Major Arcana Boots
(25609, 6703, 112, 336, 1, 67096.01778), -- Sealed Imperial Crusader Gauntlets Design
(25609, 6704, 203, 607, 1, 37110.020178), -- Sealed Imperial Crusader Boots Design
(25609, 6708, 320, 960, 1, 23483.606223), -- Sealed Draconic Leather Gloves Fabric
(25609, 6709, 468, 1402, 1, 16074.221229), -- Sealed Draconic Leather Boots Design
(25609, 6712, 648, 1944, 1, 11596.612434), -- Sealed Major Arcana Gloves fabric
(25609, 6713, 46, 136, 1, 165158.87685), -- Sealed Major Arcana Boots Design
(25609, 6578, 1, 1, 2, 182450.38917), -- Blessed Scroll: Enchant Armor (S-Grade)
(25609, 3936, 3, 9, 2, 342094.61083), -- Blessed Scroll of Resurrection
-- Epidos
(25610, 6365, 1, 1, 0, 4937.415738), -- Basalt Battlehammer
(25610, 6366, 1, 1, 0, 4937.415738), -- Imperial Staff
(25610, 6369, 1, 1, 0, 4937.415738), -- Dragon Hunter Axe
(25610, 6579, 1, 1, 0, 4937.415738), -- Arcana Mace
(25610, 6689, 16, 48, 0, 69959.464578), -- Basalt Battlehammer Head
(25610, 6690, 11, 31, 0, 108859.565946), -- Imperial Staff Head
(25610, 6693, 6, 18, 0, 193587.529044), -- Dragon Hunter Axe Blade
(25610, 6697, 23, 67, 0, 49749.77748), -- Arcana Mace Head
(25610, 6678, 1, 1, 1, 94390.889736), -- Sealed Imperial Crusader Shield
(25610, 6679, 1, 1, 1, 66071.5276), -- Sealed Imperial Crusader Helmet
(25610, 6683, 1, 1, 1, 66071.5276), -- Sealed Draconic Leather Helmet
(25610, 6687, 1, 1, 1, 66071.5276), -- Sealed Major Arcana Circlet
(25610, 6705, 293, 877, 1, 37747.108048), -- Sealed Imperial Crusader Shield Part
(25610, 6706, 60, 180, 1, 214049.352296), -- Sealed Imperial Crusader Helmet Pattern
(25610, 6710, 116, 346, 1, 111194.51564), -- Sealed Draconic Leather Helmet Pattern
(25610, 6714, 192, 576, 1, 66891.55148), -- Sealed Major Arcana Circlet Pattern
(25610, 959, 1, 1, 2, 109470.214854), -- Scroll: Enchant Weapon (S-Grade)
(25610, 960, 1, 3, 2, 547351.749337), -- Scroll: Enchant Armor (S-Grade)
(25610, 6577, 1, 1, 2, 18245.035809), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Epidos
(25611, 6693, 24, 72, 0, 268868.489694), -- Dragon Hunter Axe Blade
(25611, 6697, 53, 157, 0, 118448.510306), -- Arcana Mace Head
(25611, 6365, 1, 1, 1, 8229.02255), -- Basalt Battlehammer
(25611, 6366, 1, 1, 1, 8229.02255), -- Imperial Staff
(25611, 6369, 1, 1, 1, 8229.02255), -- Dragon Hunter Axe
(25611, 6579, 1, 1, 1, 8229.02255), -- Arcana Mace
(25611, 6689, 33, 99, 1, 56532.915285), -- Basalt Battlehammer Head
(25611, 6690, 25, 75, 1, 76201.166265), -- Imperial Staff Head
(25611, 6693, 18, 54, 1, 107548.15876), -- Dragon Hunter Axe Blade
(25611, 6697, 42, 126, 1, 44418.458245), -- Arcana Mace Head
(25611, 6680, 1, 1, 1, 22589.37135), -- Sealed Draconic Leather Armor
(25611, 6707, 24, 72, 1, 181608.839895), -- Sealed Draconic Leather Armor Part
-- Epidos
(25612, 7575, 1, 1, 0, 19749.69045), -- Draconic Bow
(25612, 7579, 12, 36, 0, 384675.30955), -- Draconic Bow Shaft
(25612, 6684, 1, 1, 1, 81320.356364), -- Sealed Major Arcana Robe
(25612, 6711, 60, 180, 1, 261515.643636), -- Sealed Major Arcana Robe Part
(25612, 959, 1, 1, 2, 109470.214854), -- Scroll: Enchant Weapon (S-Grade)
(25612, 960, 1, 3, 2, 547351.749337), -- Scroll: Enchant Armor (S-Grade)
(25612, 6577, 1, 1, 2, 18245.035809), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Cohemenes
(25634, 9991, 1, 3, 0, 28267.276264), -- Sealed Dynasty Earring Gemstone
(25634, 9992, 2, 6, 0, 16270.795784), -- Sealed Dynasty Necklace Gemstone
(25634, 9993, 1, 3, 0, 59587.972152), -- Sealed Dynasty Ring Gemstone
(25634, 9452, 1, 1, 0, 1195.938144), -- Sealed Dynasty Earring
(25634, 9453, 1, 1, 0, 896.953608), -- Sealed Dynasty Necklace
(25634, 9454, 1, 1, 0, 1794.075848), -- Sealed Dynasty Ring
(25634, 9442, 1, 1, 0, 96.457504), -- Dynasty Sword
(25634, 9443, 1, 1, 0, 96.457504), -- Dynasty Blade
(25634, 9444, 1, 1, 0, 96.457504), -- Dynasty Phantom
(25634, 9616, 1, 1, 0, 20109.871896), -- Dynasty Sword Piece
(25634, 9617, 1, 1, 0, 20109.871896), -- Dynasty Blade Piece
(25634, 9618, 1, 1, 0, 20109.871896), -- Dynasty Phantom Piece
(25634, 960, 1, 1, 1, 86801.826862), -- Scroll: Enchant Armor (S-Grade)
(25634, 959, 1, 1, 1, 8680.173138), -- Scroll: Enchant Weapon (S-Grade)
-- Argekunte
(25635, 6676, 1, 1, 0, 8150.419664), -- Sealed Imperial Crusader Gauntlet
(25635, 6677, 1, 1, 0, 8150.419664), -- Sealed Imperial Crusader Boots
(25635, 6681, 1, 1, 0, 8150.419664), -- Sealed Draconic Leather Glove
(25635, 6682, 1, 1, 0, 8150.419664), -- Sealed Draconic Leather Boots
(25635, 6685, 1, 1, 0, 8150.419664), -- Sealed Major Arcana Glove
(25635, 6686, 1, 1, 0, 8150.419664), -- Sealed Major Arcana Boots
(25635, 6703, 8, 24, 0, 115861.842832), -- Sealed Imperial Crusader Gauntlets Design
(25635, 6704, 14, 40, 0, 68659.11592), -- Sealed Imperial Crusader Boots Design
(25635, 6708, 20, 60, 0, 46344.978752), -- Sealed Draconic Leather Gloves Fabric
(25635, 6709, 28, 82, 0, 33705.274352), -- Sealed Draconic Leather Boots Design
(25635, 6712, 36, 108, 0, 25746.941952), -- Sealed Major Arcana Gloves fabric
(25635, 6713, 4, 10, 0, 264827.328208), -- Sealed Major Arcana Boots Design
(25635, 7575, 1, 1, 1, 5481.021808), -- Draconic Bow
(25635, 7579, 3, 9, 1, 427014.978192), -- Draconic Bow Shaft
(25635, 959, 1, 1, 2, 20253.796736), -- Scroll: Enchant Weapon (S-Grade)
(25635, 960, 1, 1, 2, 202538.419696), -- Scroll: Enchant Armor (S-Grade)
(25635, 6577, 1, 1, 2, 3375.783568), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Ravenous Soul Devourer
(25636, 14109, 1, 1, 0, 16666.7), -- Sealed Vesper Gauntlet
(25636, 14113, 1, 1, 0, 16666.7), -- Sealed Vesper Leather Gloves
(25636, 14116, 1, 1, 0, 16666.7), -- Sealed Vesper Gloves
(25636, 14110, 1, 1, 0, 16666.7), -- Sealed Vesper Boots
(25636, 14114, 1, 1, 0, 16666.7), -- Sealed Vesper Leather Boots
(25636, 14117, 1, 1, 0, 16666.5), -- Sealed Vesper Shoes
(25636, 14052, 110, 150, 1, 1000000), -- Noble Enhancement Stone
-- Karpencharr
(25637, 6674, 1, 1, 0, 6200.66874), -- Sealed Imperial Crusader Breastplate
(25637, 6675, 1, 1, 0, 9921.566236), -- Sealed Imperial Crusader Gaiters
(25637, 6701, 8, 22, 0, 140651.215604), -- Sealed Imperial Crusader Breastplate Part
(25637, 6702, 4, 12, 0, 339478.54942), -- Sealed Imperial Crusader Gaiters Pattern
(25637, 6367, 1, 1, 1, 5560.232489), -- Angel Slayer
(25637, 6691, 3, 9, 1, 428256.767511), -- Angel Slayer Blade
(25637, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25637, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25637, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Romerohiv
(25638, 6678, 1, 1, 0, 11810.83287), -- Sealed Imperial Crusader Shield
(25638, 6679, 1, 1, 0, 8267.583009), -- Sealed Imperial Crusader Helmet
(25638, 6683, 1, 1, 0, 8267.583009), -- Sealed Draconic Leather Helmet
(25638, 6687, 1, 1, 0, 8267.583009), -- Sealed Major Arcana Circlet
(25638, 6705, 23, 67, 0, 61402.705422), -- Sealed Imperial Crusader Shield Part
(25638, 6706, 6, 18, 0, 267836.492814), -- Sealed Imperial Crusader Helmet Pattern
(25638, 6710, 11, 31, 0, 153049.689897), -- Sealed Draconic Leather Helmet Pattern
(25638, 6714, 16, 48, 0, 100438.52997), -- Sealed Major Arcana Circlet Pattern
(25638, 6371, 1, 1, 1, 5560.2297), -- Demon Splinter
(25638, 6695, 3, 9, 1, 420184.7703), -- Demon Splinter Blade
(25638, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25638, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25638, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Hitchkarshiek
(25639, 6674, 1, 1, 0, 6200.66874), -- Sealed Imperial Crusader Breastplate
(25639, 6675, 1, 1, 0, 9921.566236), -- Sealed Imperial Crusader Gaiters
(25639, 6701, 8, 22, 0, 140651.215604), -- Sealed Imperial Crusader Breastplate Part
(25639, 6702, 4, 12, 0, 339478.54942), -- Sealed Imperial Crusader Gaiters Pattern
(25639, 6364, 1, 1, 1, 2780.117232), -- Forgotten Blade
(25639, 6372, 1, 1, 1, 2780.117232), -- Heaven's Divider
(25639, 6688, 2, 4, 1, 428264.61264), -- Forgotten Blade Edge
(25639, 6696, 4, 12, 1, 163151.152896), -- Heavens Divider Edge
(25639, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25639, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25639, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Freedkyilla
(25640, 6680, 1, 1, 0, 10175.34751), -- Sealed Draconic Leather Armor
(25640, 6707, 3, 9, 0, 654445.65249), -- Sealed Draconic Leather Armor Part
(25640, 7575, 1, 1, 1, 5560.228058), -- Draconic Bow
(25640, 7579, 3, 9, 1, 433185.771942), -- Draconic Bow Shaft
(25640, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25640, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25640, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Yehan Cravenizad
(25641, 6684, 1, 1, 0, 10175.34751), -- Sealed Major Arcana Robe
(25641, 6711, 3, 9, 0, 654445.65249), -- Sealed Major Arcana Robe Part
(25641, 6365, 1, 1, 1, 1390.05744), -- Basalt Battlehammer
(25641, 6366, 1, 1, 1, 1390.05744), -- Imperial Staff
(25641, 6369, 1, 1, 1, 1390.05744), -- Dragon Hunter Axe
(25641, 6579, 1, 1, 1, 1390.05744), -- Arcana Mace
(25641, 6689, 2, 6, 1, 157578.92112), -- Basalt Battlehammer Head
(25641, 6690, 2, 4, 1, 214548.387664), -- Imperial Staff Head
(25641, 6693, 6, 18, 1, 54505.32456), -- Dragon Hunter Axe Blade
(25641, 6697, 3, 7, 1, 126063.136896), -- Arcana Mace Head
(25641, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25641, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Yehan Jaxsibhan
(25642, 6684, 1, 1, 0, 10175.34751), -- Sealed Major Arcana Robe
(25642, 6711, 3, 9, 0, 654445.65249), -- Sealed Major Arcana Robe Part
(25642, 6364, 1, 1, 1, 2780.117232), -- Forgotten Blade
(25642, 6372, 1, 1, 1, 2780.117232), -- Heaven's Divider
(25642, 6688, 2, 4, 1, 428264.61264), -- Forgotten Blade Edge
(25642, 6696, 4, 12, 1, 163151.152896), -- Heavens Divider Edge
(25642, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25642, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Awakened Ancient Sentry
(25643, 6680, 1, 1, 0, 10175.34751), -- Sealed Draconic Leather Armor
(25643, 6707, 3, 9, 0, 654445.65249), -- Sealed Draconic Leather Armor Part
(25643, 6367, 1, 1, 1, 5560.232489), -- Angel Slayer
(25643, 6691, 3, 9, 1, 428256.767511), -- Angel Slayer Blade
(25643, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25643, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25643, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Awakened Ancient Severer
(25644, 6676, 1, 1, 0, 8268.200061), -- Sealed Imperial Crusader Gauntlet
(25644, 6677, 1, 1, 0, 8268.200061), -- Sealed Imperial Crusader Boots
(25644, 6681, 1, 1, 0, 8268.200061), -- Sealed Draconic Leather Glove
(25644, 6682, 1, 1, 0, 8268.200061), -- Sealed Draconic Leather Boots
(25644, 6685, 1, 1, 0, 8268.200061), -- Sealed Major Arcana Glove
(25644, 6686, 1, 1, 0, 8268.200061), -- Sealed Major Arcana Boots
(25644, 6703, 8, 24, 0, 117536.143593), -- Sealed Imperial Crusader Gauntlets Design
(25644, 6704, 14, 40, 0, 69651.297705), -- Sealed Imperial Crusader Boots Design
(25644, 6708, 20, 60, 0, 47014.702548), -- Sealed Draconic Leather Gloves Fabric
(25644, 6709, 28, 82, 0, 34192.343823), -- Sealed Draconic Leather Boots Design
(25644, 6712, 36, 108, 0, 26119.006848), -- Sealed Major Arcana Gloves fabric
(25644, 6713, 4, 10, 0, 268654.305117), -- Sealed Major Arcana Boots Design
(25644, 6365, 1, 1, 1, 1390.05744), -- Basalt Battlehammer
(25644, 6366, 1, 1, 1, 1390.05744), -- Imperial Staff
(25644, 6369, 1, 1, 1, 1390.05744), -- Dragon Hunter Axe
(25644, 6579, 1, 1, 1, 1390.05744), -- Arcana Mace
(25644, 6689, 2, 6, 1, 157578.92112), -- Basalt Battlehammer Head
(25644, 6690, 2, 4, 1, 214548.387664), -- Imperial Staff Head
(25644, 6693, 6, 18, 1, 54505.32456), -- Dragon Hunter Axe Blade
(25644, 6697, 3, 7, 1, 126063.136896), -- Arcana Mace Head
(25644, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25644, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Awakened Ancient Soul Extractor
(25645, 6684, 1, 1, 0, 10175.34751), -- Sealed Major Arcana Robe
(25645, 6711, 3, 9, 0, 654445.65249), -- Sealed Major Arcana Robe Part
(25645, 6364, 1, 1, 1, 2780.117232), -- Forgotten Blade
(25645, 6372, 1, 1, 1, 2780.117232), -- Heaven's Divider
(25645, 6688, 2, 4, 1, 428264.61264), -- Forgotten Blade Edge
(25645, 6696, 4, 12, 1, 163151.152896), -- Heavens Divider Edge
(25645, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25645, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Awakened Ancient Soul Devourer
(25646, 6684, 1, 1, 0, 10175.34751), -- Sealed Major Arcana Robe
(25646, 6711, 3, 9, 0, 654445.65249), -- Sealed Major Arcana Robe Part
(25646, 6367, 1, 1, 1, 5560.232489), -- Angel Slayer
(25646, 6691, 3, 9, 1, 428256.767511), -- Angel Slayer Blade
(25646, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25646, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25646, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Awakened Ancient Fighter
(25647, 6724, 1, 1, 0, 16157.140406), -- Sealed Tateossian Earring
(25647, 6725, 1, 1, 0, 24235.710609), -- Sealed Tateossian Ring
(25647, 6726, 1, 1, 0, 12114.963905), -- Sealed Tateossian Necklace
(25647, 6698, 9, 27, 0, 288277.261531), -- Sealed Tateossian Earring Part
(25647, 6699, 40, 120, 0, 71973.242063), -- Sealed Tateossian Ring Gem
(25647, 6700, 14, 42, 0, 112950.681486), -- Sealed Tateossian Necklace Chain
(25647, 6371, 1, 1, 1, 5560.2297), -- Demon Splinter
(25647, 6695, 3, 9, 1, 420184.7703), -- Demon Splinter Blade
(25647, 959, 1, 1, 2, 20546.452672), -- Scroll: Enchant Weapon (S-Grade)
(25647, 960, 1, 1, 2, 205464.985592), -- Scroll: Enchant Armor (S-Grade)
(25647, 6577, 1, 1, 2, 3424.561736), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Awakened Ancient Fighter
(25648, 6680, 1, 1, 0, 10175.34751), -- Sealed Draconic Leather Armor
(25648, 6707, 3, 9, 0, 654445.65249), -- Sealed Draconic Leather Armor Part
(25648, 6371, 1, 1, 1, 5560.2297), -- Demon Splinter
(25648, 6695, 3, 9, 1, 420184.7703), -- Demon Splinter Blade
(25648, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25648, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Awakened Ancient Executor
(25649, 6678, 1, 1, 0, 11810.83287), -- Sealed Imperial Crusader Shield
(25649, 6679, 1, 1, 0, 8267.583009), -- Sealed Imperial Crusader Helmet
(25649, 6683, 1, 1, 0, 8267.583009), -- Sealed Draconic Leather Helmet
(25649, 6687, 1, 1, 0, 8267.583009), -- Sealed Major Arcana Circlet
(25649, 6705, 23, 67, 0, 61402.705422), -- Sealed Imperial Crusader Shield Part
(25649, 6706, 6, 18, 0, 267836.492814), -- Sealed Imperial Crusader Helmet Pattern
(25649, 6710, 11, 31, 0, 153049.689897), -- Sealed Draconic Leather Helmet Pattern
(25649, 6714, 16, 48, 0, 100438.52997), -- Sealed Major Arcana Circlet Pattern
(25649, 6370, 1, 1, 1, 5560.224256), -- Saint Spear
(25649, 6694, 3, 9, 1, 436007.775744), -- Saint Spear Blade
(25649, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25649, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Awakened Ancient Executor
(25650, 6724, 1, 1, 0, 22440.460834), -- Sealed Tateossian Earring
(25650, 6725, 1, 1, 0, 33660.691251), -- Sealed Tateossian Ring
(25650, 6726, 1, 1, 0, 16826.329795), -- Sealed Tateossian Necklace
(25650, 6698, 9, 27, 0, 400384.872209), -- Sealed Tateossian Earring Part
(25650, 6699, 40, 120, 0, 99962.782957), -- Sealed Tateossian Ring Gem
(25650, 6700, 14, 42, 0, 156875.862954), -- Sealed Tateossian Necklace Chain
(25650, 6365, 1, 1, 1, 1930.63644), -- Basalt Battlehammer
(25650, 6366, 1, 1, 1, 1930.63644), -- Imperial Staff
(25650, 6369, 1, 1, 1, 1930.63644), -- Dragon Hunter Axe
(25650, 6579, 1, 1, 1, 1930.63644), -- Arcana Mace
(25650, 6689, 2, 6, 1, 218859.73812), -- Basalt Battlehammer Head
(25650, 6690, 2, 4, 1, 297984.042564), -- Imperial Staff Head
(25650, 6693, 6, 18, 1, 75701.88306), -- Dragon Hunter Axe Blade
(25650, 6697, 3, 7, 1, 175087.790496), -- Arcana Mace Head
-- Awakened Ancient Prophet
(25651, 6684, 1, 1, 0, 10175.34751), -- Sealed Major Arcana Robe
(25651, 6711, 3, 9, 0, 654445.65249), -- Sealed Major Arcana Robe Part
(25651, 6365, 1, 1, 1, 1390.05744), -- Basalt Battlehammer
(25651, 6366, 1, 1, 1, 1390.05744), -- Imperial Staff
(25651, 6369, 1, 1, 1, 1390.05744), -- Dragon Hunter Axe
(25651, 6579, 1, 1, 1, 1390.05744), -- Arcana Mace
(25651, 6689, 2, 6, 1, 157578.92112), -- Basalt Battlehammer Head
(25651, 6690, 2, 4, 1, 214548.387664), -- Imperial Staff Head
(25651, 6693, 6, 18, 1, 54505.32456), -- Dragon Hunter Axe Blade
(25651, 6697, 3, 7, 1, 126063.136896), -- Arcana Mace Head
(25651, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25651, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Awakened Ancient Prophet
(25652, 6676, 1, 1, 0, 8268.200061), -- Sealed Imperial Crusader Gauntlet
(25652, 6677, 1, 1, 0, 8268.200061), -- Sealed Imperial Crusader Boots
(25652, 6681, 1, 1, 0, 8268.200061), -- Sealed Draconic Leather Glove
(25652, 6682, 1, 1, 0, 8268.200061), -- Sealed Draconic Leather Boots
(25652, 6685, 1, 1, 0, 8268.200061), -- Sealed Major Arcana Glove
(25652, 6686, 1, 1, 0, 8268.200061), -- Sealed Major Arcana Boots
(25652, 6703, 8, 24, 0, 117536.143593), -- Sealed Imperial Crusader Gauntlets Design
(25652, 6704, 14, 40, 0, 69651.297705), -- Sealed Imperial Crusader Boots Design
(25652, 6708, 20, 60, 0, 47014.702548), -- Sealed Draconic Leather Gloves Fabric
(25652, 6709, 28, 82, 0, 34192.343823), -- Sealed Draconic Leather Boots Design
(25652, 6712, 36, 108, 0, 26119.006848), -- Sealed Major Arcana Gloves fabric
(25652, 6713, 4, 10, 0, 268654.305117), -- Sealed Major Arcana Boots Design
(25652, 6367, 1, 1, 1, 5560.232489), -- Angel Slayer
(25652, 6691, 3, 9, 1, 428256.767511), -- Angel Slayer Blade
(25652, 6578, 1, 1, 2, 34244.145537), -- Blessed Scroll: Enchant Armor (S-Grade)
(25652, 3936, 1, 1, 2, 385244.854463), -- Blessed Scroll of Resurrection
-- Kanadis Herald
(25653, 15700, 1, 1, 0, 3936.58586), -- Sealed Moirai Gaiter 
(25653, 15697, 1, 1, 0, 2460.41414), -- Sealed Moirai Breastplate 
(25653, 15651, 4, 12, 1, 308820.583024), -- Sealed Moirai Gaiter Piece
(25653, 15648, 8, 22, 1, 98275.416976), -- Sealed Moirai Breastplate Piece
(25653, 9912, 205, 415, 2, 1000000), -- Knight's Epaulette
-- Kanadis Herald
(25654, 10223, 1, 1, 0, 1377.843484), -- Icarus Spitter
(25654, 10405, 1, 1, 0, 456834.156516), -- Icarus Spitter Piece
(25654, 9912, 212, 428, 1, 1000000), -- Knight's Epaulette
-- Kanadis Herald
(25655, 10221, 1, 1, 0, 1418.813859), -- Icarus Hand
(25655, 10403, 1, 1, 0, 470418.186141), -- Icarus Hand Piece
(25655, 9912, 215, 444, 1, 1000000), -- Knight's Epaulette
-- Kanadis Guide
(25659, 15697, 1, 1, 0, 3273.940194), -- Sealed Moirai Breastplate 
(25659, 15700, 1, 1, 0, 5238.879064), -- Sealed Moirai Gaiter 
(25659, 15648, 2, 4, 0, 435946.294948), -- Sealed Moirai Breastplate Piece
(25659, 15651, 4, 12, 0, 273982.885794), -- Sealed Moirai Gaiter Piece
(25659, 9912, 218, 443, 1, 1000000), -- Knight's Epaulette
-- Kanadis Guide
(25660, 15698, 1, 1, 0, 4561.797068), -- Sealed Moirai Leather Breastplate 
(25660, 15701, 1, 1, 0, 7298.773278), -- Sealed Moirai Leather Legging 
(25660, 15649, 8, 22, 0, 123279.224254), -- Sealed Moirai Leather Breastplate Piece
(25660, 15652, 4, 12, 0, 375014.2054), -- Sealed Moirai Leather Legging Piece
(25660, 9912, 228, 461, 1, 1000000), -- Knight's Epaulette
-- Kanadis Guide
(25661, 15699, 1, 1, 0, 4743.874072), -- Sealed Moirai Tunic 
(25661, 15702, 1, 1, 0, 7590.092412), -- Sealed Moirai Stockings 
(25661, 15650, 8, 22, 0, 128199.721916), -- Sealed Moirai Tunic Piece
(25661, 15653, 4, 12, 0, 389982.3116), -- Sealed Moirai Stockings Piece
(25661, 9912, 246, 507, 1, 1000000), -- Knight's Epaulette
-- Yehan Klodekus
(25665, 6724, 1, 1, 0, 38516.308116), -- Sealed Tateossian Earring
(25665, 6725, 1, 1, 0, 57774.783352), -- Sealed Tateossian Ring
(25665, 6726, 1, 1, 0, 28880.968116), -- Sealed Tateossian Necklace
(25665, 6698, 81, 243, 0, 76356.215364), -- Sealed Tateossian Earring Part
(25665, 6699, 40, 120, 0, 171573.2876), -- Sealed Tateossian Ring Gem
(25665, 6700, 14, 42, 0, 269254.437452), -- Sealed Tateossian Necklace Chain
(25665, 6371, 1, 1, 1, 13254.803757), -- Demon Splinter
(25665, 6695, 12, 36, 1, 250412.196243), -- Demon Splinter Blade
(25665, 959, 1, 1, 2, 48979.839536), -- Scroll: Enchant Weapon (S-Grade)
(25665, 960, 1, 1, 2, 489799.489246), -- Scroll: Enchant Armor (S-Grade)
(25665, 6577, 1, 1, 2, 8163.671218), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Yehan Klanikus
(25666, 6676, 1, 1, 0, 19710.217402), -- Sealed Imperial Crusader Gauntlet
(25666, 6677, 1, 1, 0, 19710.217402), -- Sealed Imperial Crusader Boots
(25666, 6681, 1, 1, 0, 19710.217402), -- Sealed Draconic Leather Glove
(25666, 6682, 1, 1, 0, 19710.217402), -- Sealed Draconic Leather Boots
(25666, 6685, 1, 1, 0, 19710.217402), -- Sealed Major Arcana Glove
(25666, 6686, 1, 1, 0, 19710.217402), -- Sealed Major Arcana Boots
(25666, 6703, 112, 336, 0, 20013.71404), -- Sealed Imperial Crusader Gauntlets Design
(25666, 6704, 14, 40, 0, 166040.085381), -- Sealed Imperial Crusader Boots Design
(25666, 6708, 20, 60, 0, 112076.798624), -- Sealed Draconic Leather Gloves Fabric
(25666, 6709, 28, 82, 0, 81510.177388), -- Sealed Draconic Leather Boots Design
(25666, 6712, 36, 108, 0, 62264.955839), -- Sealed Major Arcana Gloves fabric
(25666, 6713, 46, 136, 0, 49263.964316), -- Sealed Major Arcana Boots Design
(25666, 6365, 1, 1, 1, 3313.69835), -- Basalt Battlehammer
(25666, 6366, 1, 1, 1, 3313.69835), -- Imperial Staff
(25666, 6369, 1, 1, 1, 3313.69835), -- Dragon Hunter Axe
(25666, 6579, 1, 1, 1, 3313.69835), -- Arcana Mace
(25666, 6689, 16, 48, 1, 46949.22675), -- Basalt Battlehammer Head
(25666, 6690, 11, 31, 1, 73054.6765), -- Imperial Staff Head
(25666, 6693, 6, 18, 1, 129915.12485), -- Dragon Hunter Axe Blade
(25666, 6697, 3, 7, 1, 300476.1785), -- Arcana Mace Head
(25666, 6578, 1, 1, 2, 81633.144203), -- Blessed Scroll: Enchant Armor (S-Grade)
(25666, 3936, 1, 3, 2, 459187.855797), -- Blessed Scroll of Resurrection
-- Queen Shyeed
(25671, 9524, 1, 1, 0, 4066.114473), -- Sealed Dynasty Tunic
(25671, 9525, 1, 1, 0, 6506.099217), -- Sealed Dynasty Stockings
(25671, 9540, 2, 4, 0, 332765.035104), -- Sealed Dynasty Tunic Piece
(25671, 9541, 4, 12, 0, 183429.751206), -- Sealed Dynasty Stocking Piece
(25671, 9514, 1, 1, 1, 4574.25635), -- Sealed Dynasty Breast Plate
(25671, 9515, 1, 1, 1, 7319.42175), -- Sealed Dynasty Gaiter
(25671, 9530, 2, 6, 1, 304761.4129), -- Sealed Dynasty Breast Plate Piece
(25671, 9531, 15, 45, 1, 120194.909), -- Sealed Dynasty Gaiters Piece
(25671, 959, 1, 1, 2, 28933.982544), -- Scroll: Enchant Weapon (S-Grade)
(25671, 960, 1, 1, 2, 289340.471634), -- Scroll: Enchant Armor (S-Grade)
(25671, 6577, 1, 1, 2, 4822.545822), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Gwindorr
(25674, 10223, 1, 1, 0, 1417.208121), -- Icarus Spitter
(25674, 10405, 1, 1, 0, 469885.791879), -- Icarus Spitter Piece
(25674, 9514, 1, 1, 1, 4506.351915), -- Sealed Dynasty Breast Plate
(25674, 9515, 1, 1, 1, 7210.765575), -- Sealed Dynasty Gaiter
(25674, 9530, 2, 6, 1, 300237.25641), -- Sealed Dynasty Breast Plate Piece
(25674, 9531, 15, 45, 1, 118410.6261), -- Sealed Dynasty Gaiters Piece
(25674, 6578, 1, 1, 2, 47507.548845), -- Blessed Scroll: Enchant Armor (S-Grade)
(25674, 3936, 1, 1, 2, 534457.451155), -- Blessed Scroll of Resurrection
-- Water Spirit Lian
(25677, 10220, 1, 1, 0, 719.28048), -- Icarus Hammer
(25677, 10222, 1, 1, 0, 719.28048), -- Icarus Hall
(25677, 10402, 1, 1, 0, 238403.21952), -- Icarus Hammer Piece
(25677, 10404, 1, 1, 0, 238403.21952), -- Icarus Hall Piece
(25677, 9516, 1, 1, 1, 8132.230473), -- Sealed Dynasty Helmet
(25677, 9529, 1, 1, 1, 11617.577593), -- Sealed Dynasty Shield
(25677, 13885, 1, 1, 1, 22175.521051), -- Sealed Arcana Sigil
(25677, 9532, 9, 27, 1, 111466.865213), -- Sealed Dynasty Helmet Piece
(25677, 9545, 5, 15, 1, 239157.578217), -- Sealed Dynasty Shield Piece
(25677, 10114, 2, 6, 1, 345871.227453), -- Sealed Dynasty Sigil Piece
(25677, 959, 1, 1, 2, 28933.982544), -- Scroll: Enchant Weapon (S-Grade)
(25677, 960, 1, 1, 2, 289340.471634), -- Scroll: Enchant Armor (S-Grade)
(25677, 6577, 1, 1, 2, 4822.545822), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Giant Marpanak
(25680, 9448, 1, 1, 0, 904.198656), -- Dynasty Cudgel
(25680, 9449, 1, 1, 0, 904.198656), -- Dynasty Mace
(25680, 10252, 1, 1, 0, 904.198656), -- Dynasty Staff
(25680, 10253, 1, 1, 0, 904.198656), -- Dynasty Crusher
(25680, 9622, 1, 1, 0, 273540.160512), -- Dynasty Cudgel Piece
(25680, 9623, 1, 1, 0, 273540.160512), -- Dynasty Mace Piece
(25680, 10546, 1, 3, 0, 141748.288), -- Dynasty Staff Fragment
(25680, 10547, 2, 4, 0, 94498.596352), -- Dynasty Crusher Fragment
(25680, 9516, 1, 1, 1, 14813.893512), -- Sealed Dynasty Helmet
(25680, 9529, 1, 1, 1, 21163.431696), -- Sealed Dynasty Shield
(25680, 13885, 1, 1, 1, 40396.864904), -- Sealed Arcana Sigil
(25680, 9532, 9, 27, 1, 203055.509712), -- Sealed Dynasty Helmet Piece
(25680, 9545, 40, 120, 1, 54457.91912), -- Sealed Dynasty Shield Piece
(25680, 10114, 14, 42, 1, 90008.381056), -- Sealed Dynasty Sigil Piece
(25680, 959, 1, 1, 2, 52706.993776), -- Scroll: Enchant Weapon (S-Grade)
(25680, 960, 1, 1, 2, 527071.114886), -- Scroll: Enchant Armor (S-Grade)
(25680, 6577, 1, 1, 2, 8784.891338), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25680, 14851, 1, 1, 2, 1000000), -- Cave Exploration Text 1 Sheet
-- Gorgolos
(25681, 9442, 1, 1, 0, 891.5514), -- Dynasty Sword
(25681, 9443, 1, 1, 0, 891.5514), -- Dynasty Blade
(25681, 9444, 1, 1, 0, 891.5514), -- Dynasty Phantom
(25681, 9616, 1, 3, 0, 139316.26916), -- Dynasty Sword Piece
(25681, 9617, 1, 1, 0, 278632.53832), -- Dynasty Blade Piece
(25681, 9618, 1, 1, 0, 278632.53832), -- Dynasty Phantom Piece
(25681, 9514, 1, 1, 1, 6162.026435), -- Sealed Dynasty Breast Plate
(25681, 9515, 1, 1, 1, 9860.066175), -- Sealed Dynasty Gaiter
(25681, 9530, 2, 6, 1, 410547.14449), -- Sealed Dynasty Breast Plate Piece
(25681, 9531, 15, 45, 1, 161915.7629), -- Sealed Dynasty Gaiters Piece
(25681, 14852, 1, 1, 2, 1000000), -- Cave Exploration Text 2 Sheet
-- Last Titan Utenus
(25684, 9519, 1, 1, 0, 4005.759612), -- Sealed Dynasty Leather Armor
(25684, 9520, 1, 1, 0, 6409.526748), -- Sealed Dynasty Leather Leggings
(25684, 9535, 2, 4, 0, 327825.678976), -- Sealed Dynasty Leather Armor Piece
(25684, 9536, 4, 12, 0, 180707.034664), -- Sealed Dynasty Leather Leggings Piece
(25684, 10220, 1, 1, 1, 1062.90688), -- Icarus Hammer
(25684, 10222, 1, 1, 1, 1062.90688), -- Icarus Hall
(25684, 10402, 1, 1, 1, 352297.09312), -- Icarus Hammer Piece
(25684, 10404, 1, 1, 1, 352297.09312), -- Icarus Hall Piece
(25684, 959, 1, 1, 2, 28504.491152), -- Scroll: Enchant Weapon (S-Grade)
(25684, 960, 1, 1, 2, 285045.548122), -- Scroll: Enchant Armor (S-Grade)
(25684, 6577, 1, 1, 2, 4750.960726), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25684, 14853, 1, 1, 2, 1000000), -- Cave Exploration Text 3 Sheet
-- Hekaton Prime
(25687, 9519, 1, 1, 0, 7424.070714), -- Sealed Dynasty Leather Armor
(25687, 9520, 1, 1, 0, 11878.70343), -- Sealed Dynasty Leather Leggings
(25687, 9535, 8, 22, 0, 121511.952732), -- Sealed Dynasty Leather Armor Piece
(25687, 9536, 4, 12, 0, 334904.273124), -- Sealed Dynasty Leather Leggings Piece
(25687, 10221, 1, 1, 1, 3939.875664), -- Icarus Hand
(25687, 10403, 1, 3, 1, 653144.124336), -- Icarus Hand Piece
(25687, 6578, 1, 1, 2, 88048.07076), -- Blessed Scroll: Enchant Armor (S-Grade)
(25687, 3936, 1, 3, 2, 495271.92924), -- Blessed Scroll of Resurrection
-- Aenkinel
(25690, 9452, 1, 1, 0, 6742.748328), -- Sealed Dynasty Earring
(25690, 9453, 1, 1, 0, 5057.21348), -- Sealed Dynasty Necklace
(25690, 9454, 1, 1, 0, 10113.818024), -- Sealed Dynasty Ring
(25690, 9991, 2, 4, 0, 159359.769072), -- Sealed Dynasty Earring Gemstone
(25690, 9992, 2, 6, 0, 91728.292232), -- Sealed Dynasty Necklace Gemstone
(25690, 9993, 1, 3, 0, 335934.158864), -- Sealed Dynasty Ring Gemstone
(25690, 9442, 1, 1, 1, 544.127377), -- Dynasty Sword
(25690, 9443, 1, 1, 1, 544.127377), -- Dynasty Blade
(25690, 9444, 1, 1, 1, 544.127377), -- Dynasty Phantom
(25690, 9616, 1, 1, 1, 170082.03533), -- Dynasty Sword Piece
(25690, 9617, 1, 1, 1, 170082.03533), -- Dynasty Blade Piece
(25690, 9618, 1, 1, 1, 170082.547209), -- Dynasty Phantom Piece
(25690, 959, 1, 1, 2, 15858.942784), -- Scroll: Enchant Weapon (S-Grade)
(25690, 960, 1, 1, 2, 158589.782024), -- Scroll: Enchant Armor (S-Grade)
(25690, 6577, 1, 1, 2, 2643.275192), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Aenkinel
(25691, 9452, 1, 1, 0, 6742.748328), -- Sealed Dynasty Earring
(25691, 9453, 1, 1, 0, 5057.21348), -- Sealed Dynasty Necklace
(25691, 9454, 1, 1, 0, 10113.818024), -- Sealed Dynasty Ring
(25691, 9991, 2, 4, 0, 159359.769072), -- Sealed Dynasty Earring Gemstone
(25691, 9992, 2, 6, 0, 91728.292232), -- Sealed Dynasty Necklace Gemstone
(25691, 9993, 1, 3, 0, 335934.158864), -- Sealed Dynasty Ring Gemstone
(25691, 9442, 1, 1, 1, 544.127377), -- Dynasty Sword
(25691, 9443, 1, 1, 1, 544.127377), -- Dynasty Blade
(25691, 9444, 1, 1, 1, 544.127377), -- Dynasty Phantom
(25691, 9616, 1, 1, 1, 170082.03533), -- Dynasty Sword Piece
(25691, 9617, 1, 1, 1, 170082.03533), -- Dynasty Blade Piece
(25691, 9618, 1, 1, 1, 170082.547209), -- Dynasty Phantom Piece
(25691, 959, 1, 1, 2, 15858.942784), -- Scroll: Enchant Weapon (S-Grade)
(25691, 960, 1, 1, 2, 158589.782024), -- Scroll: Enchant Armor (S-Grade)
(25691, 6577, 1, 1, 2, 2643.275192), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Aenkinel
(25692, 9452, 1, 1, 0, 6742.748328), -- Sealed Dynasty Earring
(25692, 9453, 1, 1, 0, 5057.21348), -- Sealed Dynasty Necklace
(25692, 9454, 1, 1, 0, 10113.818024), -- Sealed Dynasty Ring
(25692, 9991, 2, 4, 0, 159359.769072), -- Sealed Dynasty Earring Gemstone
(25692, 9992, 2, 6, 0, 91728.292232), -- Sealed Dynasty Necklace Gemstone
(25692, 9993, 1, 3, 0, 335934.158864), -- Sealed Dynasty Ring Gemstone
(25692, 9442, 1, 1, 1, 544.127377), -- Dynasty Sword
(25692, 9443, 1, 1, 1, 544.127377), -- Dynasty Blade
(25692, 9444, 1, 1, 1, 544.127377), -- Dynasty Phantom
(25692, 9616, 1, 1, 1, 170082.03533), -- Dynasty Sword Piece
(25692, 9617, 1, 1, 1, 170082.03533), -- Dynasty Blade Piece
(25692, 9618, 1, 1, 1, 170082.547209), -- Dynasty Phantom Piece
(25692, 959, 1, 1, 2, 15858.942784), -- Scroll: Enchant Weapon (S-Grade)
(25692, 960, 1, 1, 2, 158589.782024), -- Scroll: Enchant Armor (S-Grade)
(25692, 6577, 1, 1, 2, 2643.275192), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Aenkinel
(25693, 9452, 1, 1, 0, 6742.748328), -- Sealed Dynasty Earring
(25693, 9453, 1, 1, 0, 5057.21348), -- Sealed Dynasty Necklace
(25693, 9454, 1, 1, 0, 10113.818024), -- Sealed Dynasty Ring
(25693, 9991, 2, 4, 0, 159359.769072), -- Sealed Dynasty Earring Gemstone
(25693, 9992, 2, 6, 0, 91728.292232), -- Sealed Dynasty Necklace Gemstone
(25693, 9993, 1, 3, 0, 335934.158864), -- Sealed Dynasty Ring Gemstone
(25693, 9442, 1, 1, 1, 544.127377), -- Dynasty Sword
(25693, 9443, 1, 1, 1, 544.127377), -- Dynasty Blade
(25693, 9444, 1, 1, 1, 544.127377), -- Dynasty Phantom
(25693, 9616, 1, 1, 1, 170082.03533), -- Dynasty Sword Piece
(25693, 9617, 1, 1, 1, 170082.03533), -- Dynasty Blade Piece
(25693, 9618, 1, 1, 1, 170082.547209), -- Dynasty Phantom Piece
(25693, 959, 1, 1, 2, 15858.942784), -- Scroll: Enchant Weapon (S-Grade)
(25693, 960, 1, 1, 2, 158589.782024), -- Scroll: Enchant Armor (S-Grade)
(25693, 6577, 1, 1, 2, 2643.275192), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Aenkinel
(25694, 9452, 1, 1, 0, 46794.620766), -- Sealed Dynasty Earring
(25694, 9453, 1, 1, 0, 35096.086984), -- Sealed Dynasty Necklace
(25694, 9454, 1, 1, 0, 70191.68833), -- Sealed Dynasty Ring
(25694, 9991, 9, 27, 0, 184327.788004), -- Sealed Dynasty Earring Gemstone
(25694, 9992, 14, 42, 0, 90943.00007), -- Sealed Dynasty Necklace Gemstone
(25694, 9993, 40, 120, 0, 58284.815846), -- Sealed Dynasty Ring Gemstone
(25694, 9442, 1, 1, 1, 3776.237325), -- Dynasty Sword
(25694, 9443, 1, 1, 1, 3776.237325), -- Dynasty Blade
(25694, 9444, 1, 1, 1, 3776.237325), -- Dynasty Phantom
(25694, 9616, 5, 15, 1, 118022.23815), -- Dynasty Sword Piece
(25694, 9617, 9, 27, 1, 65567.964525), -- Dynasty Blade Piece
(25694, 9618, 2, 6, 1, 295056.08535), -- Dynasty Phantom Piece
(25694, 959, 1, 1, 2, 110060.97102), -- Scroll: Enchant Weapon (S-Grade)
(25694, 960, 1, 3, 2, 550305.53381), -- Scroll: Enchant Armor (S-Grade)
(25694, 6577, 1, 1, 2, 18343.49517), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25694, 15341, 1, 3, 2, 1000000), -- Guiding Tea Leaves
-- Aenkinel
(25695, 9452, 1, 1, 0, 54884.079987), -- Sealed Dynasty Earring
(25695, 9453, 1, 1, 0, 41163.202388), -- Sealed Dynasty Necklace
(25695, 9454, 1, 1, 0, 82325.835185), -- Sealed Dynasty Ring
(25695, 9991, 9, 27, 0, 216192.820778), -- Sealed Dynasty Earring Gemstone
(25695, 9992, 14, 42, 0, 106664.458615), -- Sealed Dynasty Necklace Gemstone
(25695, 9993, 40, 120, 0, 68360.603047), -- Sealed Dynasty Ring Gemstone
(25695, 10215, 1, 1, 1, 3209.028356), -- Icarus Sawsword
(25695, 10217, 1, 1, 1, 3209.028356), -- Icarus Spirit
(25695, 10218, 1, 1, 1, 3209.028356), -- Icarus Heavy Arms
(25695, 10397, 5, 15, 1, 106723.072294), -- Icarus Sawsword Piece
(25695, 10399, 2, 4, 1, 355744.558376), -- Icarus Spirit Piece
(25695, 10400, 2, 6, 1, 265952.284262), -- Icarus Heavy Arms Piece
(25695, 959, 1, 1, 2, 129087.276318), -- Scroll: Enchant Weapon (S-Grade)
(25695, 960, 1, 3, 2, 645437.177629), -- Scroll: Enchant Armor (S-Grade)
(25695, 6577, 1, 1, 2, 21514.546053), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25695, 15341, 2, 3, 2, 1000000), -- Guiding Tea Leaves
-- Taklacan
(25696, 14105, 1, 1, 0, 3128.106327), -- Sealed Vesper Breastplate
(25696, 14108, 1, 1, 0, 5004.893673), -- Sealed Vesper Gaiters
(25696, 13457, 1, 1, 1, 1018.332315), -- Vesper Cutter
(25696, 13458, 1, 1, 1, 1018.332315), -- Vesper Slasher
(25696, 13459, 1, 1, 1, 1018.33537), -- Vesper Buster
(25696, 959, 1, 1, 2, 18923.322672), -- Scroll: Enchant Weapon (S-Grade)
(25696, 960, 1, 1, 2, 189233.649342), -- Scroll: Enchant Armor (S-Grade)
(25696, 6577, 1, 1, 2, 3154.027986), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Torumba
(25697, 14106, 1, 1, 0, 7847.908904), -- Sealed Vesper Leather Breastplate
(25697, 14112, 1, 1, 0, 12556.091096), -- Sealed Vesper Leather Leggings
(25697, 13467, 1, 1, 1, 5748), -- Vesper Thrower
(25697, 6577, 1, 1, 2, 8901.536575), -- Blessed Scroll: Enchant Weapon (S-Grade)
(25697, 6578, 1, 1, 2, 59343.463425), -- Blessed Scroll: Enchant Armor (S-Grade)
-- Dopagen
(25698, 14107, 1, 1, 0, 3944.33963), -- Sealed Vesper Tunic
(25698, 14115, 1, 1, 0, 6310.66037), -- Sealed Vesper Stockings
(25698, 13463, 1, 1, 1, 722.25), -- Vesper Avenger
(25698, 13464, 1, 1, 1, 722.25), -- Vesper Retributer
(25698, 13465, 1, 1, 1, 722.25), -- Vesper Caster
(25698, 13466, 1, 1, 1, 722.25), -- Vesper Singer
(25698, 959, 1, 1, 2, 17895.982128), -- Scroll: Enchant Weapon (S-Grade)
(25698, 960, 1, 1, 2, 178960.220958), -- Scroll: Enchant Armor (S-Grade)
(25698, 6577, 1, 1, 2, 2982.796914), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Glakias
(25699, 14109, 1, 1, 0, 9279.351892), -- Sealed Vesper Gauntlet
(25699, 14113, 1, 1, 0, 9279.351892), -- Sealed Vesper Leather Gloves
(25699, 14116, 1, 1, 0, 9279.351892), -- Sealed Vesper Gloves
(25699, 14110, 1, 1, 0, 9279.351892), -- Sealed Vesper Boots
(25699, 14114, 1, 1, 0, 9279.351892), -- Sealed Vesper Leather Boots
(25699, 14117, 1, 1, 0, 9279.24054), -- Sealed Vesper Shoes
(25699, 14160, 1, 1, 1, 28505.202264), -- Sealed Vesper Earring
(25699, 14161, 1, 1, 1, 21378.901698), -- Sealed Vesper Necklace
(25699, 14162, 1, 1, 1, 42757.896038), -- Sealed Vesper Ring
(25699, 959, 1, 1, 2, 63153.209574), -- Scroll: Enchant Weapon (S-Grade)
(25699, 960, 1, 1, 2, 631532.790426), -- Scroll: Enchant Armor (S-Grade)
-- Glakias
(25700, 13143, 1, 1, 0, 10079.846548), -- Sealed Vesper Helmet
(25700, 13144, 1, 1, 0, 10079.846548), -- Sealed Vesper Leather Helmet
(25700, 13145, 1, 1, 0, 10079.846548), -- Sealed Vesper Circlet
(25700, 14111, 1, 1, 0, 14399.730178), -- Sealed Vesper Shield
(25700, 13887, 1, 1, 0, 14399.730178), -- Sealed Vesper Sigil
(25700, 14160, 1, 1, 1, 38703.653604), -- Sealed Vesper Earring
(25700, 14161, 1, 1, 1, 29027.740203), -- Sealed Vesper Necklace
(25700, 14162, 1, 1, 1, 58055.606193), -- Sealed Vesper Ring
(25700, 959, 1, 1, 2, 85748.277888), -- Scroll: Enchant Weapon (S-Grade)
(25700, 960, 1, 1, 2, 857483.722112), -- Scroll: Enchant Armor (S-Grade)
-- Anais
(25701, 14109, 1, 1, 0, 8472.45588), -- Sealed Vesper Gauntlet
(25701, 14113, 1, 1, 0, 8472.45588), -- Sealed Vesper Leather Gloves
(25701, 14116, 1, 1, 0, 8472.45588), -- Sealed Vesper Gloves
(25701, 14110, 1, 1, 0, 8472.45588), -- Sealed Vesper Boots
(25701, 14114, 1, 1, 0, 8472.45588), -- Sealed Vesper Leather Boots
(25701, 14117, 1, 1, 0, 8472.45588), -- Sealed Vesper Shoes
(25701, 15484, 1, 1, 0, 197697.26472), -- High-level Angel Circlet
(25701, 13143, 1, 1, 1, 11861.776432), -- Sealed Vesper Helmet
(25701, 13144, 1, 1, 1, 11861.776432), -- Sealed Vesper Leather Helmet
(25701, 13145, 1, 1, 1, 11861.776432), -- Sealed Vesper Circlet
(25701, 14111, 1, 1, 1, 16945.335352), -- Sealed Vesper Shield
(25701, 13887, 1, 1, 1, 16945.335352), -- Sealed Vesper Sigil
(25701, 959, 1, 1, 2, 44847.731152), -- Scroll: Enchant Weapon (S-Grade)
(25701, 960, 1, 1, 2, 448478.313122), -- Scroll: Enchant Armor (S-Grade)
(25701, 6577, 1, 1, 2, 7474.955726), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Gigantic Golem
(25703, 6364, 1, 1, 0, 4782), -- Forgotten Blade
(25703, 6372, 1, 1, 0, 4782), -- Heaven's Divider
(25703, 6366, 1, 1, 1, 3586.75), -- Imperial Staff
(25703, 6369, 1, 1, 1, 3586.75), -- Dragon Hunter Axe
(25703, 6365, 1, 1, 1, 3586.75), -- Basalt Battlehammer
(25703, 6579, 1, 1, 1, 3586.75), -- Arcana Mace
(25703, 959, 1, 1, 2, 39760.960239), -- Scroll: Enchant Weapon (S-Grade)
(25703, 960, 1, 1, 2, 397610.039761), -- Scroll: Enchant Armor (S-Grade)
-- Lost Captain
(25710, 15766, 1, 1, 0, 92325.462255), -- Sealed Moirai Ring
(25710, 15767, 1, 1, 0, 61542.907171), -- Sealed Moirai Earring
(25710, 15768, 1, 1, 0, 46158.630574), -- Sealed Moirai Necklace
(25710, 10219, 1, 1, 1, 14674), -- Icarus Trident
(25710, 959, 1, 1, 2, 147566.461799), -- Scroll: Enchant Weapon (S-Grade)
(25710, 960, 1, 3, 2, 737830.538201), -- Scroll: Enchant Armor (S-Grade)
-- Darnel
(25713, 15694, 1, 1, 0, 7682.472801), -- Sealed Moirai Helmet 
(25713, 15695, 1, 1, 0, 7682.472801), -- Sealed Moirai Leather Helmet 
(25713, 15696, 1, 1, 0, 7682.472801), -- Sealed Moirai Circlet 
(25713, 15710, 1, 1, 0, 10974.813297), -- Sealed Moirai Shield 
(25713, 15709, 1, 1, 0, 10974.7683), -- Sealed Moirai Sigil 
(25713, 10223, 1, 1, 1, 4689), -- Icarus Spitter
(25713, 959, 1, 1, 2, 47155.498299), -- Scroll: Enchant Weapon (S-Grade)
(25713, 960, 1, 1, 2, 471555.501701), -- Scroll: Enchant Armor (S-Grade)
-- Kechi
(25714, 15703, 1, 1, 0, 7378.014756), -- Sealed Moirai Gauntlet 
(25714, 15704, 1, 1, 0, 7378.014756), -- Sealed Moirai Leather Gloves 
(25714, 15705, 1, 1, 0, 7378.014756), -- Sealed Moirai Gloves 
(25714, 15706, 1, 1, 0, 7378.014756), -- Sealed Moirai Boots 
(25714, 15707, 1, 1, 0, 7378.014756), -- Sealed Moirai Leather Boots 
(25714, 15708, 1, 1, 0, 7377.92622), -- Sealed Moirai Shoes 
(25714, 10222, 1, 1, 1, 1801.5), -- Icarus Hall
(25714, 10220, 1, 1, 1, 1801.5), -- Icarus Hammer
(25714, 959, 1, 1, 2, 36230.145588), -- Scroll: Enchant Weapon (S-Grade)
(25714, 960, 1, 1, 2, 362301.854412), -- Scroll: Enchant Armor (S-Grade)
-- Tears
(25716, 15698, 1, 1, 0, 10162.93464), -- Sealed Moirai Leather Breastplate 
(25716, 15701, 1, 1, 0, 16261.06536), -- Sealed Moirai Leather Legging 
(25716, 10223, 1, 1, 1, 4963), -- Icarus Spitter
(25716, 6578, 1, 1, 2, 55453.087404), -- Blessed Scroll: Enchant Armor (S-Grade)
(25716, 6570, 1, 1, 2, 138632.912596), -- Blessed Scroll: Enchant Armor (A-Grade)
-- Queen Ant
(29001, 2499, 1, 1, 0, 60000), -- Elven Long Sword
(29001, 70, 1, 1, 0, 60000), -- Claymore
(29001, 159, 1, 1, 0, 55000), -- Bonebreaker
(29001, 189, 1, 1, 0, 55000), -- Staff of Life
(29001, 188, 1, 1, 0, 55000), -- Ghost Staff
(29001, 225, 1, 1, 0, 55000), -- Mithril Dagger
(29001, 262, 1, 1, 0, 50000), -- Scallop Jamadhr
(29001, 280, 1, 1, 0, 55000), -- Light Crossbow
(29001, 297, 1, 1, 0, 55000), -- Glaive
(29001, 851, 1, 2, 1, 350000), -- Omen Beast's Eye Earring
(29001, 914, 1, 2, 1, 300000), -- Necklace of Darkness
(29001, 882, 1, 2, 1, 350000), -- Mithril Ring
(29001, 353, 1, 2, 2, 375000), -- Half Plate Armor
(29001, 380, 1, 2, 2, 375000), -- Plate Gaiters
(29001, 396, 1, 2, 3, 425000), -- Salamander Skin Mail
(29001, 438, 1, 2, 3, 425000), -- Sage's Rag
(29001, 2412, 1, 3, 4, 200000), -- Plate Helmet
(29001, 1125, 1, 3, 4, 200000), -- Assault Boots
(29001, 607, 1, 3, 4, 200000), -- Ogre Power Gauntlets
(29001, 630, 1, 3, 4, 200000), -- Square Shield
(29001, 955, 1, 3, 4, 200000), -- Scroll: Enchant Weapon (D-Grade)
(29001, 57, 140000, 170000, 5, 1000000), -- Adena
(29001, 57, 140000, 170000, 6, 1000000), -- Adena
(29001, 57, 140000, 170000, 7, 1000000), -- Adena
(29001, 57, 140000, 170000, 8, 1000000), -- Adena
(29001, 57, 140000, 170000, 9, 1000000), -- Adena
(29001, 57, 140000, 170000, 10, 1000000), -- Adena
(29001, 57, 120000, 150000, 11, 1000000), -- Adena
(29001, 6660, 1, 1, 12, 300000), -- Ring of Queen Ant
-- Core
(29006, 75, 1, 1, 0, 48000), -- Caliburs
(29006, 84, 1, 1, 0, 40000), -- Homunkulus's Sword
(29006, 162, 1, 1, 0, 48000), -- War Axe
(29006, 174, 1, 1, 0, 40000), -- Nirvana Axe
(29006, 200, 1, 1, 0, 40000), -- Sage's Staff
(29006, 233, 1, 1, 0, 48000), -- Dark Screamer
(29006, 265, 1, 1, 0, 40000), -- Fisted Blade
(29006, 283, 1, 1, 0, 48000), -- Akat Long Bow
(29006, 301, 1, 1, 0, 48000), -- Scorpion
(29006, 60, 1, 1, 1, 120000), -- Composite Armor
(29006, 400, 1, 1, 1, 120000), -- Theca Leather Armor
(29006, 420, 1, 1, 1, 120000), -- Theca Leather Gaiters
(29006, 441, 1, 1, 1, 120000), -- Demon's Tunic
(29006, 472, 1, 1, 1, 120000), -- Demon's Stockings
(29006, 517, 1, 1, 2, 140000), -- Composite Helmet
(29006, 2435, 1, 1, 2, 140000), -- Demon's Boots
(29006, 2459, 1, 1, 2, 140000), -- Demon's Gloves
(29006, 107, 1, 1, 2, 140000), -- Composite Shield
(29006, 951, 1, 1, 2, 140000), -- Scroll: Enchant Weapon (C-Grade)
(29006, 57, 100000, 150000, 3, 1000000), -- Adena
(29006, 57, 100000, 150000, 4, 1000000), -- Adena
(29006, 57, 100000, 150000, 5, 1000000), -- Adena
(29006, 57, 100000, 150000, 6, 1000000), -- Adena
(29006, 57, 100000, 150000, 7, 1000000), -- Adena
(29006, 8744, 2, 4, 8, 450000), -- High-Grade Life Stone - Level 49
(29006, 8745, 2, 4, 8, 400000), -- High-Grade Life Stone - Level 52
(29006, 8754, 1, 2, 8, 100000), -- Top-Grade Life Stone - Level 49
(29006, 8755, 1, 2, 8, 50000), -- Top-Grade Life Stone - Level 52
(29006, 6662, 1, 1, 9, 300000), -- Ring of Core
-- Orfen
(29014, 76, 1, 1, 0, 42000), -- Sword of Delusion
(29014, 145, 1, 1, 0, 35000), -- Sword of Whispering Death
(29014, 162, 1, 1, 0, 42000), -- War Axe
(29014, 201, 1, 1, 0, 35000), -- Club of Nature
(29014, 199, 1, 1, 0, 35000), -- Pa'agrian Hammer
(29014, 231, 1, 1, 0, 42000), -- Grace Dagger
(29014, 265, 1, 1, 0, 35000), -- Fisted Blade
(29014, 283, 1, 1, 0, 42000), -- Akat Long Bow
(29014, 303, 1, 1, 0, 42000), -- Widow Maker
(29014, 854, 1, 2, 1, 350000), -- Earring of Seal
(29014, 917, 1, 2, 1, 300000), -- Necklace of Mermaid
(29014, 885, 1, 2, 1, 350000), -- Ring of Ages
(29014, 60, 1, 1, 2, 100000), -- Composite Armor
(29014, 400, 1, 1, 2, 100000), -- Theca Leather Armor
(29014, 420, 1, 1, 2, 100000), -- Theca Leather Gaiters
(29014, 441, 1, 1, 2, 100000), -- Demon's Tunic
(29014, 472, 1, 1, 2, 100000), -- Demon's Stockings
(29014, 517, 1, 2, 3, 100000), -- Composite Helmet
(29014, 64, 1, 2, 3, 100000), -- Composite Boots
(29014, 608, 1, 2, 3, 100000), -- Mithril Gauntlets
(29014, 103, 1, 2, 3, 100000), -- Tower Shield
(29014, 951, 1, 2, 3, 100000), -- Scroll: Enchant Weapon (C-Grade)
(29014, 57, 110000, 150000, 4, 1000000), -- Adena
(29014, 57, 110000, 150000, 5, 1000000), -- Adena
(29014, 57, 110000, 150000, 6, 1000000), -- Adena
(29014, 57, 110000, 150000, 7, 1000000), -- Adena
(29014, 57, 110000, 150000, 8, 1000000), -- Adena
(29014, 8744, 2, 4, 9, 450000), -- High-Grade Life Stone - Level 49
(29014, 8745, 2, 4, 9, 400000), -- High-Grade Life Stone - Level 52
(29014, 8754, 1, 2, 9, 100000), -- Top-Grade Life Stone - Level 49
(29014, 8755, 1, 2, 9, 50000), -- Top-Grade Life Stone - Level 52
(29014, 6661, 1, 1, 10, 300000), -- Earring of Orfen
-- Antharas
(29019, 80, 1, 2, 0, 250000), -- Tallum Blade
(29019, 98, 1, 2, 0, 250000), -- Halberd
(29019, 269, 1, 2, 0, 250000), -- Blood Tornado
(29019, 2504, 1, 2, 0, 250000), -- Meteor Shower
(29019, 235, 1, 2, 1, 250000), -- Bloody Orchid
(29019, 288, 1, 2, 1, 250000), -- Carnage Bow
(29019, 150, 1, 2, 1, 250000), -- Elemental Sword
(29019, 212, 1, 2, 1, 250000), -- Dasparion's Staff
(29019, 81, 1, 2, 2, 250000), -- Dragon Slayer
(29019, 151, 1, 2, 2, 250000), -- Sword of Miracles
(29019, 2500, 1, 2, 2, 250000), -- Dark Legion's Edge
(29019, 164, 1, 2, 2, 250000), -- Elysian
(29019, 236, 1, 2, 3, 200000), -- Soul Separator
(29019, 270, 1, 2, 3, 200000), -- Dragon Grinder
(29019, 289, 1, 2, 3, 200000), -- Soul Bow
(29019, 213, 1, 2, 3, 200000), -- Branch of the Mother Tree
(29019, 305, 1, 2, 3, 200000), -- Tallum Glaive
(29019, 6364, 1, 1, 4, 170000), -- Forgotten Blade
(29019, 6365, 1, 1, 4, 170000), -- Basalt Battlehammer
(29019, 6369, 1, 1, 4, 170000), -- Dragon Hunter Axe
(29019, 6370, 1, 1, 4, 170000), -- Saint Spear
(29019, 6372, 1, 1, 4, 160000), -- Heaven's Divider
(29019, 6580, 1, 1, 4, 160000), -- Tallum Blade*Dark Legion's Edge
(29019, 7575, 1, 1, 5, 200000), -- Draconic Bow
(29019, 6366, 1, 1, 5, 200000), -- Imperial Staff
(29019, 6367, 1, 1, 5, 200000), -- Angel Slayer
(29019, 6371, 1, 1, 5, 200000), -- Demon Splinter
(29019, 6579, 1, 1, 5, 200000), -- Arcana Mace
(29019, 6326, 1, 5, 6, 300000), -- Sealed Majestic Necklace
(29019, 6327, 1, 5, 6, 350000), -- Sealed Majestic Earring
(29019, 6328, 1, 5, 6, 350000), -- Sealed Majestic Ring
(29019, 6323, 1, 5, 7, 300000), -- Sealed Phoenix Necklace
(29019, 6324, 1, 5, 7, 350000), -- Sealed Phoenix Earring
(29019, 6325, 1, 5, 7, 350000), -- Sealed Phoenix Ring
(29019, 6724, 1, 1, 8, 350000), -- Sealed Tateossian Earring
(29019, 6725, 1, 1, 8, 350000), -- Sealed Tateossian Ring
(29019, 6726, 1, 1, 8, 300000), -- Sealed Tateossian Necklace
(29019, 5287, 1, 3, 9, 500000), -- Sealed Dark Crystal breastplate
(29019, 5297, 1, 3, 9, 250000), -- Sealed Dark Crystal Leather Armor
(29019, 5304, 1, 3, 9, 250000), -- Sealed Tallum Tunic
(29019, 5311, 1, 3, 10, 350000), -- Sealed Armor of Nightmare
(29019, 5320, 1, 3, 10, 350000), -- Sealed Leather Armor of Nightmare
(29019, 5326, 1, 3, 10, 300000), -- Sealed Robe of Nightmare
(29019, 5293, 1, 3, 11, 250000), -- Sealed Tallum Plate Armor
(29019, 5301, 1, 3, 11, 250000), -- Sealed Tallum Leather Armor
(29019, 5308, 1, 3, 11, 250000), -- Sealed Dark Crystal Robe
(29019, 5316, 1, 3, 11, 80000), -- Sealed Majestic Plate Armor
(29019, 5323, 1, 3, 11, 80000), -- Sealed Majestic Leather Armor
(29019, 5329, 1, 3, 11, 90000), -- Sealed Majestic Robe
(29019, 5288, 1, 3, 12, 350000), -- Sealed Dark Crystal Gaiters
(29019, 5298, 1, 3, 12, 350000), -- Sealed Dark Crystal Leggings
(29019, 5305, 1, 3, 12, 300000), -- Sealed Tallum Stockings
(29019, 6674, 1, 1, 13, 150000), -- Sealed Imperial Crusader Breastplate
(29019, 6675, 1, 1, 13, 150000), -- Sealed Imperial Crusader Gaiters
(29019, 6680, 1, 1, 13, 350000), -- Sealed Draconic Leather Armor
(29019, 6684, 1, 1, 13, 350000), -- Sealed Major Arcana Robe
(29019, 5289, 1, 3, 14, 250000), -- Sealed Dark Crystal Helmet
(29019, 5294, 1, 3, 14, 250000), -- Sealed Tallum Helmet
(29019, 5312, 1, 3, 14, 250000), -- Sealed Helm of Nightmare
(29019, 5317, 1, 3, 14, 250000), -- Sealed Majestic Circlet
(29019, 5291, 1, 3, 15, 250000), -- Sealed Dark Crystal Boots
(29019, 5296, 1, 3, 15, 250000), -- Sealed Tallum Boots
(29019, 5314, 1, 3, 15, 250000), -- Sealed Boots of Nightmare
(29019, 5319, 1, 3, 15, 250000), -- Sealed Majestic Boots
(29019, 5290, 1, 3, 16, 250000), -- Sealed Dark Crystal Gloves
(29019, 5295, 1, 3, 16, 250000), -- Sealed Tallum Gloves
(29019, 5313, 1, 3, 16, 250000), -- Sealed Gauntlets of Nightmare
(29019, 5318, 1, 3, 16, 250000), -- Sealed Majestic Gauntlets
(29019, 5292, 1, 3, 17, 400000), -- Sealed Dark Crystal Shield
(29019, 5315, 1, 3, 17, 400000), -- Sealed Shield of Nightmare
(29019, 6678, 1, 1, 17, 200000), -- Sealed Imperial Crusader Shield
(29019, 6676, 1, 1, 18, 340000), -- Sealed Imperial Crusader Gauntlet
(29019, 6681, 1, 1, 18, 330000), -- Sealed Draconic Leather Glove
(29019, 6685, 1, 1, 18, 330000), -- Sealed Major Arcana Glove
(29019, 6677, 1, 1, 19, 340000), -- Sealed Imperial Crusader Boots
(29019, 6682, 1, 1, 19, 330000), -- Sealed Draconic Leather Boots
(29019, 6686, 1, 1, 19, 330000), -- Sealed Major Arcana Boots
(29019, 6679, 1, 1, 20, 340000), -- Sealed Imperial Crusader Helmet
(29019, 6683, 1, 1, 20, 330000), -- Sealed Draconic Leather Helmet
(29019, 6687, 1, 1, 20, 330000), -- Sealed Major Arcana Circlet
(29019, 729, 1, 19, 21, 1000000), -- Scroll: Enchant Weapon (A-Grade)
(29019, 1538, 1, 59, 22, 1000000), -- Blessed Scroll of Escape
(29019, 3936, 1, 39, 23, 1000000), -- Blessed Scroll of Resurrection
(29019, 57, 14000000, 18000000, 24, 1000000), -- Adena
(29019, 57, 14000000, 18000000, 25, 1000000), -- Adena
(29019, 57, 14000000, 18000000, 26, 1000000), -- Adena
(29019, 57, 14000000, 18000000, 27, 1000000), -- Adena
(29019, 57, 14000000, 18000000, 28, 1000000), -- Adena
(29019, 57, 14000000, 18000000, 29, 1000000), -- Adena
(29019, 57, 9000000, 13000000, 30, 1000000), -- Adena
(29019, 6656, 1, 1, 31, 1000000), -- Earring of Antharas
(29019, 8620, 10, 30, 32, 500000), -- Ancient Book: Divine Inspiration (Manuscript)
(29019, 13893, 1, 2, 32, 500000), -- Sealed Holy Spirit's Cloak
-- Baium
(29020, 80, 1, 1, 0, 60000), -- Tallum Blade
(29020, 98, 1, 1, 0, 60000), -- Halberd
(29020, 288, 1, 1, 0, 60000), -- Carnage Bow
(29020, 150, 1, 1, 0, 60000), -- Elemental Sword
(29020, 6364, 1, 1, 0, 12000), -- Forgotten Blade
(29020, 6365, 1, 1, 0, 12000), -- Basalt Battlehammer
(29020, 6580, 1, 1, 0, 9000), -- Tallum Blade*Dark Legion's Edge
(29020, 6367, 1, 1, 0, 9000), -- Angel Slayer
(29020, 6369, 1, 1, 0, 9000), -- Dragon Hunter Axe
(29020, 6370, 1, 1, 0, 9000), -- Saint Spear
(29020, 269, 1, 1, 1, 60000), -- Blood Tornado
(29020, 2504, 1, 1, 1, 60000), -- Meteor Shower
(29020, 235, 1, 1, 1, 60000), -- Bloody Orchid
(29020, 212, 1, 1, 1, 60000), -- Dasparion's Staff
(29020, 7575, 1, 1, 1, 12000), -- Draconic Bow
(29020, 6366, 1, 1, 1, 12000), -- Imperial Staff
(29020, 6371, 1, 1, 1, 12000), -- Demon Splinter
(29020, 6579, 1, 1, 1, 12000), -- Arcana Mace
(29020, 6372, 1, 1, 1, 12000), -- Heaven's Divider
(29020, 8751, 1, 2, 2, 450000), -- High-Grade Life Stone - Level 70
(29020, 8752, 1, 2, 2, 400000), -- High-Grade Life Stone - Level 76
(29020, 8761, 1, 1, 2, 100000), -- Top-Grade Life Stone - Level 70
(29020, 8762, 1, 1, 2, 50000), -- Top-Grade Life Stone - Level 76
(29020, 6658, 1, 1, 3, 1000000), -- Ring of Baium
(29020, 8620, 5, 15, 4, 1000000), -- Ancient Book: Divine Inspiration (Manuscript)
-- Zaken
(29022, 135, 1, 1, 0, 48000), -- Samurai Longsword
(29022, 204, 1, 1, 0, 12000), -- Deadman's Staff
(29022, 205, 1, 1, 0, 12000), -- Ghoul's Staff
(29022, 206, 1, 1, 0, 15000), -- Demon's Staff
(29022, 228, 1, 1, 0, 48000), -- Crystal Dagger
(29022, 266, 1, 1, 0, 30000), -- Great Pata
(29022, 286, 1, 1, 0, 39000), -- Eminence Bow
(29022, 299, 1, 1, 0, 30000), -- Orcish Poleaxe
(29022, 2503, 1, 1, 0, 36000), -- Yaksa Mace
(29022, 5286, 1, 1, 0, 30000), -- Berserker Blade
(29022, 78, 1, 1, 1, 10000), -- Great Sword
(29022, 91, 1, 1, 1, 12000), -- Heavy War Axe
(29022, 92, 1, 1, 1, 13000), -- Sprite's Staff
(29022, 142, 1, 1, 1, 8000), -- Keshanberk
(29022, 148, 1, 1, 1, 8000), -- Sword of Valhalla
(29022, 229, 1, 1, 1, 8000), -- Kris
(29022, 243, 1, 1, 1, 8000), -- Hell Knife
(29022, 267, 1, 1, 1, 10000), -- Arthro Nail
(29022, 284, 1, 1, 1, 13000), -- Dark Elven Long Bow
(29022, 300, 1, 1, 1, 10000), -- Great Axe
(29022, 357, 1, 1, 2, 50000), -- Zubei's Breastplate
(29022, 2384, 1, 1, 2, 50000), -- Zubei's Leather Shirt
(29022, 2376, 1, 1, 2, 50000), -- Avadon Breastplate
(29022, 2397, 1, 1, 2, 50000), -- Tunic of Zubei
(29022, 383, 1, 1, 3, 50000), -- Zubei's Gaiters
(29022, 2379, 1, 1, 3, 50000), -- Avadon Gaiters
(29022, 2388, 1, 1, 3, 50000), -- Zubei's Leather Gaiters
(29022, 2402, 1, 1, 3, 50000), -- Stockings of Zubei
(29022, 2390, 1, 1, 4, 100000), -- Avadon Leather Armor
(29022, 2406, 1, 1, 4, 100000), -- Avadon Robe
(29022, 503, 1, 1, 5, 30000), -- Zubei's Helmet
(29022, 554, 1, 1, 5, 30000), -- Sealed Zubei's Boots
(29022, 600, 1, 1, 5, 30000), -- Sealed Avadon Boots
(29022, 612, 1, 1, 5, 30000), -- Sealed Zubei's Gauntlets
(29022, 633, 1, 1, 5, 30000), -- Zubei's Shield
(29022, 673, 1, 1, 5, 30000), -- Avadon Shield
(29022, 2415, 1, 1, 5, 30000), -- Avadon Circlet
(29022, 2464, 1, 1, 5, 30000), -- Sealed Avadon Gloves
(29022, 947, 1, 1, 5, 60000), -- Scroll: Enchant Weapon (B-Grade)
(29022, 57, 180000, 220000, 6, 1000000), -- Adena
(29022, 57, 180000, 220000, 7, 1000000), -- Adena
(29022, 57, 180000, 220000, 8, 1000000), -- Adena
(29022, 57, 180000, 220000, 9, 1000000), -- Adena
(29022, 57, 180000, 220000, 10, 1000000), -- Adena
(29022, 57, 180000, 220000, 11, 1000000), -- Adena
(29022, 57, 180000, 220000, 12, 1000000), -- Adena
(29022, 6659, 1, 1, 13, 850000), -- Earring of Zaken
(29022, 8747, 2, 4, 14, 450000), -- High-Grade Life Stone - Level 58
(29022, 8748, 2, 4, 14, 400000), -- High-Grade Life Stone - Level 61
(29022, 8757, 1, 2, 14, 100000), -- Top-Grade Life Stone - Level 58
(29022, 8758, 1, 2, 14, 50000), -- Top-Grade Life Stone - Level 61
(29022, 8922, 1, 1, 15, 10000), -- Pirate Hat
-- Doll Blader
(29023, 1061, 4, 8, 0, 200000), -- Greater Healing Potion
-- Veil Master
(29024, 1061, 4, 8, 0, 200000), -- Greater Healing Potion
-- Pirate Zombie Captain
(29026, 1061, 4, 8, 0, 200000), -- Greater Healing Potion
-- Pirate Zombie
(29027, 1061, 4, 8, 0, 200000), -- Greater Healing Potion
-- Valakas
(29028, 15560, 1, 1, 0, 63700), -- Vigwik Axe
(29028, 15561, 1, 1, 0, 63630), -- Devilish Maul
(29028, 15562, 1, 1, 0, 63630), -- Feather Eye Blade
(29028, 15563, 1, 1, 0, 63630), -- Octo Claw
(29028, 15564, 1, 1, 0, 63630), -- Doubletop Spear
(29028, 15565, 1, 1, 0, 63630), -- Rising Star
(29028, 15566, 1, 1, 0, 63630), -- Black Visage
(29028, 15567, 1, 1, 0, 63630), -- Veniplant Sword
(29028, 15568, 1, 1, 0, 63630), -- Skull Carnium Bow
(29028, 15558, 1, 1, 0, 63630), -- Periel Sword
(29028, 15559, 1, 1, 0, 63630), -- Skull Edge
(29028, 15544, 1, 1, 1, 45450), -- Eternal Core Sword
(29028, 15545, 1, 1, 1, 45450), -- Mamba Edge
(29028, 15546, 1, 1, 1, 45450), -- Eversor Mace
(29028, 15547, 1, 1, 1, 45450), -- Contristo Hammer
(29028, 15548, 1, 1, 1, 45450), -- Lava Saw
(29028, 15549, 1, 1, 1, 45450), -- Jade Claw
(29028, 15550, 1, 1, 1, 45450), -- Demitelum
(29028, 15551, 1, 1, 1, 45450), -- Sacredium
(29028, 15552, 1, 1, 1, 45450), -- Cyclic Cane
(29028, 15553, 1, 1, 1, 45450), -- Archangel Sword
(29028, 15554, 1, 1, 1, 45450), -- Recurve Thorne Bow
(29028, 15743, 1, 1, 2, 91000), -- Sealed Vorpal Helmet
(29028, 15744, 1, 1, 2, 90900), -- Sealed Vorpal Leather Helmet
(29028, 15745, 1, 1, 2, 90900), -- Sealed Vorpal Circlet
(29028, 15752, 1, 1, 2, 90900), -- Sealed Vorpal Gauntlet
(29028, 15753, 1, 1, 2, 90900), -- Sealed Vorpal Leather Gloves
(29028, 15754, 1, 1, 2, 90900), -- Sealed Vorpal Gloves
(29028, 15755, 1, 1, 2, 90900), -- Sealed Vorpal Boots
(29028, 15756, 1, 1, 2, 90900), -- Sealed Vorpal Leather Boots
(29028, 15757, 1, 1, 2, 90900), -- Sealed Vorpal Shoes
(29028, 15758, 1, 1, 2, 90900), -- Sealed Vorpal Shield
(29028, 15759, 1, 1, 2, 90900), -- Sealed Vorpal Sigil
(29028, 15746, 1, 1, 3, 166600), -- Sealed Vorpal Breastplate
(29028, 15747, 1, 1, 3, 166600), -- Sealed Vorpal Leather Breastplate
(29028, 15748, 1, 1, 3, 166600), -- Sealed Vorpal Tunic
(29028, 15749, 1, 1, 3, 167000), -- Sealed Vorpal Gaiter
(29028, 15750, 1, 1, 3, 166600), -- Sealed Vorpal Leather Legging
(29028, 15751, 1, 1, 3, 166600), -- Sealed Vorpal Stockings
(29028, 15763, 1, 1, 4, 167000), -- Sealed Vorpal Ring
(29028, 15764, 1, 1, 4, 166500), -- Sealed Vorpal Earring
(29028, 15765, 1, 1, 4, 166500), -- Sealed Vorpal Necklace
(29028, 959, 1, 19, 5, 1000000), -- Scroll: Enchant Weapon (S-Grade)
(29028, 1538, 1, 59, 6, 1000000), -- Blessed Scroll of Escape
(29028, 3936, 1, 39, 7, 1000000), -- Blessed Scroll of Resurrection
(29028, 57, 14000000, 18000000, 8, 1000000), -- Adena
(29028, 57, 2000000, 6000000, 9, 1000000), -- Adena
(29028, 16162, 2, 4, 10, 450000), -- High-Grade Life Stone - Level 85
(29028, 16166, 2, 4, 10, 400000), -- High-Grade Life Stone - Level 86
(29028, 16163, 1, 2, 10, 100000), -- Top-Grade Life Stone - Level 85
(29028, 16167, 1, 2, 10, 50000), -- Top-Grade Life Stone - Level 86
(29028, 6657, 1, 1, 11, 1000000), -- Necklace of Valakas
(29028, 8620, 10, 30, 12, 500000), -- Ancient Book: Divine Inspiration (Manuscript)
(29028, 13893, 1, 2, 12, 500000), -- Sealed Holy Spirit's Cloak
-- Fenril Hound Kerinne
(29030, 6652, 2, 6, 0, 186738.633926), -- Scroll: Protection of Valakas
(29030, 6654, 18, 54, 0, 64839.713839), -- Scroll: Flames of Valakas
(29030, 6655, 14, 42, 0, 41682.652235), -- Scroll: Slay Valakas
-- Fenril Hound Freki
(29033, 6652, 2, 6, 0, 189406.0467), -- Scroll: Protection of Valakas
(29033, 6654, 18, 54, 0, 65765.89755), -- Scroll: Flames of Valakas
(29033, 6655, 14, 42, 0, 42278.05575), -- Scroll: Slay Valakas
-- Fenril Hound Uruz
(29036, 6652, 2, 6, 0, 192246.02306), -- Scroll: Protection of Valakas
(29036, 6654, 18, 54, 0, 66751.99909), -- Scroll: Flames of Valakas
(29036, 6655, 14, 42, 0, 42911.97785), -- Scroll: Slay Valakas
-- Fenril Hound Kinaz
(29037, 6652, 2, 6, 0, 194986.027158), -- Scroll: Protection of Valakas
(29037, 6654, 18, 54, 0, 67703.388087), -- Scroll: Flames of Valakas
(29037, 6655, 14, 42, 0, 43523.584755), -- Scroll: Slay Valakas
-- Wings of Flame, Ixion
(29040, 6652, 2, 6, 0, 197625.422228), -- Scroll: Protection of Valakas
(29040, 6654, 18, 54, 0, 68619.843442), -- Scroll: Flames of Valakas
(29040, 6655, 14, 42, 0, 44112.73433), -- Scroll: Slay Valakas
-- Scarlet van Halisha
(29047, 15743, 1, 1, 0, 63700), -- Sealed Vorpal Helmet
(29047, 15744, 1, 1, 0, 63630), -- Sealed Vorpal Leather Helmet
(29047, 15745, 1, 1, 0, 63630), -- Sealed Vorpal Circlet
(29047, 15752, 1, 1, 0, 63630), -- Sealed Vorpal Gauntlet
(29047, 15753, 1, 1, 0, 63630), -- Sealed Vorpal Leather Gloves
(29047, 15754, 1, 1, 0, 63630), -- Sealed Vorpal Gloves
(29047, 15755, 1, 1, 0, 63630), -- Sealed Vorpal Boots
(29047, 15756, 1, 1, 0, 63630), -- Sealed Vorpal Leather Boots
(29047, 15757, 1, 1, 0, 63630), -- Sealed Vorpal Shoes
(29047, 15758, 1, 1, 0, 63630), -- Sealed Vorpal Shield
(29047, 15759, 1, 1, 0, 63630), -- Sealed Vorpal Sigil
(29047, 15746, 1, 1, 1, 116900), -- Sealed Vorpal Breastplate
(29047, 15747, 1, 1, 1, 116620), -- Sealed Vorpal Leather Breastplate
(29047, 15748, 1, 1, 1, 116620), -- Sealed Vorpal Tunic
(29047, 15749, 1, 1, 1, 116620), -- Sealed Vorpal Gaiter
(29047, 15750, 1, 1, 1, 116620), -- Sealed Vorpal Leather Legging
(29047, 15751, 1, 1, 1, 116620), -- Sealed Vorpal Stockings
(29047, 13457, 1, 1, 2, 45500), -- Vesper Cutter
(29047, 13458, 1, 1, 2, 45450), -- Vesper Slasher
(29047, 13459, 1, 1, 2, 45450), -- Vesper Buster
(29047, 13460, 1, 1, 2, 45450), -- Vesper Shaper
(29047, 13466, 1, 1, 2, 45450), -- Vesper Singer
(29047, 13461, 1, 1, 2, 45450), -- Vesper Fighter
(29047, 13462, 1, 1, 2, 45450), -- Vesper Stormer
(29047, 13463, 1, 1, 2, 45450), -- Vesper Avenger
(29047, 13464, 1, 1, 2, 45450), -- Vesper Retributer
(29047, 13465, 1, 1, 2, 45450), -- Vesper Caster
(29047, 13467, 1, 1, 2, 45450), -- Vesper Thrower
(29047, 1538, 1, 30, 3, 600000), -- Blessed Scroll of Escape
(29047, 3936, 1, 10, 4, 600000), -- Blessed Scroll of Resurrection
(29047, 57, 9000000, 11000000, 5, 1000000), -- Adena
(29047, 57, 9000000, 11000000, 6, 1000000), -- Adena
(29047, 16162, 2, 4, 7, 600000), -- High-Grade Life Stone - Level 85
(29047, 16166, 2, 4, 7, 400000), -- High-Grade Life Stone - Level 86
(29047, 8191, 1, 1, 8, 300000), -- Necklace of Frintezza
(29047, 8620, 5, 25, 9, 600000), -- Ancient Book: Divine Inspiration (Manuscript)
(29047, 13893, 1, 1, 9, 400000), -- Sealed Holy Spirit's Cloak
-- Benom
(29054, 6674, 1, 1, 0, 17879.70348), -- Sealed Imperial Crusader Breastplate
(29054, 6675, 1, 1, 0, 28535.160216), -- Sealed Imperial Crusader Gaiters
(29054, 6701, 8, 22, 0, 453747.82434), -- Sealed Imperial Crusader Breastplate Part
(29054, 6702, 24, 72, 0, 182529.311964), -- Sealed Imperial Crusader Gaiters Pattern
(29054, 6364, 1, 1, 1, 7859.001768), -- Forgotten Blade
(29054, 6372, 1, 1, 1, 7859.001768), -- Heaven's Divider
(29054, 6688, 8, 22, 1, 276328.943096), -- Forgotten Blade Edge
(29054, 6696, 24, 72, 1, 87725.053368), -- Heavens Divider Edge
-- Ice Fairy Sirra
(29056, 110, 1, 1, 0, 35857.45638), -- Doom Shield
(29056, 2416, 1, 1, 0, 25041.254796), -- Blue Wolf Helmet
(29056, 2417, 1, 1, 0, 25041.254796), -- Doom Helmet
(29056, 4077, 40, 120, 0, 85188.686706), -- Doom Shield Fragment
(29056, 4088, 9, 27, 0, 318088.033974), -- Blue Wolf Helmet Design
(29056, 4089, 14, 42, 0, 204485.313348), -- Doom Helmet Pattern
(29056, 171, 1, 1, 1, 2081.646216), -- Deadman's Glory
(29056, 175, 1, 1, 1, 2081.646216), -- Art of Battle Axe
(29056, 210, 1, 1, 1, 2081.646216), -- Staff of Evil Spirits
(29056, 7893, 1, 1, 1, 2081.646216), -- Kaim Vanul's Bones
(29056, 7901, 1, 1, 1, 2081.646216), -- Star Buster
(29056, 4116, 3, 9, 1, 99302.728522), -- Deadman's Glory Stone
(29056, 4117, 4, 10, 1, 85116.69505), -- Art of Battle Axe Blade
(29056, 4118, 4, 12, 1, 70562.469168), -- Evil Spirit Head
(29056, 8340, 36, 108, 1, 39452.928722), -- Bones Head of Kaim Vanul
(29056, 8348, 8, 22, 1, 189374.947458), -- Star Buster Head
(29056, 8180, 1, 1, 2, 200000), -- Circlet of Ice Fairy Sirra
(29056, 1343, 100, 200, 3, 350689), -- Silver Arrow
-- Sirra's Page
(29057, 1344, 20, 60, 0, 928000), -- Mithril Arrow
-- Sirra's Beholder
(29058, 1539, 1, 1, 0, 227733), -- Greater Healing Potion
-- Captain of the Ice Queen's Royal Guard
(29060, 2391, 1, 1, 0, 13946.16168), -- Blue Wolf Leather Armor
(29060, 2392, 1, 1, 0, 13946.16168), -- Leather Armor of Doom
(29060, 4082, 4, 12, 0, 347671.191024), -- Blue Wolf Leather Armor Texture
(29060, 4083, 8, 22, 0, 185424.485616), -- Leather Armor of Doom Design
(29060, 287, 1, 1, 1, 11274.0298), -- Bow of Peril
(29060, 4121, 3, 9, 1, 536008.9702), -- Bow of Peril Shaft
(29060, 4616, 1, 3, 2, 220057.143579), -- Greater Dye of CON (Con+4 Dex-4)
(29060, 4617, 2, 4, 2, 146704.762386), -- Greater Dye of DEX (Dex+4 Str-4)
(29060, 4618, 1, 1, 2, 440115.094035), -- Greater Dye of DEX (Dex+4 Con-4)
-- Andreas Van Halter
(29062, 6684, 1, 1, 0, 17056.01052), -- Sealed Major Arcana Robe
(29062, 6711, 12, 36, 0, 306341.98948), -- Sealed Major Arcana Robe Part
(29062, 7575, 1, 1, 1, 10504.300392), -- Draconic Bow
(29062, 7579, 12, 36, 1, 233503.699608), -- Draconic Bow Shaft
(29062, 8921, 1, 1, 2, 320095.312935), -- Demon Circlet
(29062, 959, 1, 1, 2, 32009.46354), -- Scroll: Enchant Weapon (S-Grade)
(29062, 960, 1, 1, 2, 320095.312935), -- Scroll: Enchant Armor (S-Grade)
(29062, 6577, 1, 1, 2, 5334.91059), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Andreas' Acolyte
(29063, 1344, 60, 180, 0, 384933), -- Mithril Arrow
-- Andreas' Acolyte
(29064, 1344, 60, 180, 0, 376000), -- Mithril Arrow
-- Sailren
(29065, 6680, 1, 1, 0, 7302.582144), -- Sealed Draconic Leather Armor
(29065, 6707, 3, 9, 0, 524645.417856), -- Sealed Draconic Leather Armor Part
(29065, 6367, 1, 1, 1, 4497.451441), -- Angel Slayer
(29065, 6691, 3, 9, 1, 395311.548559), -- Angel Slayer Blade
(29065, 959, 1, 1, 2, 18273.354256), -- Scroll: Enchant Weapon (S-Grade)
(29065, 960, 1, 1, 2, 182733.950666), -- Scroll: Enchant Armor (S-Grade)
(29065, 6577, 1, 1, 2, 3045.695078), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Antharas
(29066, 80, 1, 2, 0, 250000), -- Tallum Blade
(29066, 98, 1, 2, 0, 250000), -- Halberd
(29066, 269, 1, 2, 0, 250000), -- Blood Tornado
(29066, 2504, 1, 2, 0, 250000), -- Meteor Shower
(29066, 235, 1, 2, 1, 250000), -- Bloody Orchid
(29066, 288, 1, 2, 1, 250000), -- Carnage Bow
(29066, 150, 1, 2, 1, 250000), -- Elemental Sword
(29066, 212, 1, 2, 1, 250000), -- Dasparion's Staff
(29066, 81, 1, 2, 2, 250000), -- Dragon Slayer
(29066, 151, 1, 2, 2, 250000), -- Sword of Miracles
(29066, 2500, 1, 2, 2, 250000), -- Dark Legion's Edge
(29066, 164, 1, 2, 2, 250000), -- Elysian
(29066, 236, 1, 2, 3, 200000), -- Soul Separator
(29066, 270, 1, 2, 3, 200000), -- Dragon Grinder
(29066, 289, 1, 2, 3, 200000), -- Soul Bow
(29066, 213, 1, 2, 3, 200000), -- Branch of the Mother Tree
(29066, 305, 1, 2, 3, 200000), -- Tallum Glaive
(29066, 6364, 1, 1, 4, 170000), -- Forgotten Blade
(29066, 6365, 1, 1, 4, 170000), -- Basalt Battlehammer
(29066, 6369, 1, 1, 4, 170000), -- Dragon Hunter Axe
(29066, 6370, 1, 1, 4, 170000), -- Saint Spear
(29066, 6372, 1, 1, 4, 160000), -- Heaven's Divider
(29066, 6580, 1, 1, 4, 160000), -- Tallum Blade*Dark Legion's Edge
(29066, 7575, 1, 1, 5, 200000), -- Draconic Bow
(29066, 6366, 1, 1, 5, 200000), -- Imperial Staff
(29066, 6367, 1, 1, 5, 200000), -- Angel Slayer
(29066, 6371, 1, 1, 5, 200000), -- Demon Splinter
(29066, 6579, 1, 1, 5, 200000), -- Arcana Mace
(29066, 6326, 1, 5, 6, 300000), -- Sealed Majestic Necklace
(29066, 6327, 1, 5, 6, 350000), -- Sealed Majestic Earring
(29066, 6328, 1, 5, 6, 350000), -- Sealed Majestic Ring
(29066, 6323, 1, 5, 7, 300000), -- Sealed Phoenix Necklace
(29066, 6324, 1, 5, 7, 350000), -- Sealed Phoenix Earring
(29066, 6325, 1, 5, 7, 350000), -- Sealed Phoenix Ring
(29066, 6724, 1, 1, 8, 350000), -- Sealed Tateossian Earring
(29066, 6725, 1, 1, 8, 350000), -- Sealed Tateossian Ring
(29066, 6726, 1, 1, 8, 300000), -- Sealed Tateossian Necklace
(29066, 5287, 1, 3, 9, 500000), -- Sealed Dark Crystal breastplate
(29066, 5297, 1, 3, 9, 250000), -- Sealed Dark Crystal Leather Armor
(29066, 5304, 1, 3, 9, 250000), -- Sealed Tallum Tunic
(29066, 5311, 1, 3, 10, 350000), -- Sealed Armor of Nightmare
(29066, 5320, 1, 3, 10, 350000), -- Sealed Leather Armor of Nightmare
(29066, 5326, 1, 3, 10, 300000), -- Sealed Robe of Nightmare
(29066, 5293, 1, 3, 11, 250000), -- Sealed Tallum Plate Armor
(29066, 5301, 1, 3, 11, 250000), -- Sealed Tallum Leather Armor
(29066, 5308, 1, 3, 11, 250000), -- Sealed Dark Crystal Robe
(29066, 5316, 1, 3, 11, 80000), -- Sealed Majestic Plate Armor
(29066, 5323, 1, 3, 11, 80000), -- Sealed Majestic Leather Armor
(29066, 5329, 1, 3, 11, 90000), -- Sealed Majestic Robe
(29066, 5288, 1, 3, 12, 350000), -- Sealed Dark Crystal Gaiters
(29066, 5298, 1, 3, 12, 350000), -- Sealed Dark Crystal Leggings
(29066, 5305, 1, 3, 12, 300000), -- Sealed Tallum Stockings
(29066, 6674, 1, 1, 13, 150000), -- Sealed Imperial Crusader Breastplate
(29066, 6675, 1, 1, 13, 150000), -- Sealed Imperial Crusader Gaiters
(29066, 6680, 1, 1, 13, 350000), -- Sealed Draconic Leather Armor
(29066, 6684, 1, 1, 13, 350000), -- Sealed Major Arcana Robe
(29066, 5289, 1, 3, 14, 250000), -- Sealed Dark Crystal Helmet
(29066, 5294, 1, 3, 14, 250000), -- Sealed Tallum Helmet
(29066, 5312, 1, 3, 14, 250000), -- Sealed Helm of Nightmare
(29066, 5317, 1, 3, 14, 250000), -- Sealed Majestic Circlet
(29066, 5291, 1, 3, 15, 250000), -- Sealed Dark Crystal Boots
(29066, 5296, 1, 3, 15, 250000), -- Sealed Tallum Boots
(29066, 5314, 1, 3, 15, 250000), -- Sealed Boots of Nightmare
(29066, 5319, 1, 3, 15, 250000), -- Sealed Majestic Boots
(29066, 5290, 1, 3, 16, 250000), -- Sealed Dark Crystal Gloves
(29066, 5295, 1, 3, 16, 250000), -- Sealed Tallum Gloves
(29066, 5313, 1, 3, 16, 250000), -- Sealed Gauntlets of Nightmare
(29066, 5318, 1, 3, 16, 250000), -- Sealed Majestic Gauntlets
(29066, 5292, 1, 3, 17, 400000), -- Sealed Dark Crystal Shield
(29066, 5315, 1, 3, 17, 400000), -- Sealed Shield of Nightmare
(29066, 6678, 1, 1, 17, 200000), -- Sealed Imperial Crusader Shield
(29066, 6676, 1, 1, 18, 340000), -- Sealed Imperial Crusader Gauntlet
(29066, 6681, 1, 1, 18, 330000), -- Sealed Draconic Leather Glove
(29066, 6685, 1, 1, 18, 330000), -- Sealed Major Arcana Glove
(29066, 6677, 1, 1, 19, 340000), -- Sealed Imperial Crusader Boots
(29066, 6682, 1, 1, 19, 330000), -- Sealed Draconic Leather Boots
(29066, 6686, 1, 1, 19, 330000), -- Sealed Major Arcana Boots
(29066, 6679, 1, 1, 20, 340000), -- Sealed Imperial Crusader Helmet
(29066, 6683, 1, 1, 20, 330000), -- Sealed Draconic Leather Helmet
(29066, 6687, 1, 1, 20, 330000), -- Sealed Major Arcana Circlet
(29066, 729, 1, 19, 21, 1000000), -- Scroll: Enchant Weapon (A-Grade)
(29066, 1538, 1, 59, 22, 1000000), -- Blessed Scroll of Escape
(29066, 3936, 1, 39, 23, 1000000), -- Blessed Scroll of Resurrection
(29066, 57, 14000000, 18000000, 24, 1000000), -- Adena
(29066, 57, 14000000, 18000000, 25, 1000000), -- Adena
(29066, 57, 14000000, 18000000, 26, 1000000), -- Adena
(29066, 57, 14000000, 18000000, 27, 1000000), -- Adena
(29066, 57, 14000000, 18000000, 28, 1000000), -- Adena
(29066, 57, 14000000, 18000000, 29, 1000000), -- Adena
(29066, 57, 9000000, 13000000, 30, 1000000), -- Adena
(29066, 8751, 2, 4, 31, 450000), -- High-Grade Life Stone - Level 70
(29066, 8752, 2, 4, 31, 400000), -- High-Grade Life Stone - Level 76
(29066, 8761, 1, 2, 31, 100000), -- Top-Grade Life Stone - Level 70
(29066, 8762, 1, 2, 31, 50000), -- Top-Grade Life Stone - Level 76
(29066, 6656, 1, 1, 32, 1000000), -- Earring of Antharas
(29066, 8620, 10, 30, 33, 500000), -- Ancient Book: Divine Inspiration (Manuscript)
(29066, 13893, 1, 2, 33, 500000), -- Sealed Holy Spirit's Cloak
-- Antharas
(29067, 80, 1, 2, 0, 250000), -- Tallum Blade
(29067, 98, 1, 2, 0, 250000), -- Halberd
(29067, 269, 1, 2, 0, 250000), -- Blood Tornado
(29067, 2504, 1, 2, 0, 250000), -- Meteor Shower
(29067, 235, 1, 2, 1, 250000), -- Bloody Orchid
(29067, 288, 1, 2, 1, 250000), -- Carnage Bow
(29067, 150, 1, 2, 1, 250000), -- Elemental Sword
(29067, 212, 1, 2, 1, 250000), -- Dasparion's Staff
(29067, 81, 1, 2, 2, 250000), -- Dragon Slayer
(29067, 151, 1, 2, 2, 250000), -- Sword of Miracles
(29067, 2500, 1, 2, 2, 250000), -- Dark Legion's Edge
(29067, 164, 1, 2, 2, 250000), -- Elysian
(29067, 236, 1, 2, 3, 200000), -- Soul Separator
(29067, 270, 1, 2, 3, 200000), -- Dragon Grinder
(29067, 289, 1, 2, 3, 200000), -- Soul Bow
(29067, 213, 1, 2, 3, 200000), -- Branch of the Mother Tree
(29067, 305, 1, 2, 3, 200000), -- Tallum Glaive
(29067, 6364, 1, 1, 4, 170000), -- Forgotten Blade
(29067, 6365, 1, 1, 4, 170000), -- Basalt Battlehammer
(29067, 6369, 1, 1, 4, 170000), -- Dragon Hunter Axe
(29067, 6370, 1, 1, 4, 170000), -- Saint Spear
(29067, 6372, 1, 1, 4, 160000), -- Heaven's Divider
(29067, 6580, 1, 1, 4, 160000), -- Tallum Blade*Dark Legion's Edge
(29067, 7575, 1, 1, 5, 200000), -- Draconic Bow
(29067, 6366, 1, 1, 5, 200000), -- Imperial Staff
(29067, 6367, 1, 1, 5, 200000), -- Angel Slayer
(29067, 6371, 1, 1, 5, 200000), -- Demon Splinter
(29067, 6579, 1, 1, 5, 200000), -- Arcana Mace
(29067, 6326, 1, 5, 6, 300000), -- Sealed Majestic Necklace
(29067, 6327, 1, 5, 6, 350000), -- Sealed Majestic Earring
(29067, 6328, 1, 5, 6, 350000), -- Sealed Majestic Ring
(29067, 6323, 1, 5, 7, 300000), -- Sealed Phoenix Necklace
(29067, 6324, 1, 5, 7, 350000), -- Sealed Phoenix Earring
(29067, 6325, 1, 5, 7, 350000), -- Sealed Phoenix Ring
(29067, 6724, 1, 1, 8, 350000), -- Sealed Tateossian Earring
(29067, 6725, 1, 1, 8, 350000), -- Sealed Tateossian Ring
(29067, 6726, 1, 1, 8, 300000), -- Sealed Tateossian Necklace
(29067, 5287, 1, 3, 9, 500000), -- Sealed Dark Crystal breastplate
(29067, 5297, 1, 3, 9, 250000), -- Sealed Dark Crystal Leather Armor
(29067, 5304, 1, 3, 9, 250000), -- Sealed Tallum Tunic
(29067, 5311, 1, 3, 10, 350000), -- Sealed Armor of Nightmare
(29067, 5320, 1, 3, 10, 350000), -- Sealed Leather Armor of Nightmare
(29067, 5326, 1, 3, 10, 300000), -- Sealed Robe of Nightmare
(29067, 5293, 1, 3, 11, 250000), -- Sealed Tallum Plate Armor
(29067, 5301, 1, 3, 11, 250000), -- Sealed Tallum Leather Armor
(29067, 5308, 1, 3, 11, 250000), -- Sealed Dark Crystal Robe
(29067, 5316, 1, 3, 11, 80000), -- Sealed Majestic Plate Armor
(29067, 5323, 1, 3, 11, 80000), -- Sealed Majestic Leather Armor
(29067, 5329, 1, 3, 11, 90000), -- Sealed Majestic Robe
(29067, 5288, 1, 3, 12, 350000), -- Sealed Dark Crystal Gaiters
(29067, 5298, 1, 3, 12, 350000), -- Sealed Dark Crystal Leggings
(29067, 5305, 1, 3, 12, 300000), -- Sealed Tallum Stockings
(29067, 6674, 1, 1, 13, 150000), -- Sealed Imperial Crusader Breastplate
(29067, 6675, 1, 1, 13, 150000), -- Sealed Imperial Crusader Gaiters
(29067, 6680, 1, 1, 13, 350000), -- Sealed Draconic Leather Armor
(29067, 6684, 1, 1, 13, 350000), -- Sealed Major Arcana Robe
(29067, 5289, 1, 3, 14, 250000), -- Sealed Dark Crystal Helmet
(29067, 5294, 1, 3, 14, 250000), -- Sealed Tallum Helmet
(29067, 5312, 1, 3, 14, 250000), -- Sealed Helm of Nightmare
(29067, 5317, 1, 3, 14, 250000), -- Sealed Majestic Circlet
(29067, 5291, 1, 3, 15, 250000), -- Sealed Dark Crystal Boots
(29067, 5296, 1, 3, 15, 250000), -- Sealed Tallum Boots
(29067, 5314, 1, 3, 15, 250000), -- Sealed Boots of Nightmare
(29067, 5319, 1, 3, 15, 250000), -- Sealed Majestic Boots
(29067, 5290, 1, 3, 16, 250000), -- Sealed Dark Crystal Gloves
(29067, 5295, 1, 3, 16, 250000), -- Sealed Tallum Gloves
(29067, 5313, 1, 3, 16, 250000), -- Sealed Gauntlets of Nightmare
(29067, 5318, 1, 3, 16, 250000), -- Sealed Majestic Gauntlets
(29067, 5292, 1, 3, 17, 400000), -- Sealed Dark Crystal Shield
(29067, 5315, 1, 3, 17, 400000), -- Sealed Shield of Nightmare
(29067, 6678, 1, 1, 17, 200000), -- Sealed Imperial Crusader Shield
(29067, 6676, 1, 1, 18, 340000), -- Sealed Imperial Crusader Gauntlet
(29067, 6681, 1, 1, 18, 330000), -- Sealed Draconic Leather Glove
(29067, 6685, 1, 1, 18, 330000), -- Sealed Major Arcana Glove
(29067, 6677, 1, 1, 19, 340000), -- Sealed Imperial Crusader Boots
(29067, 6682, 1, 1, 19, 330000), -- Sealed Draconic Leather Boots
(29067, 6686, 1, 1, 19, 330000), -- Sealed Major Arcana Boots
(29067, 6679, 1, 1, 20, 340000), -- Sealed Imperial Crusader Helmet
(29067, 6683, 1, 1, 20, 330000), -- Sealed Draconic Leather Helmet
(29067, 6687, 1, 1, 20, 330000), -- Sealed Major Arcana Circlet
(29067, 729, 1, 19, 21, 1000000), -- Scroll: Enchant Weapon (A-Grade)
(29067, 1538, 1, 59, 22, 1000000), -- Blessed Scroll of Escape
(29067, 3936, 1, 39, 23, 1000000), -- Blessed Scroll of Resurrection
(29067, 57, 14000000, 18000000, 24, 1000000), -- Adena
(29067, 57, 14000000, 18000000, 25, 1000000), -- Adena
(29067, 57, 14000000, 18000000, 26, 1000000), -- Adena
(29067, 57, 14000000, 18000000, 27, 1000000), -- Adena
(29067, 57, 14000000, 18000000, 28, 1000000), -- Adena
(29067, 57, 14000000, 18000000, 29, 1000000), -- Adena
(29067, 57, 9000000, 13000000, 30, 1000000), -- Adena
(29067, 8751, 2, 4, 31, 450000), -- High-Grade Life Stone - Level 70
(29067, 8752, 2, 4, 31, 400000), -- High-Grade Life Stone - Level 76
(29067, 8761, 1, 2, 31, 100000), -- Top-Grade Life Stone - Level 70
(29067, 8762, 1, 2, 31, 50000), -- Top-Grade Life Stone - Level 76
(29067, 959, 8, 12, 32, 1000000), -- Scroll: Enchant Weapon (S-Grade)
(29067, 6656, 1, 1, 33, 1000000), -- Earring of Antharas
(29067, 8620, 10, 30, 34, 500000), -- Ancient Book: Divine Inspiration (Manuscript)
(29067, 13893, 1, 2, 34, 500000), -- Sealed Holy Spirit's Cloak
-- Antharas
(29068, 15560, 1, 1, 0, 63700), -- Vigwik Axe
(29068, 15561, 1, 1, 0, 63630), -- Devilish Maul
(29068, 15562, 1, 1, 0, 63630), -- Feather Eye Blade
(29068, 15563, 1, 1, 0, 63630), -- Octo Claw
(29068, 15564, 1, 1, 0, 63630), -- Doubletop Spear
(29068, 15565, 1, 1, 0, 63630), -- Rising Star
(29068, 15566, 1, 1, 0, 63630), -- Black Visage
(29068, 15567, 1, 1, 0, 63630), -- Veniplant Sword
(29068, 15568, 1, 1, 0, 63630), -- Skull Carnium Bow
(29068, 15558, 1, 1, 0, 63630), -- Periel Sword
(29068, 15559, 1, 1, 0, 63630), -- Skull Edge
(29068, 15544, 1, 1, 1, 45500), -- Eternal Core Sword
(29068, 15545, 1, 1, 1, 45450), -- Mamba Edge
(29068, 15546, 1, 1, 1, 45450), -- Eversor Mace
(29068, 15547, 1, 1, 1, 45450), -- Contristo Hammer
(29068, 15548, 1, 1, 1, 45450), -- Lava Saw
(29068, 15549, 1, 1, 1, 45450), -- Jade Claw
(29068, 15550, 1, 1, 1, 45450), -- Demitelum
(29068, 15551, 1, 1, 1, 45450), -- Sacredium
(29068, 15552, 1, 1, 1, 45450), -- Cyclic Cane
(29068, 15553, 1, 1, 1, 45450), -- Archangel Sword
(29068, 15554, 1, 1, 1, 45450), -- Recurve Thorne Bow
(29068, 15743, 1, 1, 2, 91000), -- Sealed Vorpal Helmet
(29068, 15744, 1, 1, 2, 90900), -- Sealed Vorpal Leather Helmet
(29068, 15745, 1, 1, 2, 90900), -- Sealed Vorpal Circlet
(29068, 15752, 1, 1, 2, 90900), -- Sealed Vorpal Gauntlet
(29068, 15753, 1, 1, 2, 90900), -- Sealed Vorpal Leather Gloves
(29068, 15754, 1, 1, 2, 90900), -- Sealed Vorpal Gloves
(29068, 15755, 1, 1, 2, 90900), -- Sealed Vorpal Boots
(29068, 15756, 1, 1, 2, 90900), -- Sealed Vorpal Leather Boots
(29068, 15757, 1, 1, 2, 90900), -- Sealed Vorpal Shoes
(29068, 15758, 1, 1, 2, 90900), -- Sealed Vorpal Shield
(29068, 15759, 1, 1, 2, 90900), -- Sealed Vorpal Sigil
(29068, 15746, 1, 1, 3, 167000), -- Sealed Vorpal Breastplate
(29068, 15747, 1, 1, 3, 166600), -- Sealed Vorpal Leather Breastplate
(29068, 15748, 1, 1, 3, 166600), -- Sealed Vorpal Tunic
(29068, 15749, 1, 1, 3, 166600), -- Sealed Vorpal Gaiter
(29068, 15750, 1, 1, 3, 166600), -- Sealed Vorpal Leather Legging
(29068, 15751, 1, 1, 3, 166600), -- Sealed Vorpal Stockings
(29068, 15763, 1, 1, 4, 167000), -- Sealed Vorpal Ring
(29068, 15764, 1, 1, 4, 166500), -- Sealed Vorpal Earring
(29068, 15765, 1, 1, 4, 166500), -- Sealed Vorpal Necklace
(29068, 959, 1, 19, 5, 1000000), -- Scroll: Enchant Weapon (S-Grade)
(29068, 1538, 1, 59, 6, 600000), -- Blessed Scroll of Escape
(29068, 3936, 1, 39, 7, 600000), -- Blessed Scroll of Resurrection
(29068, 57, 14000000, 18000000, 8, 1000000), -- Adena
(29068, 57, 2000000, 6000000, 9, 1000000), -- Adena
(29068, 16162, 2, 4, 10, 450000), -- High-Grade Life Stone - Level 85
(29068, 16166, 2, 4, 10, 400000), -- High-Grade Life Stone - Level 86
(29068, 16163, 1, 2, 10, 100000), -- Top-Grade Life Stone - Level 85
(29068, 16167, 1, 2, 10, 50000), -- Top-Grade Life Stone - Level 86
(29068, 6656, 1, 1, 11, 1000000), -- Earring of Antharas
(29068, 8620, 10, 30, 12, 500000), -- Ancient Book: Divine Inspiration (Manuscript)
(29068, 13893, 1, 2, 12, 500000), -- Sealed Holy Spirit's Cloak
-- Gordon
(29095, 6684, 1, 1, 0, 13184.94726), -- Sealed Major Arcana Robe
(29095, 6711, 12, 36, 0, 236814.05274), -- Sealed Major Arcana Robe Part
(29095, 6371, 1, 1, 1, 8120.219514), -- Demon Splinter
(29095, 6695, 3, 9, 1, 700326.780486), -- Demon Splinter Blade
(29095, 959, 1, 1, 2, 32992.74784), -- Scroll: Enchant Weapon (S-Grade)
(29095, 960, 1, 1, 2, 329928.21524), -- Scroll: Enchant Armor (S-Grade)
(29095, 6577, 1, 1, 2, 5499.03692), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Anais
(29096, 6674, 1, 1, 0, 8021.600769), -- Sealed Imperial Crusader Breastplate
(29096, 6675, 1, 1, 0, 12802.924329), -- Sealed Imperial Crusader Gaiters
(29096, 6701, 8, 22, 0, 203579.165907), -- Sealed Imperial Crusader Breastplate Part
(29096, 6702, 4, 12, 0, 491363.308995), -- Sealed Imperial Crusader Gaiters Pattern
(29096, 6370, 1, 1, 1, 8120.219545), -- Saint Spear
(29096, 6694, 3, 9, 1, 726674.780455), -- Saint Spear Blade
(29096, 959, 1, 1, 2, 24744.611928), -- Scroll: Enchant Weapon (S-Grade)
(29096, 960, 1, 1, 2, 247446.643042), -- Scroll: Enchant Armor (S-Grade)
(29096, 6577, 1, 1, 2, 4124.101988), -- Blessed Scroll: Enchant Weapon (S-Grade)
(29096, 8920, 1, 1, 2, 247446.643042), -- Angel Halo
-- Disciple of Splendor 
(29097, 1344, 60, 180, 0, 384933), -- Mithril Arrow
-- Splendor Worshiper
(29098, 1344, 60, 180, 0, 384933), -- Mithril Arrow
-- Baylor's Treasure Chest
(29116, 6676, 1, 1, 0, 6937.637764), -- Sealed Imperial Crusader Gauntlet
(29116, 6677, 1, 1, 0, 6937.637764), -- Sealed Imperial Crusader Boots
(29116, 6681, 1, 1, 0, 6937.637764), -- Sealed Draconic Leather Glove
(29116, 6682, 1, 1, 0, 6937.637764), -- Sealed Draconic Leather Boots
(29116, 6685, 1, 1, 0, 6937.637764), -- Sealed Major Arcana Glove
(29116, 6686, 1, 1, 0, 6937.637764), -- Sealed Major Arcana Boots
(29116, 6703, 8, 24, 0, 110503.068942), -- Sealed Imperial Crusader Gauntlets Design
(29116, 6704, 14, 40, 0, 65483.236659), -- Sealed Imperial Crusader Boots Design
(29116, 6708, 20, 60, 0, 44201.456014), -- Sealed Draconic Leather Gloves Fabric
(29116, 6709, 28, 82, 0, 32146.253877), -- Sealed Draconic Leather Boots Design
(29116, 6712, 36, 108, 0, 24556.427907), -- Sealed Major Arcana Gloves fabric
(29116, 6713, 4, 10, 0, 252576.730017), -- Sealed Major Arcana Boots Design
(29116, 9458, 1, 1, 1, 3332.282382), -- Dynasty Earrings - Stun Resistance
(29116, 9461, 1, 1, 1, 3332.282382), -- Dynasty Earrings - Poison Resistance
(29116, 9464, 1, 1, 1, 3332.282382), -- Dynasty Earrings - Bleed Resistance
(29116, 9467, 1, 1, 1, 3332.282382), -- Dynasty Earrings - Sleep Resistance
(29116, 9470, 1, 1, 1, 3332.282382), -- Dynasty Earrings - Paralysis Resistance
(29116, 9473, 1, 1, 1, 3332.282382), -- Dynasty Earrings - Hold Resistance
(29116, 9476, 1, 1, 1, 3332.305708), -- Dynasty Earrings - Fear Resistance
(29116, 6577, 1, 1, 2, 5357.74806), -- Blessed Scroll: Enchant Weapon (S-Grade)
(29116, 6578, 1, 1, 2, 35718.25194), -- Blessed Scroll: Enchant Armor (S-Grade)
-- Baylor's Treasure Chest
(29117, 6678, 1, 1, 0, 19816.558776), -- Sealed Imperial Crusader Shield
(29117, 6679, 1, 1, 0, 13875.533056), -- Sealed Imperial Crusader Helmet
(29117, 6683, 1, 1, 0, 13875.533056), -- Sealed Draconic Leather Helmet
(29117, 6687, 1, 1, 0, 13875.533056), -- Sealed Major Arcana Circlet
(29117, 6705, 23, 67, 0, 115458.625912), -- Sealed Imperial Crusader Shield Part
(29117, 6706, 60, 180, 0, 50362.863411), -- Sealed Imperial Crusader Helmet Pattern
(29117, 6710, 11, 31, 0, 287787.79092), -- Sealed Draconic Leather Helmet Pattern
(29117, 6714, 16, 48, 0, 188860.561813), -- Sealed Major Arcana Circlet Pattern
(29117, 10170, 1, 1, 1, 84497), -- Baylor's Earring
(29117, 6577, 1, 1, 2, 10715.365685), -- Blessed Scroll: Enchant Weapon (S-Grade)
(29117, 6578, 1, 1, 2, 71435.634315), -- Blessed Scroll: Enchant Armor (S-Grade)
-- Beleth
(29118, 13457, 1, 1, 0, 37700), -- Vesper Cutter
(29118, 13458, 1, 1, 0, 37600), -- Vesper Slasher
(29118, 13459, 1, 1, 0, 37600), -- Vesper Buster
(29118, 13460, 1, 1, 0, 37700), -- Vesper Shaper
(29118, 13461, 1, 1, 0, 37700), -- Vesper Fighter
(29118, 13462, 1, 1, 0, 37600), -- Vesper Stormer
(29118, 13463, 1, 1, 0, 37700), -- Vesper Avenger
(29118, 13464, 1, 1, 0, 37600), -- Vesper Retributer
(29118, 13465, 1, 1, 0, 37600), -- Vesper Caster
(29118, 13467, 1, 1, 0, 37600), -- Vesper Thrower
(29118, 13466, 1, 1, 0, 37600), -- Vesper Singer
(29118, 10215, 1, 1, 0, 65200), -- Icarus Sawsword
(29118, 10216, 1, 1, 0, 65100), -- Icarus Disperser
(29118, 10217, 1, 1, 0, 65100), -- Icarus Spirit
(29118, 10218, 1, 1, 0, 65100), -- Icarus Heavy Arms
(29118, 10219, 1, 1, 0, 65100), -- Icarus Trident
(29118, 10220, 1, 1, 0, 65100), -- Icarus Hammer
(29118, 10221, 1, 1, 0, 65100), -- Icarus Hand
(29118, 10222, 1, 1, 0, 65100), -- Icarus Hall
(29118, 10223, 1, 1, 0, 65100), -- Icarus Spitter
(29118, 13893, 1, 1, 1, 400000), -- Sealed Holy Spirit's Cloak
(29118, 10552, 1, 1, 1, 200000), -- Forgotten Scroll - Fighter's Will
(29118, 10553, 1, 1, 1, 200000), -- Forgotten Scroll - Archer's Will
(29118, 14219, 1, 1, 1, 200000), -- Forgotten Scroll - Magician's Will
-- Lost Captain
(29129, 395, 1, 1, 0, 337099.912206), -- Manticore Skin Shirt
(29129, 417, 4, 12, 0, 67295.009586), -- Manticore Skin Gaiters
(29129, 1942, 53, 157, 0, 140832.078113), -- Manticore Skin Shirt Texture
(29129, 1943, 216, 648, 0, 53302.000095), -- Manticore Skin Gaiters Pattern
(29129, 279, 1, 1, 1, 161958.50522), -- Reinforced Long Bow
(29129, 2040, 12, 36, 1, 419277.49478), -- Reinforced Long Bow Shaft
(29129, 6576, 3, 9, 2, 375804), -- Blessed Scroll: Enchant Armor (D-Grade)
-- Lost Captain
(29132, 439, 1, 1, 0, 267666.225638), -- Karmian Tunic
(29132, 471, 5, 13, 0, 47526.54886), -- Karmian Stockings
(29132, 1962, 53, 157, 0, 118691.007036), -- Karmian Tunic Pattern
(29132, 1954, 192, 576, 0, 53918.218466), -- Karmian Stocking Design
(29132, 71, 1, 1, 1, 66274.975998), -- Flamberge
(29132, 72, 1, 1, 1, 66274.975998), -- Stormbringer
(29132, 2059, 8, 22, 1, 289287.75304), -- Flamberge Blade
(29132, 2060, 24, 72, 1, 96636.294964), -- Stormbringer Blade
(29132, 4589, 4, 12, 2, 210353.377074), -- Greater Dye of STR (Str+2 Con-2)
(29132, 4590, 8, 22, 2, 112188.834389), -- Greater Dye of STR (Str+2 Dex-2)
(29132, 6574, 1, 1, 2, 288484.788537), -- Blessed Scroll: Enchant Armor (C-Grade)
-- Lost Captain
(29135, 119, 1, 1, 0, 168703.91343), -- Necklace of Seal
(29135, 855, 1, 1, 0, 224938.354914), -- Nassen's Earring
(29135, 886, 6, 16, 0, 30673.385262), -- Ring of Seal
(29135, 1920, 140, 420, 0, 44778.819384), -- Necklace of Seal Chain
(29135, 1918, 81, 243, 0, 97959.409938), -- Nassen's Earring Gemstone
(29135, 2917, 480, 1440, 0, 21924.117072), -- Ring of Seal Gemstone
(29135, 286, 1, 1, 1, 69965.61767), -- Eminence Bow
(29135, 2121, 12, 36, 1, 315949.38233), -- Eminence Bow Shaft
(29135, 4607, 5, 15, 2, 118748.903025), -- Greater Dye of INT (Int+3 Men-3)
(29135, 4608, 2, 4, 2, 395829.67675), -- Greater Dye of INT (Int+3 Wit-3)
(29135, 4609, 2, 6, 2, 296871.834025), -- Greater Dye of MEN (Men+3 Int-3)
(29135, 6573, 1, 1, 2, 35624.5862), -- Blessed Scroll: Enchant Weapon (C-Grade)
-- Lost Captain
(29138, 864, 1, 1, 0, 139480.373196), -- Earring of Black Ore
(29138, 895, 1, 1, 0, 209220.24888), -- Ring of Black Ore
(29138, 926, 1, 1, 0, 104610.12444), -- Necklace of Black Ore
(29138, 4052, 81, 243, 0, 108366.587388), -- Earring of Black Ore Piece
(29138, 4053, 280, 840, 0, 37953.27198), -- Ring of Black Ore Gemstone
(29138, 4054, 220, 660, 0, 22197.394116), -- Necklace of Black Ore Beads
(29138, 171, 1, 1, 1, 14740.849444), -- Deadman's Glory
(29138, 175, 1, 1, 1, 14740.849444), -- Art of Battle Axe
(29138, 210, 1, 1, 1, 14740.849444), -- Staff of Evil Spirits
(29138, 4116, 5, 15, 1, 325017.190366), -- Deadman's Glory Stone
(29138, 4117, 9, 27, 1, 180565.179068), -- Art of Battle Axe Blade
(29138, 4118, 14, 42, 1, 109977.082234), -- Evil Spirit Head
(29138, 4616, 5, 15, 2, 99740.374792), -- Greater Dye of CON (Con+4 Dex-4)
(29138, 4617, 2, 4, 2, 332469.081832), -- Greater Dye of DEX (Dex+4 Str-4)
(29138, 4618, 2, 6, 2, 249351.811374), -- Greater Dye of DEX (Dex+4 Con-4)
(29138, 6572, 1, 1, 2, 192832.732002), -- Blessed Scroll: Enchant Armor (B-Grade)
-- Lost Captain
(29141, 5326, 1, 1, 0, 21869.181552), -- Sealed Robe of Nightmare
(29141, 5329, 1, 1, 0, 21869.181552), -- Sealed Majestic Robe
(29141, 5487, 4, 12, 0, 406413.183306), -- Sealed Robe of Nightmare Fabric
(29141, 5488, 8, 22, 0, 216754.45359), -- Sealed Majestic Robe Fabric
(29141, 289, 1, 1, 1, 20886.512123), -- Soul Bow
(29141, 5534, 12, 36, 1, 247774.487877), -- Soul Bow Stave
(29141, 730, 1, 1, 2, 779949.88954), -- Scroll: Enchant Armor (A-Grade)
(29141, 6569, 1, 1, 2, 12479.090662), -- Blessed Scroll: Enchant Weapon (A-Grade)
(29141, 729, 1, 1, 2, 103993.019798), -- Scroll: Enchant Weapon (A-Grade)
-- Lost Captain
(29144, 6680, 1, 1, 0, 33061.60415), -- Sealed Draconic Leather Armor
(29144, 6707, 12, 36, 0, 531611.39585), -- Sealed Draconic Leather Armor Part
(29144, 7575, 1, 1, 1, 18066.235968), -- Draconic Bow
(29144, 7579, 12, 36, 1, 351885.764032), -- Draconic Bow Shaft
(29144, 959, 1, 1, 2, 66759.404064), -- Scroll: Enchant Weapon (S-Grade)
(29144, 960, 1, 1, 2, 667595.531604), -- Scroll: Enchant Armor (S-Grade)
(29144, 6577, 1, 1, 2, 11127.064332), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Lost Captain
(29147, 6678, 1, 1, 0, 36517.686153), -- Sealed Imperial Crusader Shield
(29147, 6679, 1, 1, 0, 25561.71483), -- Sealed Imperial Crusader Helmet
(29147, 6683, 1, 1, 0, 25561.71483), -- Sealed Draconic Leather Helmet
(29147, 6687, 1, 1, 0, 25561.71483), -- Sealed Major Arcana Circlet
(29147, 6705, 23, 67, 0, 189847.307088), -- Sealed Imperial Crusader Shield Part
(29147, 6706, 60, 180, 0, 82810.491486), -- Sealed Imperial Crusader Helmet Pattern
(29147, 6710, 116, 346, 0, 43018.658001), -- Sealed Draconic Leather Helmet Pattern
(29147, 6714, 16, 48, 0, 310539.712782), -- Sealed Major Arcana Circlet Pattern
(29147, 6371, 1, 1, 1, 17191.576038), -- Demon Splinter
(29147, 6695, 12, 36, 1, 324786.423962), -- Demon Splinter Blade
(29147, 959, 1, 1, 2, 63527.29328), -- Scroll: Enchant Weapon (S-Grade)
(29147, 960, 1, 1, 2, 635274.35158), -- Scroll: Enchant Armor (S-Grade)
(29147, 6577, 1, 1, 2, 10588.35514), -- Blessed Scroll: Enchant Weapon (S-Grade)
-- Ekimus
(29150, 13143, 1, 1, 0, 29400), -- Sealed Vesper Helmet
(29150, 13144, 1, 1, 0, 29400), -- Sealed Vesper Leather Helmet
(29150, 13145, 1, 1, 0, 29400), -- Sealed Vesper Circlet
(29150, 13887, 1, 1, 0, 29400), -- Sealed Vesper Sigil
(29150, 14105, 1, 1, 0, 29400), -- Sealed Vesper Breastplate
(29150, 14106, 1, 1, 0, 29400), -- Sealed Vesper Leather Breastplate
(29150, 14107, 1, 1, 0, 29400), -- Sealed Vesper Tunic
(29150, 14108, 1, 1, 0, 29400), -- Sealed Vesper Gaiters
(29150, 14109, 1, 1, 0, 29400), -- Sealed Vesper Gauntlet
(29150, 14110, 1, 1, 0, 29400), -- Sealed Vesper Boots
(29150, 14111, 1, 1, 0, 29400), -- Sealed Vesper Shield
(29150, 14112, 1, 1, 0, 29400), -- Sealed Vesper Leather Leggings
(29150, 14113, 1, 1, 0, 29400), -- Sealed Vesper Leather Gloves
(29150, 14114, 1, 1, 0, 29400), -- Sealed Vesper Leather Boots
(29150, 14115, 1, 1, 0, 29400), -- Sealed Vesper Stockings
(29150, 14116, 1, 1, 0, 29400), -- Sealed Vesper Gloves
(29150, 14117, 1, 1, 0, 29400), -- Sealed Vesper Shoes
(29150, 13146, 1, 1, 0, 29400), -- Sealed Vesper Noble Helmet
(29150, 13147, 1, 1, 0, 29400), -- Sealed Vesper Noble Leather Helmet
(29150, 13148, 1, 1, 0, 29400), -- Sealed Vesper Noble Circlet
(29150, 13886, 1, 1, 0, 29400), -- Sealed Dynasty Sigil
(29150, 17006, 1, 1, 0, 29400), -- Sealed Vesper Noble Breastplate
(29150, 17007, 1, 1, 0, 29400), -- Sealed Vesper Noble Leather Breastplate
(29150, 17008, 1, 1, 0, 29400), -- Sealed Vesper Noble Tunic
(29150, 17009, 1, 1, 0, 29400), -- Sealed Vesper Noble Gaiters
(29150, 17010, 1, 1, 0, 29400), -- Sealed Vesper Noble Gauntlet
(29150, 17011, 1, 1, 0, 29400), -- Sealed Vesper Noble Boots
(29150, 9529, 1, 1, 0, 29400), -- Sealed Dynasty Shield
(29150, 17012, 1, 1, 0, 29400), -- Sealed Vesper Noble Leather Leggings
(29150, 17013, 1, 1, 0, 29400), -- Sealed Vesper Noble Leather Gloves
(29150, 17014, 1, 1, 0, 29400), -- Sealed Vesper Noble Leather Boots
(29150, 17015, 1, 1, 0, 29400), -- Sealed Vesper Noble Stockings
(29150, 17016, 1, 1, 0, 29400), -- Sealed Vesper Noble Gloves
(29150, 17017, 1, 1, 0, 29800), -- Sealed Vesper Noble Shoes
(29150, 14160, 1, 1, 1, 350000), -- Sealed Vesper Earring
(29150, 14161, 1, 1, 1, 300000), -- Sealed Vesper Necklace
(29150, 14162, 1, 1, 1, 350000), -- Sealed Vesper Ring
-- Tiat
(29163, 13457, 1, 1, 0, 37700), -- Vesper Cutter
(29163, 13458, 1, 1, 0, 37600), -- Vesper Slasher
(29163, 13459, 1, 1, 0, 37600), -- Vesper Buster
(29163, 13460, 1, 1, 0, 37700), -- Vesper Shaper
(29163, 13461, 1, 1, 0, 37700), -- Vesper Fighter
(29163, 13462, 1, 1, 0, 37600), -- Vesper Stormer
(29163, 13463, 1, 1, 0, 37700), -- Vesper Avenger
(29163, 13464, 1, 1, 0, 37600), -- Vesper Retributer
(29163, 13465, 1, 1, 0, 37600), -- Vesper Caster
(29163, 13467, 1, 1, 0, 37600), -- Vesper Thrower
(29163, 13466, 1, 1, 0, 37600), -- Vesper Singer
(29163, 10215, 1, 1, 0, 65200), -- Icarus Sawsword
(29163, 10216, 1, 1, 0, 65100), -- Icarus Disperser
(29163, 10217, 1, 1, 0, 65100), -- Icarus Spirit
(29163, 10218, 1, 1, 0, 65100), -- Icarus Heavy Arms
(29163, 10219, 1, 1, 0, 65100), -- Icarus Trident
(29163, 10220, 1, 1, 0, 65100), -- Icarus Hammer
(29163, 10221, 1, 1, 0, 65100), -- Icarus Hand
(29163, 10222, 1, 1, 0, 65100), -- Icarus Hall
(29163, 10223, 1, 1, 0, 65100), -- Icarus Spitter
(29163, 13893, 1, 1, 1, 200000), -- Sealed Holy Spirit's Cloak
(29163, 10550, 1, 1, 1, 400000), -- Forgotten Scroll - Protection of Elemental
(29163, 10552, 1, 1, 1, 400000); -- Forgotten Scroll - Fighter's Will

INSERT INTO `droplist` VALUES
-- Tiat
(29175, 7575, 1, 1, 0, 10599.273198), -- Draconic Bow
(29175, 7579, 12, 36, 0, 206447.726802), -- Draconic Bow Shaft
(29175, 6676, 1, 1, 1, 35463.073429), -- Sealed Imperial Crusader Gauntlet
(29175, 6677, 1, 1, 1, 35463.073429), -- Sealed Imperial Crusader Boots
(29175, 6681, 1, 1, 1, 35463.073429), -- Sealed Draconic Leather Glove
(29175, 6682, 1, 1, 1, 35463.073429), -- Sealed Draconic Leather Boots
(29175, 6685, 1, 1, 1, 35463.073429), -- Sealed Major Arcana Glove
(29175, 6686, 1, 1, 1, 35463.073429), -- Sealed Major Arcana Boots
(29175, 6703, 112, 336, 1, 36009.355506), -- Sealed Imperial Crusader Gauntlets Design
(29175, 6704, 203, 607, 1, 19916.350706), -- Sealed Imperial Crusader Boots Design
(29175, 6708, 320, 960, 1, 12603.463017), -- Sealed Draconic Leather Gloves Fabric
(29175, 6709, 28, 82, 1, 146656.935735), -- Sealed Draconic Leather Boots Design
(29175, 6712, 36, 108, 1, 112029.315563), -- Sealed Major Arcana Gloves fabric
(29175, 6713, 46, 136, 1, 88639.138899), -- Sealed Major Arcana Boots Design
(29175, 6578, 1, 1, 2, 97917.478815), -- Blessed Scroll: Enchant Armor (S-Grade)
(29175, 3936, 1, 3, 2, 550787.521185), -- Blessed Scroll of Resurrection
-- Zaken
(29176, 80, 1, 1, 0, 21233.818352), -- Tallum Blade
(29176, 150, 1, 1, 0, 21233.818352), -- Elemental Sword
(29176, 5548, 24, 72, 0, 106089.540588), -- Tallum Blade Edge
(29176, 5547, 8, 22, 0, 339486.822708), -- Elemental Sword Edge
(29176, 729, 1, 1, 1, 86233.782033), -- Scroll: Enchant Weapon (A-Grade)
(29176, 730, 1, 1, 1, 646755.22359), -- Scroll: Enchant Armor (A-Grade)
(29176, 6569, 1, 1, 1, 10347.994377), -- Blessed Scroll: Enchant Weapon (A-Grade)
(29176, 6659, 1, 1, 2, 900), -- Earring of Zaken
(29176, 8922, 1, 1, 3, 900), -- Pirate Hat
(29176, 8619, 1, 1, 4, 1800), -- Ancient Book: Divine Inspiration (Original Language Version)
-- Freya
(29179, 15560, 1, 1, 0, 13650), -- Vigwik Axe
(29179, 15561, 1, 1, 0, 13635), -- Devilish Maul
(29179, 15562, 1, 1, 0, 13635), -- Feather Eye Blade
(29179, 15563, 1, 1, 0, 13635), -- Octo Claw
(29179, 15564, 1, 1, 0, 13635), -- Doubletop Spear
(29179, 15565, 1, 1, 0, 13635), -- Rising Star
(29179, 15566, 1, 1, 0, 13635), -- Black Visage
(29179, 15567, 1, 1, 0, 13635), -- Veniplant Sword
(29179, 15568, 1, 1, 0, 13635), -- Skull Carnium Bow
(29179, 15558, 1, 1, 0, 13635), -- Periel Sword
(29179, 15559, 1, 1, 0, 13635), -- Skull Edge
(29179, 13143, 1, 1, 1, 45500), -- Sealed Vesper Helmet
(29179, 13144, 1, 1, 1, 45450), -- Sealed Vesper Leather Helmet
(29179, 13145, 1, 1, 1, 45450), -- Sealed Vesper Circlet
(29179, 14109, 1, 1, 1, 45450), -- Sealed Vesper Gauntlet
(29179, 14113, 1, 1, 1, 45450), -- Sealed Vesper Leather Gloves
(29179, 14116, 1, 1, 1, 45450), -- Sealed Vesper Gloves
(29179, 14110, 1, 1, 1, 45450), -- Sealed Vesper Boots
(29179, 14114, 1, 1, 1, 45450), -- Sealed Vesper Leather Boots
(29179, 14117, 1, 1, 1, 45450), -- Sealed Vesper Shoes
(29179, 14111, 1, 1, 1, 45450), -- Sealed Vesper Shield
(29179, 13887, 1, 1, 1, 45450), -- Sealed Vesper Sigil
(29179, 14105, 1, 1, 2, 83500), -- Sealed Vesper Breastplate
(29179, 14106, 1, 1, 2, 83300), -- Sealed Vesper Leather Breastplate
(29179, 14107, 1, 1, 2, 83300), -- Sealed Vesper Tunic
(29179, 14108, 1, 1, 2, 83300), -- Sealed Vesper Gaiters
(29179, 14112, 1, 1, 2, 83300), -- Sealed Vesper Leather Leggings
(29179, 14115, 1, 1, 2, 83300), -- Sealed Vesper Stockings
(29179, 14162, 1, 1, 3, 167000), -- Sealed Vesper Ring
(29179, 14160, 1, 1, 3, 166500), -- Sealed Vesper Earring
(29179, 14161, 1, 1, 3, 166500), -- Sealed Vesper Necklace
(29179, 6577, 1, 1, 4, 5357.74806), -- Blessed Scroll: Enchant Weapon (S-Grade)
(29179, 6578, 1, 1, 4, 35718.25194), -- Blessed Scroll: Enchant Armor (S-Grade)
(29179, 16164, 2, 4, 5, 600000), -- Life Stone - Level 86
(29179, 16165, 2, 4, 5, 400000), -- Mid-Grade Life Stone - Level 86
(29179, 16025, 1, 1, 6, 250000), -- Necklace of Freya
-- Freya
(29180, 15560, 1, 1, 0, 27300), -- Vigwik Axe
(29180, 15561, 1, 1, 0, 27270), -- Devilish Maul
(29180, 15562, 1, 1, 0, 27270), -- Feather Eye Blade
(29180, 15563, 1, 1, 0, 27270), -- Octo Claw
(29180, 15564, 1, 1, 0, 27270), -- Doubletop Spear
(29180, 15565, 1, 1, 0, 27270), -- Rising Star
(29180, 15566, 1, 1, 0, 27270), -- Black Visage
(29180, 15567, 1, 1, 0, 27270), -- Veniplant Sword
(29180, 15568, 1, 1, 0, 27270), -- Skull Carnium Bow
(29180, 15558, 1, 1, 0, 27270), -- Periel Sword
(29180, 15559, 1, 1, 0, 27270), -- Skull Edge
(29180, 15726, 1, 1, 1, 45500), -- Sealed Elegia Helmet
(29180, 15727, 1, 1, 1, 45450), -- Sealed Elegia Leather Helmet
(29180, 15728, 1, 1, 1, 45450), -- Sealed Elegia Circlet
(29180, 15735, 1, 1, 1, 45450), -- Sealed Elegia Gauntlet
(29180, 15736, 1, 1, 1, 45450), -- Sealed Elegia Leather Gloves
(29180, 15737, 1, 1, 1, 45450), -- Sealed Elegia Gloves
(29180, 15738, 1, 1, 1, 45450), -- Sealed Elegia Boots
(29180, 15739, 1, 1, 1, 45450), -- Sealed Elegia Leather Boots
(29180, 15740, 1, 1, 1, 45450), -- Sealed Elegia Shoes
(29180, 15741, 1, 1, 1, 45450), -- Sealed Elegia Shield
(29180, 15742, 1, 1, 1, 45450), -- Sealed Elegia Sigil
(29180, 15729, 1, 1, 2, 83500), -- Sealed Elegia Breastplate
(29180, 15730, 1, 1, 2, 83300), -- Sealed Elegia Leather Breastplate
(29180, 15731, 1, 1, 2, 83300), -- Sealed Elegia Tunic
(29180, 15732, 1, 1, 2, 83300), -- Sealed Elegia Gaiter
(29180, 15733, 1, 1, 2, 83300), -- Sealed Elegia Leather Legging
(29180, 15734, 1, 1, 2, 83300), -- Sealed Elegia Stockings
(29180, 15760, 1, 1, 3, 167000), -- Sealed Elegia Ring
(29180, 15761, 1, 1, 3, 166500), -- Sealed Elegia Earring
(29180, 15762, 1, 1, 3, 166500), -- Sealed Elegia Necklace
(29180, 6577, 1, 1, 4, 5357.74806), -- Blessed Scroll: Enchant Weapon (S-Grade)
(29180, 6578, 1, 1, 4, 35718.25194), -- Blessed Scroll: Enchant Armor (S-Grade)
(29180, 16026, 1, 1, 5, 300000), -- Blessed Necklace of Freya
(29180, 16027, 1, 1, 6, 500000), -- Bottle of Freya's Soul
-- Zaken
(29181, 13143, 1, 1, 0, 17760), -- Sealed Vesper Helmet
(29181, 13144, 1, 1, 0, 17640), -- Sealed Vesper Leather Helmet
(29181, 13145, 1, 1, 0, 17640), -- Sealed Vesper Circlet
(29181, 14109, 1, 1, 0, 17640), -- Sealed Vesper Gauntlet
(29181, 14113, 1, 1, 0, 17640), -- Sealed Vesper Leather Gloves
(29181, 14116, 1, 1, 0, 17640), -- Sealed Vesper Gloves
(29181, 14110, 1, 1, 0, 17640), -- Sealed Vesper Boots
(29181, 14114, 1, 1, 0, 17640), -- Sealed Vesper Leather Boots
(29181, 14117, 1, 1, 0, 17640), -- Sealed Vesper Shoes
(29181, 14111, 1, 1, 0, 17640), -- Sealed Vesper Shield
(29181, 13887, 1, 1, 0, 17640), -- Sealed Vesper Sigil
(29181, 14105, 1, 1, 0, 17640), -- Sealed Vesper Breastplate
(29181, 14106, 1, 1, 0, 17640), -- Sealed Vesper Leather Breastplate
(29181, 14107, 1, 1, 0, 17640), -- Sealed Vesper Tunic
(29181, 14108, 1, 1, 0, 17640), -- Sealed Vesper Gaiters
(29181, 14112, 1, 1, 0, 17640), -- Sealed Vesper Leather Leggings
(29181, 14115, 1, 1, 0, 17640), -- Sealed Vesper Stockings
(29181, 15694, 1, 1, 1, 41440), -- Sealed Moirai Helmet 
(29181, 15695, 1, 1, 1, 41160), -- Sealed Moirai Leather Helmet 
(29181, 15696, 1, 1, 1, 41160), -- Sealed Moirai Circlet 
(29181, 15703, 1, 1, 1, 41160), -- Sealed Moirai Gauntlet 
(29181, 15704, 1, 1, 1, 41160), -- Sealed Moirai Leather Gloves 
(29181, 15705, 1, 1, 1, 41160), -- Sealed Moirai Gloves 
(29181, 15706, 1, 1, 1, 41160), -- Sealed Moirai Boots 
(29181, 15707, 1, 1, 1, 41160), -- Sealed Moirai Leather Boots 
(29181, 15708, 1, 1, 1, 41160), -- Sealed Moirai Shoes 
(29181, 15710, 1, 1, 1, 41160), -- Sealed Moirai Shield 
(29181, 15709, 1, 1, 1, 41160), -- Sealed Moirai Sigil 
(29181, 15697, 1, 1, 1, 41160), -- Sealed Moirai Breastplate 
(29181, 15698, 1, 1, 1, 41160), -- Sealed Moirai Leather Breastplate 
(29181, 15699, 1, 1, 1, 41160), -- Sealed Moirai Tunic 
(29181, 15700, 1, 1, 1, 41160), -- Sealed Moirai Gaiter 
(29181, 15701, 1, 1, 1, 41160), -- Sealed Moirai Leather Legging 
(29181, 15702, 1, 1, 1, 41160), -- Sealed Moirai Stockings 
(29181, 14162, 1, 1, 2, 167000), -- Sealed Vesper Ring
(29181, 14160, 1, 1, 2, 166500), -- Sealed Vesper Earring
(29181, 14161, 1, 1, 2, 166500), -- Sealed Vesper Necklace
(29181, 1538, 1, 30, 3, 1000000), -- Blessed Scroll of Escape
(29181, 3936, 1, 10, 4, 1000000), -- Blessed Scroll of Resurrection
(29181, 57, 9000000, 11000000, 5, 1000000), -- Adena
(29181, 16162, 2, 4, 6, 600000), -- High-Grade Life Stone - Level 85
(29181, 16166, 2, 4, 6, 400000), -- High-Grade Life Stone - Level 86
(29181, 6659, 1, 1, 7, 900), -- Earring of Zaken
-- Baylor
(29186, 13143, 1, 1, 0, 83700), -- Sealed Vesper Helmet
(29186, 13144, 1, 1, 0, 83300), -- Sealed Vesper Leather Helmet
(29186, 13145, 1, 1, 0, 83300), -- Sealed Vesper Circlet
(29186, 14109, 1, 1, 0, 83300), -- Sealed Vesper Gauntlet
(29186, 14113, 1, 1, 0, 83300), -- Sealed Vesper Leather Gloves
(29186, 14116, 1, 1, 0, 83300), -- Sealed Vesper Gloves
(29186, 14110, 1, 1, 0, 83300), -- Sealed Vesper Boots
(29186, 14114, 1, 1, 0, 83300), -- Sealed Vesper Leather Boots
(29186, 14117, 1, 1, 0, 83300), -- Sealed Vesper Shoes
(29186, 14111, 1, 1, 0, 83300), -- Sealed Vesper Shield
(29186, 13887, 1, 1, 0, 83300), -- Sealed Vesper Sigil
(29186, 10170, 1, 1, 0, 83300), -- Baylor's Earring
(29186, 6577, 1, 1, 1, 5357.74806), -- Blessed Scroll: Enchant Weapon (S-Grade)
(29186, 6578, 1, 1, 1, 35718.25194), -- Blessed Scroll: Enchant Armor (S-Grade)
-- Supply Box
(35665, 9579, 1, 1, 0, 56706.1815), -- Silk Shirt
(35665, 1538, 1, 1, 0, 30243.8185), -- Blessed Scroll of Escape
(35665, 9912, 40, 80, 1, 1000000), -- Knight's Epaulette
-- Rebel Commander
(35670, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35670, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35670, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35671, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(35672, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(35673, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35674, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35676, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(35677, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(35679, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35680, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35681, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35682, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35683, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35684, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Supply Box
(35697, 9589, 1, 1, 0, 44791.4136), -- Iron Bracelet
(35697, 1538, 1, 1, 0, 64498.5864), -- Blessed Scroll of Escape
(35697, 9912, 80, 160, 1, 1000000), -- Knight's Epaulette
-- Rebel Commander
(35702, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35702, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35702, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35703, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(35704, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(35705, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35706, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35711, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(35711, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(35712, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(35713, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(35715, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35716, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35717, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35718, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35719, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35720, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(35721, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister 
(35722, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Supply Box
(35734, 9580, 1, 1, 0, 53538.489), -- Thin Leather Shirt
(35734, 1538, 1, 1, 0, 92801.511), -- Blessed Scroll of Escape
(35734, 9912, 120, 240, 1, 1000000), -- Knight's Epaulette
-- Rebel Commander
(35739, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35739, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35739, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35740, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(35741, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(35742, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35743, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35745, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(35746, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(35748, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35749, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35750, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35751, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35752, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35753, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Supply Box
(35766, 9580, 1, 1, 0, 71384.652), -- Thin Leather Shirt
(35766, 1538, 1, 1, 0, 123735.348), -- Blessed Scroll of Escape
(35766, 9912, 160, 320, 1, 1000000), -- Knight's Epaulette
-- Rebel Commander
(35771, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35771, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35771, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35772, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(35773, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(35774, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35775, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35780, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(35780, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(35781, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(35782, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(35784, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35785, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35786, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35787, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35788, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35789, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(35790, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister 
(35791, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Supply Box
(35803, 9590, 1, 1, 0, 51572.1084), -- Bronze Bracelet
(35803, 3936, 1, 1, 0, 61886.757), -- Blessed Scroll of Resurrection
(35803, 9912, 200, 400, 1, 1000000), -- Knight's Epaulette
-- Rebel Commander
(35808, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35808, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35808, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35809, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(35810, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(35811, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35812, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35814, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(35815, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(35817, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35818, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35819, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35820, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35821, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35822, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Supply Box
(35834, 9590, 1, 1, 0, 61981.0744), -- Bronze Bracelet
(35834, 3936, 1, 1, 0, 74377.562), -- Blessed Scroll of Resurrection
(35834, 9912, 240, 480, 1, 1000000), -- Knight's Epaulette
-- Rebel Commander
(35839, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35839, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35839, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35840, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(35841, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(35842, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35843, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35845, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(35846, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(35848, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35849, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35850, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35851, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35852, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35853, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Rebel Commander
(35871, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35871, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35871, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35872, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(35873, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(35874, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35875, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35880, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(35880, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(35881, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(35882, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(35884, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35885, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35886, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35887, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35888, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35889, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(35890, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister 
(35891, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(35908, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35908, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35908, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35909, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(35910, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(35911, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35912, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35914, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(35915, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(35917, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35918, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35919, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35920, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35921, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35922, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Rebel Commander
(35940, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35940, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35940, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35941, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(35942, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(35943, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35944, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35949, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(35949, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(35950, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(35951, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(35953, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35954, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35955, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35956, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35957, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35958, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(35959, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister 
(35960, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(35978, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(35978, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(35978, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(35979, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(35980, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(35981, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(35982, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(35987, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(35987, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(35988, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(35989, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(35991, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(35992, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(35993, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(35994, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(35995, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(35996, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(35997, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister 
(35998, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36015, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36015, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36015, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36016, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(36017, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(36018, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36019, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36021, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(36022, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(36024, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36025, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36026, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36027, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36028, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36029, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Rebel Commander
(36047, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36047, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36047, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36048, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36049, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36050, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36051, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36056, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36056, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36057, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36058, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36060, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36061, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36062, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36063, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36064, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36065, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36066, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister
(36067, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36085, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36085, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36085, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36086, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36087, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36088, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36089, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36094, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36094, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36095, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36096, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36098, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36099, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36100, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36101, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36102, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36103, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36104, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister
(36105, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36122, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36122, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36122, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36123, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(36124, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(36125, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36126, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36128, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(36129, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(36131, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36132, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36133, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36134, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36135, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36136, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Rebel Commander
(36153, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36153, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36153, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36154, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(36155, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(36156, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36157, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36159, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(36160, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(36162, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36163, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36164, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36165, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36166, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36167, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Rebel Commander
(36185, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36185, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36185, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36186, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36187, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36188, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36189, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36194, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36194, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36195, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36196, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36198, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36199, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36200, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36201, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36202, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36203, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36204, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister
(36205, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36223, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36223, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36223, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36224, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36225, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36226, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36227, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36232, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36232, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36233, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36234, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36236, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36237, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36238, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36239, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36240, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36241, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36242, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister 
(36243, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36261, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36261, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36261, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36262, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36263, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36264, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36265, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36270, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36270, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36271, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36272, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36274, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36275, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36276, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36277, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36278, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36279, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36280, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister
(36281, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36298, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36298, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36298, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36299, 9912, 4, 16, 0, 781650), -- Knight's Epaulette
-- Rebel Private
(36300, 9912, 4, 12, 0, 718570), -- Knight's Epaulette
-- Court Guard
(36301, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36302, 9912, 4, 12, 0, 672110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36304, 9912, 4, 12, 0, 617370), -- Knight's Epaulette
-- Guard Captain
(36305, 9912, 140, 300, 0, 841370), -- Knight's Epaulette
-- Guard
(36307, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36308, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36309, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36310, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36311, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36312, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- Rebel Commander
(36330, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36330, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36330, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36331, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36332, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36333, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36334, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36339, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36339, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36340, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36341, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36343, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36344, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36345, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36346, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36347, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36348, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36349, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister
(36350, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Rebel Commander
(36368, 9581, 1, 1, 0, 91018.0024), -- Scale Shirt
(36368, 9591, 1, 1, 0, 46781.9976), -- Steel Bracelet
(36368, 9912, 40, 200, 1, 900000), -- Knight's Epaulette
-- Decorated Rebel Soldier
(36369, 9912, 4, 16, 0, 780050), -- Knight's Epaulette
-- Rebel Private
(36370, 9912, 4, 12, 0, 719570), -- Knight's Epaulette
-- Court Guard
(36371, 9912, 4, 12, 0, 662800), -- Knight's Epaulette
-- Guard
(36372, 9912, 4, 12, 0, 662110), -- Knight's Epaulette
-- Dwarven Gunnery Sergeant
(36377, 9912, 24, 72, 0, 19311.04), -- Knight's Epaulette
(36377, 10014, 1, 1, 0, 463464.96), -- Control Room Card
-- Scout Golem
(36378, 9912, 4, 6, 0, 460000), -- Knight's Epaulette
-- Guard Captain
(36379, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Guard
(36381, 9912, 4, 16, 0, 730100), -- Knight's Epaulette
-- Support Unit Captain
(36382, 9912, 140, 300, 0, 841571), -- Knight's Epaulette
-- Wizard
(36383, 9912, 4, 16, 0, 775740), -- Knight's Epaulette
-- Healer
(36384, 9912, 4, 16, 0, 823820), -- Knight's Epaulette
-- Archer Captain
(36385, 9912, 140, 300, 0, 842235), -- Knight's Epaulette
-- Archer
(36386, 9912, 4, 16, 0, 710000), -- Knight's Epaulette
-- General
(36387, 9912, 40, 154, 0, 704766), -- Knight's Epaulette
-- Minister
(36388, 9912, 40, 154, 0, 704766); -- Knight's Epaulette
